type Property = string;
type Class = string;
type Datatype = string;
type OwlClass = string;
type OwlObjectProperty = string;
type OwlDatatypeProperty = string;
type HydraResource = string;
type HydraClass = string;
type HydraLink = string;
type HydraTemplatedLink = string;
type HydraVariableRepresentation = string;

/**
 * VEVENT
 *
 * Provide a grouping of component properties that describe an event.
 *
 * http://www.w3.org/2002/12/cal/ical#Vevent
 */
export const Vevent = 'http://www.w3.org/2002/12/cal/ical#Vevent' satisfies OwlClass;

/**
 * VTODO
 *
 * Provide a grouping of calendar properties that describe a to-do.
 *
 * http://www.w3.org/2002/12/cal/ical#Vtodo
 */
export const Vtodo = 'http://www.w3.org/2002/12/cal/ical#Vtodo' satisfies OwlClass;

/**
 * VJOURNAL
 *
 * Provide a grouping of component properties that describe a journal entry.
 *
 * http://www.w3.org/2002/12/cal/ical#Vjournal
 */
export const Vjournal = 'http://www.w3.org/2002/12/cal/ical#Vjournal' satisfies OwlClass;

/**
 * VFREEBUSY
 *
 * Provide a grouping of component properties that describe either a request for free/busy time, describe a response to a request for free/busy time or describe a published set of busy time.
 *
 * http://www.w3.org/2002/12/cal/ical#Vfreebusy
 */
export const Vfreebusy = 'http://www.w3.org/2002/12/cal/ical#Vfreebusy' satisfies OwlClass;

/**
 * VTIMEZONE
 *
 * Provide a grouping of component properties that defines a time zone.
 *
 * http://www.w3.org/2002/12/cal/ical#Vtimezone
 */
export const Vtimezone = 'http://www.w3.org/2002/12/cal/ical#Vtimezone' satisfies OwlClass;

/**
 * VALARM
 *
 * Provide a grouping of component properties that define an alarm.
 *
 * http://www.w3.org/2002/12/cal/ical#Valarm
 */
export const Valarm = 'http://www.w3.org/2002/12/cal/ical#Valarm' satisfies OwlClass;

/**
 * CALSCALE
 *
 * This property defines the calendar scale used for the calendar information specified in the iCalendar object.
 *
 * http://www.w3.org/2002/12/cal/ical#calscale
 */
export const calscale = 'http://www.w3.org/2002/12/cal/ical#calscale' satisfies OwlDatatypeProperty;

/**
 * METHOD
 *
 * This property defines the iCalendar object method associated with the calendar object.
 *
 * http://www.w3.org/2002/12/cal/ical#method
 */
export const method = 'http://www.w3.org/2002/12/cal/ical#method' satisfies OwlDatatypeProperty;

/**
 * PRODID
 *
 * This property specifies the identifier for the product that created the iCalendar object.
 *
 * http://www.w3.org/2002/12/cal/ical#prodid
 */
export const prodid = 'http://www.w3.org/2002/12/cal/ical#prodid' satisfies OwlDatatypeProperty;

/**
 * VERSION
 *
 * This property specifies the identifier corresponding to the highest version number or the minimum and maximum range of the iCalendar specification that is required in order to interpret the iCalendar object.
 *
 * http://www.w3.org/2002/12/cal/ical#version
 */
export const version = 'http://www.w3.org/2002/12/cal/ical#version' satisfies OwlDatatypeProperty;

/**
 * ATTACH
 *
 * The property provides the capability to associate a document object with a calendar component.
 *
 * http://www.w3.org/2002/12/cal/ical#attach
 */
export const attach = 'http://www.w3.org/2002/12/cal/ical#attach' satisfies OwlObjectProperty;

/**
 * CATEGORIES
 *
 * This property defines the categories for a calendar component.
 *
 * http://www.w3.org/2002/12/cal/ical#categories
 */
export const categories = 'http://www.w3.org/2002/12/cal/ical#categories' satisfies OwlDatatypeProperty;

/**
 * CLASS
 *
 * This property defines the access classification for a calendar component.
 * Note that `class` is a reserved Javascript keyword, and is therefore suffixed by `__workaround`.
 * For a list of reserved keywords, see https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Lexical_grammar#Keywords.
 *
 * http://www.w3.org/2002/12/cal/ical#class
 */
export const class__workaround = 'http://www.w3.org/2002/12/cal/ical#class' satisfies OwlDatatypeProperty;

/**
 * COMMENT
 *
 * This property specifies non-processing information intended to provide a comment to the calendar user.
 *
 * http://www.w3.org/2002/12/cal/ical#comment
 */
export const comment = 'http://www.w3.org/2002/12/cal/ical#comment' satisfies OwlDatatypeProperty;

/**
 * DESCRIPTION
 *
 * This property provides a more complete description of the calendar component, than that provided by the "SUMMARY" property.
 *
 * http://www.w3.org/2002/12/cal/ical#description
 */
export const description = 'http://www.w3.org/2002/12/cal/ical#description' satisfies OwlDatatypeProperty;

/**
 * GEO
 *
 * This property specifies information related to the global position for the activity specified by a calendar component.
 *
 * http://www.w3.org/2002/12/cal/ical#geo
 */
export const geo = 'http://www.w3.org/2002/12/cal/ical#geo' satisfies OwlObjectProperty;

/**
 * http://www.w3.org/2002/12/cal/ical#List_of_Float
 */
export const List_of_Float = 'http://www.w3.org/2002/12/cal/ical#List_of_Float' satisfies OwlClass;

/**
 * LOCATION
 *
 * The property defines the intended venue for the activity defined by a calendar component.
 *
 * http://www.w3.org/2002/12/cal/ical#location
 */
export const location = 'http://www.w3.org/2002/12/cal/ical#location' satisfies OwlDatatypeProperty;

/**
 * PERCENT-COMPLETE
 *
 * This property is used by an assignee or delegatee of a to-do to convey the percent completion of a to-do to the Organizer.
 *
 * http://www.w3.org/2002/12/cal/ical#percentComplete
 */
export const percentComplete = 'http://www.w3.org/2002/12/cal/ical#percentComplete' satisfies OwlDatatypeProperty;

/**
 * PRIORITY
 *
 * The property defines the relative priority for a calendar component.
 *
 * http://www.w3.org/2002/12/cal/ical#priority
 */
export const priority = 'http://www.w3.org/2002/12/cal/ical#priority' satisfies OwlDatatypeProperty;

/**
 * RESOURCES
 *
 * This property defines the equipment or resources anticipated for an activity specified by a calendar entity..
 *
 * http://www.w3.org/2002/12/cal/ical#resources
 */
export const resources = 'http://www.w3.org/2002/12/cal/ical#resources' satisfies OwlDatatypeProperty;

/**
 * STATUS
 *
 * This property defines the overall status or confirmation for the calendar component.
 *
 * http://www.w3.org/2002/12/cal/ical#status
 */
export const status = 'http://www.w3.org/2002/12/cal/ical#status' satisfies OwlDatatypeProperty;

/**
 * SUMMARY
 *
 * This property defines a short summary or subject for the calendar component.
 *
 * http://www.w3.org/2002/12/cal/ical#summary
 */
export const summary = 'http://www.w3.org/2002/12/cal/ical#summary' satisfies OwlDatatypeProperty;

/**
 * COMPLETED
 *
 * This property defines the date and time that a to-do was actually completed.
 *
 * http://www.w3.org/2002/12/cal/ical#completed
 */
export const completed = 'http://www.w3.org/2002/12/cal/ical#completed' satisfies OwlObjectProperty;

/**
 * DTEND
 *
 * This property specifies the date and time that a calendar component ends.
 *
 * http://www.w3.org/2002/12/cal/ical#dtend
 */
export const dtend = 'http://www.w3.org/2002/12/cal/ical#dtend' satisfies OwlObjectProperty;

/**
 * http://www.w3.org/2002/12/cal/ical#Value_DATE
 */
export const Value_DATE = 'http://www.w3.org/2002/12/cal/ical#Value_DATE' satisfies OwlClass;

/**
 * DUE
 *
 * This property defines the date and time that a to-do is expected to be completed.
 *
 * http://www.w3.org/2002/12/cal/ical#due
 */
export const due = 'http://www.w3.org/2002/12/cal/ical#due' satisfies OwlObjectProperty;

/**
 * DTSTART
 *
 * This property specifies when the calendar component begins.
 *
 * http://www.w3.org/2002/12/cal/ical#dtstart
 */
export const dtstart = 'http://www.w3.org/2002/12/cal/ical#dtstart' satisfies OwlObjectProperty;

/**
 * DURATION
 *
 * The property specifies a positive duration of time.
 *
 * http://www.w3.org/2002/12/cal/ical#duration
 */
export const duration = 'http://www.w3.org/2002/12/cal/ical#duration' satisfies OwlObjectProperty;

/**
 * http://www.w3.org/2002/12/cal/ical#Value_DURATION
 */
export const Value_DURATION = 'http://www.w3.org/2002/12/cal/ical#Value_DURATION' satisfies OwlClass;

/**
 * FREEBUSY
 *
 * The property defines one or more free or busy time intervals.
 *
 * http://www.w3.org/2002/12/cal/ical#freebusy
 */
export const freebusy = 'http://www.w3.org/2002/12/cal/ical#freebusy' satisfies OwlObjectProperty;

/**
 * http://www.w3.org/2002/12/cal/ical#Value_PERIOD
 */
export const Value_PERIOD = 'http://www.w3.org/2002/12/cal/ical#Value_PERIOD' satisfies OwlClass;

/**
 * TRANSP
 *
 * This property defines whether an event is transparent or not to busy time searches.
 *
 * http://www.w3.org/2002/12/cal/ical#transp
 */
export const transp = 'http://www.w3.org/2002/12/cal/ical#transp' satisfies OwlDatatypeProperty;

/**
 * TZID
 *
 * This property specifies the text value that uniquely identifies the "VTIMEZONE" calendar component.
 *
 * http://www.w3.org/2002/12/cal/ical#tzid
 */
export const tzid = 'http://www.w3.org/2002/12/cal/ical#tzid' satisfies OwlDatatypeProperty;

/**
 * TZNAME
 *
 * This property specifies the customary designation for a time zone description.
 *
 * http://www.w3.org/2002/12/cal/ical#tzname
 */
export const tzname = 'http://www.w3.org/2002/12/cal/ical#tzname' satisfies OwlDatatypeProperty;

/**
 * TZOFFSETFROM
 *
 * This property specifies the offset which is in use prior to this time zone observance.
 *
 * http://www.w3.org/2002/12/cal/ical#tzoffsetfrom
 */
export const tzoffsetfrom = 'http://www.w3.org/2002/12/cal/ical#tzoffsetfrom' satisfies OwlDatatypeProperty;

/**
 * TZOFFSETTO
 *
 * This property specifies the offset which is in use in this time zone observance.
 *
 * http://www.w3.org/2002/12/cal/ical#tzoffsetto
 */
export const tzoffsetto = 'http://www.w3.org/2002/12/cal/ical#tzoffsetto' satisfies OwlDatatypeProperty;

/**
 * TZURL
 *
 * The TZURL provides a means for a VTIMEZONE component to point to a network location that can be used to retrieve an up-to- date version of itself.
 *
 * http://www.w3.org/2002/12/cal/ical#tzurl
 */
export const tzurl = 'http://www.w3.org/2002/12/cal/ical#tzurl' satisfies OwlObjectProperty;

/**
 * ATTENDEE
 *
 * The property defines an "Attendee" within a calendar component.
 *
 * http://www.w3.org/2002/12/cal/ical#attendee
 */
export const attendee = 'http://www.w3.org/2002/12/cal/ical#attendee' satisfies OwlObjectProperty;

/**
 * CONTACT
 *
 * The property is used to represent contact information or alternately a reference to contact information associated with the calendar component.
 *
 * http://www.w3.org/2002/12/cal/ical#contact
 */
export const contact = 'http://www.w3.org/2002/12/cal/ical#contact' satisfies OwlDatatypeProperty;

/**
 * ORGANIZER
 *
 * The property defines the organizer for a calendar component.
 *
 * http://www.w3.org/2002/12/cal/ical#organizer
 */
export const organizer = 'http://www.w3.org/2002/12/cal/ical#organizer' satisfies OwlObjectProperty;

/**
 * RECURRENCE-ID
 *
 * This property is used in conjunction with the "UID" and "SEQUENCE" property to identify a specific instance of a recurring "VEVENT", "VTODO" or "VJOURNAL" calendar component. The property value is the effective value of the "DTSTART" property of the recurrence instance.
 *
 * http://www.w3.org/2002/12/cal/ical#recurrenceId
 */
export const recurrenceId = 'http://www.w3.org/2002/12/cal/ical#recurrenceId' satisfies OwlObjectProperty;

/**
 * http://www.w3.org/2002/12/cal/ical#DomainOf_rrule
 */
export const DomainOf_rrule = 'http://www.w3.org/2002/12/cal/ical#DomainOf_rrule' satisfies OwlClass;

/**
 * RELATED-TO
 *
 * The property is used to represent a relationship or reference between one calendar component and another.
 *
 * http://www.w3.org/2002/12/cal/ical#relatedTo
 */
export const relatedTo = 'http://www.w3.org/2002/12/cal/ical#relatedTo' satisfies OwlDatatypeProperty;

/**
 * URL
 *
 * This property defines a Uniform Resource Locator (URL) associated with the iCalendar object.
 *
 * http://www.w3.org/2002/12/cal/ical#url
 */
export const url = 'http://www.w3.org/2002/12/cal/ical#url' satisfies OwlObjectProperty;

/**
 * UID
 *
 * This property defines the persistent, globally unique identifier for the calendar component.
 *
 * http://www.w3.org/2002/12/cal/ical#uid
 */
export const uid = 'http://www.w3.org/2002/12/cal/ical#uid' satisfies OwlDatatypeProperty;

/**
 * EXDATE
 *
 * This property defines the list of date/time exceptions for a recurring calendar component.
 *
 * http://www.w3.org/2002/12/cal/ical#exdate
 */
export const exdate = 'http://www.w3.org/2002/12/cal/ical#exdate' satisfies OwlObjectProperty;

/**
 * EXRULE
 *
 * This property defines a rule or repeating pattern for an exception to a recurrence set.
 *
 * http://www.w3.org/2002/12/cal/ical#exrule
 */
export const exrule = 'http://www.w3.org/2002/12/cal/ical#exrule' satisfies OwlObjectProperty;

/**
 * http://www.w3.org/2002/12/cal/ical#Value_RECUR
 */
export const Value_RECUR = 'http://www.w3.org/2002/12/cal/ical#Value_RECUR' satisfies OwlClass;

/**
 * RDATE
 *
 * This property defines the list of date/times for a recurrence set.
 *
 * http://www.w3.org/2002/12/cal/ical#rdate
 */
export const rdate = 'http://www.w3.org/2002/12/cal/ical#rdate' satisfies OwlObjectProperty;

/**
 * RRULE
 *
 * This property defines a rule or repeating pattern for recurring events, to-dos, or time zone definitions.
 *
 * http://www.w3.org/2002/12/cal/ical#rrule
 */
export const rrule = 'http://www.w3.org/2002/12/cal/ical#rrule' satisfies OwlObjectProperty;

/**
 * ACTION
 *
 * This property defines the action to be invoked when an alarm is triggered.
 *
 * http://www.w3.org/2002/12/cal/ical#action
 */
export const action = 'http://www.w3.org/2002/12/cal/ical#action' satisfies OwlDatatypeProperty;

/**
 * REPEAT
 *
 * This property defines the number of time the alarm should be repeated, after the initial trigger.
 *
 * http://www.w3.org/2002/12/cal/ical#repeat
 */
export const repeat = 'http://www.w3.org/2002/12/cal/ical#repeat' satisfies OwlDatatypeProperty;

/**
 * TRIGGER
 *
 * This property specifies when an alarm will trigger.
 *
 * http://www.w3.org/2002/12/cal/ical#trigger
 */
export const trigger = 'http://www.w3.org/2002/12/cal/ical#trigger' satisfies OwlObjectProperty;

/**
 * CREATED
 *
 * This property specifies the date and time that the calendar information was created by the calendar user agent in the calendar store. Note: This is analogous to the creation date and time for a file in the file system.
 *
 * http://www.w3.org/2002/12/cal/ical#created
 */
export const created = 'http://www.w3.org/2002/12/cal/ical#created' satisfies OwlObjectProperty;

/**
 * DTSTAMP
 *
 * The property indicates the date/time that the instance of the iCalendar object was created.
 *
 * http://www.w3.org/2002/12/cal/ical#dtstamp
 */
export const dtstamp = 'http://www.w3.org/2002/12/cal/ical#dtstamp' satisfies OwlObjectProperty;

/**
 * LAST-MODIFIED
 *
 * The property specifies the date and time that the information associated with the calendar component was last revised in the calendar store. Note: This is analogous to the modification date and time for a file in the file system.
 *
 * http://www.w3.org/2002/12/cal/ical#lastModified
 */
export const lastModified = 'http://www.w3.org/2002/12/cal/ical#lastModified' satisfies OwlObjectProperty;

/**
 * SEQUENCE
 *
 * This property defines the revision sequence number of the calendar component within a sequence of revisions.
 *
 * http://www.w3.org/2002/12/cal/ical#sequence
 */
export const sequence = 'http://www.w3.org/2002/12/cal/ical#sequence' satisfies OwlDatatypeProperty;

/**
 * REQUEST-STATUS
 *
 * This property defines the status code returned for a scheduling request.
 *
 * http://www.w3.org/2002/12/cal/ical#requestStatus
 */
export const requestStatus = 'http://www.w3.org/2002/12/cal/ical#requestStatus' satisfies OwlDatatypeProperty;
