type Property = string;
type Class = string;
type Datatype = string;
type OwlClass = string;
type OwlObjectProperty = string;
type OwlDatatypeProperty = string;
type HydraResource = string;
type HydraClass = string;
type HydraLink = string;
type HydraTemplatedLink = string;
type HydraVariableRepresentation = string;

/**
 * http://www.w3.org/2000/10/swap/pim/contact#Address
 */
export const Address = 'http://www.w3.org/2000/10/swap/pim/contact#Address' satisfies Class;

/**
 * contact point
 *
 * A place, or mobile situation, with address, phone number, fax, etc. 
 *     Related to a person by home, office, etc.
 *     Note one person's workplace may be another person's home.
 *     A person may have more than one home and more than one workplace.
 *     (In practice it sometimes maybe useful with restriucted datasets to
 *     assume that this is not the case, when extracting data from other ontologies
 *     with no concept of ContactLocation).  Strongly related to a person: 
 *     in some ways a role that a person can be in.
 *
 * http://www.w3.org/2000/10/swap/pim/contact#ContactLocation
 */
export const ContactLocation = 'http://www.w3.org/2000/10/swap/pim/contact#ContactLocation' satisfies Class;

/**
 * http://www.w3.org/2000/10/swap/pim/contact#Female
 */
export const Female = 'http://www.w3.org/2000/10/swap/pim/contact#Female' satisfies Class;

/**
 * http://www.w3.org/2000/10/swap/pim/contact#LanguageCode
 */
export const LanguageCode = 'http://www.w3.org/2000/10/swap/pim/contact#LanguageCode' satisfies Class;

/**
 * http://www.w3.org/2000/10/swap/pim/contact#Male
 */
export const Male = 'http://www.w3.org/2000/10/swap/pim/contact#Male' satisfies Class;

/**
 * 
 *     An end-point in the public swiitched telephone system.
 *     Anything identified by a URI with tel: scheme is in this class.
 *     
 *
 * http://www.w3.org/2000/10/swap/pim/contact#Phone
 */
export const Phone = 'http://www.w3.org/2000/10/swap/pim/contact#Phone' satisfies Class;

/**
 * The sort of thing which can have a phone number.
 *     Typically a person or an incorporated company, or unincorporated group.
 *
 * http://www.w3.org/2000/10/swap/pim/contact#SocialEntity
 */
export const SocialEntity = 'http://www.w3.org/2000/10/swap/pim/contact#SocialEntity' satisfies Class;

/**
 * http://www.w3.org/2000/10/swap/pim/contact#_addressProperty
 */
export const _addressProperty = 'http://www.w3.org/2000/10/swap/pim/contact#_addressProperty' satisfies Property;

/**
 * http://www.w3.org/2000/10/swap/pim/contact#address
 */
export const address = 'http://www.w3.org/2000/10/swap/pim/contact#address' satisfies Property;

/**
 * assistant
 *
 * A person (or other agent) who is an assistant to the subject.
 *
 * http://www.w3.org/2000/10/swap/pim/contact#assistant
 */
export const assistant = 'http://www.w3.org/2000/10/swap/pim/contact#assistant' satisfies Property;

/**
 * http://www.w3.org/2000/10/swap/pim/contact#birthday
 */
export const birthday = 'http://www.w3.org/2000/10/swap/pim/contact#birthday' satisfies Property;

/**
 * http://www.w3.org/2000/10/swap/pim/contact#child
 */
export const child = 'http://www.w3.org/2000/10/swap/pim/contact#child' satisfies Property;

/**
 * http://www.w3.org/2000/10/swap/pim/contact#description
 */
export const description = 'http://www.w3.org/2000/10/swap/pim/contact#description' satisfies Property;

/**
 * emergency only
 *
 * http://www.w3.org/2000/10/swap/pim/contact#emergency
 */
export const emergency = 'http://www.w3.org/2000/10/swap/pim/contact#emergency' satisfies Property;

/**
 * http://www.w3.org/2000/10/swap/pim/contact#fax
 */
export const fax = 'http://www.w3.org/2000/10/swap/pim/contact#fax' satisfies Property;

/**
 * full name
 *
 * http://www.w3.org/2000/10/swap/pim/contact#fullName
 */
export const fullName = 'http://www.w3.org/2000/10/swap/pim/contact#fullName' satisfies Property;

/**
 * home
 *
 * http://www.w3.org/2000/10/swap/pim/contact#home
 */
export const home = 'http://www.w3.org/2000/10/swap/pim/contact#home' satisfies Property;

/**
 * name
 *
 * A person may be known as various strings.
 * 	For example, an email friendly name string.
 * 	If you have an email from someone using a string as the human-readable phrase,
 * 	then it is reasonable to assume that there are :knownAs that.
 *
 * http://www.w3.org/2000/10/swap/pim/contact#knownAs
 */
export const knownAs = 'http://www.w3.org/2000/10/swap/pim/contact#knownAs' satisfies Property;

/**
 * mobile
 *
 * http://www.w3.org/2000/10/swap/pim/contact#mobile
 */
export const mobile = 'http://www.w3.org/2000/10/swap/pim/contact#mobile' satisfies Property;

/**
 * http://www.w3.org/2000/10/swap/pim/contact#motherTongue
 */
export const motherTongue = 'http://www.w3.org/2000/10/swap/pim/contact#motherTongue' satisfies Property;

/**
 * nearest airport
 *
 * ?X nearestAirport ?Y locates ?X in an international
 *    context; for example, for the purpose of organizing a face-to-face
 *    meeting of a W3C working group. This property is intended to mitigate
 *    privacy risks of giving out detailed contact info.
 *
 * http://www.w3.org/2000/10/swap/pim/contact#nearestAirport
 */
export const nearestAirport = 'http://www.w3.org/2000/10/swap/pim/contact#nearestAirport' satisfies Property;

/**
 * work
 *
 * http://www.w3.org/2000/10/swap/pim/contact#office
 */
export const office = 'http://www.w3.org/2000/10/swap/pim/contact#office' satisfies Property;

/**
 * participant
 *
 * A person (or other agent) who  particpates in an event, meeting, etc.
 *
 * http://www.w3.org/2000/10/swap/pim/contact#participant
 */
export const participant = 'http://www.w3.org/2000/10/swap/pim/contact#participant' satisfies Property;

/**
 * http://www.w3.org/2000/10/swap/pim/contact#partner
 */
export const partner = 'http://www.w3.org/2000/10/swap/pim/contact#partner' satisfies Property;

/**
 * http://www.w3.org/2000/10/swap/pim/contact#phone
 */
export const phone = 'http://www.w3.org/2000/10/swap/pim/contact#phone' satisfies Property;

/**
 * preferred
 *
 * A string which is the URI a person, organization, etc, prefers that people use for them.
 *
 * http://www.w3.org/2000/10/swap/pim/contact#preferredURI
 */
export const preferredURI = 'http://www.w3.org/2000/10/swap/pim/contact#preferredURI' satisfies Property;

/**
 * region
 *
 * The sub-national unit such as state (us),
 * province (ca), county (uk), département (fr), and so on
 *
 * http://www.w3.org/2000/10/swap/pim/contact#region
 */
export const region = 'http://www.w3.org/2000/10/swap/pim/contact#region' satisfies Property;

/**
 * sort name
 *
 * re-arranged for lexicographic ordering; ala Doe, John
 *
 * http://www.w3.org/2000/10/swap/pim/contact#sortName
 */
export const sortName = 'http://www.w3.org/2000/10/swap/pim/contact#sortName' satisfies Property;

/**
 * vacation
 *
 * http://www.w3.org/2000/10/swap/pim/contact#vacationHome
 */
export const vacationHome = 'http://www.w3.org/2000/10/swap/pim/contact#vacationHome' satisfies Property;

/**
 * web page
 *
 * A related web page
 *
 * http://www.w3.org/2000/10/swap/pim/contact#webPage
 */
export const webPage = 'http://www.w3.org/2000/10/swap/pim/contact#webPage' satisfies Property;
