type Property = string;
type Class = string;
type Datatype = string;
type OwlClass = string;
type OwlObjectProperty = string;
type OwlDatatypeProperty = string;
type HydraResource = string;
type HydraClass = string;
type HydraLink = string;
type HydraTemplatedLink = string;
type HydraVariableRepresentation = string;

/**
 * ApiDocumentation
 *
 * The Hydra API documentation class
 *
 * http://www.w3.org/ns/hydra/core#ApiDocumentation
 */
export const ApiDocumentation = 'http://www.w3.org/ns/hydra/core#ApiDocumentation' satisfies HydraClass;

/**
 * Base Uri source
 *
 * Provides a base abstract for base Uri source for Iri template resolution.
 *
 * http://www.w3.org/ns/hydra/core#BaseUriSource
 */
export const BaseUriSource = 'http://www.w3.org/ns/hydra/core#BaseUriSource' satisfies HydraClass;

/**
 * BasicRepresentation
 *
 * A representation that serializes just the lexical form of a variable value, but omits language and type information.
 *
 * http://www.w3.org/ns/hydra/core#BasicRepresentation
 */
export const BasicRepresentation = 'http://www.w3.org/ns/hydra/core#BasicRepresentation' satisfies HydraVariableRepresentation;

/**
 * Hydra Class
 *
 * The class of Hydra classes.
 *
 * http://www.w3.org/ns/hydra/core#Class
 */
export const Class = 'http://www.w3.org/ns/hydra/core#Class' satisfies HydraResource;

/**
 * Collection
 *
 * A collection holding references to a number of related resources.
 *
 * http://www.w3.org/ns/hydra/core#Collection
 */
export const Collection = 'http://www.w3.org/ns/hydra/core#Collection' satisfies HydraClass;

/**
 * Error
 *
 * A runtime error, used to report information beyond the returned status code.
 * Note that `Error` is a reserved Javascript keyword, and is therefore suffixed by `__workaround`.
 * For a list of reserved keywords, see https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Lexical_grammar#Keywords.
 *
 * http://www.w3.org/ns/hydra/core#Error
 */
export const Error__workaround = 'http://www.w3.org/ns/hydra/core#Error' satisfies HydraClass;

/**
 * ExplicitRepresentation
 *
 * A representation that serializes a variable value including its language and type information and thus differentiating between IRIs and literals.
 *
 * http://www.w3.org/ns/hydra/core#ExplicitRepresentation
 */
export const ExplicitRepresentation = 'http://www.w3.org/ns/hydra/core#ExplicitRepresentation' satisfies HydraVariableRepresentation;

/**
 * Header specification
 *
 * Specifies a possible either expected or returned header values
 *
 * http://www.w3.org/ns/hydra/core#HeaderSpecification
 */
export const HeaderSpecification = 'http://www.w3.org/ns/hydra/core#HeaderSpecification' satisfies Class;

/**
 * IRI Template
 *
 * The class of IRI templates.
 *
 * http://www.w3.org/ns/hydra/core#IriTemplate
 */
export const IriTemplate = 'http://www.w3.org/ns/hydra/core#IriTemplate' satisfies HydraClass;

/**
 * IriTemplateMapping
 *
 * A mapping from an IRI template variable to a property.
 *
 * http://www.w3.org/ns/hydra/core#IriTemplateMapping
 */
export const IriTemplateMapping = 'http://www.w3.org/ns/hydra/core#IriTemplateMapping' satisfies HydraClass;

/**
 * Link
 *
 * The class of properties representing links.
 *
 * http://www.w3.org/ns/hydra/core#Link
 */
export const Link = 'http://www.w3.org/ns/hydra/core#Link' satisfies HydraClass;

/**
 * Operation
 *
 * An operation.
 *
 * http://www.w3.org/ns/hydra/core#Operation
 */
export const Operation = 'http://www.w3.org/ns/hydra/core#Operation' satisfies HydraClass;

/**
 * PartialCollectionView
 *
 * A PartialCollectionView describes a partial view of a Collection. Multiple PartialCollectionViews can be connected with the the next/previous properties to allow a client to retrieve all members of the collection.
 *
 * http://www.w3.org/ns/hydra/core#PartialCollectionView
 */
export const PartialCollectionView = 'http://www.w3.org/ns/hydra/core#PartialCollectionView' satisfies HydraClass;

/**
 * Hydra Resource
 *
 * The class of dereferenceable resources by means a client can attempt to dereference; however, the received responses should still be verified.
 *
 * http://www.w3.org/ns/hydra/core#Resource
 */
export const Resource = 'http://www.w3.org/ns/hydra/core#Resource' satisfies HydraClass;

/**
 * RFC6570 IRI template
 *
 * An IRI template as defined by RFC6570.
 *
 * http://www.w3.org/ns/hydra/core#Rfc6570Template
 */
export const Rfc6570Template = 'http://www.w3.org/ns/hydra/core#Rfc6570Template' satisfies Datatype;

/**
 * Status code description
 *
 * Additional information about a status code that might be returned.
 *
 * http://www.w3.org/ns/hydra/core#Status
 */
export const Status = 'http://www.w3.org/ns/hydra/core#Status' satisfies HydraClass;

/**
 * Supported Property
 *
 * A property known to be supported by a Hydra class.
 *
 * http://www.w3.org/ns/hydra/core#SupportedProperty
 */
export const SupportedProperty = 'http://www.w3.org/ns/hydra/core#SupportedProperty' satisfies HydraClass;

/**
 * Templated Link
 *
 * A templated link.
 *
 * http://www.w3.org/ns/hydra/core#TemplatedLink
 */
export const TemplatedLink = 'http://www.w3.org/ns/hydra/core#TemplatedLink' satisfies HydraClass;

/**
 * VariableRepresentation
 *
 * A representation specifies how to serialize variable values into strings.
 *
 * http://www.w3.org/ns/hydra/core#VariableRepresentation
 */
export const VariableRepresentation = 'http://www.w3.org/ns/hydra/core#VariableRepresentation' satisfies HydraClass;

/**
 * apiDocumentation
 *
 * A link to the API documentation
 *
 * http://www.w3.org/ns/hydra/core#apiDocumentation
 */
export const apiDocumentation = 'http://www.w3.org/ns/hydra/core#apiDocumentation' satisfies HydraLink;

/**
 * closed set
 *
 * Determines whether the provided set of header values is closed or not.
 *
 * http://www.w3.org/ns/hydra/core#closedSet
 */
export const closedSet = 'http://www.w3.org/ns/hydra/core#closedSet' satisfies Property;

/**
 * collection
 *
 * Collections somehow related to this resource.
 *
 * http://www.w3.org/ns/hydra/core#collection
 */
export const collection = 'http://www.w3.org/ns/hydra/core#collection' satisfies HydraLink;

/**
 * description
 *
 * A description.
 *
 * http://www.w3.org/ns/hydra/core#description
 */
export const description = 'http://www.w3.org/ns/hydra/core#description' satisfies Property;

/**
 * entrypoint
 *
 * A link to main entry point of the Web API
 *
 * http://www.w3.org/ns/hydra/core#entrypoint
 */
export const entrypoint = 'http://www.w3.org/ns/hydra/core#entrypoint' satisfies HydraLink;

/**
 * expects
 *
 * The information expected by the Web API.
 *
 * http://www.w3.org/ns/hydra/core#expects
 */
export const expects = 'http://www.w3.org/ns/hydra/core#expects' satisfies HydraLink;

/**
 * expects header
 *
 * Specification of the header expected by the operation.
 *
 * http://www.w3.org/ns/hydra/core#expectsHeader
 */
export const expectsHeader = 'http://www.w3.org/ns/hydra/core#expectsHeader' satisfies Property;

/**
 * extension
 *
 * Hint on what kind of extensions are in use.
 *
 * http://www.w3.org/ns/hydra/core#extension
 */
export const extension = 'http://www.w3.org/ns/hydra/core#extension' satisfies Property;

/**
 * first
 *
 * The first resource of an interlinked set of resources.
 *
 * http://www.w3.org/ns/hydra/core#first
 */
export const first = 'http://www.w3.org/ns/hydra/core#first' satisfies HydraLink;

/**
 * freetext query
 *
 * A property representing a freetext query.
 *
 * http://www.w3.org/ns/hydra/core#freetextQuery
 */
export const freetextQuery = 'http://www.w3.org/ns/hydra/core#freetextQuery' satisfies Property;

/**
 * header name
 *
 * Name of the header.
 *
 * http://www.w3.org/ns/hydra/core#headerName
 */
export const headerName = 'http://www.w3.org/ns/hydra/core#headerName' satisfies Property;

/**
 * last
 *
 * The last resource of an interlinked set of resources.
 *
 * http://www.w3.org/ns/hydra/core#last
 */
export const last = 'http://www.w3.org/ns/hydra/core#last' satisfies HydraLink;

/**
 * take
 *
 * Instructs to limit set only to N elements.
 *
 * http://www.w3.org/ns/hydra/core#limit
 */
export const limit = 'http://www.w3.org/ns/hydra/core#limit' satisfies Property;

/**
 * mapping
 *
 * A variable-to-property mapping of the IRI template.
 *
 * http://www.w3.org/ns/hydra/core#mapping
 */
export const mapping = 'http://www.w3.org/ns/hydra/core#mapping' satisfies Property;

/**
 * member
 *
 * A member of the collection
 *
 * http://www.w3.org/ns/hydra/core#member
 */
export const member = 'http://www.w3.org/ns/hydra/core#member' satisfies HydraLink;

/**
 * method
 *
 * The HTTP method.
 *
 * http://www.w3.org/ns/hydra/core#method
 */
export const method = 'http://www.w3.org/ns/hydra/core#method' satisfies Property;

/**
 * next
 *
 * The resource following the current instance in an interlinked set of resources.
 *
 * http://www.w3.org/ns/hydra/core#next
 */
export const next = 'http://www.w3.org/ns/hydra/core#next' satisfies HydraLink;

/**
 * skip
 *
 * Instructs to skip N elements of the set.
 *
 * http://www.w3.org/ns/hydra/core#offset
 */
export const offset = 'http://www.w3.org/ns/hydra/core#offset' satisfies Property;

/**
 * operation
 *
 * An operation supported by the Hydra resource
 *
 * http://www.w3.org/ns/hydra/core#operation
 */
export const operation = 'http://www.w3.org/ns/hydra/core#operation' satisfies HydraLink;

/**
 * page index
 *
 * Instructs to provide a specific page of the collection at a given index.
 *
 * http://www.w3.org/ns/hydra/core#pageIndex
 */
export const pageIndex = 'http://www.w3.org/ns/hydra/core#pageIndex' satisfies Property;

/**
 * page reference
 *
 * Instructs to provide a specific page reference of the collection.
 *
 * http://www.w3.org/ns/hydra/core#pageReference
 */
export const pageReference = 'http://www.w3.org/ns/hydra/core#pageReference' satisfies Property;

/**
 * possible status
 *
 * A status that might be returned by the Web API (other statuses should be expected and properly handled as well)
 *
 * http://www.w3.org/ns/hydra/core#possibleStatus
 */
export const possibleStatus = 'http://www.w3.org/ns/hydra/core#possibleStatus' satisfies HydraLink;

/**
 * possible header value
 *
 * Possible value of the header.
 *
 * http://www.w3.org/ns/hydra/core#possibleValue
 */
export const possibleValue = 'http://www.w3.org/ns/hydra/core#possibleValue' satisfies Property;

/**
 * previous
 *
 * The resource preceding the current instance in an interlinked set of resources.
 *
 * http://www.w3.org/ns/hydra/core#previous
 */
export const previous = 'http://www.w3.org/ns/hydra/core#previous' satisfies HydraLink;

/**
 * property
 *
 * A property
 *
 * http://www.w3.org/ns/hydra/core#property
 */
export const property = 'http://www.w3.org/ns/hydra/core#property' satisfies Property;

/**
 * readable
 *
 * True if the client can retrieve the property's value, false otherwise.
 *
 * http://www.w3.org/ns/hydra/core#readable
 */
export const readable = 'http://www.w3.org/ns/hydra/core#readable' satisfies Property;

/**
 * required
 *
 * True if the property is required, false otherwise.
 *
 * http://www.w3.org/ns/hydra/core#required
 */
export const required = 'http://www.w3.org/ns/hydra/core#required' satisfies Property;

/**
 * relative Uri resolution
 *
 * http://www.w3.org/ns/hydra/core#resolveRelativeUsing
 */
export const resolveRelativeUsing = 'http://www.w3.org/ns/hydra/core#resolveRelativeUsing' satisfies Property;

/**
 * returns
 *
 * The information returned by the Web API on success
 *
 * http://www.w3.org/ns/hydra/core#returns
 */
export const returns = 'http://www.w3.org/ns/hydra/core#returns' satisfies HydraLink;

/**
 * returns header
 *
 * Name of the header returned by the operation.
 *
 * http://www.w3.org/ns/hydra/core#returnsHeader
 */
export const returnsHeader = 'http://www.w3.org/ns/hydra/core#returnsHeader' satisfies Property;

/**
 * search
 *
 * A IRI template that can be used to query a collection.
 *
 * http://www.w3.org/ns/hydra/core#search
 */
export const search = 'http://www.w3.org/ns/hydra/core#search' satisfies HydraTemplatedLink;

/**
 * status code
 *
 * The HTTP status code. Please note it may happen this value will be different to actual status code received.
 *
 * http://www.w3.org/ns/hydra/core#statusCode
 */
export const statusCode = 'http://www.w3.org/ns/hydra/core#statusCode' satisfies Property;

/**
 * supported classes
 *
 * A class known to be supported by the Web API
 *
 * http://www.w3.org/ns/hydra/core#supportedClass
 */
export const supportedClass = 'http://www.w3.org/ns/hydra/core#supportedClass' satisfies HydraLink;

/**
 * supported operation
 *
 * An operation supported by instances of the specific Hydra class, or the target of the Hydra link, or IRI template.
 *
 * http://www.w3.org/ns/hydra/core#supportedOperation
 */
export const supportedOperation = 'http://www.w3.org/ns/hydra/core#supportedOperation' satisfies HydraLink;

/**
 * supported properties
 *
 * The properties known to be supported by a Hydra class
 *
 * http://www.w3.org/ns/hydra/core#supportedProperty
 */
export const supportedProperty = 'http://www.w3.org/ns/hydra/core#supportedProperty' satisfies HydraLink;

/**
 * template
 *
 * A templated string with placeholders. The literal's datatype indicates the template syntax; if not specified, hydra:Rfc6570Template is assumed.
 *
 * http://www.w3.org/ns/hydra/core#template
 */
export const template = 'http://www.w3.org/ns/hydra/core#template' satisfies Property;

/**
 * title
 *
 * A title, often used along with a description.
 *
 * http://www.w3.org/ns/hydra/core#title
 */
export const title = 'http://www.w3.org/ns/hydra/core#title' satisfies Property;

/**
 * total items
 *
 * The total number of items referenced by a collection.
 *
 * http://www.w3.org/ns/hydra/core#totalItems
 */
export const totalItems = 'http://www.w3.org/ns/hydra/core#totalItems' satisfies Property;

/**
 * variable
 *
 * An IRI template variable
 *
 * http://www.w3.org/ns/hydra/core#variable
 */
export const variable = 'http://www.w3.org/ns/hydra/core#variable' satisfies Property;

/**
 * variable representation
 *
 * The representation format to use when expanding the IRI template.
 *
 * http://www.w3.org/ns/hydra/core#variableRepresentation
 */
export const variableRepresentation = 'http://www.w3.org/ns/hydra/core#variableRepresentation' satisfies Property;

/**
 * view
 *
 * A specific view of a resource.
 *
 * http://www.w3.org/ns/hydra/core#view
 */
export const view = 'http://www.w3.org/ns/hydra/core#view' satisfies HydraLink;

/**
 * writable
 *
 * True if the client can change the property's value, false otherwise.
 *
 * http://www.w3.org/ns/hydra/core#writable
 */
export const writable = 'http://www.w3.org/ns/hydra/core#writable' satisfies Property;
