type Property = string;
type Class = string;
type Datatype = string;
type OwlClass = string;
type OwlObjectProperty = string;
type OwlDatatypeProperty = string;
type HydraResource = string;
type HydraClass = string;
type HydraLink = string;
type HydraTemplatedLink = string;
type HydraVariableRepresentation = string;

/**
 * HTML
 *
 * The datatype of RDF literals storing fragments of HTML content
 *
 * http://www.w3.org/1999/02/22-rdf-syntax-ns#HTML
 */
export const HTML = 'http://www.w3.org/1999/02/22-rdf-syntax-ns#HTML' satisfies Datatype;

/**
 * langString
 *
 * The datatype of language-tagged string values
 *
 * http://www.w3.org/1999/02/22-rdf-syntax-ns#langString
 */
export const langString = 'http://www.w3.org/1999/02/22-rdf-syntax-ns#langString' satisfies Datatype;

/**
 * PlainLiteral
 *
 * The class of plain (i.e. untyped) literal values, as used in RIF and OWL 2
 *
 * http://www.w3.org/1999/02/22-rdf-syntax-ns#PlainLiteral
 */
export const PlainLiteral = 'http://www.w3.org/1999/02/22-rdf-syntax-ns#PlainLiteral' satisfies Datatype;

/**
 * type
 *
 * The subject is an instance of a class.
 *
 * http://www.w3.org/1999/02/22-rdf-syntax-ns#type
 */
export const type = 'http://www.w3.org/1999/02/22-rdf-syntax-ns#type' satisfies Property;

/**
 * Property
 *
 * The class of RDF properties.
 *
 * http://www.w3.org/1999/02/22-rdf-syntax-ns#Property
 */
export const Property = 'http://www.w3.org/1999/02/22-rdf-syntax-ns#Property' satisfies Class;

/**
 * Statement
 *
 * The class of RDF statements.
 *
 * http://www.w3.org/1999/02/22-rdf-syntax-ns#Statement
 */
export const Statement = 'http://www.w3.org/1999/02/22-rdf-syntax-ns#Statement' satisfies Class;

/**
 * subject
 *
 * The subject of the subject RDF statement.
 *
 * http://www.w3.org/1999/02/22-rdf-syntax-ns#subject
 */
export const subject = 'http://www.w3.org/1999/02/22-rdf-syntax-ns#subject' satisfies Property;

/**
 * predicate
 *
 * The predicate of the subject RDF statement.
 *
 * http://www.w3.org/1999/02/22-rdf-syntax-ns#predicate
 */
export const predicate = 'http://www.w3.org/1999/02/22-rdf-syntax-ns#predicate' satisfies Property;

/**
 * object
 *
 * The object of the subject RDF statement.
 *
 * http://www.w3.org/1999/02/22-rdf-syntax-ns#object
 */
export const object = 'http://www.w3.org/1999/02/22-rdf-syntax-ns#object' satisfies Property;

/**
 * Bag
 *
 * The class of unordered containers.
 *
 * http://www.w3.org/1999/02/22-rdf-syntax-ns#Bag
 */
export const Bag = 'http://www.w3.org/1999/02/22-rdf-syntax-ns#Bag' satisfies Class;

/**
 * Seq
 *
 * The class of ordered containers.
 *
 * http://www.w3.org/1999/02/22-rdf-syntax-ns#Seq
 */
export const Seq = 'http://www.w3.org/1999/02/22-rdf-syntax-ns#Seq' satisfies Class;

/**
 * Alt
 *
 * The class of containers of alternatives.
 *
 * http://www.w3.org/1999/02/22-rdf-syntax-ns#Alt
 */
export const Alt = 'http://www.w3.org/1999/02/22-rdf-syntax-ns#Alt' satisfies Class;

/**
 * value
 *
 * Idiomatic property used for structured values.
 *
 * http://www.w3.org/1999/02/22-rdf-syntax-ns#value
 */
export const value = 'http://www.w3.org/1999/02/22-rdf-syntax-ns#value' satisfies Property;

/**
 * List
 *
 * The class of RDF Lists.
 *
 * http://www.w3.org/1999/02/22-rdf-syntax-ns#List
 */
export const List = 'http://www.w3.org/1999/02/22-rdf-syntax-ns#List' satisfies Class;

/**
 * first
 *
 * The first item in the subject RDF list.
 *
 * http://www.w3.org/1999/02/22-rdf-syntax-ns#first
 */
export const first = 'http://www.w3.org/1999/02/22-rdf-syntax-ns#first' satisfies Property;

/**
 * rest
 *
 * The rest of the subject RDF list after the first item.
 *
 * http://www.w3.org/1999/02/22-rdf-syntax-ns#rest
 */
export const rest = 'http://www.w3.org/1999/02/22-rdf-syntax-ns#rest' satisfies Property;

/**
 * XMLLiteral
 *
 * The datatype of XML literal values.
 *
 * http://www.w3.org/1999/02/22-rdf-syntax-ns#XMLLiteral
 */
export const XMLLiteral = 'http://www.w3.org/1999/02/22-rdf-syntax-ns#XMLLiteral' satisfies Datatype;

/**
 * JSON
 *
 * The datatype of RDF literals storing JSON content.
 * Note that `JSON` is a reserved Javascript keyword, and is therefore suffixed by `__workaround`.
 * For a list of reserved keywords, see https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Lexical_grammar#Keywords.
 *
 * http://www.w3.org/1999/02/22-rdf-syntax-ns#JSON
 */
export const JSON__workaround = 'http://www.w3.org/1999/02/22-rdf-syntax-ns#JSON' satisfies Datatype;

/**
 * CompoundLiteral
 *
 * A class representing a compound literal.
 *
 * http://www.w3.org/1999/02/22-rdf-syntax-ns#CompoundLiteral
 */
export const CompoundLiteral = 'http://www.w3.org/1999/02/22-rdf-syntax-ns#CompoundLiteral' satisfies Class;

/**
 * language
 *
 * The language component of a CompoundLiteral.
 *
 * http://www.w3.org/1999/02/22-rdf-syntax-ns#language
 */
export const language = 'http://www.w3.org/1999/02/22-rdf-syntax-ns#language' satisfies Property;

/**
 * direction
 *
 * The base direction component of a CompoundLiteral.
 *
 * http://www.w3.org/1999/02/22-rdf-syntax-ns#direction
 */
export const direction = 'http://www.w3.org/1999/02/22-rdf-syntax-ns#direction' satisfies Property;
