type Property = string;
type Class = string;
type Datatype = string;
type OwlClass = string;
type OwlObjectProperty = string;
type OwlDatatypeProperty = string;
type HydraResource = string;
type HydraClass = string;
type HydraLink = string;
type HydraTemplatedLink = string;
type HydraVariableRepresentation = string;

/**
 * Resource
 *
 * The class resource, everything.
 *
 * http://www.w3.org/2000/01/rdf-schema#Resource
 */
export const Resource = 'http://www.w3.org/2000/01/rdf-schema#Resource' satisfies Class;

/**
 * Class
 *
 * The class of classes.
 *
 * http://www.w3.org/2000/01/rdf-schema#Class
 */
export const Class = 'http://www.w3.org/2000/01/rdf-schema#Class' satisfies Class;

/**
 * subClassOf
 *
 * The subject is a subclass of a class.
 *
 * http://www.w3.org/2000/01/rdf-schema#subClassOf
 */
export const subClassOf = 'http://www.w3.org/2000/01/rdf-schema#subClassOf' satisfies Property;

/**
 * subPropertyOf
 *
 * The subject is a subproperty of a property.
 *
 * http://www.w3.org/2000/01/rdf-schema#subPropertyOf
 */
export const subPropertyOf = 'http://www.w3.org/2000/01/rdf-schema#subPropertyOf' satisfies Property;

/**
 * comment
 *
 * A description of the subject resource.
 *
 * http://www.w3.org/2000/01/rdf-schema#comment
 */
export const comment = 'http://www.w3.org/2000/01/rdf-schema#comment' satisfies Property;

/**
 * label
 *
 * A human-readable name for the subject.
 *
 * http://www.w3.org/2000/01/rdf-schema#label
 */
export const label = 'http://www.w3.org/2000/01/rdf-schema#label' satisfies Property;

/**
 * domain
 *
 * A domain of the subject property.
 *
 * http://www.w3.org/2000/01/rdf-schema#domain
 */
export const domain = 'http://www.w3.org/2000/01/rdf-schema#domain' satisfies Property;

/**
 * range
 *
 * A range of the subject property.
 *
 * http://www.w3.org/2000/01/rdf-schema#range
 */
export const range = 'http://www.w3.org/2000/01/rdf-schema#range' satisfies Property;

/**
 * seeAlso
 *
 * Further information about the subject resource.
 *
 * http://www.w3.org/2000/01/rdf-schema#seeAlso
 */
export const seeAlso = 'http://www.w3.org/2000/01/rdf-schema#seeAlso' satisfies Property;

/**
 * isDefinedBy
 *
 * The definition of the subject resource.
 *
 * http://www.w3.org/2000/01/rdf-schema#isDefinedBy
 */
export const isDefinedBy = 'http://www.w3.org/2000/01/rdf-schema#isDefinedBy' satisfies Property;

/**
 * Literal
 *
 * The class of literal values, eg. textual strings and integers.
 *
 * http://www.w3.org/2000/01/rdf-schema#Literal
 */
export const Literal = 'http://www.w3.org/2000/01/rdf-schema#Literal' satisfies Class;

/**
 * Container
 *
 * The class of RDF containers.
 *
 * http://www.w3.org/2000/01/rdf-schema#Container
 */
export const Container = 'http://www.w3.org/2000/01/rdf-schema#Container' satisfies Class;

/**
 * ContainerMembershipProperty
 *
 * The class of container membership properties, rdf:_1, rdf:_2, ..., all of which are sub-properties of 'member'.
 *
 * http://www.w3.org/2000/01/rdf-schema#ContainerMembershipProperty
 */
export const ContainerMembershipProperty = 'http://www.w3.org/2000/01/rdf-schema#ContainerMembershipProperty' satisfies Class;

/**
 * member
 *
 * A member of the subject resource.
 *
 * http://www.w3.org/2000/01/rdf-schema#member
 */
export const member = 'http://www.w3.org/2000/01/rdf-schema#member' satisfies Property;

/**
 * Datatype
 *
 * The class of RDF datatypes.
 *
 * http://www.w3.org/2000/01/rdf-schema#Datatype
 */
export const Datatype = 'http://www.w3.org/2000/01/rdf-schema#Datatype' satisfies Class;
