type Property = string;
type Class = string;
type Datatype = string;
type OwlClass = string;
type OwlObjectProperty = string;
type OwlDatatypeProperty = string;
type HydraResource = string;
type HydraClass = string;
type HydraLink = string;
type HydraTemplatedLink = string;
type HydraVariableRepresentation = string;

/**
 * BBS Signature, 2020 version
 *
 * https://w3id.org/security#BbsBlsSignature2020
 */
export const BbsBlsSignature2020 = 'https://w3id.org/security#BbsBlsSignature2020' satisfies Class;

/**
 * BBS Signature Proof, 2020 version
 *
 * https://w3id.org/security#BbsBlsSignatureProof2020
 */
export const BbsBlsSignatureProof2020 = 'https://w3id.org/security#BbsBlsSignatureProof2020' satisfies Class;

/**
 * BLS 12381 G1 Signature Key, 2020 version
 *
 * https://w3id.org/security#Bls12381G1Key2020
 */
export const Bls12381G1Key2020 = 'https://w3id.org/security#Bls12381G1Key2020' satisfies Class;

/**
 * BLS 12381 G2 Signature Key, 2020 version
 *
 * https://w3id.org/security#Bls12381G2Key2020
 */
export const Bls12381G2Key2020 = 'https://w3id.org/security#Bls12381G2Key2020' satisfies Class;

/**
 * Controlled Identifier Document
 *
 * https://w3id.org/security#ControlledIdentifierDocument
 */
export const ControlledIdentifierDocument = 'https://w3id.org/security#ControlledIdentifierDocument' satisfies Class;

/**
 * A Data Integrity Proof
 *
 * https://w3id.org/security#DataIntegrityProof
 */
export const DataIntegrityProof = 'https://w3id.org/security#DataIntegrityProof' satisfies Class;

/**
 * ecdsa-secp256k1 recovery method, 2020 version
 *
 * https://w3id.org/security#EcdsaSecp256k1RecoveryMethod2020
 */
export const EcdsaSecp256k1RecoveryMethod2020 = 'https://w3id.org/security#EcdsaSecp256k1RecoveryMethod2020' satisfies Class;

/**
 * ecdsa-secp256k1 recovery signature, 2020 version
 *
 * https://w3id.org/security#EcdsaSecp256k1RecoverySignature2020
 */
export const EcdsaSecp256k1RecoverySignature2020 = 'https://w3id.org/security#EcdsaSecp256k1RecoverySignature2020' satisfies Class;

/**
 * ecdsa-sep256k1, 2019 version
 *
 * https://w3id.org/security#EcdsaSecp256k1Signature2019
 */
export const EcdsaSecp256k1Signature2019 = 'https://w3id.org/security#EcdsaSecp256k1Signature2019' satisfies Class;

/**
 * ecdsa-sep256k1, 2020 version
 *
 * https://w3id.org/security#EcdsaSecp256k1Signature2020
 */
export const EcdsaSecp256k1Signature2020 = 'https://w3id.org/security#EcdsaSecp256k1Signature2020' satisfies Class;

/**
 * ecdsa-secp256k1 verification key, 2019 version
 *
 * https://w3id.org/security#EcdsaSecp256k1VerificationKey2019
 */
export const EcdsaSecp256k1VerificationKey2019 = 'https://w3id.org/security#EcdsaSecp256k1VerificationKey2019' satisfies Class;

/**
 * Ed25519 Signature Suite, 2020 version
 *
 * https://w3id.org/security#Ed25519Signature2020
 */
export const Ed25519Signature2020 = 'https://w3id.org/security#Ed25519Signature2020' satisfies Class;

/**
 * ED2559 Verification Key, 2018 version
 *
 * https://w3id.org/security#Ed25519VerificationKey2018
 */
export const Ed25519VerificationKey2018 = 'https://w3id.org/security#Ed25519VerificationKey2018' satisfies Class;

/**
 * ED2559 Verification Key, 2020 version
 *
 * https://w3id.org/security#Ed25519VerificationKey2020
 */
export const Ed25519VerificationKey2020 = 'https://w3id.org/security#Ed25519VerificationKey2020' satisfies Class;

/**
 * JSON Web Key Verification Method
 *
 * https://w3id.org/security#JsonWebKey
 */
export const JsonWebKey = 'https://w3id.org/security#JsonWebKey' satisfies Class;

/**
 * JSON Web Key, 2020 version
 *
 * https://w3id.org/security#JsonWebKey2020
 */
export const JsonWebKey2020 = 'https://w3id.org/security#JsonWebKey2020' satisfies Class;

/**
 * JSON Web Signature, 2020 version
 *
 * https://w3id.org/security#JsonWebSignature2020
 */
export const JsonWebSignature2020 = 'https://w3id.org/security#JsonWebSignature2020' satisfies Class;

/**
 * Cryptographic key
 *
 * https://w3id.org/security#Key
 */
export const Key = 'https://w3id.org/security#Key' satisfies Class;

/**
 * Merkle Proof
 *
 * https://w3id.org/security#MerkleProof2019
 */
export const MerkleProof2019 = 'https://w3id.org/security#MerkleProof2019' satisfies Class;

/**
 * Multikey Verification Method
 *
 * https://w3id.org/security#Multikey
 */
export const Multikey = 'https://w3id.org/security#Multikey' satisfies Class;

/**
 * Processing error
 *
 * https://w3id.org/security#ProcessingError
 */
export const ProcessingError = 'https://w3id.org/security#ProcessingError' satisfies Class;

/**
 * Digital proof
 *
 * https://w3id.org/security#Proof
 */
export const Proof = 'https://w3id.org/security#Proof' satisfies Class;

/**
 * An RDF Graph for a digital proof
 *
 * https://w3id.org/security#ProofGraph
 */
export const ProofGraph = 'https://w3id.org/security#ProofGraph' satisfies Class;

/**
 * Verification method
 *
 * https://w3id.org/security#VerificationMethod
 */
export const VerificationMethod = 'https://w3id.org/security#VerificationMethod' satisfies Class;

/**
 * Verification relationship
 *
 * https://w3id.org/security#VerificationRelationship
 */
export const VerificationRelationship = 'https://w3id.org/security#VerificationRelationship' satisfies Class;

/**
 * X25519 Key Agreement Key, 2019 version
 *
 * https://w3id.org/security#X25519KeyAgreementKey2019
 */
export const X25519KeyAgreementKey2019 = 'https://w3id.org/security#X25519KeyAgreementKey2019' satisfies Class;

/**
 * Allowed action
 *
 * https://w3id.org/security#allowedAction
 */
export const allowedAction = 'https://w3id.org/security#allowedAction' satisfies Property;

/**
 * Assertion method
 *
 * https://w3id.org/security#assertionMethod
 */
export const assertionMethod = 'https://w3id.org/security#assertionMethod' satisfies Property;

/**
 * Authentication method
 *
 * https://w3id.org/security#authentication
 */
export const authentication = 'https://w3id.org/security#authentication' satisfies Property;

/**
 * Blockchain account ID
 *
 * https://w3id.org/security#blockchainAccountId
 */
export const blockchainAccountId = 'https://w3id.org/security#blockchainAccountId' satisfies Property;

/**
 * Capability action
 *
 * https://w3id.org/security#capabilityAction
 */
export const capabilityAction = 'https://w3id.org/security#capabilityAction' satisfies Property;

/**
 * Capability chain
 *
 * https://w3id.org/security#capabilityChain
 */
export const capabilityChain = 'https://w3id.org/security#capabilityChain' satisfies Property;

/**
 * Capability delegation method
 *
 * https://w3id.org/security#capabilityDelegationMethod
 */
export const capabilityDelegationMethod = 'https://w3id.org/security#capabilityDelegationMethod' satisfies Property;

/**
 * Capability invocation method
 *
 * https://w3id.org/security#capabilityInvocationMethod
 */
export const capabilityInvocationMethod = 'https://w3id.org/security#capabilityInvocationMethod' satisfies Property;

/**
 * Caveat
 *
 * https://w3id.org/security#caveat
 */
export const caveat = 'https://w3id.org/security#caveat' satisfies Property;

/**
 * Challenge of a proof
 *
 * https://w3id.org/security#challenge
 */
export const challenge = 'https://w3id.org/security#challenge' satisfies Property;

/**
 * Controller
 *
 * https://w3id.org/security#controller
 */
export const controller = 'https://w3id.org/security#controller' satisfies Property;

/**
 * Proof creation time
 *
 * https://w3id.org/security#created
 */
export const created = 'https://w3id.org/security#created' satisfies Property;

/**
 * Cryptographic suite
 *
 * https://w3id.org/security#cryptosuite
 */
export const cryptosuite = 'https://w3id.org/security#cryptosuite' satisfies Property;

/**
 * Datatype for cryptosuite Identifiers
 *
 * https://w3id.org/security#cryptosuiteString
 */
export const cryptosuiteString = 'https://w3id.org/security#cryptosuiteString' satisfies Datatype;

/**
 * Delegator
 *
 * https://w3id.org/security#delegator
 */
export const delegator = 'https://w3id.org/security#delegator' satisfies Property;

/**
 * Digest multibase
 *
 * https://w3id.org/security#digestMultibase
 */
export const digestMultibase = 'https://w3id.org/security#digestMultibase' satisfies Property;

/**
 * Domain of a proof
 *
 * https://w3id.org/security#domain
 */
export const domain = 'https://w3id.org/security#domain' satisfies Property;

/**
 * Ethereum address
 *
 * https://w3id.org/security#ethereumAddress
 */
export const ethereumAddress = 'https://w3id.org/security#ethereumAddress' satisfies Property;

/**
 * Expiration time for a proof or verification method
 *
 * https://w3id.org/security#expiration
 */
export const expiration = 'https://w3id.org/security#expiration' satisfies Property;

/**
 * Invocation target
 *
 * https://w3id.org/security#invocationTarget
 */
export const invocationTarget = 'https://w3id.org/security#invocationTarget' satisfies Property;

/**
 * Invoker
 *
 * https://w3id.org/security#invoker
 */
export const invoker = 'https://w3id.org/security#invoker' satisfies Property;

/**
 * Json Web Signature
 *
 * https://w3id.org/security#jws
 */
export const jws = 'https://w3id.org/security#jws' satisfies Property;

/**
 * Key agreement protocols
 *
 * https://w3id.org/security#keyAgreementMethod
 */
export const keyAgreementMethod = 'https://w3id.org/security#keyAgreementMethod' satisfies Property;

/**
 * Datatype for multibase values
 *
 * https://w3id.org/security#multibase
 */
export const multibase = 'https://w3id.org/security#multibase' satisfies Datatype;

/**
 * Nonce supplied by proof creator
 *
 * https://w3id.org/security#nonce
 */
export const nonce = 'https://w3id.org/security#nonce' satisfies Property;

/**
 * Previous proof
 *
 * https://w3id.org/security#previousProof
 */
export const previousProof = 'https://w3id.org/security#previousProof' satisfies Property;

/**
 * Proof sets
 *
 * https://w3id.org/security#proof
 */
export const proof = 'https://w3id.org/security#proof' satisfies Property;

/**
 * Proof purpose
 *
 * https://w3id.org/security#proofPurpose
 */
export const proofPurpose = 'https://w3id.org/security#proofPurpose' satisfies Property;

/**
 * Proof value
 *
 * https://w3id.org/security#proofValue
 */
export const proofValue = 'https://w3id.org/security#proofValue' satisfies Property;

/**
 * Base58-encoded Public Key
 *
 * https://w3id.org/security#publicKeyBase58
 */
export const publicKeyBase58 = 'https://w3id.org/security#publicKeyBase58' satisfies Property;

/**
 * Hex-encoded version of public Key
 *
 * https://w3id.org/security#publicKeyHex
 */
export const publicKeyHex = 'https://w3id.org/security#publicKeyHex' satisfies Property;

/**
 * Public key JWK
 *
 * https://w3id.org/security#publicKeyJwk
 */
export const publicKeyJwk = 'https://w3id.org/security#publicKeyJwk' satisfies Property;

/**
 * Public key multibase
 *
 * https://w3id.org/security#publicKeyMultibase
 */
export const publicKeyMultibase = 'https://w3id.org/security#publicKeyMultibase' satisfies Property;

/**
 * Public key PEM
 *
 * https://w3id.org/security#publicKeyPem
 */
export const publicKeyPem = 'https://w3id.org/security#publicKeyPem' satisfies Property;

/**
 * Revocation time
 *
 * https://w3id.org/security#revoked
 */
export const revoked = 'https://w3id.org/security#revoked' satisfies Property;

/**
 * Secret key JWK
 *
 * https://w3id.org/security#secretKeyJwk
 */
export const secretKeyJwk = 'https://w3id.org/security#secretKeyJwk' satisfies Property;

/**
 * Secret key multibase
 *
 * https://w3id.org/security#secretKeyMultibase
 */
export const secretKeyMultibase = 'https://w3id.org/security#secretKeyMultibase' satisfies Property;

/**
 * Verification method
 *
 * https://w3id.org/security#verificationMethod
 */
export const verificationMethod = 'https://w3id.org/security#verificationMethod' satisfies Property;
