type Property = string;
type Class = string;
type Datatype = string;
type OwlClass = string;
type OwlObjectProperty = string;
type OwlDatatypeProperty = string;
type HydraResource = string;
type HydraClass = string;
type HydraLink = string;
type HydraTemplatedLink = string;
type HydraVariableRepresentation = string;

/**
 * An obligation taken on by a person, typically at a meeting.
 *     
 *
 * http://www.w3.org/2005/01/wf/flow#ActionItem
 */
export const ActionItem = 'http://www.w3.org/2005/01/wf/flow#ActionItem' satisfies Class;

/**
 * change
 *
 * The universal class of things which
 * change the state of a task.
 * Included now: Creation, Transition. (Maybe in the future
 * more π-calculus constructions such as splitting & merging tasks,
 * and import/export of obligations to a foreign opaque system.)
 * 
 *
 * http://www.w3.org/2005/01/wf/flow#Change
 */
export const Change = 'http://www.w3.org/2005/01/wf/flow#Change' satisfies Class;

/**
 * A task which does not need attention. It may be closed because
 *         has been abandoned or completed, for example.
 * 	
 *
 * http://www.w3.org/2005/01/wf/flow#Closed
 */
export const Closed = 'http://www.w3.org/2005/01/wf/flow#Closed' satisfies Class;

/**
 * creation
 *
 * A creation is a change from existence
 * to non-existence
 * a task. Typical properties include date and/or source
 * (a document causing the transition), and a final state.
 *
 * http://www.w3.org/2005/01/wf/flow#Creation
 */
export const Creation = 'http://www.w3.org/2005/01/wf/flow#Creation' satisfies Class;

/**
 * http://www.w3.org/2005/01/wf/flow#Message
 */
export const Message = 'http://www.w3.org/2005/01/wf/flow#Message' satisfies Class;

/**
 * non-terminal state
 *
 * A state from which there are transitions.
 *
 * http://www.w3.org/2005/01/wf/flow#NonTerminalState
 */
export const NonTerminalState = 'http://www.w3.org/2005/01/wf/flow#NonTerminalState' satisfies Class;

/**
 * A task which needs attention. The very crude states of Open and Closed all
 *         interoperability between different systems if the states for a given
 *         application are made subclasses of either Open or Closed. This allows
 *         tasks from different systems to be mixed and treated together with
 *         limited but valuable functionality.
 * 	
 *
 * http://www.w3.org/2005/01/wf/flow#Open
 */
export const Open = 'http://www.w3.org/2005/01/wf/flow#Open' satisfies Class;

/**
 * product
 *
 * A product is a task which monitors something
 *                 which must be produced.
 *
 * http://www.w3.org/2005/01/wf/flow#Product
 */
export const Product = 'http://www.w3.org/2005/01/wf/flow#Product' satisfies Class;

/**
 * Something to be done in a wide sense,
 * 	an agenda item at a meeting is one example, but any
 * 	issue, task, action item, goal, product, deliverable, milestone, can such a thing.
 * 	The requirement for this framework was that it would allow
 * 	one to customize ontologies for things such as agenda items,
 * 	action items, working group issues with a spec, w3c Last Call issues,
 * 	software bugs and administrative requests.
 * 	In π-calculus, a process.
 * 	Make your type of issue a subclass of Task.
 * 	
 *
 * http://www.w3.org/2005/01/wf/flow#Task
 */
export const Task = 'http://www.w3.org/2005/01/wf/flow#Task' satisfies Class;

/**
 * terminal state
 *
 * A state from which there are no transitions.
 *
 * http://www.w3.org/2005/01/wf/flow#TerminalState
 */
export const TerminalState = 'http://www.w3.org/2005/01/wf/flow#TerminalState' satisfies Class;

/**
 * tracker
 *
 * A set of issues and
 *                 the constraints on how they evolve.
 *                 To use this ontology, craete a new tracker.
 *                 Copy an existing one or make up your own.
 *
 * http://www.w3.org/2005/01/wf/flow#Tracker
 */
export const Tracker = 'http://www.w3.org/2005/01/wf/flow#Tracker' satisfies Class;

/**
 * transition
 *
 * A transition is a change of state of
 * a task. Typical properties include date and/or source
 * (a document causing the transition), and a final state.
 *
 * http://www.w3.org/2005/01/wf/flow#Transition
 */
export const Transition = 'http://www.w3.org/2005/01/wf/flow#Transition' satisfies Class;

/**
 * affects
 *
 * http://www.w3.org/2005/01/wf/flow#affects
 */
export const affects = 'http://www.w3.org/2005/01/wf/flow#affects' satisfies Property;

/**
 * allowed transitions
 *
 * The state machine is defined
 * 	by these lists of transition allowed for each issue.
 * 	(An interesting option in the Web is to make an allowed transition
 * 	to a state in soemone else's ontology, which in turn allows
 * 	transitions into many ontologies.  So a finite state maxchine
 * 	may become very large. In practice this means that a task handed
 * 	off to another organization may be processed on all kinds of ways.)
 *
 * http://www.w3.org/2005/01/wf/flow#allowedTransitions
 */
export const allowedTransitions = 'http://www.w3.org/2005/01/wf/flow#allowedTransitions' satisfies Property;

/**
 * assignees must be
 *
 * When an issue is assigned, the assignee must be from this class
 *
 * http://www.w3.org/2005/01/wf/flow#asigneeClass
 */
export const asigneeClass = 'http://www.w3.org/2005/01/wf/flow#asigneeClass' satisfies Property;

/**
 * assigned to
 *
 * The person or group to whom this has been assigned.
 *
 * http://www.w3.org/2005/01/wf/flow#assignee
 */
export const assignee = 'http://www.w3.org/2005/01/wf/flow#assignee' satisfies Property;

/**
 * attachment
 *
 * Something related is attached for information.
 *
 * http://www.w3.org/2005/01/wf/flow#attachment
 */
export const attachment = 'http://www.w3.org/2005/01/wf/flow#attachment' satisfies Property;

/**
 * creates
 *
 * http://www.w3.org/2005/01/wf/flow#creates
 */
export const creates = 'http://www.w3.org/2005/01/wf/flow#creates' satisfies Property;

/**
 * The date this task is due.
 *                 
 *
 * http://www.w3.org/2005/01/wf/flow#dateDue
 */
export const dateDue = 'http://www.w3.org/2005/01/wf/flow#dateDue' satisfies Property;

/**
 * Something which must be delivered to accomplish this
 *
 * http://www.w3.org/2005/01/wf/flow#deliverable
 */
export const deliverable = 'http://www.w3.org/2005/01/wf/flow#deliverable' satisfies Property;

/**
 * how
 *
 * Another task upon which this depends, in the sense that
 *         this task cannot be completed without that task being done.
 *         You can't use this for dependencies on anything other than other tasks.
 *         (Note the US spelling of the URI. In the UK, a dependant is a something
 *         which is dependent on somehing else.)
 *
 * http://www.w3.org/2005/01/wf/flow#dependent
 */
export const dependent = 'http://www.w3.org/2005/01/wf/flow#dependent' satisfies Property;

/**
 * description
 *
 * The description, definition,
 *         or abstract. Information explaining what this is.
 *         Not arbitrary comment about anything, only about the subject.
 *         (Use this property for anything. There is no domain restriction.).
 *
 * http://www.w3.org/2005/01/wf/flow#description
 */
export const description = 'http://www.w3.org/2005/01/wf/flow#description' satisfies Property;

/**
 * to
 *
 * http://www.w3.org/2005/01/wf/flow#final
 */
export const final = 'http://www.w3.org/2005/01/wf/flow#final' satisfies Property;

/**
 * goals
 *
 * A textual description of the goals of this product, etc.
 *
 * http://www.w3.org/2005/01/wf/flow#goalDescription
 */
export const goalDescription = 'http://www.w3.org/2005/01/wf/flow#goalDescription' satisfies Property;

/**
 * The initial state for a new issue
 *
 * http://www.w3.org/2005/01/wf/flow#initialState
 */
export const initialState = 'http://www.w3.org/2005/01/wf/flow#initialState' satisfies Property;

/**
 * issue
 *
 * A transition changes the state of the given issue.
 *
 * http://www.w3.org/2005/01/wf/flow#issue
 */
export const issue = 'http://www.w3.org/2005/01/wf/flow#issue' satisfies Property;

/**
 * issue category
 *
 * Issues may be categorized according to the
 *                 subclasses of this class
 *
 * http://www.w3.org/2005/01/wf/flow#issueCategory
 */
export const issueCategory = 'http://www.w3.org/2005/01/wf/flow#issueCategory' satisfies Property;

/**
 * all issues must be in
 *
 * The class of issues which are allowed in this tracker.
 *                 This is essemtial to the operation of the tracker,
 *                 as it defines which states an issue can be in.
 *                 (The issueClass must be a disjointUnionOf the state classes)
 *
 * http://www.w3.org/2005/01/wf/flow#issueClass
 */
export const issueClass = 'http://www.w3.org/2005/01/wf/flow#issueClass' satisfies Property;

/**
 * A message about this. Attached for information.
 *
 * http://www.w3.org/2005/01/wf/flow#message
 */
export const message = 'http://www.w3.org/2005/01/wf/flow#message' satisfies Property;

/**
 * changed by
 *
 * http://www.w3.org/2005/01/wf/flow#modifiedBy
 */
export const modifiedBy = 'http://www.w3.org/2005/01/wf/flow#modifiedBy' satisfies Property;

/**
 * to
 *
 * http://www.w3.org/2005/01/wf/flow#recipent
 */
export const recipent = 'http://www.w3.org/2005/01/wf/flow#recipent' satisfies Property;

/**
 * requires
 *
 * To be a valid transition,
 * 		a necessary (but not necessarily sufficuent) condition
 * 		is that there be recorded these properties for the record
 *
 * http://www.w3.org/2005/01/wf/flow#requires
 */
export const requires = 'http://www.w3.org/2005/01/wf/flow#requires' satisfies Property;

/**
 * An image taken by capturing the state of a
 *                  computer screen, for example to demonstrate a problem
 *
 * http://www.w3.org/2005/01/wf/flow#screenShot
 */
export const screenShot = 'http://www.w3.org/2005/01/wf/flow#screenShot' satisfies Property;

/**
 * from
 *
 * http://www.w3.org/2005/01/wf/flow#sender
 */
export const sender = 'http://www.w3.org/2005/01/wf/flow#sender' satisfies Property;

/**
 * source
 *
 * The source of a transition is
 * 				the document by which it happened
 *
 * http://www.w3.org/2005/01/wf/flow#source
 */
export const source = 'http://www.w3.org/2005/01/wf/flow#source' satisfies Property;

/**
 * state store
 *
 * A read-write document.
 *                 The state of the issues is modified here.
 *                 When you set up a trcaker, thgis must be set to point
 *                 to a writeble data resource on the web.
 *
 * http://www.w3.org/2005/01/wf/flow#stateStore
 */
export const stateStore = 'http://www.w3.org/2005/01/wf/flow#stateStore' satisfies Property;

/**
 * subscriber
 *
 * http://www.w3.org/2005/01/wf/flow#subscriber
 */
export const subscriber = 'http://www.w3.org/2005/01/wf/flow#subscriber' satisfies Property;

/**
 * success criteria
 *
 * A textual description of the successs critera.
 *                 How when we know this is done?
 *
 * http://www.w3.org/2005/01/wf/flow#successCriteria
 */
export const successCriteria = 'http://www.w3.org/2005/01/wf/flow#successCriteria' satisfies Property;

/**
 * task
 *
 * http://www.w3.org/2005/01/wf/flow#task
 */
export const task = 'http://www.w3.org/2005/01/wf/flow#task' satisfies Property;

/**
 * A file showing user interaction from a
 *                 text terminal or console etc. 
 *
 * http://www.w3.org/2005/01/wf/flow#terminalOutput
 */
export const terminalOutput = 'http://www.w3.org/2005/01/wf/flow#terminalOutput' satisfies Property;

/**
 * A file which can be used as inpiut to a test
 *                 or to demonstrate a problem. 
 *
 * http://www.w3.org/2005/01/wf/flow#testData
 */
export const testData = 'http://www.w3.org/2005/01/wf/flow#testData' satisfies Property;

/**
 * tracker
 *
 * http://www.w3.org/2005/01/wf/flow#tracker
 */
export const tracker = 'http://www.w3.org/2005/01/wf/flow#tracker' satisfies Property;

/**
 * transaction store
 *
 * An appendable document. Transactions and messsages
 *                     can be written into here
 *
 * http://www.w3.org/2005/01/wf/flow#transactionStore
 */
export const transactionStore = 'http://www.w3.org/2005/01/wf/flow#transactionStore' satisfies Property;
