/**
 * constituent
 *
 * ManufacturedItemDefinition.component.component.constituent: A reference to a constituent of the manufactured item as a whole, linked here so that its component location within the item can be indicated. This not where the item's ingredient are primarily stated (for which see Ingredient.for or ManufacturedItemDefinition.ingredient).
 *
 * http://hl7.org/fhir/constituent
 */
var constituent = 'http://hl7.org/fhir/constituent';
/**
 * _careTeam
 *
 * (Modified) ExplanationOfBenefit.careTeam
 *
 * http://hl7.org/fhir/_careTeam
 */
var _careTeam = 'http://hl7.org/fhir/_careTeam';
/**
 * ClinicalUseDefinitionWarningComponent
 *
 * ClinicalUseDefinitionWarningComponent: A critical piece of information about environmental, health or physical risks or hazards that serve as caution to the user. For example 'Do not operate heavy machinery', 'May cause drowsiness', or 'Get medical advice/attention if you feel unwell'.
 *
 * http://hl7.org/fhir/ClinicalUseDefinitionWarningComponent
 */
var ClinicalUseDefinitionWarningComponent = 'http://hl7.org/fhir/ClinicalUseDefinitionWarningComponent';
/**
 * PlanDefinitionActionParticipantComponent
 *
 * PlanDefinitionActionComponentAction.PlanDefinitionActionParticipantComponent: Indicates who should participate in performing the action described.
 *
 * http://hl7.org/fhir/PlanDefinitionActionParticipantComponent
 */
var PlanDefinitionActionParticipantComponent = 'http://hl7.org/fhir/PlanDefinitionActionParticipantComponent';
/**
 * VisionPrescriptionLensSpecificationComponent
 *
 * VisionPrescriptionLensSpecificationComponent: Contain the details of  the individual lens specifications and serves as the authorization for the fullfillment by certified professionals.
 *
 * http://hl7.org/fhir/VisionPrescriptionLensSpecificationComponent
 */
var VisionPrescriptionLensSpecificationComponent = 'http://hl7.org/fhir/VisionPrescriptionLensSpecificationComponent';
/**
 * _answerOption
 *
 * (Modified) Questionnaire.item.item.answerOption
 *
 * http://hl7.org/fhir/_answerOption
 */
var _answerOption = 'http://hl7.org/fhir/_answerOption';
/**
 * decimal
 *
 * A rational number with implicit precision
 *
 * http://hl7.org/fhir/decimal
 */
var decimal = 'http://hl7.org/fhir/decimal';
/**
 * _applies
 *
 * (Modified) Contract.term.group.applies
 *
 * http://hl7.org/fhir/_applies
 */
var _applies = 'http://hl7.org/fhir/_applies';
/**
 * serviceProvider
 *
 * Encounter.serviceProvider: The organization that is primarily responsible for this Encounter's services. This MAY be the same as the organization on the Patient record, however it could be different, such as if the actor performing the services was from an external organization (which may be billed seperately) for an external consultation.  Refer to the colonoscopy example on the Encounter examples tab.
 *
 * http://hl7.org/fhir/serviceProvider
 */
var serviceProvider = 'http://hl7.org/fhir/serviceProvider';
/**
 * NutritionProductIngredientComponent
 *
 * NutritionProductIngredientComponent: Ingredients contained in this product.
 *
 * http://hl7.org/fhir/NutritionProductIngredientComponent
 */
var NutritionProductIngredientComponent = 'http://hl7.org/fhir/NutritionProductIngredientComponent';
/**
 * Error
 *
 * ClaimResponse.Error: Errors encountered during the processing of the adjudication.
 * Note that `Error` is a reserved Javascript keyword, and is therefore suffixed by `__workaround`.
 * For a list of reserved keywords, see https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Lexical_grammar#Keywords.
 *
 * http://hl7.org/fhir/Error
 */
var Error__workaround = 'http://hl7.org/fhir/Error';
/**
 * productStatus
 *
 * BiologicallyDerivedProduct.productStatus: Whether the product is currently available.
 *
 * http://hl7.org/fhir/productStatus
 */
var productStatus = 'http://hl7.org/fhir/productStatus';
/**
 * ImagingStudySeriesPerformerComponent
 *
 * ImagingStudySeriesComponent.ImagingStudySeriesPerformerComponent: Indicates who or what performed the series and how they were involved.
 *
 * http://hl7.org/fhir/ImagingStudySeriesPerformerComponent
 */
var ImagingStudySeriesPerformerComponent = 'http://hl7.org/fhir/ImagingStudySeriesPerformerComponent';
/**
 * _lowerLimit
 *
 * (Modified) SampledData.lowerLimit
 *
 * http://hl7.org/fhir/_lowerLimit
 */
var _lowerLimit = 'http://hl7.org/fhir/_lowerLimit';
/**
 * Medication
 *
 * This resource is primarily used for the identification and definition of a medication, including ingredients, for the purposes of prescribing, dispensing, and administering a medication as well as for making statements about medication use.
 *
 * http://hl7.org/fhir/Medication
 */
var Medication = 'http://hl7.org/fhir/Medication';
/**
 * header
 *
 * Endpoint.header: Additional headers / information to send as part of the notification.
 *
 * http://hl7.org/fhir/header
 */
var header = 'http://hl7.org/fhir/header';
/**
 * StructureMapGroupRuleComponent
 *
 * StructureMapGroupComponent.StructureMapGroupRuleComponent: Transform Rule from source to target.
 *
 * http://hl7.org/fhir/StructureMapGroupRuleComponent
 */
var StructureMapGroupRuleComponent = 'http://hl7.org/fhir/StructureMapGroupRuleComponent';
/**
 * _productType
 *
 * (Modified) MedicationKnowledge.productType
 *
 * http://hl7.org/fhir/_productType
 */
var _productType = 'http://hl7.org/fhir/_productType';
/**
 * _relatedItem
 *
 * (Modified) InventoryItem.association.relatedItem
 *
 * http://hl7.org/fhir/_relatedItem
 */
var _relatedItem = 'http://hl7.org/fhir/_relatedItem';
/**
 * author
 *
 * Basic.author: Indicates who was responsible for creating the resource instance.
 *
 * http://hl7.org/fhir/author
 */
var author = 'http://hl7.org/fhir/author';
/**
 * _direction
 *
 * (Modified) TestScript.test.action.assert.direction
 *
 * http://hl7.org/fhir/_direction
 */
var _direction = 'http://hl7.org/fhir/_direction';
/**
 * _frequencyOfOccurrence
 *
 * (Modified) ClinicalUseDefinition.undesirableEffect.frequencyOfOccurrence
 *
 * http://hl7.org/fhir/_frequencyOfOccurrence
 */
var _frequencyOfOccurrence = 'http://hl7.org/fhir/_frequencyOfOccurrence';
/**
 * RequestOrchestration
 *
 * A set of related requests that can be used to capture intended activities that have inter-dependencies such as "give this medication after that one".
 *
 * http://hl7.org/fhir/RequestOrchestration
 */
var RequestOrchestration = 'http://hl7.org/fhir/RequestOrchestration';
/**
 * Detail
 *
 * Claim.Item.Detail: A claim detail line. Either a simple (a product or service) or a 'group' of sub-details which are simple items.
 *
 * http://hl7.org/fhir/Detail
 */
var Detail = 'http://hl7.org/fhir/Detail';
/**
 * numberOfRepeatsAllowed
 *
 * MedicationRequest.dispenseRequest.numberOfRepeatsAllowed: An integer indicating the number of times, in addition to the original dispense, (aka refills or repeats) that the patient can receive the prescribed medication. Usage Notes: This integer does not include the original order dispense. This means that if an order indicates dispense 30 tablets plus "3 repeats", then the order can be dispensed a total of 4 times and the patient can receive a total of 120 tablets.  A prescriber may explicitly say that zero refills are permitted after the initial dispense.
 *
 * http://hl7.org/fhir/numberOfRepeatsAllowed
 */
var numberOfRepeatsAllowed = 'http://hl7.org/fhir/numberOfRepeatsAllowed';
/**
 * _communicationRequest
 *
 * (Modified) ClaimResponse.communicationRequest
 *
 * http://hl7.org/fhir/_communicationRequest
 */
var _communicationRequest = 'http://hl7.org/fhir/_communicationRequest';
/**
 * DocumentReferenceContentProfileComponent
 *
 * DocumentReferenceContentComponent.DocumentReferenceContentProfileComponent: An identifier of the document constraints, encoding, structure, and template that the document conforms to beyond the base format indicated in the mimeType.
 *
 * http://hl7.org/fhir/DocumentReferenceContentProfileComponent
 */
var DocumentReferenceContentProfileComponent = 'http://hl7.org/fhir/DocumentReferenceContentProfileComponent';
/**
 * _masterFile
 *
 * (Modified) MedicinalProductDefinition.masterFile
 *
 * http://hl7.org/fhir/_masterFile
 */
var _masterFile = 'http://hl7.org/fhir/_masterFile';
/**
 * comment
 *
 * Schedule.comment: Comments on the availability to describe any extended information. Such as custom constraints on the slots that may be associated.
 *
 * http://hl7.org/fhir/comment
 */
var comment = 'http://hl7.org/fhir/comment';
/**
 * availableTime
 *
 * Availability.availableTime: Times the {item} is available.
 *
 * http://hl7.org/fhir/availableTime
 */
var availableTime = 'http://hl7.org/fhir/availableTime';
/**
 * _assert
 *
 * (Modified) TestScript.test.action.assert
 *
 * http://hl7.org/fhir/_assert
 */
var _assert = 'http://hl7.org/fhir/_assert';
/**
 * listRuleId
 *
 * StructureMap.group.rule.rule.target.listRuleId: Internal rule reference for shared list items.
 *
 * http://hl7.org/fhir/listRuleId
 */
var listRuleId = 'http://hl7.org/fhir/listRuleId';
/**
 * preAdmissionIdentifier
 *
 * Encounter.admission.preAdmissionIdentifier: Pre-admission identifier.
 *
 * http://hl7.org/fhir/preAdmissionIdentifier
 */
var preAdmissionIdentifier = 'http://hl7.org/fhir/preAdmissionIdentifier';
/**
 * participantType
 *
 * AppointmentResponse.participantType: Role of participant in the appointment.
 *
 * http://hl7.org/fhir/participantType
 */
var participantType = 'http://hl7.org/fhir/participantType';
/**
 * _related
 *
 * (Modified) ExplanationOfBenefit.related
 *
 * http://hl7.org/fhir/_related
 */
var _related = 'http://hl7.org/fhir/_related';
/**
 * SupplementSchedule
 *
 * NutritionOrderSupplementComponent.SupplementSchedule: Schedule information for a supplement.
 *
 * http://hl7.org/fhir/SupplementSchedule
 */
var SupplementSchedule = 'http://hl7.org/fhir/SupplementSchedule';
/**
 * reAdmission
 *
 * Encounter.admission.reAdmission: Indicates that this encounter is directly related to a prior admission, often because the conditions addressed in the prior admission were not fully addressed.
 *
 * http://hl7.org/fhir/reAdmission
 */
var reAdmission = 'http://hl7.org/fhir/reAdmission';
/**
 * _requestURL
 *
 * (Modified) TestScript.test.action.assert.requestURL
 *
 * http://hl7.org/fhir/_requestURL
 */
var _requestURL = 'http://hl7.org/fhir/_requestURL';
/**
 * _caseSensitive
 *
 * (Modified) CodeSystem.caseSensitive
 *
 * http://hl7.org/fhir/_caseSensitive
 */
var _caseSensitive = 'http://hl7.org/fhir/_caseSensitive';
/**
 * _chargeItem
 *
 * (Modified) Invoice.lineItem.chargeItem
 *
 * http://hl7.org/fhir/_chargeItem
 */
var _chargeItem = 'http://hl7.org/fhir/_chargeItem';
/**
 * _withdrawalPeriod
 *
 * (Modified) AdministrableProductDefinition.routeOfAdministration.targetSpecies.withdrawalPeriod
 *
 * http://hl7.org/fhir/_withdrawalPeriod
 */
var _withdrawalPeriod = 'http://hl7.org/fhir/_withdrawalPeriod';
/**
 * CapabilityStatementImplementationComponent
 *
 * CapabilityStatementImplementationComponent: Identifies a specific implementation instance that is described by the capability statement - i.e. a particular installation, rather than the capabilities of a software program.
 *
 * http://hl7.org/fhir/CapabilityStatementImplementationComponent
 */
var CapabilityStatementImplementationComponent = 'http://hl7.org/fhir/CapabilityStatementImplementationComponent';
/**
 * analysis
 *
 * GenomicStudy.analysis: The details about a specific analysis that was performed in this GenomicStudy.
 *
 * http://hl7.org/fhir/analysis
 */
var analysis = 'http://hl7.org/fhir/analysis';
/**
 * monitoringProgram
 *
 * MedicationKnowledge.monitoringProgram: The program under which the medication is reviewed.
 *
 * http://hl7.org/fhir/monitoringProgram
 */
var monitoringProgram = 'http://hl7.org/fhir/monitoringProgram';
/**
 * _date
 *
 * (Modified) ResearchStudy.date
 *
 * http://hl7.org/fhir/_date
 */
var _date = 'http://hl7.org/fhir/_date';
/**
 * satisfiedBy
 *
 * Requirements.statement.satisfiedBy: A reference to another artifact that satisfies this requirement. This could be a Profile, extension, or an element in one of those, or a CapabilityStatement, OperationDefinition, SearchParameter, CodeSystem(/code), ValueSet, Libary etc.
 *
 * http://hl7.org/fhir/satisfiedBy
 */
var satisfiedBy = 'http://hl7.org/fhir/satisfiedBy';
/**
 * artifact
 *
 * TestScript.scope.artifact: The specific conformance artifact being tested. The canonical reference can be version-specific.
 *
 * http://hl7.org/fhir/artifact
 */
var artifact = 'http://hl7.org/fhir/artifact';
/**
 * timing
 *
 * RequestOrchestration.action.timing
 *
 * http://hl7.org/fhir/timing
 */
var timing = 'http://hl7.org/fhir/timing';
/**
 * appliesToAll
 *
 * CoverageEligibilityRequest.supportingInfo.appliesToAll: The supporting materials are applicable for all detail items, product/servce categories and specific billing codes.
 *
 * http://hl7.org/fhir/appliesToAll
 */
var appliesToAll = 'http://hl7.org/fhir/appliesToAll';
/**
 * _appointmentRequired
 *
 * (Modified) HealthcareService.appointmentRequired
 *
 * http://hl7.org/fhir/_appointmentRequired
 */
var _appointmentRequired = 'http://hl7.org/fhir/_appointmentRequired';
/**
 * _canFilterBy
 *
 * (Modified) SubscriptionTopic.canFilterBy
 *
 * http://hl7.org/fhir/_canFilterBy
 */
var _canFilterBy = 'http://hl7.org/fhir/_canFilterBy';
/**
 * filter
 *
 * ValueSet.compose.exclude.filter: Select concepts by specifying a matching criterion based on the properties (including relationships) defined by the system, or on filters defined by the system. If multiple filters are specified within the include, they SHALL all be true.
 *
 * http://hl7.org/fhir/filter
 */
var filter = 'http://hl7.org/fhir/filter';
/**
 * _targetNumber
 *
 * (Modified) ResearchStudy.recruitment.targetNumber
 *
 * http://hl7.org/fhir/_targetNumber
 */
var _targetNumber = 'http://hl7.org/fhir/_targetNumber';
/**
 * _additive
 *
 * (Modified) SpecimenDefinition.typeTested.container.additive.additive
 *
 * http://hl7.org/fhir/_additive
 */
var _additive = 'http://hl7.org/fhir/_additive';
/**
 * _management
 *
 * (Modified) ClinicalUseDefinition.interaction.management
 *
 * http://hl7.org/fhir/_management
 */
var _management = 'http://hl7.org/fhir/_management';
/**
 * _phylum
 *
 * (Modified) SubstanceSourceMaterial.organism.organismGeneral.phylum
 *
 * http://hl7.org/fhir/_phylum
 */
var _phylum = 'http://hl7.org/fhir/_phylum';
/**
 * _distributor
 *
 * (Modified) DeviceDefinition.packaging.packaging.distributor
 *
 * http://hl7.org/fhir/_distributor
 */
var _distributor = 'http://hl7.org/fhir/_distributor';
/**
 * _clinicalRecommendationStatement
 *
 * (Modified) Measure.clinicalRecommendationStatement
 *
 * http://hl7.org/fhir/_clinicalRecommendationStatement
 */
var _clinicalRecommendationStatement = 'http://hl7.org/fhir/_clinicalRecommendationStatement';
/**
 * _manifest
 *
 * (Modified) ImplementationGuide.manifest
 *
 * http://hl7.org/fhir/_manifest
 */
var _manifest = 'http://hl7.org/fhir/_manifest';
/**
 * cancellationDate
 *
 * Appointment.cancellationDate: The date/time describing when the appointment was cancelled.
 *
 * http://hl7.org/fhir/cancellationDate
 */
var cancellationDate = 'http://hl7.org/fhir/cancellationDate';
/**
 * _doseQuantity
 *
 * (Modified) Immunization.doseQuantity
 *
 * http://hl7.org/fhir/_doseQuantity
 */
var _doseQuantity = 'http://hl7.org/fhir/_doseQuantity';
/**
 * DeviceDefinitionPackagingComponentUdiDeviceIdentifier
 *
 * Unique Device Identifier (UDI) Barcode string on the packaging.
 *
 * http://hl7.org/fhir/DeviceDefinitionPackagingComponentUdiDeviceIdentifier
 */
var DeviceDefinitionPackagingComponentUdiDeviceIdentifier = 'http://hl7.org/fhir/DeviceDefinitionPackagingComponentUdiDeviceIdentifier';
/**
 * VerificationResult
 *
 * Describes validation requirements, source(s), status and dates for one or more elements.
 *
 * http://hl7.org/fhir/VerificationResult
 */
var VerificationResult = 'http://hl7.org/fhir/VerificationResult';
/**
 * preference
 *
 * SpecimenDefinition.typeTested.preference: The preference for this type of conditioned specimen.
 *
 * http://hl7.org/fhir/preference
 */
var preference = 'http://hl7.org/fhir/preference';
/**
 * _asserter
 *
 * (Modified) Permission.asserter
 *
 * http://hl7.org/fhir/_asserter
 */
var _asserter = 'http://hl7.org/fhir/_asserter';
/**
 * _regulatoryIdentifier
 *
 * (Modified) DeviceDefinition.regulatoryIdentifier
 *
 * http://hl7.org/fhir/_regulatoryIdentifier
 */
var _regulatoryIdentifier = 'http://hl7.org/fhir/_regulatoryIdentifier';
/**
 * molecularFormula
 *
 * SubstanceDefinition.structure.molecularFormula: An expression which states the number and type of atoms present in a molecule of a substance.
 *
 * http://hl7.org/fhir/molecularFormula
 */
var molecularFormula = 'http://hl7.org/fhir/molecularFormula';
/**
 * isActive
 *
 * Medication.ingredient.isActive: Indication of whether this ingredient affects the therapeutic action of the drug.
 *
 * http://hl7.org/fhir/isActive
 */
var isActive = 'http://hl7.org/fhir/isActive';
/**
 * dispenserInstruction
 *
 * MedicationRequest.dispenseRequest.dispenserInstruction: Provides additional information to the dispenser, for example, counselling to be provided to the patient.
 *
 * http://hl7.org/fhir/dispenserInstruction
 */
var dispenserInstruction = 'http://hl7.org/fhir/dispenserInstruction';
/**
 * MedicationKnowledgeRelatedMedicationKnowledgeComponent
 *
 * MedicationKnowledgeRelatedMedicationKnowledgeComponent: Associated or related medications. For example, if the medication is a branded product (e.g. Crestor), this is the Therapeutic Moeity (e.g. Rosuvastatin) or if this is a generic medication (e.g. Rosuvastatin), this would link to a branded product (e.g. Crestor.
 *
 * http://hl7.org/fhir/MedicationKnowledgeRelatedMedicationKnowledgeComponent
 */
var MedicationKnowledgeRelatedMedicationKnowledgeComponent = 'http://hl7.org/fhir/MedicationKnowledgeRelatedMedicationKnowledgeComponent';
/**
 * CapabilityStatementRestSecurityComponent
 *
 * CapabilityStatementRestComponent.CapabilityStatementRestSecurityComponent: Information about security implementation from an interface perspective - what a client needs to know.
 *
 * http://hl7.org/fhir/CapabilityStatementRestSecurityComponent
 */
var CapabilityStatementRestSecurityComponent = 'http://hl7.org/fhir/CapabilityStatementRestSecurityComponent';
/**
 * initialSelected
 *
 * Questionnaire.item.item.answerOption.initialSelected: Indicates whether the answer value is selected when the list of possible answers is initially shown.
 *
 * http://hl7.org/fhir/initialSelected
 */
var initialSelected = 'http://hl7.org/fhir/initialSelected';
/**
 * _preventiveAction
 *
 * (Modified) AdverseEvent.preventiveAction
 *
 * http://hl7.org/fhir/_preventiveAction
 */
var _preventiveAction = 'http://hl7.org/fhir/_preventiveAction';
/**
 * DeviceDefinitionConformsToComponent
 *
 * DeviceDefinitionConformsToComponent: Identifies the standards, specifications, or formal guidances for the capabilities supported by the device. The device may be certified as conformant to these specifications e.g., communication, performance, process, measurement, or specialization standards.
 *
 * http://hl7.org/fhir/DeviceDefinitionConformsToComponent
 */
var DeviceDefinitionConformsToComponent = 'http://hl7.org/fhir/DeviceDefinitionConformsToComponent';
/**
 * _MedicationStatement
 *
 * (Modified) MedicationStatement
 *
 * http://hl7.org/fhir/_MedicationStatement
 */
var _MedicationStatement = 'http://hl7.org/fhir/_MedicationStatement';
/**
 * _availableStartTime
 *
 * (Modified) Availability.availableTime.availableStartTime
 *
 * http://hl7.org/fhir/_availableStartTime
 */
var _availableStartTime = 'http://hl7.org/fhir/_availableStartTime';
/**
 * validationType
 *
 * VerificationResult.validationType: What the target is validated against (nothing; primary source; multiple sources).
 *
 * http://hl7.org/fhir/validationType
 */
var validationType = 'http://hl7.org/fhir/validationType';
/**
 * _axis
 *
 * (Modified) VisionPrescription.lensSpecification.axis
 *
 * http://hl7.org/fhir/_axis
 */
var _axis = 'http://hl7.org/fhir/_axis';
/**
 * _serialNumber
 *
 * (Modified) Device.serialNumber
 *
 * http://hl7.org/fhir/_serialNumber
 */
var _serialNumber = 'http://hl7.org/fhir/_serialNumber';
/**
 * Narrative
 *
 * A human-readable summary of the resource conveying the essential clinical and business information for the resource.
 *
 * http://hl7.org/fhir/Narrative
 */
var Narrative = 'http://hl7.org/fhir/Narrative';
/**
 * _dependency
 *
 * (Modified) TestPlan.testCase.dependency
 *
 * http://hl7.org/fhir/_dependency
 */
var _dependency = 'http://hl7.org/fhir/_dependency';
/**
 * endDate
 *
 * ResearchSubject.progress.endDate: The date when the state ended.
 *
 * http://hl7.org/fhir/endDate
 */
var endDate = 'http://hl7.org/fhir/endDate';
/**
 * _prognosisReference
 *
 * (Modified) ClinicalImpression.prognosisReference
 *
 * http://hl7.org/fhir/_prognosisReference
 */
var _prognosisReference = 'http://hl7.org/fhir/_prognosisReference';
/**
 * _recruitment
 *
 * (Modified) ResearchStudy.recruitment
 *
 * http://hl7.org/fhir/_recruitment
 */
var _recruitment = 'http://hl7.org/fhir/_recruitment';
/**
 * searchParam
 *
 * DataRequirement.valueFilter.searchParam: A search parameter defined on the specified type of the DataRequirement, and which searches on elements of a type compatible with the type of the valueFilter.value[x] for the filter.
 *
 * http://hl7.org/fhir/searchParam
 */
var searchParam = 'http://hl7.org/fhir/searchParam';
/**
 * _usageInstruction
 *
 * (Modified) DeviceDispense.usageInstruction
 *
 * http://hl7.org/fhir/_usageInstruction
 */
var _usageInstruction = 'http://hl7.org/fhir/_usageInstruction';
/**
 * _generation
 *
 * (Modified) ImplementationGuide.definition.page.page.generation
 *
 * http://hl7.org/fhir/_generation
 */
var _generation = 'http://hl7.org/fhir/_generation';
/**
 * artifactAssessment
 *
 * Citation.citedArtifact.classification.artifactAssessment: Complex or externally created classification.
 *
 * http://hl7.org/fhir/artifactAssessment
 */
var artifactAssessment = 'http://hl7.org/fhir/artifactAssessment';
/**
 * complete
 *
 * Citation.citedArtifact.contributorship.complete: Indicates if the list includes all authors and/or contributors.
 *
 * http://hl7.org/fhir/complete
 */
var complete = 'http://hl7.org/fhir/complete';
/**
 * _dependent
 *
 * (Modified) StructureMap.group.rule.dependent
 *
 * http://hl7.org/fhir/_dependent
 */
var _dependent = 'http://hl7.org/fhir/_dependent';
/**
 * _due
 *
 * (Modified) PlanDefinition.goal.target.due
 *
 * http://hl7.org/fhir/_due
 */
var _due = 'http://hl7.org/fhir/_due';
/**
 * _replaces
 *
 * (Modified) DeviceRequest.replaces
 *
 * http://hl7.org/fhir/_replaces
 */
var _replaces = 'http://hl7.org/fhir/_replaces';
/**
 * EvidenceStatisticModelCharacteristicComponent
 *
 * EvidenceStatisticComponent.EvidenceStatisticModelCharacteristicComponent: A component of the method to generate the statistic.
 *
 * http://hl7.org/fhir/EvidenceStatisticModelCharacteristicComponent
 */
var EvidenceStatisticModelCharacteristicComponent = 'http://hl7.org/fhir/EvidenceStatisticModelCharacteristicComponent';
/**
 * _friday
 *
 * (Modified) Appointment.recurrenceTemplate.weeklyTemplate.friday
 *
 * http://hl7.org/fhir/_friday
 */
var _friday = 'http://hl7.org/fhir/_friday';
/**
 * orderedBy
 *
 * EvidenceReport.section.orderedBy: Specifies the order applied to the items in the section entries.
 *
 * http://hl7.org/fhir/orderedBy
 */
var orderedBy = 'http://hl7.org/fhir/orderedBy';
/**
 * _modality
 *
 * (Modified) ImagingStudy.series.modality
 *
 * http://hl7.org/fhir/_modality
 */
var _modality = 'http://hl7.org/fhir/_modality';
/**
 * expirationType
 *
 * Contract.expirationType: Event resulting in discontinuation or termination of this Contract instance by one or more parties to the contract.
 *
 * http://hl7.org/fhir/expirationType
 */
var expirationType = 'http://hl7.org/fhir/expirationType';
/**
 * party
 *
 * Contract.signer.party: Party which is a signator to this Contract.
 *
 * http://hl7.org/fhir/party
 */
var party = 'http://hl7.org/fhir/party';
/**
 * _objective
 *
 * (Modified) ResearchStudy.objective
 *
 * http://hl7.org/fhir/_objective
 */
var _objective = 'http://hl7.org/fhir/_objective';
/**
 * _totalNet
 *
 * (Modified) Invoice.totalNet
 *
 * http://hl7.org/fhir/_totalNet
 */
var _totalNet = 'http://hl7.org/fhir/_totalNet';
/**
 * _adherence
 *
 * (Modified) MedicationStatement.adherence
 *
 * http://hl7.org/fhir/_adherence
 */
var _adherence = 'http://hl7.org/fhir/_adherence';
/**
 * _cardinalityBehavior
 *
 * (Modified) RequestOrchestration.action.action.cardinalityBehavior
 *
 * http://hl7.org/fhir/_cardinalityBehavior
 */
var _cardinalityBehavior = 'http://hl7.org/fhir/_cardinalityBehavior';
/**
 * startDate
 *
 * ResearchSubject.progress.startDate: The date when the new status started.
 *
 * http://hl7.org/fhir/startDate
 */
var startDate = 'http://hl7.org/fhir/startDate';
/**
 * basis
 *
 * RegulatedAuthorization.basis: The legal or regulatory framework against which this authorization is granted, or other reasons for it.
 *
 * http://hl7.org/fhir/basis
 */
var basis = 'http://hl7.org/fhir/basis';
/**
 * _minutesDuration
 *
 * (Modified) Appointment.minutesDuration
 *
 * http://hl7.org/fhir/_minutesDuration
 */
var _minutesDuration = 'http://hl7.org/fhir/_minutesDuration';
/**
 * instruction
 *
 * SpecimenDefinition.typeTested.handling.instruction: Additional textual instructions for the preservation or transport of the specimen. For instance, 'Protect from light exposure'.
 *
 * http://hl7.org/fhir/instruction
 */
var instruction = 'http://hl7.org/fhir/instruction';
/**
 * _targetDisease
 *
 * (Modified) ImmunizationRecommendation.recommendation.targetDisease
 *
 * http://hl7.org/fhir/_targetDisease
 */
var _targetDisease = 'http://hl7.org/fhir/_targetDisease';
/**
 * eventTrigger
 *
 * SubscriptionTopic.eventTrigger: Event definition which can be used to trigger the SubscriptionTopic.
 *
 * http://hl7.org/fhir/eventTrigger
 */
var eventTrigger = 'http://hl7.org/fhir/eventTrigger';
/**
 * closure
 *
 * TerminologyCapabilities.closure: Whether the $closure operation is supported.
 *
 * http://hl7.org/fhir/closure
 */
var closure = 'http://hl7.org/fhir/closure';
/**
 * numberOfParticipants
 *
 * Evidence.statistic.sampleSize.numberOfParticipants: A human-readable string to clarify or explain concepts about the sample size.
 *
 * http://hl7.org/fhir/numberOfParticipants
 */
var numberOfParticipants = 'http://hl7.org/fhir/numberOfParticipants';
/**
 * businessArrangement
 *
 * CoverageEligibilityRequest.insurance.businessArrangement: A business agreement number established between the provider and the insurer for special business processing purposes.
 *
 * http://hl7.org/fhir/businessArrangement
 */
var businessArrangement = 'http://hl7.org/fhir/businessArrangement';
/**
 * requesterLinkId
 *
 * Contract.term.group.action.requesterLinkId: Id [identifier??] of the clause or question text related to the requester of this action in the referenced form or QuestionnaireResponse.
 *
 * http://hl7.org/fhir/requesterLinkId
 */
var requesterLinkId = 'http://hl7.org/fhir/requesterLinkId';
/**
 * _programEligibility
 *
 * (Modified) Immunization.programEligibility
 *
 * http://hl7.org/fhir/_programEligibility
 */
var _programEligibility = 'http://hl7.org/fhir/_programEligibility';
/**
 * _average
 *
 * (Modified) SubstancePolymer.repeat.repeatUnit.degreeOfPolymerisation.average
 *
 * http://hl7.org/fhir/_average
 */
var _average = 'http://hl7.org/fhir/_average';
/**
 * proxySignature
 *
 * VerificationResult.attestation.proxySignature: Signed assertion by the proxy entity indicating that they have the right to submit attested information on behalf of the attestation source.
 *
 * http://hl7.org/fhir/proxySignature
 */
var proxySignature = 'http://hl7.org/fhir/proxySignature';
/**
 * _assessmentMethod
 *
 * (Modified) AdverseEvent.suspectEntity.causality.assessmentMethod
 *
 * http://hl7.org/fhir/_assessmentMethod
 */
var _assessmentMethod = 'http://hl7.org/fhir/_assessmentMethod';
/**
 * _series
 *
 * (Modified) ImmunizationRecommendation.recommendation.series
 *
 * http://hl7.org/fhir/_series
 */
var _series = 'http://hl7.org/fhir/_series';
/**
 * _performingOrganization
 *
 * (Modified) ChargeItem.performingOrganization
 *
 * http://hl7.org/fhir/_performingOrganization
 */
var _performingOrganization = 'http://hl7.org/fhir/_performingOrganization';
/**
 * frames
 *
 * Attachment.frames: The number of frames in a photo. This is used with a multi-page fax, or an imaging acquisition context that takes multiple slices in a single image, or an animated gif. If there is more than one frame, this SHALL have a value in order to alert interface software that a multi-frame capable rendering widget is required.
 *
 * http://hl7.org/fhir/frames
 */
var frames = 'http://hl7.org/fhir/frames';
/**
 * _paternalOrganismName
 *
 * (Modified) SubstanceSourceMaterial.organism.hybrid.paternalOrganismName
 *
 * http://hl7.org/fhir/_paternalOrganismName
 */
var _paternalOrganismName = 'http://hl7.org/fhir/_paternalOrganismName';
/**
 * inputProfile
 *
 * OperationDefinition.inputProfile: Additional validation information for the in parameters - a single profile that covers all the parameters. The profile is a constraint on the parameters resource as a whole.
 *
 * http://hl7.org/fhir/inputProfile
 */
var inputProfile = 'http://hl7.org/fhir/inputProfile';
/**
 * _guarantor
 *
 * (Modified) Account.guarantor
 *
 * http://hl7.org/fhir/_guarantor
 */
var _guarantor = 'http://hl7.org/fhir/_guarantor';
/**
 * _human
 *
 * (Modified) ElementDefinition.constraint.human
 *
 * http://hl7.org/fhir/_human
 */
var _human = 'http://hl7.org/fhir/_human';
/**
 * NutritionProductCharacteristicComponent
 *
 * NutritionProductCharacteristicComponent: Specifies descriptive properties of the nutrition product.
 *
 * http://hl7.org/fhir/NutritionProductCharacteristicComponent
 */
var NutritionProductCharacteristicComponent = 'http://hl7.org/fhir/NutritionProductCharacteristicComponent';
/**
 * _orderDetail
 *
 * (Modified) ServiceRequest.orderDetail
 *
 * http://hl7.org/fhir/_orderDetail
 */
var _orderDetail = 'http://hl7.org/fhir/_orderDetail';
/**
 * maxParticipants
 *
 * VirtualServiceDetail.maxParticipants: Maximum number of participants supported by the virtual service.
 *
 * http://hl7.org/fhir/maxParticipants
 */
var maxParticipants = 'http://hl7.org/fhir/maxParticipants';
/**
 * ClinicalUseDefinitionUndesirableEffectComponent
 *
 * ClinicalUseDefinitionUndesirableEffectComponent: Describe the possible undesirable effects (negative outcomes) from the use of the medicinal product as treatment.
 *
 * http://hl7.org/fhir/ClinicalUseDefinitionUndesirableEffectComponent
 */
var ClinicalUseDefinitionUndesirableEffectComponent = 'http://hl7.org/fhir/ClinicalUseDefinitionUndesirableEffectComponent';
/**
 * _observed
 *
 * (Modified) Evidence.variableDefinition.observed
 *
 * http://hl7.org/fhir/_observed
 */
var _observed = 'http://hl7.org/fhir/_observed';
/**
 * validityPeriod
 *
 * RegulatedAuthorization.validityPeriod: The time period in which the regulatory approval, clearance or licencing is in effect. As an example, a Marketing Authorization includes the date of authorization and/or an expiration date.
 *
 * http://hl7.org/fhir/validityPeriod
 */
var validityPeriod = 'http://hl7.org/fhir/validityPeriod';
/**
 * ComputableLanguage
 *
 * Contract.ComputableLanguage: List of Computable Policy Rule Language Representations of this Contract.
 *
 * http://hl7.org/fhir/ComputableLanguage
 */
var ComputableLanguage = 'http://hl7.org/fhir/ComputableLanguage';
/**
 * surfaceOrientation
 *
 * BodyStructure.excludedStructure.bodyLandmarkOrientation.surfaceOrientation: The surface area a body location is in relation to a landmark.
 *
 * http://hl7.org/fhir/surfaceOrientation
 */
var surfaceOrientation = 'http://hl7.org/fhir/surfaceOrientation';
/**
 * _Provenance
 *
 * (Modified) Provenance
 *
 * http://hl7.org/fhir/_Provenance
 */
var _Provenance = 'http://hl7.org/fhir/_Provenance';
/**
 * testRun
 *
 * TestPlan.testCase.testRun: The actual test to be executed.
 *
 * http://hl7.org/fhir/testRun
 */
var testRun = 'http://hl7.org/fhir/testRun';
/**
 * SubstanceProtein
 *
 * A SubstanceProtein is defined as a single unit of a linear amino acid sequence, or a combination of subunits that are either covalently linked or have a defined invariant stoichiometric relationship. This includes all synthetic, recombinant and purified SubstanceProteins of defined sequence, whether the use is therapeutic or prophylactic. This set of elements will be used to describe albumins, coagulation factors, cytokines, growth factors, peptide/SubstanceProtein hormones, enzymes, toxins, toxoids, recombinant vaccines, and immunomodulators.
 *
 * http://hl7.org/fhir/SubstanceProtein
 */
var SubstanceProtein = 'http://hl7.org/fhir/SubstanceProtein';
/**
 * _focalDevice
 *
 * (Modified) Procedure.focalDevice
 *
 * http://hl7.org/fhir/_focalDevice
 */
var _focalDevice = 'http://hl7.org/fhir/_focalDevice';
/**
 * _operationType
 *
 * (Modified) InventoryReport.operationType
 *
 * http://hl7.org/fhir/_operationType
 */
var _operationType = 'http://hl7.org/fhir/_operationType';
/**
 * context
 *
 * Contract.term.group.asset.context: Circumstance of the asset.
 *
 * http://hl7.org/fhir/context
 */
var context = 'http://hl7.org/fhir/context';
/**
 * occurrenceDateTime
 *
 * GuidanceResponse.occurrenceDateTime: Indicates when the guidance response was processed.
 *
 * http://hl7.org/fhir/occurrenceDateTime
 */
var occurrenceDateTime = 'http://hl7.org/fhir/occurrenceDateTime';
/**
 * DetectedIssueEvidenceComponent
 *
 * DetectedIssueEvidenceComponent: Supporting evidence or manifestations that provide the basis for identifying the detected issue such as a GuidanceResponse or MeasureReport.
 *
 * http://hl7.org/fhir/DetectedIssueEvidenceComponent
 */
var DetectedIssueEvidenceComponent = 'http://hl7.org/fhir/DetectedIssueEvidenceComponent';
/**
 * _ExplanationOfBenefit
 *
 * (Modified) ExplanationOfBenefit
 *
 * http://hl7.org/fhir/_ExplanationOfBenefit
 */
var _ExplanationOfBenefit = 'http://hl7.org/fhir/_ExplanationOfBenefit';
/**
 * validated
 *
 * TestScript.metadata.capability.validated: Whether or not the test execution will validate the given capabilities of the server in order for this test script to execute.
 *
 * http://hl7.org/fhir/validated
 */
var validated = 'http://hl7.org/fhir/validated';
/**
 * _subunit
 *
 * (Modified) SubstanceProtein.subunit.subunit
 *
 * http://hl7.org/fhir/_subunit
 */
var _subunit = 'http://hl7.org/fhir/_subunit';
/**
 * EvidenceStatisticAttributeEstimateComponent
 *
 * EvidenceStatisticComponent.EvidenceStatisticAttributeEstimateComponent: A statistical attribute of the statistic such as a measure of heterogeneity.
 *
 * http://hl7.org/fhir/EvidenceStatisticAttributeEstimateComponent
 */
var EvidenceStatisticAttributeEstimateComponent = 'http://hl7.org/fhir/EvidenceStatisticAttributeEstimateComponent';
/**
 * replacedSequence
 *
 * MolecularSequence.relative.edit.replacedSequence: Allele in the starting sequence. Nucleotide(s)/amino acids from start position of sequence to stop position of sequence on the positive (+) strand of the starting sequence. When the sequence  type is DNA, it should be the sequence on the positive (+) strand. This will lay in the range between variant.start and variant.end.
 *
 * http://hl7.org/fhir/replacedSequence
 */
var replacedSequence = 'http://hl7.org/fhir/replacedSequence';
/**
 * specimen
 *
 * ObservationDefinition.specimen: The kind of specimen that this type of observation is produced on.
 *
 * http://hl7.org/fhir/specimen
 */
var specimen = 'http://hl7.org/fhir/specimen';
/**
 * rater
 *
 * Evidence.certainty.subcomponent.rater: Individual or group who did the rating.
 *
 * http://hl7.org/fhir/rater
 */
var rater = 'http://hl7.org/fhir/rater';
/**
 * relatedMedicationKnowledge
 *
 * MedicationKnowledge.relatedMedicationKnowledge: Associated or related medications. For example, if the medication is a branded product (e.g. Crestor), this is the Therapeutic Moeity (e.g. Rosuvastatin) or if this is a generic medication (e.g. Rosuvastatin), this would link to a branded product (e.g. Crestor.
 *
 * http://hl7.org/fhir/relatedMedicationKnowledge
 */
var relatedMedicationKnowledge = 'http://hl7.org/fhir/relatedMedicationKnowledge';
/**
 * lastModified
 *
 * Transport.lastModified: The date and time of last modification to this transport.
 *
 * http://hl7.org/fhir/lastModified
 */
var lastModified = 'http://hl7.org/fhir/lastModified';
/**
 * RequestOrchestrationActionParticipantComponent
 *
 * RequestOrchestrationActionComponent.RequestOrchestrationActionParticipantComponent: The participant that should perform or be responsible for this action.
 *
 * http://hl7.org/fhir/RequestOrchestrationActionParticipantComponent
 */
var RequestOrchestrationActionParticipantComponent = 'http://hl7.org/fhir/RequestOrchestrationActionParticipantComponent';
/**
 * _informationType
 *
 * (Modified) ArtifactAssessment.content.component.informationType
 *
 * http://hl7.org/fhir/_informationType
 */
var _informationType = 'http://hl7.org/fhir/_informationType';
/**
 * citation
 *
 * Citation.citedArtifact.relatesTo.citation: A bibliographic citation for the related artifact. This text SHOULD be formatted according to an accepted citation format.
 *
 * http://hl7.org/fhir/citation
 */
var citation = 'http://hl7.org/fhir/citation';
/**
 * paymentStatus
 *
 * PaymentNotice.paymentStatus: A code indicating whether payment has been sent or cleared.
 *
 * http://hl7.org/fhir/paymentStatus
 */
var paymentStatus = 'http://hl7.org/fhir/paymentStatus';
/**
 * treatment
 *
 * ClinicalUseDefinition.indication.otherTherapy.treatment: Reference to a specific medication (active substance, medicinal product or class of products, biological, food etc.) as part of an indication or contraindication.
 *
 * http://hl7.org/fhir/treatment
 */
var treatment = 'http://hl7.org/fhir/treatment';
/**
 * _initial
 *
 * (Modified) Questionnaire.item.item.initial
 *
 * http://hl7.org/fhir/_initial
 */
var _initial = 'http://hl7.org/fhir/_initial';
/**
 * priceComponent
 *
 * Invoice.lineItem.priceComponent: The price for a ChargeItem may be calculated as a base price with surcharges/deductions that apply in certain conditions. A ChargeItemDefinition resource that defines the prices, factors and conditions that apply to a billing code is currently under development. The priceComponent element can be used to offer transparency to the recipient of the Invoice as to how the prices have been calculated.
 *
 * http://hl7.org/fhir/priceComponent
 */
var priceComponent = 'http://hl7.org/fhir/priceComponent';
/**
 * _Linkage
 *
 * (Modified) Linkage
 *
 * http://hl7.org/fhir/_Linkage
 */
var _Linkage = 'http://hl7.org/fhir/_Linkage';
/**
 * _indicationGuideline
 *
 * (Modified) MedicationKnowledge.indicationGuideline
 *
 * http://hl7.org/fhir/_indicationGuideline
 */
var _indicationGuideline = 'http://hl7.org/fhir/_indicationGuideline';
/**
 * SubstanceSourceMaterial
 *
 * Source material shall capture information on the taxonomic and anatomical origins as well as the fraction of a material that can result in or can be modified to form a substance. This set of data elements shall be used to define polymer substances isolated from biological matrices. Taxonomic and anatomical origins shall be described using a controlled vocabulary as required. This information is captured for naturally derived polymers ( . starch) and structurally diverse substances. For Organisms belonging to the Kingdom Plantae the Substance level defines the fresh material of a single species or infraspecies, the Herbal Drug and the Herbal preparation. For Herbal preparations, the fraction information will be captured at the Substance information level and additional information for herbal extracts will be captured at the Specified Substance Group 1 information level. See for further explanation the Substance Class: Structurally Diverse and the herbal annex.
 *
 * http://hl7.org/fhir/SubstanceSourceMaterial
 */
var SubstanceSourceMaterial = 'http://hl7.org/fhir/SubstanceSourceMaterial';
/**
 * _conditionalRead
 *
 * (Modified) CapabilityStatement.rest.resource.conditionalRead
 *
 * http://hl7.org/fhir/_conditionalRead
 */
var _conditionalRead = 'http://hl7.org/fhir/_conditionalRead';
/**
 * managingEntity
 *
 * Subscription.managingEntity: Entity with authorization to make subsequent revisions to the Subscription and also determines what data the subscription is authorized to disclose.
 *
 * http://hl7.org/fhir/managingEntity
 */
var managingEntity = 'http://hl7.org/fhir/managingEntity';
/**
 * EvidenceVariableCharacteristicDefinitionByTypeAndValueComponent
 *
 * EvidenceVariableCharacteristicComponent.EvidenceVariableCharacteristicDefinitionByCombinationComponentCharacteristic.EvidenceVariableCharacteristicDefinitionByTypeAndValueComponent: Defines the characteristic using both a type and value[x] elements.
 *
 * http://hl7.org/fhir/EvidenceVariableCharacteristicDefinitionByTypeAndValueComponent
 */
var EvidenceVariableCharacteristicDefinitionByTypeAndValueComponent = 'http://hl7.org/fhir/EvidenceVariableCharacteristicDefinitionByTypeAndValueComponent';
/**
 * operationalStatus
 *
 * Location.operationalStatus: The operational status covers operation values most relevant to beds (but can also apply to rooms/units/chairs/etc. such as an isolation unit/dialysis chair). This typically covers concepts such as contamination, housekeeping, and other activities like maintenance.
 *
 * http://hl7.org/fhir/operationalStatus
 */
var operationalStatus = 'http://hl7.org/fhir/operationalStatus';
/**
 * _module
 *
 * (Modified) GuidanceResponse.module
 *
 * http://hl7.org/fhir/_module
 */
var _module = 'http://hl7.org/fhir/_module';
/**
 * MedicationAdministration
 *
 * Describes the event of a patient consuming or otherwise being administered a medication.  This may be as simple as swallowing a tablet or it may be a long running infusion. Related resources tie this event to the authorizing prescription, and the specific encounter between patient and health care practitioner. This event can also be used to record waste using a status of not-done and the appropriate statusReason.
 *
 * http://hl7.org/fhir/MedicationAdministration
 */
var MedicationAdministration = 'http://hl7.org/fhir/MedicationAdministration';
/**
 * UdiDeviceIdentifierMarketDistribution
 *
 * DeviceDefinitionPackagingComponentPackagingUdiDeviceIdentifier.UdiDeviceIdentifierMarketDistribution: Indicates where and when the device is available on the market.
 *
 * http://hl7.org/fhir/UdiDeviceIdentifierMarketDistribution
 */
var UdiDeviceIdentifierMarketDistribution = 'http://hl7.org/fhir/UdiDeviceIdentifierMarketDistribution';
/**
 * _probability
 *
 * (Modified) RiskAssessment.prediction.probability
 *
 * http://hl7.org/fhir/_probability
 */
var _probability = 'http://hl7.org/fhir/_probability';
/**
 * clinicalRecommendationStatement
 *
 * Measure.clinicalRecommendationStatement: Provides a summary of relevant clinical guidelines or other clinical recommendations supporting the measure.
 *
 * http://hl7.org/fhir/clinicalRecommendationStatement
 */
var clinicalRecommendationStatement = 'http://hl7.org/fhir/clinicalRecommendationStatement';
/**
 * _image
 *
 * (Modified) ImplementationGuide.manifest.image
 *
 * http://hl7.org/fhir/_image
 */
var _image = 'http://hl7.org/fhir/_image';
/**
 * SubscriptionTopicNotificationShapeComponent
 *
 * SubscriptionTopicNotificationShapeComponent: List of properties to describe the shape (e.g., resources) included in notifications from this Subscription Topic.
 *
 * http://hl7.org/fhir/SubscriptionTopicNotificationShapeComponent
 */
var SubscriptionTopicNotificationShapeComponent = 'http://hl7.org/fhir/SubscriptionTopicNotificationShapeComponent';
/**
 * _componentPart
 *
 * (Modified) PackagedProductDefinition.packaging.packaging.componentPart
 *
 * http://hl7.org/fhir/_componentPart
 */
var _componentPart = 'http://hl7.org/fhir/_componentPart';
/**
 * op
 *
 * ValueSet.compose.exclude.filter.op: The kind of operation to perform as a part of the filter criteria.
 *
 * http://hl7.org/fhir/op
 */
var op = 'http://hl7.org/fhir/op';
/**
 * _processingFacility
 *
 * (Modified) BiologicallyDerivedProduct.processingFacility
 *
 * http://hl7.org/fhir/_processingFacility
 */
var _processingFacility = 'http://hl7.org/fhir/_processingFacility';
/**
 * unit
 *
 * Quantity.unit: A human-readable form of the unit.
 *
 * http://hl7.org/fhir/unit
 */
var unit = 'http://hl7.org/fhir/unit';
/**
 * _problem
 *
 * (Modified) ClinicalImpression.problem
 *
 * http://hl7.org/fhir/_problem
 */
var _problem = 'http://hl7.org/fhir/_problem';
/**
 * SubstanceDefinitionPropertyComponent
 *
 * SubstanceDefinitionPropertyComponent: General specifications for this substance.
 *
 * http://hl7.org/fhir/SubstanceDefinitionPropertyComponent
 */
var SubstanceDefinitionPropertyComponent = 'http://hl7.org/fhir/SubstanceDefinitionPropertyComponent';
/**
 * _fluidConsistencyType
 *
 * (Modified) NutritionOrder.oralDiet.fluidConsistencyType
 *
 * http://hl7.org/fhir/_fluidConsistencyType
 */
var _fluidConsistencyType = 'http://hl7.org/fhir/_fluidConsistencyType';
/**
 * _SubstancePolymer
 *
 * (Modified) SubstancePolymer
 *
 * http://hl7.org/fhir/_SubstancePolymer
 */
var _SubstancePolymer = 'http://hl7.org/fhir/_SubstancePolymer';
/**
 * ValueSetComposeIncludeConceptDesignationComponent
 *
 * ValueSetComposeComponent.ConceptSet.ConceptReference.ValueSetComposeIncludeConceptDesignationComponent: Additional representations for this concept when used in this value set - other languages, aliases, specialized purposes, used for particular purposes, etc.
 *
 * http://hl7.org/fhir/ValueSetComposeIncludeConceptDesignationComponent
 */
var ValueSetComposeIncludeConceptDesignationComponent = 'http://hl7.org/fhir/ValueSetComposeIncludeConceptDesignationComponent';
/**
 * versionReference
 *
 * ExampleScenario.process.step.alternative.step.process.step.operation.request.versionReference: A reference to the key of a specific version of an instance in this instance.
 *
 * http://hl7.org/fhir/versionReference
 */
var versionReference = 'http://hl7.org/fhir/versionReference';
/**
 * _maxSingleDose
 *
 * (Modified) AdministrableProductDefinition.routeOfAdministration.maxSingleDose
 *
 * http://hl7.org/fhir/_maxSingleDose
 */
var _maxSingleDose = 'http://hl7.org/fhir/_maxSingleDose';
/**
 * meaning
 *
 * Permission.rule.data.resource.meaning: How the resource reference is interpreted when testing consent restrictions.
 *
 * http://hl7.org/fhir/meaning
 */
var meaning = 'http://hl7.org/fhir/meaning';
/**
 * measurementPoint
 *
 * Ingredient.substance.strength.referenceStrength.measurementPoint: For when strength is measured at a particular point or distance.
 *
 * http://hl7.org/fhir/measurementPoint
 */
var measurementPoint = 'http://hl7.org/fhir/measurementPoint';
/**
 * diagnosisRelatedGroup
 *
 * ExplanationOfBenefit.diagnosisRelatedGroup: A package billing code or bundle code used to group products and services to a particular health condition (such as heart attack) which is based on a predetermined grouping code system.
 *
 * http://hl7.org/fhir/diagnosisRelatedGroup
 */
var diagnosisRelatedGroup = 'http://hl7.org/fhir/diagnosisRelatedGroup';
/**
 * _relative
 *
 * (Modified) MolecularSequence.relative
 *
 * http://hl7.org/fhir/_relative
 */
var _relative = 'http://hl7.org/fhir/_relative';
/**
 * _publicationForm
 *
 * (Modified) Citation.citedArtifact.publicationForm
 *
 * http://hl7.org/fhir/_publicationForm
 */
var _publicationForm = 'http://hl7.org/fhir/_publicationForm';
/**
 * _Patient
 *
 * (Modified) Patient
 *
 * http://hl7.org/fhir/_Patient
 */
var _Patient = 'http://hl7.org/fhir/_Patient';
/**
 * GuidanceResponse
 *
 * A guidance response is the formal response to a guidance request, including any output parameters returned by the evaluation, as well as the description of any proposed actions to be taken.
 *
 * http://hl7.org/fhir/GuidanceResponse
 */
var GuidanceResponse = 'http://hl7.org/fhir/GuidanceResponse';
/**
 * entity
 *
 * Contract.term.asset.valuedItem.entity
 *
 * http://hl7.org/fhir/entity
 */
var entity = 'http://hl7.org/fhir/entity';
/**
 * sourceReference
 *
 * Consent.sourceReference: A reference to a consent that links back to such a source, a reference to a document repository (e.g. XDS) that stores the original consent document.
 *
 * http://hl7.org/fhir/sourceReference
 */
var sourceReference = 'http://hl7.org/fhir/sourceReference';
/**
 * valueFilter
 *
 * DataRequirement.valueFilter: Value filters specify additional constraints on the data for elements other than code-valued or date-valued. Each value filter specifies an additional constraint on the data (i.e. valueFilters are AND'ed, not OR'ed).
 *
 * http://hl7.org/fhir/valueFilter
 */
var valueFilter = 'http://hl7.org/fhir/valueFilter';
/**
 * _useBy
 *
 * (Modified) NutritionProduct.instance.useBy
 *
 * http://hl7.org/fhir/_useBy
 */
var _useBy = 'http://hl7.org/fhir/_useBy';
/**
 * bodyLandmarkOrientation
 *
 * BodyStructure.excludedStructure.bodyLandmarkOrientation: Body locations in relation to a specific body landmark (tatoo, scar, other body structure).
 *
 * http://hl7.org/fhir/bodyLandmarkOrientation
 */
var bodyLandmarkOrientation = 'http://hl7.org/fhir/bodyLandmarkOrientation';
/**
 * SubstanceDefinitionNameComponentName
 *
 * A synonym of this particular name, by which the substance is also known.
 *
 * http://hl7.org/fhir/SubstanceDefinitionNameComponentName
 */
var SubstanceDefinitionNameComponentName = 'http://hl7.org/fhir/SubstanceDefinitionNameComponentName';
/**
 * _policyText
 *
 * (Modified) Consent.policyText
 *
 * http://hl7.org/fhir/_policyText
 */
var _policyText = 'http://hl7.org/fhir/_policyText';
/**
 * _changePattern
 *
 * (Modified) ClinicalImpression.changePattern
 *
 * http://hl7.org/fhir/_changePattern
 */
var _changePattern = 'http://hl7.org/fhir/_changePattern';
/**
 * subDetail
 *
 * ExplanationOfBenefit.item.detail.subDetail: Third-tier of goods and services.
 *
 * http://hl7.org/fhir/subDetail
 */
var subDetail = 'http://hl7.org/fhir/subDetail';
/**
 * allDay
 *
 * Availability.availableTime.allDay: Always available? i.e. 24 hour service.
 *
 * http://hl7.org/fhir/allDay
 */
var allDay = 'http://hl7.org/fhir/allDay';
/**
 * _modification
 *
 * (Modified) SubstancePolymer.modification
 *
 * http://hl7.org/fhir/_modification
 */
var _modification = 'http://hl7.org/fhir/_modification';
/**
 * _nodeId
 *
 * (Modified) GraphDefinition.node.nodeId
 *
 * http://hl7.org/fhir/_nodeId
 */
var _nodeId = 'http://hl7.org/fhir/_nodeId';
/**
 * AdverseEventContributingFactorComponent
 *
 * AdverseEventContributingFactorComponent: The contributing factors suspected to have increased the probability or severity of the adverse event.
 *
 * http://hl7.org/fhir/AdverseEventContributingFactorComponent
 */
var AdverseEventContributingFactorComponent = 'http://hl7.org/fhir/AdverseEventContributingFactorComponent';
/**
 * TestPlanTestCaseComponent
 *
 * TestPlanTestCaseComponent: The individual test cases that are part of this plan, when they they are made explicit.
 *
 * http://hl7.org/fhir/TestPlanTestCaseComponent
 */
var TestPlanTestCaseComponent = 'http://hl7.org/fhir/TestPlanTestCaseComponent';
/**
 * sunday
 *
 * Appointment.recurrenceTemplate.weeklyTemplate.sunday: Indicates that recurring appointments should occur on Sundays.
 *
 * http://hl7.org/fhir/sunday
 */
var sunday = 'http://hl7.org/fhir/sunday';
/**
 * cancellationReason
 *
 * Appointment.cancellationReason: The coded reason for the appointment being cancelled. This is often used in reporting/billing/futher processing to determine if further actions are required, or specific fees apply.
 *
 * http://hl7.org/fhir/cancellationReason
 */
var cancellationReason = 'http://hl7.org/fhir/cancellationReason';
/**
 * _title
 *
 * (Modified) ExampleScenario.process.step.process.step.alternative.step.operation.title
 *
 * http://hl7.org/fhir/_title
 */
var _title = 'http://hl7.org/fhir/_title';
/**
 * _sourceId
 *
 * (Modified) OperationDefinition.parameter.referencedFrom.sourceId
 *
 * http://hl7.org/fhir/_sourceId
 */
var _sourceId = 'http://hl7.org/fhir/_sourceId';
/**
 * _entityRelatedness
 *
 * (Modified) AdverseEvent.suspectEntity.causality.entityRelatedness
 *
 * http://hl7.org/fhir/_entityRelatedness
 */
var _entityRelatedness = 'http://hl7.org/fhir/_entityRelatedness';
/**
 * line
 *
 * Address.line: This component contains the house number, apartment number, street name, street direction,  P.O. Box number, delivery hints, and similar address information.
 *
 * http://hl7.org/fhir/line
 */
var line = 'http://hl7.org/fhir/line';
/**
 * _effectivePeriod
 *
 * (Modified) PlanDefinition.effectivePeriod
 *
 * http://hl7.org/fhir/_effectivePeriod
 */
var _effectivePeriod = 'http://hl7.org/fhir/_effectivePeriod';
/**
 * preAuthRef
 *
 * ClaimResponse.preAuthRef: Reference from the Insurer which is used in later communications which refers to this adjudication.
 *
 * http://hl7.org/fhir/preAuthRef
 */
var preAuthRef = 'http://hl7.org/fhir/preAuthRef';
/**
 * requestId
 *
 * TestScript.teardown.action.operation.requestId: The fixture id (maybe new) to map to the request.
 *
 * http://hl7.org/fhir/requestId
 */
var requestId = 'http://hl7.org/fhir/requestId';
/**
 * _autodelete
 *
 * (Modified) TestScript.fixture.autodelete
 *
 * http://hl7.org/fhir/_autodelete
 */
var _autodelete = 'http://hl7.org/fhir/_autodelete';
/**
 * _fundsReserve
 *
 * (Modified) ExplanationOfBenefit.fundsReserve
 *
 * http://hl7.org/fhir/_fundsReserve
 */
var _fundsReserve = 'http://hl7.org/fhir/_fundsReserve';
/**
 * BundleEntryComponentLink
 *
 * A series of links that provide context to this entry.
 *
 * http://hl7.org/fhir/BundleEntryComponentLink
 */
var BundleEntryComponentLink = 'http://hl7.org/fhir/BundleEntryComponentLink';
/**
 * DocumentReferenceContentComponent
 *
 * DocumentReferenceContentComponent: The document and format referenced.  If there are multiple content element repetitions, these must all represent the same document in different format, or attachment metadata.
 *
 * http://hl7.org/fhir/DocumentReferenceContentComponent
 */
var DocumentReferenceContentComponent = 'http://hl7.org/fhir/DocumentReferenceContentComponent';
/**
 * _holder
 *
 * (Modified) RegulatedAuthorization.holder
 *
 * http://hl7.org/fhir/_holder
 */
var _holder = 'http://hl7.org/fhir/_holder';
/**
 * _qualifiers
 *
 * (Modified) InsurancePlan.plan.specificCost.benefit.cost.qualifiers
 *
 * http://hl7.org/fhir/_qualifiers
 */
var _qualifiers = 'http://hl7.org/fhir/_qualifiers';
/**
 * _Specimen
 *
 * (Modified) Specimen
 *
 * http://hl7.org/fhir/_Specimen
 */
var _Specimen = 'http://hl7.org/fhir/_Specimen';
/**
 * CodeSystemFilterComponent
 *
 * CodeSystemFilterComponent: A filter that can be used in a value set compose statement when selecting concepts using a filter.
 *
 * http://hl7.org/fhir/CodeSystemFilterComponent
 */
var CodeSystemFilterComponent = 'http://hl7.org/fhir/CodeSystemFilterComponent';
/**
 * _replacementSequence
 *
 * (Modified) MolecularSequence.relative.edit.replacementSequence
 *
 * http://hl7.org/fhir/_replacementSequence
 */
var _replacementSequence = 'http://hl7.org/fhir/_replacementSequence';
/**
 * serviceCategory
 *
 * Slot.serviceCategory: A broad categorization of the service that is to be performed during this appointment.
 *
 * http://hl7.org/fhir/serviceCategory
 */
var serviceCategory = 'http://hl7.org/fhir/serviceCategory';
/**
 * _next
 *
 * (Modified) ValueSet.expansion.next
 *
 * http://hl7.org/fhir/_next
 */
var _next = 'http://hl7.org/fhir/_next';
/**
 * paymentTerms
 *
 * Invoice.paymentTerms: Payment details such as banking details, period of payment, deductibles, methods of payment.
 *
 * http://hl7.org/fhir/paymentTerms
 */
var paymentTerms = 'http://hl7.org/fhir/paymentTerms';
/**
 * _started
 *
 * (Modified) ImagingStudy.series.started
 *
 * http://hl7.org/fhir/_started
 */
var _started = 'http://hl7.org/fhir/_started';
/**
 * offer
 *
 * Contract.term.group.offer: The matter of concern in the context of this provision of the agrement.
 *
 * http://hl7.org/fhir/offer
 */
var offer = 'http://hl7.org/fhir/offer';
/**
 * coordinateSystem
 *
 * MolecularSequence.relative.coordinateSystem: These are different ways of identifying nucleotides or amino acids within a sequence. Different databases and file types may use different systems. For detail definitions, see https://loinc.org/92822-6/ for more detail.
 *
 * http://hl7.org/fhir/coordinateSystem
 */
var coordinateSystem = 'http://hl7.org/fhir/coordinateSystem';
/**
 * DeviceDefinition
 *
 * This is a specialized resource that defines the characteristics and capabilities of a device.
 *
 * http://hl7.org/fhir/DeviceDefinition
 */
var DeviceDefinition = 'http://hl7.org/fhir/DeviceDefinition';
/**
 * _intent
 *
 * (Modified) RequestOrchestration.intent
 *
 * http://hl7.org/fhir/_intent
 */
var _intent = 'http://hl7.org/fhir/_intent';
/**
 * _text
 *
 * (Modified) QuestionnaireResponse.item.item.text
 *
 * http://hl7.org/fhir/_text
 */
var _text = 'http://hl7.org/fhir/_text';
/**
 * _level
 *
 * (Modified) Evidence.statistic.modelCharacteristic.attributeEstimate.level
 *
 * http://hl7.org/fhir/_level
 */
var _level = 'http://hl7.org/fhir/_level';
/**
 * facility
 *
 * CoverageEligibilityRequest.item.facility: Facility where the services will be provided.
 *
 * http://hl7.org/fhir/facility
 */
var facility = 'http://hl7.org/fhir/facility';
/**
 * qualifiedValue
 *
 * ObservationDefinition.component.qualifiedValue: A set of qualified values associated with a context and a set of conditions -  provides a range for quantitative and ordinal observations and a collection of value sets for qualitative observations.
 *
 * http://hl7.org/fhir/qualifiedValue
 */
var qualifiedValue = 'http://hl7.org/fhir/qualifiedValue';
/**
 * ManifestResource
 *
 * ImplementationGuideManifestComponent.ManifestResource: A resource that is part of the implementation guide. Conformance resources (value set, structure definition, capability statements etc.) are obvious candidates for inclusion, but any kind of resource can be included as an example resource.
 *
 * http://hl7.org/fhir/ManifestResource
 */
var ManifestResource = 'http://hl7.org/fhir/ManifestResource';
/**
 * prism
 *
 * VisionPrescription.lensSpecification.prism: Allows for adjustment on two axis.
 *
 * http://hl7.org/fhir/prism
 */
var prism = 'http://hl7.org/fhir/prism';
/**
 * MedicationBatchComponent
 *
 * MedicationBatchComponent: Information that only applies to packages (not products).
 *
 * http://hl7.org/fhir/MedicationBatchComponent
 */
var MedicationBatchComponent = 'http://hl7.org/fhir/MedicationBatchComponent';
/**
 * resultForDelete
 *
 * SubscriptionTopic.resourceTrigger.queryCriteria.resultForDelete: For 'delete' interactions, should the 'current' query criteria count as an automatic pass or an automatic fail. If not present, the testing behavior during `delete` interactions is unspecified (server discretion).
 *
 * http://hl7.org/fhir/resultForDelete
 */
var resultForDelete = 'http://hl7.org/fhir/resultForDelete';
/**
 * _accept
 *
 * (Modified) TestScript.teardown.action.operation.accept
 *
 * http://hl7.org/fhir/_accept
 */
var _accept = 'http://hl7.org/fhir/_accept';
/**
 * overbooked
 *
 * Slot.overbooked: This slot has already been overbooked, appointments are unlikely to be accepted for this time.
 *
 * http://hl7.org/fhir/overbooked
 */
var overbooked = 'http://hl7.org/fhir/overbooked';
/**
 * _plan
 *
 * (Modified) InsurancePlan.plan
 *
 * http://hl7.org/fhir/_plan
 */
var _plan = 'http://hl7.org/fhir/_plan';
/**
 * ReviewOutcome
 *
 * ClaimResponse.Item.ReviewOutcome: The high-level results of the adjudication if adjudication has been performed.
 *
 * http://hl7.org/fhir/ReviewOutcome
 */
var ReviewOutcome = 'http://hl7.org/fhir/ReviewOutcome';
/**
 * CitationCitedArtifactContributorshipEntryComponent
 *
 * CitationCitedArtifactComponent.CitationCitedArtifactContributorshipComponent.CitationCitedArtifactContributorshipEntryComponent: An individual entity named as a contributor, for example in the author list or contributor list.
 *
 * http://hl7.org/fhir/CitationCitedArtifactContributorshipEntryComponent
 */
var CitationCitedArtifactContributorshipEntryComponent = 'http://hl7.org/fhir/CitationCitedArtifactContributorshipEntryComponent';
/**
 * discriminator
 *
 * ElementDefinition.slicing.discriminator: Designates which child elements are used to discriminate between the slices when processing an instance. If one or more discriminators are provided, the value of the child elements in the instance data SHALL completely distinguish which slice the element in the resource matches based on the allowed values for those elements in each of the slices.
 *
 * http://hl7.org/fhir/discriminator
 */
var discriminator = 'http://hl7.org/fhir/discriminator';
/**
 * ordered
 *
 * ElementDefinition.slicing.ordered: If the matching elements have to occur in the same order as defined in the profile.
 *
 * http://hl7.org/fhir/ordered
 */
var ordered = 'http://hl7.org/fhir/ordered';
/**
 * LegalLanguage
 *
 * Contract.LegalLanguage: List of Legal expressions or representations of this Contract.
 *
 * http://hl7.org/fhir/LegalLanguage
 */
var LegalLanguage = 'http://hl7.org/fhir/LegalLanguage';
/**
 * frequencyOfOccurrence
 *
 * ClinicalUseDefinition.undesirableEffect.frequencyOfOccurrence: How often the effect is seen.
 *
 * http://hl7.org/fhir/frequencyOfOccurrence
 */
var frequencyOfOccurrence = 'http://hl7.org/fhir/frequencyOfOccurrence';
/**
 * _validationType
 *
 * (Modified) VerificationResult.validationType
 *
 * http://hl7.org/fhir/_validationType
 */
var _validationType = 'http://hl7.org/fhir/_validationType';
/**
 * PermissionRuleDataComponent
 *
 * Permission.Rule.PermissionRuleDataComponent: A description or definition of which activities are allowed to be done on the data.
 *
 * http://hl7.org/fhir/PermissionRuleDataComponent
 */
var PermissionRuleDataComponent = 'http://hl7.org/fhir/PermissionRuleDataComponent';
/**
 * _versionNeeded
 *
 * (Modified) CodeSystem.versionNeeded
 *
 * http://hl7.org/fhir/_versionNeeded
 */
var _versionNeeded = 'http://hl7.org/fhir/_versionNeeded';
/**
 * PackagedProductDefinitionPackagingContainedItemComponent
 *
 * PackagedProductDefinitionPackagingComponent.PackagedProductDefinitionPackagingContainedItemComponent: The item(s) within the packaging.
 *
 * http://hl7.org/fhir/PackagedProductDefinitionPackagingContainedItemComponent
 */
var PackagedProductDefinitionPackagingContainedItemComponent = 'http://hl7.org/fhir/PackagedProductDefinitionPackagingContainedItemComponent';
/**
 * predecessor
 *
 * TestPlan.testCase.dependency.predecessor: Link to predecessor test plans.
 *
 * http://hl7.org/fhir/predecessor
 */
var predecessor = 'http://hl7.org/fhir/predecessor';
/**
 * ArtifactAssessment
 *
 * This Resource provides one or more comments, classifiers or ratings about a Resource and supports attribution and rights management metadata for the added content.
 *
 * http://hl7.org/fhir/ArtifactAssessment
 */
var ArtifactAssessment = 'http://hl7.org/fhir/ArtifactAssessment';
/**
 * _dependsOn
 *
 * (Modified) ImplementationGuide.dependsOn
 *
 * http://hl7.org/fhir/_dependsOn
 */
var _dependsOn = 'http://hl7.org/fhir/_dependsOn';
/**
 * evidence
 *
 * Condition.evidence: Supporting evidence / manifestations that are the basis of the Condition's verification status, such as evidence that confirmed or refuted the condition.
 *
 * http://hl7.org/fhir/evidence
 */
var evidence = 'http://hl7.org/fhir/evidence';
/**
 * MeasureGroupPopulationComponent
 *
 * MeasureGroupComponent.MeasureGroupPopulationComponent: A population criteria for the measure.
 *
 * http://hl7.org/fhir/MeasureGroupPopulationComponent
 */
var MeasureGroupPopulationComponent = 'http://hl7.org/fhir/MeasureGroupPopulationComponent';
/**
 * opticalActivity
 *
 * SubstanceDefinition.structure.opticalActivity: Optical activity type.
 *
 * http://hl7.org/fhir/opticalActivity
 */
var opticalActivity = 'http://hl7.org/fhir/opticalActivity';
/**
 * nutritionProduct
 *
 * NutritionIntake.consumedItem.nutritionProduct: Identifies the food or fluid product that was consumed. This is potentially a link to a resource representing the details of the food product (TBD) or a simple attribute carrying a code that identifies the food from a known list of foods.
 *
 * http://hl7.org/fhir/nutritionProduct
 */
var nutritionProduct = 'http://hl7.org/fhir/nutritionProduct';
/**
 * specialMeasures
 *
 * MedicinalProductDefinition.specialMeasures: Whether the Medicinal Product is subject to special measures for regulatory reasons, such as a requirement to conduct post-authorization studies.
 *
 * http://hl7.org/fhir/specialMeasures
 */
var specialMeasures = 'http://hl7.org/fhir/specialMeasures';
/**
 * packageId
 *
 * ImplementationGuide.dependsOn.packageId: The NPM package name for the Implementation Guide that this IG depends on.
 *
 * http://hl7.org/fhir/packageId
 */
var packageId = 'http://hl7.org/fhir/packageId';
/**
 * TerminologyCapabilitiesCodeSystemVersionFilterComponent
 *
 * TerminologyCapabilitiesCodeSystemComponent.TerminologyCapabilitiesCodeSystemVersionComponent.TerminologyCapabilitiesCodeSystemVersionFilterComponent: Filter Properties supported.
 *
 * http://hl7.org/fhir/TerminologyCapabilitiesCodeSystemVersionFilterComponent
 */
var TerminologyCapabilitiesCodeSystemVersionFilterComponent = 'http://hl7.org/fhir/TerminologyCapabilitiesCodeSystemVersionFilterComponent';
/**
 * SubDetail
 *
 * ExplanationOfBenefit.Item.Detail.SubDetail: Third-tier of goods and services.
 *
 * http://hl7.org/fhir/SubDetail
 */
var SubDetail = 'http://hl7.org/fhir/SubDetail';
/**
 * _received
 *
 * (Modified) Communication.received
 *
 * http://hl7.org/fhir/_received
 */
var _received = 'http://hl7.org/fhir/_received';
/**
 * CapabilityStatementDocumentComponent
 *
 * CapabilityStatementDocumentComponent: A document definition.
 *
 * http://hl7.org/fhir/CapabilityStatementDocumentComponent
 */
var CapabilityStatementDocumentComponent = 'http://hl7.org/fhir/CapabilityStatementDocumentComponent';
/**
 * observationResultRequirement
 *
 * ActivityDefinition.observationResultRequirement: Defines the observations that are expected to be produced by the action.
 *
 * http://hl7.org/fhir/observationResultRequirement
 */
var observationResultRequirement = 'http://hl7.org/fhir/observationResultRequirement';
/**
 * FriendlyLanguage
 *
 * Contract.FriendlyLanguage: The "patient friendly language" versionof the Contract in whole or in parts. "Patient friendly language" means the representation of the Contract and Contract Provisions in a manner that is readily accessible and understandable by a layperson in accordance with best practices for communication styles that ensure that those agreeing to or signing the Contract understand the roles, actions, obligations, responsibilities, and implication of the agreement.
 *
 * http://hl7.org/fhir/FriendlyLanguage
 */
var FriendlyLanguage = 'http://hl7.org/fhir/FriendlyLanguage';
/**
 * _observedGroup
 *
 * (Modified) ResearchStudy.comparisonGroup.observedGroup
 *
 * http://hl7.org/fhir/_observedGroup
 */
var _observedGroup = 'http://hl7.org/fhir/_observedGroup';
/**
 * cancelledReason
 *
 * Invoice.cancelledReason: In case of Invoice cancellation a reason must be given (entered in error, superseded by corrected invoice etc.).
 *
 * http://hl7.org/fhir/cancelledReason
 */
var cancelledReason = 'http://hl7.org/fhir/cancelledReason';
/**
 * _expirationType
 *
 * (Modified) Contract.expirationType
 *
 * http://hl7.org/fhir/_expirationType
 */
var _expirationType = 'http://hl7.org/fhir/_expirationType';
/**
 * _actualNumber
 *
 * (Modified) ResearchStudy.recruitment.actualNumber
 *
 * http://hl7.org/fhir/_actualNumber
 */
var _actualNumber = 'http://hl7.org/fhir/_actualNumber';
/**
 * derivation
 *
 * StructureDefinition.derivation: How the type relates to the baseDefinition.
 *
 * http://hl7.org/fhir/derivation
 */
var derivation = 'http://hl7.org/fhir/derivation';
/**
 * AdverseEventSuspectEntityComponent
 *
 * AdverseEventSuspectEntityComponent: Describes the entity that is suspected to have caused the adverse event.
 *
 * http://hl7.org/fhir/AdverseEventSuspectEntityComponent
 */
var AdverseEventSuspectEntityComponent = 'http://hl7.org/fhir/AdverseEventSuspectEntityComponent';
/**
 * ImmunizationRecommendation
 *
 * A patient's point-in-time set of recommendations (i.e. forecasting) according to a published schedule with optional supporting justification.
 *
 * http://hl7.org/fhir/ImmunizationRecommendation
 */
var ImmunizationRecommendation = 'http://hl7.org/fhir/ImmunizationRecommendation';
/**
 * _BiologicallyDerivedProductDispense
 *
 * (Modified) BiologicallyDerivedProductDispense
 *
 * http://hl7.org/fhir/_BiologicallyDerivedProductDispense
 */
var _BiologicallyDerivedProductDispense = 'http://hl7.org/fhir/_BiologicallyDerivedProductDispense';
/**
 * _definitionId
 *
 * (Modified) EvidenceVariable.characteristic.definitionByCombination.characteristic.definitionId
 *
 * http://hl7.org/fhir/_definitionId
 */
var _definitionId = 'http://hl7.org/fhir/_definitionId';
/**
 * _authoredOn
 *
 * (Modified) ServiceRequest.authoredOn
 *
 * http://hl7.org/fhir/_authoredOn
 */
var _authoredOn = 'http://hl7.org/fhir/_authoredOn';
/**
 * keyword
 *
 * StructureDefinition.keyword: (DEPRECATED) A set of key words or terms from external terminologies that may be used to assist with indexing and searching of templates nby describing the use of this structure definition, or the content it describes.
 *
 * http://hl7.org/fhir/keyword
 */
var keyword = 'http://hl7.org/fhir/keyword';
/**
 * characteristic
 *
 * PackagedProductDefinition.characteristic: Allows the key features to be recorded, such as "hospital pack", "nurse prescribable", "calendar pack".
 *
 * http://hl7.org/fhir/characteristic
 */
var characteristic = 'http://hl7.org/fhir/characteristic';
/**
 * _note
 *
 * (Modified) List.note
 *
 * http://hl7.org/fhir/_note
 */
var _note = 'http://hl7.org/fhir/_note';
/**
 * ImagingStudySeriesInstanceComponent
 *
 * ImagingStudySeriesComponent.ImagingStudySeriesInstanceComponent: A single SOP instance within the series, e.g. an image, or presentation state.
 *
 * http://hl7.org/fhir/ImagingStudySeriesInstanceComponent
 */
var ImagingStudySeriesInstanceComponent = 'http://hl7.org/fhir/ImagingStudySeriesInstanceComponent';
/**
 * _signature
 *
 * (Modified) Provenance.signature
 *
 * http://hl7.org/fhir/_signature
 */
var _signature = 'http://hl7.org/fhir/_signature';
/**
 * slicing
 *
 * ElementDefinition.slicing: Indicates that the element is sliced into a set of alternative definitions (i.e. in a structure definition, there are multiple different constraints on a single element in the base resource). Slicing can be used in any resource that has cardinality ..* on the base resource, or any resource with a choice of types. The set of slices is any elements that come after this in the element sequence that have the same path, until a shorter path occurs (the shorter path terminates the set).
 *
 * http://hl7.org/fhir/slicing
 */
var slicing = 'http://hl7.org/fhir/slicing';
/**
 * _population
 *
 * (Modified) MeasureReport.group.stratifier.stratum.population
 *
 * http://hl7.org/fhir/_population
 */
var _population = 'http://hl7.org/fhir/_population';
/**
 * cap
 *
 * SpecimenDefinition.typeTested.container.cap: Color of container cap.
 *
 * http://hl7.org/fhir/cap
 */
var cap = 'http://hl7.org/fhir/cap';
/**
 * given
 *
 * HumanName.given: Given name.
 *
 * http://hl7.org/fhir/given
 */
var given = 'http://hl7.org/fhir/given';
/**
 * account
 *
 * Account.relatedAccount.account: Reference to an associated Account.
 *
 * http://hl7.org/fhir/account
 */
var account = 'http://hl7.org/fhir/account';
/**
 * _organism
 *
 * (Modified) SubstanceSourceMaterial.organism
 *
 * http://hl7.org/fhir/_organism
 */
var _organism = 'http://hl7.org/fhir/_organism';
/**
 * _need
 *
 * (Modified) VerificationResult.need
 *
 * http://hl7.org/fhir/_need
 */
var _need = 'http://hl7.org/fhir/_need';
/**
 * environmentalSetting
 *
 * MedicationKnowledge.storageGuideline.environmentalSetting: Describes a setting/value on the environment for the adequate storage of the medication and other substances.  Environment settings may involve temperature, humidity, or exposure to light.
 *
 * http://hl7.org/fhir/environmentalSetting
 */
var environmentalSetting = 'http://hl7.org/fhir/environmentalSetting';
/**
 * volume
 *
 * Citation.citedArtifact.publicationForm.volume: Volume number of journal or other collection in which the article is published.
 *
 * http://hl7.org/fhir/volume
 */
var volume = 'http://hl7.org/fhir/volume';
/**
 * weeklyTemplate
 *
 * Appointment.recurrenceTemplate.weeklyTemplate: Information about weekly recurring appointments.
 *
 * http://hl7.org/fhir/weeklyTemplate
 */
var weeklyTemplate = 'http://hl7.org/fhir/weeklyTemplate';
/**
 * lowerLimit
 *
 * SampledData.lowerLimit: The lower limit of detection of the measured points. This is needed if any of the data points have the value "L" (lower than detection limit).
 *
 * http://hl7.org/fhir/lowerLimit
 */
var lowerLimit = 'http://hl7.org/fhir/lowerLimit';
/**
 * _justification
 *
 * (Modified) Permission.justification
 *
 * http://hl7.org/fhir/_justification
 */
var _justification = 'http://hl7.org/fhir/_justification';
/**
 * _fixture
 *
 * (Modified) TestScript.fixture
 *
 * http://hl7.org/fhir/_fixture
 */
var _fixture = 'http://hl7.org/fhir/_fixture';
/**
 * unitPriceComponent
 *
 * ChargeItem.unitPriceComponent: The unit price of the chargable item.
 *
 * http://hl7.org/fhir/unitPriceComponent
 */
var unitPriceComponent = 'http://hl7.org/fhir/unitPriceComponent';
/**
 * availabilityStatus
 *
 * Device.availabilityStatus: The availability of the device.
 *
 * http://hl7.org/fhir/availabilityStatus
 */
var availabilityStatus = 'http://hl7.org/fhir/availabilityStatus';
/**
 * _proxySignature
 *
 * (Modified) VerificationResult.attestation.proxySignature
 *
 * http://hl7.org/fhir/_proxySignature
 */
var _proxySignature = 'http://hl7.org/fhir/_proxySignature';
/**
 * statusChanged
 *
 * MedicationRequest.statusChanged: The date (and perhaps time) when the status was changed.
 *
 * http://hl7.org/fhir/statusChanged
 */
var statusChanged = 'http://hl7.org/fhir/statusChanged';
/**
 * _about
 *
 * (Modified) CommunicationRequest.about
 *
 * http://hl7.org/fhir/_about
 */
var _about = 'http://hl7.org/fhir/_about';
/**
 * occurence
 *
 * MedicationAdministration.occurence
 *
 * http://hl7.org/fhir/occurence
 */
var occurence = 'http://hl7.org/fhir/occurence';
/**
 * actualPeriod
 *
 * EncounterHistory.actualPeriod: The start and end time associated with this set of values associated with the encounter, may be different to the planned times for various reasons.
 *
 * http://hl7.org/fhir/actualPeriod
 */
var actualPeriod = 'http://hl7.org/fhir/actualPeriod';
/**
 * _originalPrescription
 *
 * (Modified) ExplanationOfBenefit.originalPrescription
 *
 * http://hl7.org/fhir/_originalPrescription
 */
var _originalPrescription = 'http://hl7.org/fhir/_originalPrescription';
/**
 * _dosage
 *
 * (Modified) MedicationStatement.dosage
 *
 * http://hl7.org/fhir/_dosage
 */
var _dosage = 'http://hl7.org/fhir/_dosage';
/**
 * returnedAmount
 *
 * PaymentReconciliation.returnedAmount: The amount returned by the receiver which is excess to the amount payable, often referred to as 'change'.
 *
 * http://hl7.org/fhir/returnedAmount
 */
var returnedAmount = 'http://hl7.org/fhir/returnedAmount';
/**
 * _cTerminalModification
 *
 * (Modified) SubstanceProtein.subunit.cTerminalModification
 *
 * http://hl7.org/fhir/_cTerminalModification
 */
var _cTerminalModification = 'http://hl7.org/fhir/_cTerminalModification';
/**
 * name
 *
 * ObservationDefinition.name: A natural language name identifying the ObservationDefinition. This name should be usable as an identifier for the module by machine processing applications such as code generation.
 *
 * http://hl7.org/fhir/name
 */
var name = 'http://hl7.org/fhir/name';
/**
 * masterFile
 *
 * MedicinalProductDefinition.masterFile: A master file for the medicinal product (e.g. Pharmacovigilance System Master File). Drug master files (DMFs) are documents submitted to regulatory agencies to provide confidential detailed information about facilities, processes or articles used in the manufacturing, processing, packaging and storing of drug products.
 *
 * http://hl7.org/fhir/masterFile
 */
var masterFile = 'http://hl7.org/fhir/masterFile';
/**
 * baseFormulaType
 *
 * NutritionOrder.enteralFormula.baseFormulaType: The type of enteral or infant formula such as an adult standard formula with fiber or a soy-based infant formula.
 *
 * http://hl7.org/fhir/baseFormulaType
 */
var baseFormulaType = 'http://hl7.org/fhir/baseFormulaType';
/**
 * threshold
 *
 * EvidenceVariable.characteristic.definitionByCombination.characteristic.definitionByCombination.threshold: Provides the value of "n" when "at-least" or "at-most" codes are used.
 *
 * http://hl7.org/fhir/threshold
 */
var threshold = 'http://hl7.org/fhir/threshold';
/**
 * active
 *
 * Organization.active: Whether the organization's record is still in active use.
 *
 * http://hl7.org/fhir/active
 */
var active = 'http://hl7.org/fhir/active';
/**
 * IngredientSubstanceComponent
 *
 * IngredientSubstanceComponent: The substance that comprises this ingredient.
 *
 * http://hl7.org/fhir/IngredientSubstanceComponent
 */
var IngredientSubstanceComponent = 'http://hl7.org/fhir/IngredientSubstanceComponent';
/**
 * size
 *
 * Attachment.size: The number of bytes of data that make up this attachment (before base64 encoding, if that is done).
 *
 * http://hl7.org/fhir/size
 */
var size = 'http://hl7.org/fhir/size';
/**
 * _validityPeriod
 *
 * (Modified) RegulatedAuthorization.validityPeriod
 *
 * http://hl7.org/fhir/_validityPeriod
 */
var _validityPeriod = 'http://hl7.org/fhir/_validityPeriod';
/**
 * who
 *
 * Provenance.entity.agent.who: Indicates who or what performed in the event.
 *
 * http://hl7.org/fhir/who
 */
var who = 'http://hl7.org/fhir/who';
/**
 * ExampleScenarioProcessStepAlternativeComponent
 *
 * ExampleScenarioProcessComponent.ExampleScenarioProcessStepComponent.ExampleScenarioProcessStepAlternativeComponentStepProcess.ExampleScenarioProcessStepComponent.ExampleScenarioProcessStepAlternativeComponent: Indicates an alternative step that can be taken instead of the sub-process, scenario or operation.  E.g. to represent non-happy-path/exceptional/atypical circumstances.
 *
 * http://hl7.org/fhir/ExampleScenarioProcessStepAlternativeComponent
 */
var ExampleScenarioProcessStepAlternativeComponent = 'http://hl7.org/fhir/ExampleScenarioProcessStepAlternativeComponent';
/**
 * InsurancePlanPlanSpecificCostComponent
 *
 * InsurancePlanPlanComponent.InsurancePlanPlanSpecificCostComponent: Costs associated with the coverage provided by the product.
 *
 * http://hl7.org/fhir/InsurancePlanPlanSpecificCostComponent
 */
var InsurancePlanPlanSpecificCostComponent = 'http://hl7.org/fhir/InsurancePlanPlanSpecificCostComponent';
/**
 * interaction
 *
 * CapabilityStatement.rest.interaction: A specification of restful operations supported by the system.
 *
 * http://hl7.org/fhir/interaction
 */
var interaction = 'http://hl7.org/fhir/interaction';
/**
 * _beneficiary
 *
 * (Modified) Coverage.beneficiary
 *
 * http://hl7.org/fhir/_beneficiary
 */
var _beneficiary = 'http://hl7.org/fhir/_beneficiary';
/**
 * requestURL
 *
 * TestScript.test.action.assert.requestURL: The value to use in a comparison against the request URL path string.
 *
 * http://hl7.org/fhir/requestURL
 */
var requestURL = 'http://hl7.org/fhir/requestURL';
/**
 * transform
 *
 * StructureMap.group.rule.rule.target.transform: How the data is copied / created.
 *
 * http://hl7.org/fhir/transform
 */
var transform = 'http://hl7.org/fhir/transform';
/**
 * sugar
 *
 * SubstanceNucleicAcid.subunit.sugar: 5.3.6.8.1 Sugar ID (Mandatory).
 *
 * http://hl7.org/fhir/sugar
 */
var sugar = 'http://hl7.org/fhir/sugar';
/**
 * _subscriptionTopic
 *
 * (Modified) TriggerDefinition.subscriptionTopic
 *
 * http://hl7.org/fhir/_subscriptionTopic
 */
var _subscriptionTopic = 'http://hl7.org/fhir/_subscriptionTopic';
/**
 * _usageStatus
 *
 * (Modified) DeviceUsage.usageStatus
 *
 * http://hl7.org/fhir/_usageStatus
 */
var _usageStatus = 'http://hl7.org/fhir/_usageStatus';
/**
 * _recurring
 *
 * (Modified) AppointmentResponse.recurring
 *
 * http://hl7.org/fhir/_recurring
 */
var _recurring = 'http://hl7.org/fhir/_recurring';
/**
 * chargeItem
 *
 * Invoice.lineItem.chargeItem
 *
 * http://hl7.org/fhir/chargeItem
 */
var chargeItem = 'http://hl7.org/fhir/chargeItem';
/**
 * DiagnosticReportMediaComponent
 *
 * DiagnosticReportMediaComponent: A list of key images or data associated with this report. The images or data are generally created during the diagnostic process, and may be directly of the patient, or of treated specimens (i.e. slides of interest).
 *
 * http://hl7.org/fhir/DiagnosticReportMediaComponent
 */
var DiagnosticReportMediaComponent = 'http://hl7.org/fhir/DiagnosticReportMediaComponent';
/**
 * validationProcess
 *
 * VerificationResult.validationProcess: The primary process by which the target is validated (edit check; value set; primary source; multiple sources; standalone; in context).
 *
 * http://hl7.org/fhir/validationProcess
 */
var validationProcess = 'http://hl7.org/fhir/validationProcess';
/**
 * _DiagnosticReport
 *
 * (Modified) DiagnosticReport
 *
 * http://hl7.org/fhir/_DiagnosticReport
 */
var _DiagnosticReport = 'http://hl7.org/fhir/_DiagnosticReport';
/**
 * moiety
 *
 * SubstanceDefinition.moiety: Moiety, for structural modifications.
 *
 * http://hl7.org/fhir/moiety
 */
var moiety = 'http://hl7.org/fhir/moiety';
/**
 * _marketingStatus
 *
 * (Modified) PackagedProductDefinition.marketingStatus
 *
 * http://hl7.org/fhir/_marketingStatus
 */
var _marketingStatus = 'http://hl7.org/fhir/_marketingStatus';
/**
 * _citedArtifact
 *
 * (Modified) Citation.citedArtifact
 *
 * http://hl7.org/fhir/_citedArtifact
 */
var _citedArtifact = 'http://hl7.org/fhir/_citedArtifact';
/**
 * CitationCitedArtifactPartComponent
 *
 * CitationCitedArtifactComponent.CitationCitedArtifactPartComponent: The component of the article or artifact.
 *
 * http://hl7.org/fhir/CitationCitedArtifactPartComponent
 */
var CitationCitedArtifactPartComponent = 'http://hl7.org/fhir/CitationCitedArtifactPartComponent';
/**
 * TerminologyCapabilitiesImplementationComponent
 *
 * TerminologyCapabilitiesImplementationComponent: Identifies a specific implementation instance that is described by the terminology capability statement - i.e. a particular installation, rather than the capabilities of a software program.
 *
 * http://hl7.org/fhir/TerminologyCapabilitiesImplementationComponent
 */
var TerminologyCapabilitiesImplementationComponent = 'http://hl7.org/fhir/TerminologyCapabilitiesImplementationComponent';
/**
 * _immutable
 *
 * (Modified) ValueSet.immutable
 *
 * http://hl7.org/fhir/_immutable
 */
var _immutable = 'http://hl7.org/fhir/_immutable';
/**
 * _requester
 *
 * (Modified) Contract.term.action.requester
 *
 * http://hl7.org/fhir/_requester
 */
var _requester = 'http://hl7.org/fhir/_requester';
/**
 * regionsStudied
 *
 * GenomicStudy.analysis.regionsStudied: The genomic regions to be studied in the analysis (BED file).
 *
 * http://hl7.org/fhir/regionsStudied
 */
var regionsStudied = 'http://hl7.org/fhir/regionsStudied';
/**
 * _code
 *
 * (Modified) ClinicalUseDefinition.warning.code
 *
 * http://hl7.org/fhir/_code
 */
var _code = 'http://hl7.org/fhir/_code';
/**
 * sourceMaterial
 *
 * SubstanceDefinition.sourceMaterial: Material or taxonomic/anatomical source for the substance.
 *
 * http://hl7.org/fhir/sourceMaterial
 */
var sourceMaterial = 'http://hl7.org/fhir/sourceMaterial';
/**
 * subrogation
 *
 * Coverage.subrogation: When 'subrogation=true' this insurance instance has been included not for adjudication but to provide insurers with the details to recover costs.
 *
 * http://hl7.org/fhir/subrogation
 */
var subrogation = 'http://hl7.org/fhir/subrogation';
/**
 * _structureVersion
 *
 * (Modified) ExampleScenario.instance.structureVersion
 *
 * http://hl7.org/fhir/_structureVersion
 */
var _structureVersion = 'http://hl7.org/fhir/_structureVersion';
/**
 * _priceComponent
 *
 * (Modified) Invoice.lineItem.priceComponent
 *
 * http://hl7.org/fhir/_priceComponent
 */
var _priceComponent = 'http://hl7.org/fhir/_priceComponent';
/**
 * management
 *
 * ClinicalUseDefinition.interaction.management: Actions for managing the interaction.
 *
 * http://hl7.org/fhir/management
 */
var management = 'http://hl7.org/fhir/management';
/**
 * _additionalInstruction
 *
 * (Modified) Dosage.additionalInstruction
 *
 * http://hl7.org/fhir/_additionalInstruction
 */
var _additionalInstruction = 'http://hl7.org/fhir/_additionalInstruction';
/**
 * _managingEntity
 *
 * (Modified) Subscription.managingEntity
 *
 * http://hl7.org/fhir/_managingEntity
 */
var _managingEntity = 'http://hl7.org/fhir/_managingEntity';
/**
 * patchFormat
 *
 * CapabilityStatement.patchFormat: A list of the patch formats supported by this implementation using their content types.
 *
 * http://hl7.org/fhir/patchFormat
 */
var patchFormat = 'http://hl7.org/fhir/patchFormat';
/**
 * proxyIdentityCertificate
 *
 * VerificationResult.attestation.proxyIdentityCertificate: A digital identity certificate associated with the proxy entity submitting attested information on behalf of the attestation source.
 *
 * http://hl7.org/fhir/proxyIdentityCertificate
 */
var proxyIdentityCertificate = 'http://hl7.org/fhir/proxyIdentityCertificate';
/**
 * DeviceVersionComponent
 *
 * DeviceVersionComponent: The actual design of the device or software version running on the device.
 *
 * http://hl7.org/fhir/DeviceVersionComponent
 */
var DeviceVersionComponent = 'http://hl7.org/fhir/DeviceVersionComponent';
/**
 * TaskRestrictionComponent
 *
 * TaskRestrictionComponent: If the Task.focus is a request resource and the task is seeking fulfillment (i.e. is asking for the request to be actioned), this element identifies any limitations on what parts of the referenced request should be actioned.
 *
 * http://hl7.org/fhir/TaskRestrictionComponent
 */
var TaskRestrictionComponent = 'http://hl7.org/fhir/TaskRestrictionComponent';
/**
 * _frameOfReferenceUid
 *
 * (Modified) ImagingSelection.frameOfReferenceUid
 *
 * http://hl7.org/fhir/_frameOfReferenceUid
 */
var _frameOfReferenceUid = 'http://hl7.org/fhir/_frameOfReferenceUid';
/**
 * MedicinalProductDefinition
 *
 * Detailed definition of a medicinal product, typically for uses other than direct patient care (e.g. regulatory use, drug catalogs, to support prescribing, adverse events management etc.).
 *
 * http://hl7.org/fhir/MedicinalProductDefinition
 */
var MedicinalProductDefinition = 'http://hl7.org/fhir/MedicinalProductDefinition';
/**
 * paternalOrganismId
 *
 * SubstanceSourceMaterial.organism.hybrid.paternalOrganismId: The identifier of the paternal species constituting the hybrid organism shall be specified based on a controlled vocabulary.
 *
 * http://hl7.org/fhir/paternalOrganismId
 */
var paternalOrganismId = 'http://hl7.org/fhir/paternalOrganismId';
/**
 * averageMolecularFormula
 *
 * SubstancePolymer.repeat.averageMolecularFormula: A representation of an (average) molecular formula from a polymer.
 *
 * http://hl7.org/fhir/averageMolecularFormula
 */
var averageMolecularFormula = 'http://hl7.org/fhir/averageMolecularFormula';
/**
 * EvidenceStatisticSampleSizeComponent
 *
 * EvidenceStatisticComponent.EvidenceStatisticSampleSizeComponent: Number of samples in the statistic.
 *
 * http://hl7.org/fhir/EvidenceStatisticSampleSizeComponent
 */
var EvidenceStatisticSampleSizeComponent = 'http://hl7.org/fhir/EvidenceStatisticSampleSizeComponent';
/**
 * _occurred
 *
 * (Modified) Provenance.occurred
 *
 * http://hl7.org/fhir/_occurred
 */
var _occurred = 'http://hl7.org/fhir/_occurred';
/**
 * definitionByCombination
 *
 * EvidenceVariable.characteristic.definitionByCombination: Defines the characteristic as a combination of two or more characteristics.
 *
 * http://hl7.org/fhir/definitionByCombination
 */
var definitionByCombination = 'http://hl7.org/fhir/definitionByCombination';
/**
 * _compositional
 *
 * (Modified) TerminologyCapabilities.codeSystem.version.compositional
 *
 * http://hl7.org/fhir/_compositional
 */
var _compositional = 'http://hl7.org/fhir/_compositional';
/**
 * financial
 *
 * ExplanationOfBenefit.benefitBalance.financial: Benefits Used to date.
 *
 * http://hl7.org/fhir/financial
 */
var financial = 'http://hl7.org/fhir/financial';
/**
 * _bodysite
 *
 * (Modified) ChargeItem.bodysite
 *
 * http://hl7.org/fhir/_bodysite
 */
var _bodysite = 'http://hl7.org/fhir/_bodysite';
/**
 * sourceScope
 *
 * ConceptMap.sourceScope
 *
 * http://hl7.org/fhir/sourceScope
 */
var sourceScope = 'http://hl7.org/fhir/sourceScope';
/**
 * parameter
 *
 * ServiceRequest.orderDetail.parameter: The parameter details for the service being requested.
 *
 * http://hl7.org/fhir/parameter
 */
var parameter = 'http://hl7.org/fhir/parameter';
/**
 * lineItem
 *
 * Invoice.lineItem: Each line item represents one charge for goods and services rendered. Details such.ofType(date), code and amount are found in the referenced ChargeItem resource.
 *
 * http://hl7.org/fhir/lineItem
 */
var lineItem = 'http://hl7.org/fhir/lineItem';
/**
 * _businessArrangement
 *
 * (Modified) CoverageEligibilityRequest.insurance.businessArrangement
 *
 * http://hl7.org/fhir/_businessArrangement
 */
var _businessArrangement = 'http://hl7.org/fhir/_businessArrangement';
/**
 * _ordinalPosition
 *
 * (Modified) MolecularSequence.relative.ordinalPosition
 *
 * http://hl7.org/fhir/_ordinalPosition
 */
var _ordinalPosition = 'http://hl7.org/fhir/_ordinalPosition';
/**
 * dependency
 *
 * TestPlan.testCase.dependency: The required criteria to execute the test case - e.g. preconditions, previous tests.
 *
 * http://hl7.org/fhir/dependency
 */
var dependency = 'http://hl7.org/fhir/dependency';
/**
 * DeviceUsage
 *
 * A record of a device being used by a patient where the record is the result of a report from the patient or a clinician.
 *
 * http://hl7.org/fhir/DeviceUsage
 */
var DeviceUsage = 'http://hl7.org/fhir/DeviceUsage';
/**
 * sent
 *
 * Communication.sent: The time when this communication was sent.
 *
 * http://hl7.org/fhir/sent
 */
var sent = 'http://hl7.org/fhir/sent';
/**
 * _associatedMedication
 *
 * (Modified) MedicationKnowledge.associatedMedication
 *
 * http://hl7.org/fhir/_associatedMedication
 */
var _associatedMedication = 'http://hl7.org/fhir/_associatedMedication';
/**
 * ParametersParameterComponentParameter
 *
 * A named part of a multi-part parameter.
 *
 * http://hl7.org/fhir/ParametersParameterComponentParameter
 */
var ParametersParameterComponentParameter = 'http://hl7.org/fhir/ParametersParameterComponentParameter';
/**
 * executionPeriod
 *
 * Task.executionPeriod: Identifies the time action was first taken against the task (start) and/or the time final action was taken against the task prior to marking it as completed (end).
 *
 * http://hl7.org/fhir/executionPeriod
 */
var executionPeriod = 'http://hl7.org/fhir/executionPeriod';
/**
 * _custodian
 *
 * (Modified) DocumentReference.custodian
 *
 * http://hl7.org/fhir/_custodian
 */
var _custodian = 'http://hl7.org/fhir/_custodian';
/**
 * specification
 *
 * DeviceDefinition.conformsTo.specification: Code that identifies the specific standard, specification, protocol, formal guidance, regulation, legislation, or certification scheme to which the device adheres.
 *
 * http://hl7.org/fhir/specification
 */
var specification = 'http://hl7.org/fhir/specification';
/**
 * HumanName
 *
 * A name, normally of a human, that can be used for other living entities (e.g. animals but not organizations) that have been assigned names by a human and may need the use of name parts or the need for usage information.
 *
 * http://hl7.org/fhir/HumanName
 */
var HumanName = 'http://hl7.org/fhir/HumanName';
/**
 * ObservationDefinitionComponentComponentQualifiedValue
 *
 * A set of qualified values associated with a context and a set of conditions -  provides a range for quantitative and ordinal observations and a collection of value sets for qualitative observations.
 *
 * http://hl7.org/fhir/ObservationDefinitionComponentComponentQualifiedValue
 */
var ObservationDefinitionComponentComponentQualifiedValue = 'http://hl7.org/fhir/ObservationDefinitionComponentComponentQualifiedValue';
/**
 * _searchInclude
 *
 * (Modified) CapabilityStatement.rest.resource.searchInclude
 *
 * http://hl7.org/fhir/_searchInclude
 */
var _searchInclude = 'http://hl7.org/fhir/_searchInclude';
/**
 * _technique
 *
 * (Modified) SubstanceDefinition.structure.technique
 *
 * http://hl7.org/fhir/_technique
 */
var _technique = 'http://hl7.org/fhir/_technique';
/**
 * legalStatusOfSupply
 *
 * PackagedProductDefinition.legalStatusOfSupply: The legal status of supply of the packaged item as classified by the regulator.
 *
 * http://hl7.org/fhir/legalStatusOfSupply
 */
var legalStatusOfSupply = 'http://hl7.org/fhir/legalStatusOfSupply';
/**
 * short
 *
 * ElementDefinition.short: A concise description of what this element means (e.g. for use in autogenerated summaries).
 *
 * http://hl7.org/fhir/short
 */
var short = 'http://hl7.org/fhir/short';
/**
 * generation
 *
 * ImplementationGuide.definition.page.page.generation: A code that indicates how the page is generated.
 *
 * http://hl7.org/fhir/generation
 */
var generation = 'http://hl7.org/fhir/generation';
/**
 * doseAndRate
 *
 * Dosage.doseAndRate: Depending on the resource,this is the amount of medication administered, to  be administered or typical amount to be administered.
 *
 * http://hl7.org/fhir/doseAndRate
 */
var doseAndRate = 'http://hl7.org/fhir/doseAndRate';
/**
 * _condition
 *
 * (Modified) Account.diagnosis.condition
 *
 * http://hl7.org/fhir/_condition
 */
var _condition = 'http://hl7.org/fhir/_condition';
/**
 * _followUp
 *
 * (Modified) Procedure.followUp
 *
 * http://hl7.org/fhir/_followUp
 */
var _followUp = 'http://hl7.org/fhir/_followUp';
/**
 * manufacturer
 *
 * PackagedProductDefinition.manufacturer: Manufacturer of this package type. When there are multiple it means these are all possible manufacturers.
 *
 * http://hl7.org/fhir/manufacturer
 */
var manufacturer = 'http://hl7.org/fhir/manufacturer';
/**
 * BiologicallyDerivedProductDispense
 *
 * A record of dispensation of a biologically derived product.
 *
 * http://hl7.org/fhir/BiologicallyDerivedProductDispense
 */
var BiologicallyDerivedProductDispense = 'http://hl7.org/fhir/BiologicallyDerivedProductDispense';
/**
 * _seriesUid
 *
 * (Modified) ImagingSelection.seriesUid
 *
 * http://hl7.org/fhir/_seriesUid
 */
var _seriesUid = 'http://hl7.org/fhir/_seriesUid';
/**
 * relatesTo
 *
 * Citation.citedArtifact.relatesTo: The artifact related to the cited artifact.
 *
 * http://hl7.org/fhir/relatesTo
 */
var relatesTo = 'http://hl7.org/fhir/relatesTo';
/**
 * temperatureQualifier
 *
 * SpecimenDefinition.typeTested.handling.temperatureQualifier: It qualifies the interval of temperature, which characterizes an occurrence of handling. Conditions that are not related to temperature may be handled in the instruction element.
 *
 * http://hl7.org/fhir/temperatureQualifier
 */
var temperatureQualifier = 'http://hl7.org/fhir/temperatureQualifier';
/**
 * _PackagedProductDefinition
 *
 * (Modified) PackagedProductDefinition
 *
 * http://hl7.org/fhir/_PackagedProductDefinition
 */
var _PackagedProductDefinition = 'http://hl7.org/fhir/_PackagedProductDefinition';
/**
 * _correspondingContact
 *
 * (Modified) Citation.citedArtifact.contributorship.entry.correspondingContact
 *
 * http://hl7.org/fhir/_correspondingContact
 */
var _correspondingContact = 'http://hl7.org/fhir/_correspondingContact';
/**
 * citeAs
 *
 * EvidenceReport.citeAs
 *
 * http://hl7.org/fhir/citeAs
 */
var citeAs = 'http://hl7.org/fhir/citeAs';
/**
 * _DeviceAssociation
 *
 * (Modified) DeviceAssociation
 *
 * http://hl7.org/fhir/_DeviceAssociation
 */
var _DeviceAssociation = 'http://hl7.org/fhir/_DeviceAssociation';
/**
 * requireBoth
 *
 * SubscriptionTopic.resourceTrigger.queryCriteria.requireBoth: If set to `true`, both the `current` and `previous` query criteria must evaluate `true` to trigger a notification for this topic.  If set to `false` or not present, a notification for this topic will be triggered if either the `current` or `previous` tests evaluate to `true`.
 *
 * http://hl7.org/fhir/requireBoth
 */
var requireBoth = 'http://hl7.org/fhir/requireBoth';
/**
 * provisionData
 *
 * Consent.provision.provisionData: The resources controlled by this provision if specific resources are referenced.
 *
 * http://hl7.org/fhir/provisionData
 */
var provisionData = 'http://hl7.org/fhir/provisionData';
/**
 * _characterization
 *
 * (Modified) SubstanceDefinition.characterization
 *
 * http://hl7.org/fhir/_characterization
 */
var _characterization = 'http://hl7.org/fhir/_characterization';
/**
 * criticality
 *
 * AllergyIntolerance.criticality: Estimate of the potential clinical harm, or seriousness, of the reaction to the identified substance.
 *
 * http://hl7.org/fhir/criticality
 */
var criticality = 'http://hl7.org/fhir/criticality';
/**
 * ConditionDefinitionPlanComponent
 *
 * ConditionDefinitionPlanComponent: Plan that is appropriate.
 *
 * http://hl7.org/fhir/ConditionDefinitionPlanComponent
 */
var ConditionDefinitionPlanComponent = 'http://hl7.org/fhir/ConditionDefinitionPlanComponent';
/**
 * canPushUpdates
 *
 * VerificationResult.primarySource.canPushUpdates: Ability of the primary source to push updates/alerts (yes; no; undetermined).
 *
 * http://hl7.org/fhir/canPushUpdates
 */
var canPushUpdates = 'http://hl7.org/fhir/canPushUpdates';
/**
 * _nTerminalModificationId
 *
 * (Modified) SubstanceProtein.subunit.nTerminalModificationId
 *
 * http://hl7.org/fhir/_nTerminalModificationId
 */
var _nTerminalModificationId = 'http://hl7.org/fhir/_nTerminalModificationId';
/**
 * _regionsCalled
 *
 * (Modified) GenomicStudy.analysis.regionsCalled
 *
 * http://hl7.org/fhir/_regionsCalled
 */
var _regionsCalled = 'http://hl7.org/fhir/_regionsCalled';
/**
 * TestPlanTestCaseTestRunComponent
 *
 * TestPlanTestCaseComponent.TestPlanTestCaseTestRunComponent: The actual test to be executed.
 *
 * http://hl7.org/fhir/TestPlanTestCaseTestRunComponent
 */
var TestPlanTestCaseTestRunComponent = 'http://hl7.org/fhir/TestPlanTestCaseTestRunComponent';
/**
 * _productOrService
 *
 * (Modified) CoverageEligibilityRequest.item.productOrService
 *
 * http://hl7.org/fhir/_productOrService
 */
var _productOrService = 'http://hl7.org/fhir/_productOrService';
/**
 * reviewOutcome
 *
 * ClaimResponse.addItem.reviewOutcome: The high-level results of the adjudication if adjudication has been performed.
 *
 * http://hl7.org/fhir/reviewOutcome
 */
var reviewOutcome = 'http://hl7.org/fhir/reviewOutcome';
/**
 * maxDispense
 *
 * MedicationKnowledge.regulatory.maxDispense: The maximum number of units of the medication that can be dispensed in a period.
 *
 * http://hl7.org/fhir/maxDispense
 */
var maxDispense = 'http://hl7.org/fhir/maxDispense';
/**
 * filterDefinition
 *
 * SubscriptionTopic.canFilterBy.filterDefinition: Either the canonical URL to a search parameter (like "http://hl7.org/fhir/SearchParameter/encounter-patient") or the officially-defined URI for a shared filter concept (like "http://example.org/concepts/shared-common-event").
 *
 * http://hl7.org/fhir/filterDefinition
 */
var filterDefinition = 'http://hl7.org/fhir/filterDefinition';
/**
 * sourceAttachment
 *
 * Consent.sourceAttachment: The source on which this consent statement is based. The source might be a scanned original paper form.
 *
 * http://hl7.org/fhir/sourceAttachment
 */
var sourceAttachment = 'http://hl7.org/fhir/sourceAttachment';
/**
 * provisionActor
 *
 * Consent.provision.provisionActor: Who or what is controlled by this provision. Use group to identify a set of actors by some property they share (e.g. 'admitting officers').
 *
 * http://hl7.org/fhir/provisionActor
 */
var provisionActor = 'http://hl7.org/fhir/provisionActor';
/**
 * NamingSystem
 *
 * A curated namespace that issues unique symbols within that namespace for the identification of concepts, people, devices, etc.  Represents a "System" used within the Identifier and Coding data types.
 *
 * http://hl7.org/fhir/NamingSystem
 */
var NamingSystem = 'http://hl7.org/fhir/NamingSystem';
/**
 * dateOfService
 *
 * Account.procedure.dateOfService: Date of the procedure when using a coded procedure. If using a reference to a procedure, then the date on the procedure should be used.
 *
 * http://hl7.org/fhir/dateOfService
 */
var dateOfService = 'http://hl7.org/fhir/dateOfService';
/**
 * VisionPrescription
 *
 * An authorization for the provision of glasses and/or contact lenses to a patient.
 *
 * http://hl7.org/fhir/VisionPrescription
 */
var VisionPrescription = 'http://hl7.org/fhir/VisionPrescription';
/**
 * _unitPrice
 *
 * (Modified) Claim.item.unitPrice
 *
 * http://hl7.org/fhir/_unitPrice
 */
var _unitPrice = 'http://hl7.org/fhir/_unitPrice';
/**
 * resource
 *
 * SubscriptionTopic.notificationShape.resource: URL of the Resource that is the type used in this shape. This is the 'focus' resource of the topic (or one of them if there are more than one) and the root resource for this shape definition. It will be the same, a generality, or a specificity of SubscriptionTopic.resourceTrigger.resource or SubscriptionTopic.eventTrigger.resource when they are present.
 *
 * http://hl7.org/fhir/resource
 */
var resource = 'http://hl7.org/fhir/resource';
/**
 * _response
 *
 * (Modified) TestScript.test.action.assert.response
 *
 * http://hl7.org/fhir/_response
 */
var _response = 'http://hl7.org/fhir/_response';
/**
 * _agent
 *
 * (Modified) Provenance.entity.agent
 *
 * http://hl7.org/fhir/_agent
 */
var _agent = 'http://hl7.org/fhir/_agent';
/**
 * contraindicatedVaccineCode
 *
 * ImmunizationRecommendation.recommendation.contraindicatedVaccineCode: Vaccine(s) which should not be used to fulfill the recommendation.
 *
 * http://hl7.org/fhir/contraindicatedVaccineCode
 */
var contraindicatedVaccineCode = 'http://hl7.org/fhir/contraindicatedVaccineCode';
/**
 * collector
 *
 * Specimen.collection.collector: Person who collected the specimen.
 *
 * http://hl7.org/fhir/collector
 */
var collector = 'http://hl7.org/fhir/collector';
/**
 * enterer
 *
 * CoverageEligibilityRequest.enterer: Person who created the request.
 *
 * http://hl7.org/fhir/enterer
 */
var enterer = 'http://hl7.org/fhir/enterer';
/**
 * _supportedInteraction
 *
 * (Modified) SubscriptionTopic.resourceTrigger.supportedInteraction
 *
 * http://hl7.org/fhir/_supportedInteraction
 */
var _supportedInteraction = 'http://hl7.org/fhir/_supportedInteraction';
/**
 * _differential
 *
 * (Modified) StructureDefinition.differential
 *
 * http://hl7.org/fhir/_differential
 */
var _differential = 'http://hl7.org/fhir/_differential';
/**
 * _qualifiedValue
 *
 * (Modified) ObservationDefinition.component.qualifiedValue
 *
 * http://hl7.org/fhir/_qualifiedValue
 */
var _qualifiedValue = 'http://hl7.org/fhir/_qualifiedValue';
/**
 * ManufacturedItemDefinitionComponentConstituentComponent
 *
 * ManufacturedItemDefinitionComponentComponent.ManufacturedItemDefinitionComponentConstituentComponent: A reference to a constituent of the manufactured item as a whole, linked here so that its component location within the item can be indicated. This not where the item's ingredient are primarily stated (for which see Ingredient.for or ManufacturedItemDefinition.ingredient).
 *
 * http://hl7.org/fhir/ManufacturedItemDefinitionComponentConstituentComponent
 */
var ManufacturedItemDefinitionComponentConstituentComponent = 'http://hl7.org/fhir/ManufacturedItemDefinitionComponentConstituentComponent';
/**
 * _additionalMonitoringIndicator
 *
 * (Modified) MedicinalProductDefinition.additionalMonitoringIndicator
 *
 * http://hl7.org/fhir/_additionalMonitoringIndicator
 */
var _additionalMonitoringIndicator = 'http://hl7.org/fhir/_additionalMonitoringIndicator';
/**
 * _position
 *
 * (Modified) Location.position
 *
 * http://hl7.org/fhir/_position
 */
var _position = 'http://hl7.org/fhir/_position';
/**
 * limit
 *
 * Permission.rule.limit: What limits apply to the use of the data.
 *
 * http://hl7.org/fhir/limit
 */
var limit = 'http://hl7.org/fhir/limit';
/**
 * _reason
 *
 * (Modified) Appointment.reason
 *
 * http://hl7.org/fhir/_reason
 */
var _reason = 'http://hl7.org/fhir/_reason';
/**
 * _planningHorizon
 *
 * (Modified) Schedule.planningHorizon
 *
 * http://hl7.org/fhir/_planningHorizon
 */
var _planningHorizon = 'http://hl7.org/fhir/_planningHorizon';
/**
 * _safety
 *
 * (Modified) DeviceDefinition.safety
 *
 * http://hl7.org/fhir/_safety
 */
var _safety = 'http://hl7.org/fhir/_safety';
/**
 * Identifier
 *
 * An identifier - identifies some entity uniquely and unambiguously. Typically this is used for business identifiers.
 *
 * http://hl7.org/fhir/Identifier
 */
var Identifier = 'http://hl7.org/fhir/Identifier';
/**
 * _mitigation
 *
 * (Modified) RiskAssessment.mitigation
 *
 * http://hl7.org/fhir/_mitigation
 */
var _mitigation = 'http://hl7.org/fhir/_mitigation';
/**
 * _specialCourtesy
 *
 * (Modified) Encounter.specialCourtesy
 *
 * http://hl7.org/fhir/_specialCourtesy
 */
var _specialCourtesy = 'http://hl7.org/fhir/_specialCourtesy';
/**
 * ExampleScenarioInstanceContainedInstanceComponent
 *
 * ExampleScenarioInstanceComponent.ExampleScenarioInstanceContainedInstanceComponent: References to other instances that can be found within this instance (e.g. the observations contained in a bundle).
 *
 * http://hl7.org/fhir/ExampleScenarioInstanceContainedInstanceComponent
 */
var ExampleScenarioInstanceContainedInstanceComponent = 'http://hl7.org/fhir/ExampleScenarioInstanceContainedInstanceComponent';
/**
 * edit
 *
 * MolecularSequence.relative.edit: Changes in sequence from the starting sequence.
 *
 * http://hl7.org/fhir/edit
 */
var edit = 'http://hl7.org/fhir/edit';
/**
 * qualitativeRisk
 *
 * RiskAssessment.prediction.qualitativeRisk: Indicates how likely the outcome is (in the specified timeframe), expressed as a qualitative value (e.g. low, medium, or high).
 *
 * http://hl7.org/fhir/qualitativeRisk
 */
var qualitativeRisk = 'http://hl7.org/fhir/qualitativeRisk';
/**
 * immunizationEvent
 *
 * ImmunizationEvaluation.immunizationEvent: The vaccine administration event being evaluated.
 *
 * http://hl7.org/fhir/immunizationEvent
 */
var immunizationEvent = 'http://hl7.org/fhir/immunizationEvent';
/**
 * reference
 *
 * Contract.term.offer.party.reference: Participant in the offer.
 *
 * http://hl7.org/fhir/reference
 */
var reference = 'http://hl7.org/fhir/reference';
/**
 * reporter
 *
 * MeasureReport.reporter: The individual or organization that is reporting the data.
 *
 * http://hl7.org/fhir/reporter
 */
var reporter = 'http://hl7.org/fhir/reporter';
/**
 * BackboneElement
 *
 * Base definition for all elements that are defined inside a resource - but not those in a data type.
 *
 * http://hl7.org/fhir/BackboneElement
 */
var BackboneElement = 'http://hl7.org/fhir/BackboneElement';
/**
 * _hasMember
 *
 * (Modified) ObservationDefinition.hasMember
 *
 * http://hl7.org/fhir/_hasMember
 */
var _hasMember = 'http://hl7.org/fhir/_hasMember';
/**
 * Provenance
 *
 * Provenance of a resource is a record that describes entities and processes involved in producing and delivering or otherwise influencing that resource. Provenance provides a critical foundation for assessing authenticity, enabling trust, and allowing reproducibility. Provenance assertions are a form of contextual metadata and can themselves become important records with their own provenance. Provenance statement indicates clinical significance in terms of confidence in authenticity, reliability, and trustworthiness, integrity, and stage in lifecycle (e.g. Document Completion - has the artifact been legally authenticated), all of which may impact security, privacy, and trust policies.
 *
 * http://hl7.org/fhir/Provenance
 */
var Provenance = 'http://hl7.org/fhir/Provenance';
/**
 * reasonLinkId
 *
 * Contract.term.group.action.reasonLinkId: Id [identifier??] of the clause or question text related to the reason type or reference of this  action in the referenced form or QuestionnaireResponse.
 *
 * http://hl7.org/fhir/reasonLinkId
 */
var reasonLinkId = 'http://hl7.org/fhir/reasonLinkId';
/**
 * owner
 *
 * DeviceDefinition.owner: An organization that is responsible for the provision and ongoing maintenance of the device.
 *
 * http://hl7.org/fhir/owner
 */
var owner = 'http://hl7.org/fhir/owner';
/**
 * _assignedComparisonGroup
 *
 * (Modified) ResearchSubject.assignedComparisonGroup
 *
 * http://hl7.org/fhir/_assignedComparisonGroup
 */
var _assignedComparisonGroup = 'http://hl7.org/fhir/_assignedComparisonGroup';
/**
 * _Condition
 *
 * (Modified) Condition
 *
 * http://hl7.org/fhir/_Condition
 */
var _Condition = 'http://hl7.org/fhir/_Condition';
/**
 * ConsentPolicyBasisComponent
 *
 * ConsentPolicyBasisComponent: A Reference or URL used to uniquely identify the policy the organization will enforce for this Consent. This Reference or URL should be specific to the version of the policy and should be dereferencable to a computable policy of some form.
 *
 * http://hl7.org/fhir/ConsentPolicyBasisComponent
 */
var ConsentPolicyBasisComponent = 'http://hl7.org/fhir/ConsentPolicyBasisComponent';
/**
 * communicationMethod
 *
 * VerificationResult.attestation.communicationMethod: The method by which attested information was submitted/retrieved (manual; API; Push).
 *
 * http://hl7.org/fhir/communicationMethod
 */
var communicationMethod = 'http://hl7.org/fhir/communicationMethod';
/**
 * _param
 *
 * (Modified) CompartmentDefinition.resource.param
 *
 * http://hl7.org/fhir/_param
 */
var _param = 'http://hl7.org/fhir/_param';
/**
 * _power
 *
 * (Modified) VisionPrescription.lensSpecification.power
 *
 * http://hl7.org/fhir/_power
 */
var _power = 'http://hl7.org/fhir/_power';
/**
 * _issue
 *
 * (Modified) OperationOutcome.issue
 *
 * http://hl7.org/fhir/_issue
 */
var _issue = 'http://hl7.org/fhir/_issue';
/**
 * concept
 *
 * CodeSystem.concept.concept.concept: Defines children of a concept to produce a hierarchy of concepts. The nature of the relationships is variable (is-a/contains/categorizes) - see hierarchyMeaning.
 *
 * http://hl7.org/fhir/concept
 */
var concept = 'http://hl7.org/fhir/concept';
/**
 * decisionMode
 *
 * Contract.term.group.offer.decisionMode: How the decision about a Contract was conveyed.
 *
 * http://hl7.org/fhir/decisionMode
 */
var decisionMode = 'http://hl7.org/fhir/decisionMode';
/**
 * instantiatesUri
 *
 * CarePlan.instantiatesUri: The URL pointing to an externally maintained protocol, guideline, questionnaire or other definition that is adhered to in whole or in part by this CarePlan.
 *
 * http://hl7.org/fhir/instantiatesUri
 */
var instantiatesUri = 'http://hl7.org/fhir/instantiatesUri';
/**
 * _ifMatch
 *
 * (Modified) Bundle.entry.request.ifMatch
 *
 * http://hl7.org/fhir/_ifMatch
 */
var _ifMatch = 'http://hl7.org/fhir/_ifMatch';
/**
 * sequenceType
 *
 * SubstanceProtein.sequenceType: The SubstanceProtein descriptive elements will only be used when a complete or partial amino acid sequence is available or derivable from a nucleic acid sequence.
 *
 * http://hl7.org/fhir/sequenceType
 */
var sequenceType = 'http://hl7.org/fhir/sequenceType';
/**
 * _fastingStatus
 *
 * (Modified) Specimen.collection.fastingStatus
 *
 * http://hl7.org/fhir/_fastingStatus
 */
var _fastingStatus = 'http://hl7.org/fhir/_fastingStatus';
/**
 * preferredReportName
 *
 * ObservationDefinition.preferredReportName: The preferred name to be used when reporting the results of observations conforming to this ObservationDefinition.
 *
 * http://hl7.org/fhir/preferredReportName
 */
var preferredReportName = 'http://hl7.org/fhir/preferredReportName';
/**
 * _numberOfSeries
 *
 * (Modified) ImagingStudy.numberOfSeries
 *
 * http://hl7.org/fhir/_numberOfSeries
 */
var _numberOfSeries = 'http://hl7.org/fhir/_numberOfSeries';
/**
 * rankingOrder
 *
 * Citation.citedArtifact.contributorship.entry.rankingOrder: Provides a numerical ranking to represent the degree of contributorship relative to other contributors, such as 1 for first author and 2 for second author.
 *
 * http://hl7.org/fhir/rankingOrder
 */
var rankingOrder = 'http://hl7.org/fhir/rankingOrder';
/**
 * _currency
 *
 * (Modified) Account.currency
 *
 * http://hl7.org/fhir/_currency
 */
var _currency = 'http://hl7.org/fhir/_currency';
/**
 * testTools
 *
 * TestPlan.testTools: A description of test tools to be used in the test plan.
 *
 * http://hl7.org/fhir/testTools
 */
var testTools = 'http://hl7.org/fhir/testTools';
/**
 * _warning
 *
 * (Modified) DeviceDefinition.guideline.warning
 *
 * http://hl7.org/fhir/_warning
 */
var _warning = 'http://hl7.org/fhir/_warning';
/**
 * CoverageEligibilityResponseEventComponent
 *
 * CoverageEligibilityResponseEventComponent: Information code for an event with a corresponding date or period.
 *
 * http://hl7.org/fhir/CoverageEligibilityResponseEventComponent
 */
var CoverageEligibilityResponseEventComponent = 'http://hl7.org/fhir/CoverageEligibilityResponseEventComponent';
/**
 * _characteristic
 *
 * (Modified) Group.characteristic
 *
 * http://hl7.org/fhir/_characteristic
 */
var _characteristic = 'http://hl7.org/fhir/_characteristic';
/**
 * dataRequirement
 *
 * Library.dataRequirement: Describes a set of data that must be provided in order to be able to successfully perform the computations defined by the library.
 *
 * http://hl7.org/fhir/dataRequirement
 */
var dataRequirement = 'http://hl7.org/fhir/dataRequirement';
/**
 * _domain
 *
 * (Modified) SubstanceDefinition.name.translation.domain
 *
 * http://hl7.org/fhir/_domain
 */
var _domain = 'http://hl7.org/fhir/_domain';
/**
 * InventoryReport
 *
 * A report of inventory or stock items.
 *
 * http://hl7.org/fhir/InventoryReport
 */
var InventoryReport = 'http://hl7.org/fhir/InventoryReport';
/**
 * _parameterName
 *
 * (Modified) OperationDefinition.overload.parameterName
 *
 * http://hl7.org/fhir/_parameterName
 */
var _parameterName = 'http://hl7.org/fhir/_parameterName';
/**
 * progressStatus
 *
 * ResearchStudy.progressStatus: Status of study with time for that status.
 *
 * http://hl7.org/fhir/progressStatus
 */
var progressStatus = 'http://hl7.org/fhir/progressStatus';
/**
 * _narrative
 *
 * (Modified) TestPlan.testCase.testRun.narrative
 *
 * http://hl7.org/fhir/_narrative
 */
var _narrative = 'http://hl7.org/fhir/_narrative';
/**
 * Endpoint
 *
 * The technical details of an endpoint that can be used for electronic services, such as for web services providing XDS.b, a REST endpoint for another FHIR server, or a s/Mime email address. This may include any security context information.
 *
 * http://hl7.org/fhir/Endpoint
 */
var Endpoint = 'http://hl7.org/fhir/Endpoint';
/**
 * subjectState
 *
 * ResearchSubject.progress.subjectState: The current state of the subject.
 *
 * http://hl7.org/fhir/subjectState
 */
var subjectState = 'http://hl7.org/fhir/subjectState';
/**
 * entry
 *
 * Composition.section.entry: A reference to the actual resource from which the narrative in the section is derived.
 *
 * http://hl7.org/fhir/entry
 */
var entry = 'http://hl7.org/fhir/entry';
/**
 * _weeklyTemplate
 *
 * (Modified) Appointment.recurrenceTemplate.weeklyTemplate
 *
 * http://hl7.org/fhir/_weeklyTemplate
 */
var _weeklyTemplate = 'http://hl7.org/fhir/_weeklyTemplate';
/**
 * what
 *
 * Provenance.entity.what: Identity of the  Entity used. May be a logical or physical uri and maybe absolute or relative.
 *
 * http://hl7.org/fhir/what
 */
var what = 'http://hl7.org/fhir/what';
/**
 * whenPrepared
 *
 * MedicationDispense.whenPrepared: The time when the dispensed product was packaged and reviewed.
 *
 * http://hl7.org/fhir/whenPrepared
 */
var whenPrepared = 'http://hl7.org/fhir/whenPrepared';
/**
 * Action
 *
 * Contract.TermTerm.Action: An actor taking a role in an activity for which it can be assigned some degree of responsibility for the activity taking place.
 *
 * http://hl7.org/fhir/Action
 */
var Action = 'http://hl7.org/fhir/Action';
/**
 * _observationRequirement
 *
 * (Modified) ActivityDefinition.observationRequirement
 *
 * http://hl7.org/fhir/_observationRequirement
 */
var _observationRequirement = 'http://hl7.org/fhir/_observationRequirement';
/**
 * focal
 *
 * ExplanationOfBenefit.insurance.focal: A flag to indicate that this Coverage is to be used for adjudication of this claim when set to true.
 *
 * http://hl7.org/fhir/focal
 */
var focal = 'http://hl7.org/fhir/focal';
/**
 * verification
 *
 * Consent.verification: Whether a treatment instruction (e.g. artificial respiration: yes or no) was verified with the patient, his/her family or another authorized person.
 *
 * http://hl7.org/fhir/verification
 */
var verification = 'http://hl7.org/fhir/verification';
/**
 * _availability
 *
 * (Modified) PractitionerRole.availability
 *
 * http://hl7.org/fhir/_availability
 */
var _availability = 'http://hl7.org/fhir/_availability';
/**
 * resultingEffect
 *
 * AdverseEvent.resultingEffect: Information about the condition that occurred as a result of the adverse event, such as hives due to the exposure to a substance (for example, a drug or a chemical) or a broken leg as a result of the fall.
 *
 * http://hl7.org/fhir/resultingEffect
 */
var resultingEffect = 'http://hl7.org/fhir/resultingEffect';
/**
 * timeout
 *
 * Subscription.timeout: If present, the maximum amount of time a server will allow before failing a notification attempt.
 *
 * http://hl7.org/fhir/timeout
 */
var timeout = 'http://hl7.org/fhir/timeout';
/**
 * CapabilityStatementMessagingSupportedMessageComponent
 *
 * CapabilityStatementMessagingComponent.CapabilityStatementMessagingSupportedMessageComponent: References to message definitions for messages this system can send or receive.
 *
 * http://hl7.org/fhir/CapabilityStatementMessagingSupportedMessageComponent
 */
var CapabilityStatementMessagingSupportedMessageComponent = 'http://hl7.org/fhir/CapabilityStatementMessagingSupportedMessageComponent';
/**
 * _revenue
 *
 * (Modified) ExplanationOfBenefit.item.detail.subDetail.revenue
 *
 * http://hl7.org/fhir/_revenue
 */
var _revenue = 'http://hl7.org/fhir/_revenue';
/**
 * _returnedAmount
 *
 * (Modified) PaymentReconciliation.returnedAmount
 *
 * http://hl7.org/fhir/_returnedAmount
 */
var _returnedAmount = 'http://hl7.org/fhir/_returnedAmount';
/**
 * MedicationKnowledgeDefinitionalIngredientComponent
 *
 * MedicationKnowledgeDefinitionalComponent.MedicationKnowledgeDefinitionalIngredientComponent: Identifies a particular constituent of interest in the product.
 *
 * http://hl7.org/fhir/MedicationKnowledgeDefinitionalIngredientComponent
 */
var MedicationKnowledgeDefinitionalIngredientComponent = 'http://hl7.org/fhir/MedicationKnowledgeDefinitionalIngredientComponent';
/**
 * candidate
 *
 * EnrollmentRequest.candidate: Patient Resource.
 *
 * http://hl7.org/fhir/candidate
 */
var candidate = 'http://hl7.org/fhir/candidate';
/**
 * Subscription
 *
 * The subscription resource describes a particular client's request to be notified about a SubscriptionTopic.
 *
 * http://hl7.org/fhir/Subscription
 */
var Subscription = 'http://hl7.org/fhir/Subscription';
/**
 * relatedAction
 *
 * PlanDefinition.action.action.relatedAction: A relationship to another action such as "before" or "30-60 minutes after start of".
 *
 * http://hl7.org/fhir/relatedAction
 */
var relatedAction = 'http://hl7.org/fhir/relatedAction';
/**
 * textPresentation
 *
 * Ingredient.substance.strength.textPresentation: A textual represention of either the whole of the presentation strength or a part of it - with the rest being in Strength.presentation as a ratio.
 *
 * http://hl7.org/fhir/textPresentation
 */
var textPresentation = 'http://hl7.org/fhir/textPresentation';
/**
 * _supplements
 *
 * (Modified) CodeSystem.supplements
 *
 * http://hl7.org/fhir/_supplements
 */
var _supplements = 'http://hl7.org/fhir/_supplements';
/**
 * result
 *
 * DiagnosticReport.result: [Observations](observation.html)  that are part of this diagnostic report.
 *
 * http://hl7.org/fhir/result
 */
var result = 'http://hl7.org/fhir/result';
/**
 * policyText
 *
 * Consent.policyText: A Reference to the human readable policy explaining the basis for the Consent.
 *
 * http://hl7.org/fhir/policyText
 */
var policyText = 'http://hl7.org/fhir/policyText';
/**
 * _regionType
 *
 * (Modified) ImagingSelection.instance.imageRegion3D.regionType
 *
 * http://hl7.org/fhir/_regionType
 */
var _regionType = 'http://hl7.org/fhir/_regionType';
/**
 * StratifierGroup
 *
 * MeasureReportGroupComponent.MeasureReportGroupStratifierComponent.StratifierGroup: This element contains the results for a single stratum within the stratifier. For example, when stratifying on administrative gender, there will be four strata, one for each possible gender value.
 *
 * http://hl7.org/fhir/StratifierGroup
 */
var StratifierGroup = 'http://hl7.org/fhir/StratifierGroup';
/**
 * _contract
 *
 * (Modified) Coverage.contract
 *
 * http://hl7.org/fhir/_contract
 */
var _contract = 'http://hl7.org/fhir/_contract';
/**
 * _timeFromEvent
 *
 * (Modified) EvidenceVariable.characteristic.timeFromEvent
 *
 * http://hl7.org/fhir/_timeFromEvent
 */
var _timeFromEvent = 'http://hl7.org/fhir/_timeFromEvent';
/**
 * notificationEvent
 *
 * SubscriptionStatus.notificationEvent: Detailed information about events relevant to this subscription notification.
 *
 * http://hl7.org/fhir/notificationEvent
 */
var notificationEvent = 'http://hl7.org/fhir/notificationEvent';
/**
 * _inclusionCriteria
 *
 * (Modified) ValueSet.scope.inclusionCriteria
 *
 * http://hl7.org/fhir/_inclusionCriteria
 */
var _inclusionCriteria = 'http://hl7.org/fhir/_inclusionCriteria';
/**
 * _orderMeaning
 *
 * (Modified) ElementDefinition.orderMeaning
 *
 * http://hl7.org/fhir/_orderMeaning
 */
var _orderMeaning = 'http://hl7.org/fhir/_orderMeaning';
/**
 * autodelete
 *
 * TestScript.fixture.autodelete: Whether or not to implicitly delete the fixture during teardown. If true, the fixture is automatically deleted on each server being tested during teardown, therefore no delete operation is required for this fixture in the TestScript.teardown section.
 *
 * http://hl7.org/fhir/autodelete
 */
var autodelete = 'http://hl7.org/fhir/autodelete';
/**
 * qualifiers
 *
 * InsurancePlan.plan.specificCost.benefit.cost.qualifiers: Additional information about the cost, such as information about funding sources (e.g. HSA, HRA, FSA, RRA).
 *
 * http://hl7.org/fhir/qualifiers
 */
var qualifiers = 'http://hl7.org/fhir/qualifiers';
/**
 * _regionsStudied
 *
 * (Modified) GenomicStudy.analysis.regionsStudied
 *
 * http://hl7.org/fhir/_regionsStudied
 */
var _regionsStudied = 'http://hl7.org/fhir/_regionsStudied';
/**
 * _application
 *
 * (Modified) RegulatedAuthorization.case.application
 *
 * http://hl7.org/fhir/_application
 */
var _application = 'http://hl7.org/fhir/_application';
/**
 * frequency
 *
 * VerificationResult.frequency: Frequency of revalidation.
 *
 * http://hl7.org/fhir/frequency
 */
var frequency = 'http://hl7.org/fhir/frequency';
/**
 * _sourceMaterial
 *
 * (Modified) SubstanceDefinition.sourceMaterial
 *
 * http://hl7.org/fhir/_sourceMaterial
 */
var _sourceMaterial = 'http://hl7.org/fhir/_sourceMaterial';
/**
 * regulatoryBasis
 *
 * Consent.regulatoryBasis: A set of codes that indicate the regulatory basis (if any) that this consent supports.
 *
 * http://hl7.org/fhir/regulatoryBasis
 */
var regulatoryBasis = 'http://hl7.org/fhir/regulatoryBasis';
/**
 * associationType
 *
 * InventoryItem.association.associationType: This attribute defined the type of association when establishing associations or relations between items, e.g. 'packaged within' or 'used with' or 'to be mixed with.
 *
 * http://hl7.org/fhir/associationType
 */
var associationType = 'http://hl7.org/fhir/associationType';
/**
 * _software
 *
 * (Modified) TerminologyCapabilities.software
 *
 * http://hl7.org/fhir/_software
 */
var _software = 'http://hl7.org/fhir/_software';
/**
 * _copolymerConnectivity
 *
 * (Modified) SubstancePolymer.copolymerConnectivity
 *
 * http://hl7.org/fhir/_copolymerConnectivity
 */
var _copolymerConnectivity = 'http://hl7.org/fhir/_copolymerConnectivity';
/**
 * _approvalDate
 *
 * (Modified) NamingSystem.approvalDate
 *
 * http://hl7.org/fhir/_approvalDate
 */
var _approvalDate = 'http://hl7.org/fhir/_approvalDate';
/**
 * totalVolume
 *
 * Medication.totalVolume: When the specified product code does not infer a package size, this is the specific amount of drug in the product.  For example, when specifying a product that has the same strength (For example, Insulin glargine 100 unit per mL solution for injection), this attribute provides additional clarification of the package amount (For example, 3 mL, 10mL, etc.).
 *
 * http://hl7.org/fhir/totalVolume
 */
var totalVolume = 'http://hl7.org/fhir/totalVolume';
/**
 * AppointmentRecurrenceTemplateWeeklyTemplateComponent
 *
 * AppointmentRecurrenceTemplateComponent.AppointmentRecurrenceTemplateWeeklyTemplateComponent: Information about weekly recurring appointments.
 *
 * http://hl7.org/fhir/AppointmentRecurrenceTemplateWeeklyTemplateComponent
 */
var AppointmentRecurrenceTemplateWeeklyTemplateComponent = 'http://hl7.org/fhir/AppointmentRecurrenceTemplateWeeklyTemplateComponent';
/**
 * _requestedPerformer
 *
 * (Modified) Task.requestedPerformer
 *
 * http://hl7.org/fhir/_requestedPerformer
 */
var _requestedPerformer = 'http://hl7.org/fhir/_requestedPerformer';
/**
 * packagedProduct
 *
 * MedicationKnowledge.packaging.packagedProduct: A reference to a PackagedProductDefinition that provides the details of the product that is in the packaging and is being priced.
 *
 * http://hl7.org/fhir/packagedProduct
 */
var packagedProduct = 'http://hl7.org/fhir/packagedProduct';
/**
 * tissue
 *
 * AdministrableProductDefinition.routeOfAdministration.targetSpecies.withdrawalPeriod.tissue: Coded expression for the type of tissue for which the withdrawal period applies, e.g. meat, milk.
 *
 * http://hl7.org/fhir/tissue
 */
var tissue = 'http://hl7.org/fhir/tissue';
/**
 * isSubpotent
 *
 * Immunization.isSubpotent: Indication if a dose is considered to be subpotent. By default, a dose should be considered to be potent.
 *
 * http://hl7.org/fhir/isSubpotent
 */
var isSubpotent = 'http://hl7.org/fhir/isSubpotent';
/**
 * _supportingInfoSequence
 *
 * (Modified) CoverageEligibilityRequest.item.supportingInfoSequence
 *
 * http://hl7.org/fhir/_supportingInfoSequence
 */
var _supportingInfoSequence = 'http://hl7.org/fhir/_supportingInfoSequence';
/**
 * _rating
 *
 * (Modified) Evidence.certainty.subcomponent.rating
 *
 * http://hl7.org/fhir/_rating
 */
var _rating = 'http://hl7.org/fhir/_rating';
/**
 * maternalOrganismName
 *
 * SubstanceSourceMaterial.organism.hybrid.maternalOrganismName: The name of the maternal species constituting the hybrid organism shall be specified. For plants, the parents aren’t always known, and it is unlikely that it will be known which is maternal and which is paternal.
 *
 * http://hl7.org/fhir/maternalOrganismName
 */
var maternalOrganismName = 'http://hl7.org/fhir/maternalOrganismName';
/**
 * CommunicationRequest
 *
 * A request to convey information; e.g. the CDS system proposes that an alert be sent to a responsible provider, the CDS system proposes that the public health agency be notified about a reportable condition.
 *
 * http://hl7.org/fhir/CommunicationRequest
 */
var CommunicationRequest = 'http://hl7.org/fhir/CommunicationRequest';
/**
 * polymer
 *
 * SubstanceDefinition.polymer: Data items specific to polymers.
 *
 * http://hl7.org/fhir/polymer
 */
var polymer = 'http://hl7.org/fhir/polymer';
/**
 * initiatorActive
 *
 * ExampleScenario.process.step.process.step.alternative.step.operation.initiatorActive: If false, the initiator is deactivated right after the operation.
 *
 * http://hl7.org/fhir/initiatorActive
 */
var initiatorActive = 'http://hl7.org/fhir/initiatorActive';
/**
 * _productStatus
 *
 * (Modified) BiologicallyDerivedProduct.productStatus
 *
 * http://hl7.org/fhir/_productStatus
 */
var _productStatus = 'http://hl7.org/fhir/_productStatus';
/**
 * strand
 *
 * MolecularSequence.relative.startingSequence.strand: An absolute reference to a strand. The Watson strand is the strand whose 5'-end is on the short arm of the chromosome, and the Crick strand as the one whose 5'-end is on the long arm.
 *
 * http://hl7.org/fhir/strand
 */
var strand = 'http://hl7.org/fhir/strand';
/**
 * _outputParameters
 *
 * (Modified) GuidanceResponse.outputParameters
 *
 * http://hl7.org/fhir/_outputParameters
 */
var _outputParameters = 'http://hl7.org/fhir/_outputParameters';
/**
 * participantStatus
 *
 * AppointmentResponse.participantStatus: Participation status of the participant. When the status is declined or tentative if the start/end times are different to the appointment, then these times should be interpreted as a requested time change. When the status is accepted, the times can either be the time of the appointment (as a confirmation of the time) or can be empty.
 *
 * http://hl7.org/fhir/participantStatus
 */
var participantStatus = 'http://hl7.org/fhir/participantStatus';
/**
 * label
 *
 * RelatedArtifact.label: A short label that can be used to reference the citation from elsewhere in the containing artifact, such as a footnote index.
 *
 * http://hl7.org/fhir/label
 */
var label = 'http://hl7.org/fhir/label';
/**
 * manipulated
 *
 * Procedure.focalDevice.manipulated: The device that was manipulated (changed) during the procedure.
 *
 * http://hl7.org/fhir/manipulated
 */
var manipulated = 'http://hl7.org/fhir/manipulated';
/**
 * _geometry
 *
 * (Modified) SubstancePolymer.geometry
 *
 * http://hl7.org/fhir/_geometry
 */
var _geometry = 'http://hl7.org/fhir/_geometry';
/**
 * Coding
 *
 * A reference to a code defined by a terminology system.
 *
 * http://hl7.org/fhir/Coding
 */
var Coding = 'http://hl7.org/fhir/Coding';
/**
 * requisition
 *
 * ServiceRequest.requisition: A shared identifier common to all service requests that were authorized more or less simultaneously by a single author, representing the composite or group identifier.
 *
 * http://hl7.org/fhir/requisition
 */
var requisition = 'http://hl7.org/fhir/requisition';
/**
 * InventoryReportInventoryListingComponent
 *
 * InventoryReportInventoryListingComponent: An inventory listing section (grouped by any of the attributes).
 *
 * http://hl7.org/fhir/InventoryReportInventoryListingComponent
 */
var InventoryReportInventoryListingComponent = 'http://hl7.org/fhir/InventoryReportInventoryListingComponent';
/**
 * _parent
 *
 * (Modified) Specimen.parent
 *
 * http://hl7.org/fhir/_parent
 */
var _parent = 'http://hl7.org/fhir/_parent';
/**
 * _net
 *
 * (Modified) Claim.item.net
 *
 * http://hl7.org/fhir/_net
 */
var _net = 'http://hl7.org/fhir/_net';
/**
 * presentation
 *
 * Ingredient.substance.strength.presentation
 *
 * http://hl7.org/fhir/presentation
 */
var presentation = 'http://hl7.org/fhir/presentation';
/**
 * flag
 *
 * List.entry.flag: The flag allows the system constructing the list to indicate the role and significance of the item in the list.
 *
 * http://hl7.org/fhir/flag
 */
var flag = 'http://hl7.org/fhir/flag';
/**
 * hoursOfOperation
 *
 * Location.hoursOfOperation: What days/times during a week is this location usually open, and any exceptions where the location is not available.
 *
 * http://hl7.org/fhir/hoursOfOperation
 */
var hoursOfOperation = 'http://hl7.org/fhir/hoursOfOperation';
/**
 * encounter
 *
 * AdverseEvent.encounter: The Encounter associated with the start of the AdverseEvent.
 *
 * http://hl7.org/fhir/encounter
 */
var encounter = 'http://hl7.org/fhir/encounter';
/**
 * applicability
 *
 * ChargeItemDefinition.propertyGroup.applicability: Expressions that describe applicability criteria for the priceComponent.
 *
 * http://hl7.org/fhir/applicability
 */
var applicability = 'http://hl7.org/fhir/applicability';
/**
 * releaseDate
 *
 * CapabilityStatement.software.releaseDate: Date this version of the software was released.
 *
 * http://hl7.org/fhir/releaseDate
 */
var releaseDate = 'http://hl7.org/fhir/releaseDate';
/**
 * _relationshipType
 *
 * (Modified) ClinicalUseDefinition.indication.otherTherapy.relationshipType
 *
 * http://hl7.org/fhir/_relationshipType
 */
var _relationshipType = 'http://hl7.org/fhir/_relationshipType';
/**
 * _managingOrganization
 *
 * (Modified) Person.managingOrganization
 *
 * http://hl7.org/fhir/_managingOrganization
 */
var _managingOrganization = 'http://hl7.org/fhir/_managingOrganization';
/**
 * derivedFromCanonical
 *
 * SpecimenDefinition.derivedFromCanonical: The canonical URL pointing to another FHIR-defined SpecimenDefinition that is adhered to in whole or in part by this definition.
 *
 * http://hl7.org/fhir/derivedFromCanonical
 */
var derivedFromCanonical = 'http://hl7.org/fhir/derivedFromCanonical';
/**
 * _hasSeverity
 *
 * (Modified) ConditionDefinition.hasSeverity
 *
 * http://hl7.org/fhir/_hasSeverity
 */
var _hasSeverity = 'http://hl7.org/fhir/_hasSeverity';
/**
 * cTerminalModification
 *
 * SubstanceProtein.subunit.cTerminalModification: The modification at the C-terminal shall be specified.
 *
 * http://hl7.org/fhir/cTerminalModification
 */
var cTerminalModification = 'http://hl7.org/fhir/cTerminalModification';
/**
 * ContentDefinition
 *
 * Contract.ContentDefinition: Precusory content developed with a focus and intent of supporting the formation a Contract instance, which may be associated with and transformable into a Contract.
 *
 * http://hl7.org/fhir/ContentDefinition
 */
var ContentDefinition = 'http://hl7.org/fhir/ContentDefinition';
/**
 * _bodyLandmarkOrientation
 *
 * (Modified) BodyStructure.excludedStructure.bodyLandmarkOrientation
 *
 * http://hl7.org/fhir/_bodyLandmarkOrientation
 */
var _bodyLandmarkOrientation = 'http://hl7.org/fhir/_bodyLandmarkOrientation';
/**
 * relationship
 *
 * PlanDefinition.action.action.relatedAction.relationship: The relationship of the start of this action to the related action.
 *
 * http://hl7.org/fhir/relationship
 */
var relationship = 'http://hl7.org/fhir/relationship';
/**
 * goal
 *
 * PlanDefinition.goal: A goal describes an expected outcome that activities within the plan are intended to achieve. For example, weight loss, restoring an activity of daily living, obtaining herd immunity via immunization, meeting a process improvement objective, meeting the acceptance criteria for a test as specified by a quality specification, etc.
 *
 * http://hl7.org/fhir/goal
 */
var goal = 'http://hl7.org/fhir/goal';
/**
 * _connectivity
 *
 * (Modified) SubstanceNucleicAcid.subunit.linkage.connectivity
 *
 * http://hl7.org/fhir/_connectivity
 */
var _connectivity = 'http://hl7.org/fhir/_connectivity';
/**
 * _listMode
 *
 * (Modified) StructureMap.group.rule.rule.target.listMode
 *
 * http://hl7.org/fhir/_listMode
 */
var _listMode = 'http://hl7.org/fhir/_listMode';
/**
 * _availableTime
 *
 * (Modified) Availability.availableTime
 *
 * http://hl7.org/fhir/_availableTime
 */
var _availableTime = 'http://hl7.org/fhir/_availableTime';
/**
 * property
 *
 * DeviceDefinition.property: Static or essentially fixed characteristics or features of this kind of device that are otherwise not captured in more specific attributes, e.g., time or timing attributes, resolution, accuracy, and physical attributes.
 *
 * http://hl7.org/fhir/property
 */
var property = 'http://hl7.org/fhir/property';
/**
 * _calibration
 *
 * (Modified) DeviceMetric.calibration
 *
 * http://hl7.org/fhir/_calibration
 */
var _calibration = 'http://hl7.org/fhir/_calibration';
/**
 * TerminologyCapabilitiesExpansionParameterComponent
 *
 * TerminologyCapabilitiesExpansionComponent.TerminologyCapabilitiesExpansionParameterComponent: Supported expansion parameter.
 *
 * http://hl7.org/fhir/TerminologyCapabilitiesExpansionParameterComponent
 */
var TerminologyCapabilitiesExpansionParameterComponent = 'http://hl7.org/fhir/TerminologyCapabilitiesExpansionParameterComponent';
/**
 * adjustmentReason
 *
 * ExplanationOfBenefit.payment.adjustmentReason: Reason for the payment adjustment.
 *
 * http://hl7.org/fhir/adjustmentReason
 */
var adjustmentReason = 'http://hl7.org/fhir/adjustmentReason';
/**
 * AdministrableProductDefinitionRouteOfAdministrationTargetSpeciesComponent
 *
 * AdministrableProductDefinitionRouteOfAdministrationComponent.AdministrableProductDefinitionRouteOfAdministrationTargetSpeciesComponent: A species for which this route applies.
 *
 * http://hl7.org/fhir/AdministrableProductDefinitionRouteOfAdministrationTargetSpeciesComponent
 */
var AdministrableProductDefinitionRouteOfAdministrationTargetSpeciesComponent = 'http://hl7.org/fhir/AdministrableProductDefinitionRouteOfAdministrationTargetSpeciesComponent';
/**
 * Basic
 *
 * Basic is used for handling concepts not yet defined in FHIR, narrative-only resources that don't map to an existing resource, and custom resources not appropriate for inclusion in the FHIR specification.
 *
 * http://hl7.org/fhir/Basic
 */
var Basic = 'http://hl7.org/fhir/Basic';
/**
 * _isDerived
 *
 * (Modified) SpecimenDefinition.typeTested.isDerived
 *
 * http://hl7.org/fhir/_isDerived
 */
var _isDerived = 'http://hl7.org/fhir/_isDerived';
/**
 * hierarchical
 *
 * TerminologyCapabilities.expansion.hierarchical: Whether the server can return nested value sets.
 *
 * http://hl7.org/fhir/hierarchical
 */
var hierarchical = 'http://hl7.org/fhir/hierarchical';
/**
 * _resultForCreate
 *
 * (Modified) SubscriptionTopic.resourceTrigger.queryCriteria.resultForCreate
 *
 * http://hl7.org/fhir/_resultForCreate
 */
var _resultForCreate = 'http://hl7.org/fhir/_resultForCreate';
/**
 * _deviceName
 *
 * (Modified) DeviceDefinition.deviceName
 *
 * http://hl7.org/fhir/_deviceName
 */
var _deviceName = 'http://hl7.org/fhir/_deviceName';
/**
 * _startDate
 *
 * (Modified) ResearchSubject.progress.startDate
 *
 * http://hl7.org/fhir/_startDate
 */
var _startDate = 'http://hl7.org/fhir/_startDate';
/**
 * Attachment
 *
 * For referring to data content defined in other formats.
 *
 * http://hl7.org/fhir/Attachment
 */
var Attachment = 'http://hl7.org/fhir/Attachment';
/**
 * _patientPreparation
 *
 * (Modified) SpecimenDefinition.patientPreparation
 *
 * http://hl7.org/fhir/_patientPreparation
 */
var _patientPreparation = 'http://hl7.org/fhir/_patientPreparation';
/**
 * CitationCitedArtifactPublicationFormComponent
 *
 * CitationCitedArtifactComponent.CitationCitedArtifactPublicationFormComponent: If multiple, used to represent alternative forms of the article that are not separate citations.
 *
 * http://hl7.org/fhir/CitationCitedArtifactPublicationFormComponent
 */
var CitationCitedArtifactPublicationFormComponent = 'http://hl7.org/fhir/CitationCitedArtifactPublicationFormComponent';
/**
 * windowStart
 *
 * MolecularSequence.relative.startingSequence.windowStart: Start position of the window on the starting sequence. This value should honor the rules of the coordinateSystem.
 *
 * http://hl7.org/fhir/windowStart
 */
var windowStart = 'http://hl7.org/fhir/windowStart';
/**
 * _propertyGroup
 *
 * (Modified) ChargeItemDefinition.propertyGroup
 *
 * http://hl7.org/fhir/_propertyGroup
 */
var _propertyGroup = 'http://hl7.org/fhir/_propertyGroup';
/**
 * languageCode
 *
 * DeviceDefinition.languageCode: Language code for the human-readable text strings produced by the device (all supported).
 *
 * http://hl7.org/fhir/languageCode
 */
var languageCode = 'http://hl7.org/fhir/languageCode';
/**
 * _canPushUpdates
 *
 * (Modified) VerificationResult.primarySource.canPushUpdates
 *
 * http://hl7.org/fhir/_canPushUpdates
 */
var _canPushUpdates = 'http://hl7.org/fhir/_canPushUpdates';
/**
 * groupingBehavior
 *
 * PlanDefinition.action.action.groupingBehavior: Defines the grouping behavior for the action and its children.
 *
 * http://hl7.org/fhir/groupingBehavior
 */
var groupingBehavior = 'http://hl7.org/fhir/groupingBehavior';
/**
 * for
 *
 * Ingredient.for: The product which this ingredient is a constituent part of.
 * Note that `for` is a reserved Javascript keyword, and is therefore suffixed by `__workaround`.
 * For a list of reserved keywords, see https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Lexical_grammar#Keywords.
 *
 * http://hl7.org/fhir/for
 */
var for__workaround = 'http://hl7.org/fhir/for';
/**
 * _studyUid
 *
 * (Modified) ImagingSelection.studyUid
 *
 * http://hl7.org/fhir/_studyUid
 */
var _studyUid = 'http://hl7.org/fhir/_studyUid';
/**
 * _event
 *
 * (Modified) MessageHeader.event
 *
 * http://hl7.org/fhir/_event
 */
var _event = 'http://hl7.org/fhir/_event';
/**
 * informationProvider
 *
 * CommunicationRequest.informationProvider: The entity (e.g. person, organization, clinical information system, or device) which is to be the source of the communication.
 *
 * http://hl7.org/fhir/informationProvider
 */
var informationProvider = 'http://hl7.org/fhir/informationProvider';
/**
 * network
 *
 * InsurancePlan.coverage.network: Reference to the network that providing the type of coverage.
 *
 * http://hl7.org/fhir/network
 */
var network = 'http://hl7.org/fhir/network';
/**
 * _manufacturedDoseForm
 *
 * (Modified) ManufacturedItemDefinition.manufacturedDoseForm
 *
 * http://hl7.org/fhir/_manufacturedDoseForm
 */
var _manufacturedDoseForm = 'http://hl7.org/fhir/_manufacturedDoseForm';
/**
 * assert
 *
 * TestScript.setup.action.assert: Evaluates the results of previous operations to determine if the server under test behaves appropriately.
 *
 * http://hl7.org/fhir/assert
 */
var assert = 'http://hl7.org/fhir/assert';
/**
 * _warningOnly
 *
 * (Modified) TestScript.test.action.assert.warningOnly
 *
 * http://hl7.org/fhir/_warningOnly
 */
var _warningOnly = 'http://hl7.org/fhir/_warningOnly';
/**
 * isSummary
 *
 * ElementDefinition.isSummary: Whether the element should be included if a client requests a search with the parameter _summary=true.
 *
 * http://hl7.org/fhir/isSummary
 */
var isSummary = 'http://hl7.org/fhir/isSummary';
/**
 * attachedDocument
 *
 * RegulatedAuthorization.attachedDocument: Additional information or supporting documentation about the authorization.
 *
 * http://hl7.org/fhir/attachedDocument
 */
var attachedDocument = 'http://hl7.org/fhir/attachedDocument';
/**
 * _unit
 *
 * (Modified) SubstancePolymer.repeat.repeatUnit.unit
 *
 * http://hl7.org/fhir/_unit
 */
var _unit = 'http://hl7.org/fhir/_unit';
/**
 * _endDate
 *
 * (Modified) ResearchSubject.progress.endDate
 *
 * http://hl7.org/fhir/_endDate
 */
var _endDate = 'http://hl7.org/fhir/_endDate';
/**
 * authoredOn
 *
 * RequestOrchestration.authoredOn: Indicates when the request orchestration was created.
 *
 * http://hl7.org/fhir/authoredOn
 */
var authoredOn = 'http://hl7.org/fhir/authoredOn';
/**
 * _geographicalLocation
 *
 * (Modified) SubstanceSourceMaterial.geographicalLocation
 *
 * http://hl7.org/fhir/_geographicalLocation
 */
var _geographicalLocation = 'http://hl7.org/fhir/_geographicalLocation';
/**
 * CitationCitedArtifactClassificationComponent
 *
 * CitationCitedArtifactComponent.CitationCitedArtifactClassificationComponent: The assignment to an organizing scheme.
 *
 * http://hl7.org/fhir/CitationCitedArtifactClassificationComponent
 */
var CitationCitedArtifactClassificationComponent = 'http://hl7.org/fhir/CitationCitedArtifactClassificationComponent';
/**
 * userSelected
 *
 * Coding.userSelected: Indicates that this coding was chosen by a user directly - e.g. off a pick list of available items (codes or displays).
 *
 * http://hl7.org/fhir/userSelected
 */
var userSelected = 'http://hl7.org/fhir/userSelected';
/**
 * _prognosisCodeableConcept
 *
 * (Modified) ClinicalImpression.prognosisCodeableConcept
 *
 * http://hl7.org/fhir/_prognosisCodeableConcept
 */
var _prognosisCodeableConcept = 'http://hl7.org/fhir/_prognosisCodeableConcept';
/**
 * dateCriterion
 *
 * ImmunizationRecommendation.recommendation.dateCriterion: Vaccine date recommendations.  For example, earliest date to administer, latest date to administer, etc.
 *
 * http://hl7.org/fhir/dateCriterion
 */
var dateCriterion = 'http://hl7.org/fhir/dateCriterion';
/**
 * additionalInstruction
 *
 * Dosage.additionalInstruction: Supplemental instructions to the patient on how to take the medication  (e.g. "with meals" or"take half to one hour before food") or warnings for the patient about the medication (e.g. "may cause drowsiness" or "avoid exposure of skin to direct sunlight or sunlamps").
 *
 * http://hl7.org/fhir/additionalInstruction
 */
var additionalInstruction = 'http://hl7.org/fhir/additionalInstruction';
/**
 * specialPrecautionsForStorage
 *
 * ProductShelfLife.specialPrecautionsForStorage: Special precautions for storage, if any, can be specified using an appropriate controlled vocabulary The controlled term and the controlled term identifier shall be specified.
 *
 * http://hl7.org/fhir/specialPrecautionsForStorage
 */
var specialPrecautionsForStorage = 'http://hl7.org/fhir/specialPrecautionsForStorage';
/**
 * population
 *
 * ClinicalUseDefinition.population: The population group to which this applies.
 *
 * http://hl7.org/fhir/population
 */
var population = 'http://hl7.org/fhir/population';
/**
 * _member
 *
 * (Modified) Group.member
 *
 * http://hl7.org/fhir/_member
 */
var _member = 'http://hl7.org/fhir/_member';
/**
 * securityLabel
 *
 * AuditEvent.entity.securityLabel: Security labels for the identified entity.
 *
 * http://hl7.org/fhir/securityLabel
 */
var securityLabel = 'http://hl7.org/fhir/securityLabel';
/**
 * _renderedDosageInstruction
 *
 * (Modified) MedicationStatement.renderedDosageInstruction
 *
 * http://hl7.org/fhir/_renderedDosageInstruction
 */
var _renderedDosageInstruction = 'http://hl7.org/fhir/_renderedDosageInstruction';
/**
 * Notes
 *
 * PaymentReconciliation.Notes: A note that describes or explains the processing in a human readable form.
 *
 * http://hl7.org/fhir/Notes
 */
var Notes = 'http://hl7.org/fhir/Notes';
/**
 * _dynamicValue
 *
 * (Modified) RequestOrchestration.action.action.dynamicValue
 *
 * http://hl7.org/fhir/_dynamicValue
 */
var _dynamicValue = 'http://hl7.org/fhir/_dynamicValue';
/**
 * _confidentialityIndicator
 *
 * (Modified) MedicinalProductDefinition.operation.confidentialityIndicator
 *
 * http://hl7.org/fhir/_confidentialityIndicator
 */
var _confidentialityIndicator = 'http://hl7.org/fhir/_confidentialityIndicator';
/**
 * _intendedUse
 *
 * (Modified) RegulatedAuthorization.intendedUse
 *
 * http://hl7.org/fhir/_intendedUse
 */
var _intendedUse = 'http://hl7.org/fhir/_intendedUse';
/**
 * lastUpdated
 *
 * Meta.lastUpdated: When the resource last changed - e.g. when the version changed.
 *
 * http://hl7.org/fhir/lastUpdated
 */
var lastUpdated = 'http://hl7.org/fhir/lastUpdated';
/**
 * deceased
 *
 * Practitioner.deceased
 *
 * http://hl7.org/fhir/deceased
 */
var deceased = 'http://hl7.org/fhir/deceased';
/**
 * NutritionOrderEnteralFormulaAdditiveComponent
 *
 * NutritionOrderEnteralFormulaComponent.NutritionOrderEnteralFormulaAdditiveComponent: Indicates modular components to be provided in addition or mixed with the base formula.
 *
 * http://hl7.org/fhir/NutritionOrderEnteralFormulaAdditiveComponent
 */
var NutritionOrderEnteralFormulaAdditiveComponent = 'http://hl7.org/fhir/NutritionOrderEnteralFormulaAdditiveComponent';
/**
 * designation
 *
 * ValueSet.expansion.contains.designation: Additional representations for this item - other languages, aliases, specialized purposes, used for particular purposes, etc. These are relevant when the conditions of the expansion do not fix to a single correct representation.
 *
 * http://hl7.org/fhir/designation
 */
var designation = 'http://hl7.org/fhir/designation';
/**
 * reportedDateTime
 *
 * InventoryReport.reportedDateTime: When the report has been submitted.
 *
 * http://hl7.org/fhir/reportedDateTime
 */
var reportedDateTime = 'http://hl7.org/fhir/reportedDateTime';
/**
 * productOrServiceEnd
 *
 * ExplanationOfBenefit.addItem.productOrServiceEnd: This contains the end of a range of product, service, drug or other billing codes for the item. This element is not used when the .productOrService is a group code. This value may only be present when a .productOfService code has been provided to convey the start of the range. Typically this value may be used only with preauthorizations and not with claims.
 *
 * http://hl7.org/fhir/productOrServiceEnd
 */
var productOrServiceEnd = 'http://hl7.org/fhir/productOrServiceEnd';
/**
 * teardown
 *
 * TestScript.teardown: A series of operations required to clean up after all the tests are executed (successfully or otherwise).
 *
 * http://hl7.org/fhir/teardown
 */
var teardown = 'http://hl7.org/fhir/teardown';
/**
 * securityLabelNumber
 *
 * Contract.term.action.securityLabelNumber: Security labels that protects the action.
 *
 * http://hl7.org/fhir/securityLabelNumber
 */
var securityLabelNumber = 'http://hl7.org/fhir/securityLabelNumber';
/**
 * _manufactureDate
 *
 * (Modified) Device.manufactureDate
 *
 * http://hl7.org/fhir/_manufactureDate
 */
var _manufactureDate = 'http://hl7.org/fhir/_manufactureDate';
/**
 * _textFilter
 *
 * (Modified) TerminologyCapabilities.expansion.textFilter
 *
 * http://hl7.org/fhir/_textFilter
 */
var _textFilter = 'http://hl7.org/fhir/_textFilter';
/**
 * _route
 *
 * (Modified) MedicinalProductDefinition.route
 *
 * http://hl7.org/fhir/_route
 */
var _route = 'http://hl7.org/fhir/_route';
/**
 * parentSubstanceName
 *
 * SubstanceSourceMaterial.parentSubstanceName: The parent substance of the Herbal Drug, or Herbal preparation.
 *
 * http://hl7.org/fhir/parentSubstanceName
 */
var parentSubstanceName = 'http://hl7.org/fhir/parentSubstanceName';
/**
 * _docStatus
 *
 * (Modified) DocumentReference.docStatus
 *
 * http://hl7.org/fhir/_docStatus
 */
var _docStatus = 'http://hl7.org/fhir/_docStatus';
/**
 * ArtifactAssessmentContentComponentContentContent
 *
 * If the informationType is container, the components of the content.
 *
 * http://hl7.org/fhir/ArtifactAssessmentContentComponentContentContent
 */
var ArtifactAssessmentContentComponentContentContent = 'http://hl7.org/fhir/ArtifactAssessmentContentComponentContentContent';
/**
 * _subscriber
 *
 * (Modified) Coverage.subscriber
 *
 * http://hl7.org/fhir/_subscriber
 */
var _subscriber = 'http://hl7.org/fhir/_subscriber';
/**
 * workflowStatus
 *
 * ArtifactAssessment.workflowStatus: Indicates the workflow status of the comment or change request.
 *
 * http://hl7.org/fhir/workflowStatus
 */
var workflowStatus = 'http://hl7.org/fhir/workflowStatus';
/**
 * phylum
 *
 * SubstanceSourceMaterial.organism.organismGeneral.phylum: The phylum of an organism shall be specified.
 *
 * http://hl7.org/fhir/phylum
 */
var phylum = 'http://hl7.org/fhir/phylum';
/**
 * _mustSupport
 *
 * (Modified) ElementDefinition.mustSupport
 *
 * http://hl7.org/fhir/_mustSupport
 */
var _mustSupport = 'http://hl7.org/fhir/_mustSupport';
/**
 * forecastStatus
 *
 * ImmunizationRecommendation.recommendation.forecastStatus: Indicates the patient status with respect to the path to immunity for the target disease.
 *
 * http://hl7.org/fhir/forecastStatus
 */
var forecastStatus = 'http://hl7.org/fhir/forecastStatus';
/**
 * _closure
 *
 * (Modified) TerminologyCapabilities.closure
 *
 * http://hl7.org/fhir/_closure
 */
var _closure = 'http://hl7.org/fhir/_closure';
/**
 * _abstract
 *
 * (Modified) ValueSet.expansion.contains.contains.abstract
 *
 * http://hl7.org/fhir/_abstract
 */
var _abstract = 'http://hl7.org/fhir/_abstract';
/**
 * relatedClinicalInformation
 *
 * MedicationStatement.relatedClinicalInformation: Link to information that is relevant to a medication statement, for example, illicit drug use, gestational age, etc.
 *
 * http://hl7.org/fhir/relatedClinicalInformation
 */
var relatedClinicalInformation = 'http://hl7.org/fhir/relatedClinicalInformation';
/**
 * PersonCommunicationComponent
 *
 * PersonCommunicationComponent: A language which may be used to communicate with the person about his or her health.
 *
 * http://hl7.org/fhir/PersonCommunicationComponent
 */
var PersonCommunicationComponent = 'http://hl7.org/fhir/PersonCommunicationComponent';
/**
 * _relativePath
 *
 * (Modified) ImplementationGuide.manifest.resource.relativePath
 *
 * http://hl7.org/fhir/_relativePath
 */
var _relativePath = 'http://hl7.org/fhir/_relativePath';
/**
 * CitationCitedArtifactVersionComponent
 *
 * CitationCitedArtifactComponent.CitationCitedArtifactVersionComponent: The defined version of the cited artifact.
 *
 * http://hl7.org/fhir/CitationCitedArtifactVersionComponent
 */
var CitationCitedArtifactVersionComponent = 'http://hl7.org/fhir/CitationCitedArtifactVersionComponent';
/**
 * _paging
 *
 * (Modified) TerminologyCapabilities.expansion.paging
 *
 * http://hl7.org/fhir/_paging
 */
var _paging = 'http://hl7.org/fhir/_paging';
/**
 * _uniqueId
 *
 * (Modified) NamingSystem.uniqueId
 *
 * http://hl7.org/fhir/_uniqueId
 */
var _uniqueId = 'http://hl7.org/fhir/_uniqueId';
/**
 * _readOnly
 *
 * (Modified) Questionnaire.item.item.readOnly
 *
 * http://hl7.org/fhir/_readOnly
 */
var _readOnly = 'http://hl7.org/fhir/_readOnly';
/**
 * _jurisdiction
 *
 * (Modified) DeviceDefinition.packaging.packaging.udiDeviceIdentifier.jurisdiction
 *
 * http://hl7.org/fhir/_jurisdiction
 */
var _jurisdiction = 'http://hl7.org/fhir/_jurisdiction';
/**
 * _treatment
 *
 * (Modified) ClinicalUseDefinition.indication.otherTherapy.treatment
 *
 * http://hl7.org/fhir/_treatment
 */
var _treatment = 'http://hl7.org/fhir/_treatment';
/**
 * _responsibleParty
 *
 * (Modified) MedicationDispense.substitution.responsibleParty
 *
 * http://hl7.org/fhir/_responsibleParty
 */
var _responsibleParty = 'http://hl7.org/fhir/_responsibleParty';
/**
 * RequestOrchestrationActionComponentActionAction
 *
 * Sub actions.
 *
 * http://hl7.org/fhir/RequestOrchestrationActionComponentActionAction
 */
var RequestOrchestrationActionComponentActionAction = 'http://hl7.org/fhir/RequestOrchestrationActionComponentActionAction';
/**
 * _role
 *
 * (Modified) PlanDefinition.action.action.participant.role
 *
 * http://hl7.org/fhir/_role
 */
var _role = 'http://hl7.org/fhir/_role';
/**
 * TestPlanDependencyComponent
 *
 * TestPlanDependencyComponent: The required criteria to execute the test plan - e.g. preconditions, previous tests...
 *
 * http://hl7.org/fhir/TestPlanDependencyComponent
 */
var TestPlanDependencyComponent = 'http://hl7.org/fhir/TestPlanDependencyComponent';
/**
 * Binary
 *
 * A resource that represents the data of a single raw artifact as digital content accessible in its native format.  A Binary resource can contain any content, whether text, image, pdf, zip archive, etc.
 *
 * http://hl7.org/fhir/Binary
 */
var Binary = 'http://hl7.org/fhir/Binary';
/**
 * contentDerivative
 *
 * Contract.contentDerivative: The minimal content derived from the basal information source at a specific stage in its lifecycle.
 *
 * http://hl7.org/fhir/contentDerivative
 */
var contentDerivative = 'http://hl7.org/fhir/contentDerivative';
/**
 * inforce
 *
 * CoverageEligibilityResponse.insurance.inforce: Flag indicating if the coverage provided is inforce currently if no service date(s) specified or for the whole duration of the service dates.
 *
 * http://hl7.org/fhir/inforce
 */
var inforce = 'http://hl7.org/fhir/inforce';
/**
 * RiskAssessmentPredictionComponent
 *
 * RiskAssessmentPredictionComponent: Describes the expected outcome for the subject.
 *
 * http://hl7.org/fhir/RiskAssessmentPredictionComponent
 */
var RiskAssessmentPredictionComponent = 'http://hl7.org/fhir/RiskAssessmentPredictionComponent';
/**
 * _enteredDate
 *
 * (Modified) ChargeItem.enteredDate
 *
 * http://hl7.org/fhir/_enteredDate
 */
var _enteredDate = 'http://hl7.org/fhir/_enteredDate';
/**
 * _legalStatusOfSupply
 *
 * (Modified) PackagedProductDefinition.legalStatusOfSupply
 *
 * http://hl7.org/fhir/_legalStatusOfSupply
 */
var _legalStatusOfSupply = 'http://hl7.org/fhir/_legalStatusOfSupply';
/**
 * valueAlternatives
 *
 * ElementDefinition.valueAlternatives: Specifies a list of extensions that can appear in place of a primitive value.
 *
 * http://hl7.org/fhir/valueAlternatives
 */
var valueAlternatives = 'http://hl7.org/fhir/valueAlternatives';
/**
 * subject
 *
 * Account.subject: Identifies the entity which incurs the expenses. While the immediate recipients of services or goods might be entities related to the subject, the expenses were ultimately incurred by the subject of the Account.
 *
 * http://hl7.org/fhir/subject
 */
var subject = 'http://hl7.org/fhir/subject';
/**
 * _publicationDate
 *
 * (Modified) Contract.contentDefinition.publicationDate
 *
 * http://hl7.org/fhir/_publicationDate
 */
var _publicationDate = 'http://hl7.org/fhir/_publicationDate';
/**
 * occurrenceChanged
 *
 * Appointment.occurrenceChanged: This appointment varies from the recurring pattern.
 *
 * http://hl7.org/fhir/occurrenceChanged
 */
var occurrenceChanged = 'http://hl7.org/fhir/occurrenceChanged';
/**
 * _referralRequest
 *
 * (Modified) EpisodeOfCare.referralRequest
 *
 * http://hl7.org/fhir/_referralRequest
 */
var _referralRequest = 'http://hl7.org/fhir/_referralRequest';
/**
 * friday
 *
 * Appointment.recurrenceTemplate.weeklyTemplate.friday: Indicates that recurring appointments should occur on Fridays.
 *
 * http://hl7.org/fhir/friday
 */
var friday = 'http://hl7.org/fhir/friday';
/**
 * productType
 *
 * MedicationKnowledge.productType: Category of the medication or product (e.g. branded product, therapeutic moeity, generic product, innovator product, etc.).
 *
 * http://hl7.org/fhir/productType
 */
var productType = 'http://hl7.org/fhir/productType';
/**
 * _payeeType
 *
 * (Modified) ClaimResponse.payeeType
 *
 * http://hl7.org/fhir/_payeeType
 */
var _payeeType = 'http://hl7.org/fhir/_payeeType';
/**
 * _fixed
 *
 * (Modified) ElementDefinition.fixed
 *
 * http://hl7.org/fhir/_fixed
 */
var _fixed = 'http://hl7.org/fhir/_fixed';
/**
 * _nTerminalModification
 *
 * (Modified) SubstanceProtein.subunit.nTerminalModification
 *
 * http://hl7.org/fhir/_nTerminalModification
 */
var _nTerminalModification = 'http://hl7.org/fhir/_nTerminalModification';
/**
 * _progressStatus
 *
 * (Modified) ResearchStudy.progressStatus
 *
 * http://hl7.org/fhir/_progressStatus
 */
var _progressStatus = 'http://hl7.org/fhir/_progressStatus';
/**
 * _age
 *
 * (Modified) ObservationDefinition.component.qualifiedValue.age
 *
 * http://hl7.org/fhir/_age
 */
var _age = 'http://hl7.org/fhir/_age';
/**
 * _verificationDate
 *
 * (Modified) Consent.verification.verificationDate
 *
 * http://hl7.org/fhir/_verificationDate
 */
var _verificationDate = 'http://hl7.org/fhir/_verificationDate';
/**
 * CompartmentDefinitionResourceComponent
 *
 * CompartmentDefinitionResourceComponent: Information about how a resource is related to the compartment.
 *
 * http://hl7.org/fhir/CompartmentDefinitionResourceComponent
 */
var CompartmentDefinitionResourceComponent = 'http://hl7.org/fhir/CompartmentDefinitionResourceComponent';
/**
 * _questionnaire
 *
 * (Modified) QuestionnaireResponse.questionnaire
 *
 * http://hl7.org/fhir/_questionnaire
 */
var _questionnaire = 'http://hl7.org/fhir/_questionnaire';
/**
 * TestScript
 *
 * A structured set of tests against a FHIR server or client implementation to determine compliance against the FHIR specification.
 *
 * http://hl7.org/fhir/TestScript
 */
var TestScript = 'http://hl7.org/fhir/TestScript';
/**
 * billingStatus
 *
 * Account.billingStatus: The BillingStatus tracks the lifecycle of the account through the billing process. It indicates how transactions are treated when they are allocated to the account.
 *
 * http://hl7.org/fhir/billingStatus
 */
var billingStatus = 'http://hl7.org/fhir/billingStatus';
/**
 * _resourceTrigger
 *
 * (Modified) SubscriptionTopic.resourceTrigger
 *
 * http://hl7.org/fhir/_resourceTrigger
 */
var _resourceTrigger = 'http://hl7.org/fhir/_resourceTrigger';
/**
 * compose
 *
 * ValueSet.compose: A set of criteria that define the contents of the value set by including or excluding codes selected from the specified code system(s) that the value set draws from. This is also known as the Content Logical Definition (CLD).
 *
 * http://hl7.org/fhir/compose
 */
var compose = 'http://hl7.org/fhir/compose';
/**
 * _submitter
 *
 * (Modified) PaymentReconciliation.allocation.submitter
 *
 * http://hl7.org/fhir/_submitter
 */
var _submitter = 'http://hl7.org/fhir/_submitter';
/**
 * _productReference
 *
 * (Modified) InventoryItem.productReference
 *
 * http://hl7.org/fhir/_productReference
 */
var _productReference = 'http://hl7.org/fhir/_productReference';
/**
 * payment
 *
 * ClaimResponse.payment: Payment details for the adjudication of the claim.
 *
 * http://hl7.org/fhir/payment
 */
var payment = 'http://hl7.org/fhir/payment';
/**
 * rateAggregation
 *
 * Measure.group.rateAggregation: Describes how to combine the information calculated, based on logic in each of several populations, into one summarized result.
 *
 * http://hl7.org/fhir/rateAggregation
 */
var rateAggregation = 'http://hl7.org/fhir/rateAggregation';
/**
 * OrganizationQualificationComponent
 *
 * OrganizationQualificationComponent: The official certifications, accreditations, training, designations and licenses that authorize and/or otherwise endorse the provision of care by the organization.

For example, an approval to provide a type of services issued by a certifying body (such as the US Joint Commission) to an organization.
 *
 * http://hl7.org/fhir/OrganizationQualificationComponent
 */
var OrganizationQualificationComponent = 'http://hl7.org/fhir/OrganizationQualificationComponent';
/**
 * identityCertificate
 *
 * VerificationResult.validator.identityCertificate: A digital identity certificate associated with the validator.
 *
 * http://hl7.org/fhir/identityCertificate
 */
var identityCertificate = 'http://hl7.org/fhir/identityCertificate';
/**
 * _subDetail
 *
 * (Modified) ExplanationOfBenefit.addItem.detail.subDetail
 *
 * http://hl7.org/fhir/_subDetail
 */
var _subDetail = 'http://hl7.org/fhir/_subDetail';
/**
 * contextInvariant
 *
 * StructureDefinition.contextInvariant: A set of rules as FHIRPath Invariants about when the extension can be used (e.g. co-occurrence variants for the extension). All the rules must be true.
 *
 * http://hl7.org/fhir/contextInvariant
 */
var contextInvariant = 'http://hl7.org/fhir/contextInvariant';
/**
 * _suffix
 *
 * (Modified) HumanName.suffix
 *
 * http://hl7.org/fhir/_suffix
 */
var _suffix = 'http://hl7.org/fhir/_suffix';
/**
 * _recurrenceId
 *
 * (Modified) AppointmentResponse.recurrenceId
 *
 * http://hl7.org/fhir/_recurrenceId
 */
var _recurrenceId = 'http://hl7.org/fhir/_recurrenceId';
/**
 * dispenseInterval
 *
 * MedicationRequest.dispenseRequest.dispenseInterval: The minimum period of time that must occur between dispenses of the medication.
 *
 * http://hl7.org/fhir/dispenseInterval
 */
var dispenseInterval = 'http://hl7.org/fhir/dispenseInterval';
/**
 * _map
 *
 * (Modified) ElementDefinition.mapping.map
 *
 * http://hl7.org/fhir/_map
 */
var _map = 'http://hl7.org/fhir/_map';
/**
 * _lensSpecification
 *
 * (Modified) VisionPrescription.lensSpecification
 *
 * http://hl7.org/fhir/_lensSpecification
 */
var _lensSpecification = 'http://hl7.org/fhir/_lensSpecification';
/**
 * allergyIntolerance
 *
 * NutritionOrder.allergyIntolerance: A link to a record of allergies or intolerances  which should be included in the nutrition order.
 *
 * http://hl7.org/fhir/allergyIntolerance
 */
var allergyIntolerance = 'http://hl7.org/fhir/allergyIntolerance';
/**
 * asset
 *
 * Contract.term.group.asset: Contract Term Asset List.
 *
 * http://hl7.org/fhir/asset
 */
var asset = 'http://hl7.org/fhir/asset';
/**
 * CoverageEligibilityResponse
 *
 * This resource provides eligibility and plan details from the processing of an CoverageEligibilityRequest resource.
 *
 * http://hl7.org/fhir/CoverageEligibilityResponse
 */
var CoverageEligibilityResponse = 'http://hl7.org/fhir/CoverageEligibilityResponse';
/**
 * OperationDefinitionParameterComponentParameter
 *
 * The parts of a nested Parameter.
 *
 * http://hl7.org/fhir/OperationDefinitionParameterComponentParameter
 */
var OperationDefinitionParameterComponentParameter = 'http://hl7.org/fhir/OperationDefinitionParameterComponentParameter';
/**
 * packagedMedicinalProduct
 *
 * MedicinalProductDefinition.packagedMedicinalProduct: Package type for the product. See also the PackagedProductDefinition resource.
 *
 * http://hl7.org/fhir/packagedMedicinalProduct
 */
var packagedMedicinalProduct = 'http://hl7.org/fhir/packagedMedicinalProduct';
/**
 * _count
 *
 * (Modified) DeviceDefinition.packaging.packaging.count
 *
 * http://hl7.org/fhir/_count
 */
var _count = 'http://hl7.org/fhir/_count';
/**
 * SubstancePolymerRepeatRepeatUnitDegreeOfPolymerisationComponent
 *
 * SubstancePolymerRepeatComponent.SubstancePolymerRepeatRepeatUnitComponent.SubstancePolymerRepeatRepeatUnitDegreeOfPolymerisationComponent: Applies to homopolymer and block co-polymers where the degree of polymerisation within a block can be described.
 *
 * http://hl7.org/fhir/SubstancePolymerRepeatRepeatUnitDegreeOfPolymerisationComponent
 */
var SubstancePolymerRepeatRepeatUnitDegreeOfPolymerisationComponent = 'http://hl7.org/fhir/SubstancePolymerRepeatRepeatUnitDegreeOfPolymerisationComponent';
/**
 * adjudication
 *
 * ExplanationOfBenefit.adjudication: The adjudication results which are presented at the header level rather than at the line-item or add-item levels.
 *
 * http://hl7.org/fhir/adjudication
 */
var adjudication = 'http://hl7.org/fhir/adjudication';
/**
 * RequestOrchestrationActionConditionComponent
 *
 * RequestOrchestrationActionComponentAction.RequestOrchestrationActionConditionComponent: An expression that describes applicability criteria, or start/stop conditions for the action.
 *
 * http://hl7.org/fhir/RequestOrchestrationActionConditionComponent
 */
var RequestOrchestrationActionConditionComponent = 'http://hl7.org/fhir/RequestOrchestrationActionConditionComponent';
/**
 * validator
 *
 * VerificationResult.validator: Information about the entity validating information.
 *
 * http://hl7.org/fhir/validator
 */
var validator = 'http://hl7.org/fhir/validator';
/**
 * _gene
 *
 * (Modified) SubstanceReferenceInformation.gene.gene
 *
 * http://hl7.org/fhir/_gene
 */
var _gene = 'http://hl7.org/fhir/_gene';
/**
 * _length
 *
 * (Modified) SubstanceProtein.subunit.length
 *
 * http://hl7.org/fhir/_length
 */
var _length = 'http://hl7.org/fhir/_length';
/**
 * series
 *
 * ImmunizationEvaluation.series: One possible path to achieve presumed immunity against a disease - within the context of an authority.
 *
 * http://hl7.org/fhir/series
 */
var series = 'http://hl7.org/fhir/series';
/**
 * maxDosePerAdministration
 *
 * Dosage.maxDosePerAdministration: Upper limit on medication per administration.
 *
 * http://hl7.org/fhir/maxDosePerAdministration
 */
var maxDosePerAdministration = 'http://hl7.org/fhir/maxDosePerAdministration';
/**
 * _performerRole
 *
 * (Modified) Contract.term.group.action.performerRole
 *
 * http://hl7.org/fhir/_performerRole
 */
var _performerRole = 'http://hl7.org/fhir/_performerRole';
/**
 * _balance
 *
 * (Modified) Account.balance
 *
 * http://hl7.org/fhir/_balance
 */
var _balance = 'http://hl7.org/fhir/_balance';
/**
 * _correctiveAction
 *
 * (Modified) DeviceDefinition.correctiveAction
 *
 * http://hl7.org/fhir/_correctiveAction
 */
var _correctiveAction = 'http://hl7.org/fhir/_correctiveAction';
/**
 * dispenser
 *
 * MedicationRequest.dispenseRequest.dispenser: Indicates the intended performing Organization that will dispense the medication as specified by the prescriber.
 *
 * http://hl7.org/fhir/dispenser
 */
var dispenser = 'http://hl7.org/fhir/dispenser';
/**
 * NutritionOrderOralDietComponent
 *
 * NutritionOrderOralDietComponent: Diet given orally in contrast to enteral (tube) feeding.
 *
 * http://hl7.org/fhir/NutritionOrderOralDietComponent
 */
var NutritionOrderOralDietComponent = 'http://hl7.org/fhir/NutritionOrderOralDietComponent';
/**
 * _meaning
 *
 * (Modified) Permission.rule.data.resource.meaning
 *
 * http://hl7.org/fhir/_meaning
 */
var _meaning = 'http://hl7.org/fhir/_meaning';
/**
 * endParam
 *
 * CompartmentDefinition.resource.endParam: Search Parameter for mapping requests made with $everything.end (e.g. on [Patient.$everything](patient-operation-everything.html)).
 *
 * http://hl7.org/fhir/endParam
 */
var endParam = 'http://hl7.org/fhir/endParam';
/**
 * _provider
 *
 * (Modified) CoverageEligibilityRequest.item.provider
 *
 * http://hl7.org/fhir/_provider
 */
var _provider = 'http://hl7.org/fhir/_provider';
/**
 * inResponseTo
 *
 * Communication.inResponseTo: Prior communication that this communication is in response to.
 *
 * http://hl7.org/fhir/inResponseTo
 */
var inResponseTo = 'http://hl7.org/fhir/inResponseTo';
/**
 * authorDescription
 *
 * SubstanceSourceMaterial.organism.author.authorDescription: The author of an organism species shall be specified. The author year of an organism shall also be specified when applicable; refers to the year in which the first author(s) published the infraspecific plant/animal name (of any rank).
 *
 * http://hl7.org/fhir/authorDescription
 */
var authorDescription = 'http://hl7.org/fhir/authorDescription';
/**
 * _intendedExposure
 *
 * (Modified) ResearchStudy.comparisonGroup.intendedExposure
 *
 * http://hl7.org/fhir/_intendedExposure
 */
var _intendedExposure = 'http://hl7.org/fhir/_intendedExposure';
/**
 * _cycle
 *
 * (Modified) Device.cycle
 *
 * http://hl7.org/fhir/_cycle
 */
var _cycle = 'http://hl7.org/fhir/_cycle';
/**
 * ProvenanceEntityComponentAgent
 *
 * The entity is attributed to an agent to express the agent's responsibility for that entity, possibly along with other agents. This description can be understood as shorthand for saying that the agent was responsible for the activity which used the entity.
 *
 * http://hl7.org/fhir/ProvenanceEntityComponentAgent
 */
var ProvenanceEntityComponentAgent = 'http://hl7.org/fhir/ProvenanceEntityComponentAgent';
/**
 * high
 *
 * Range.high: The high limit. The boundary is inclusive.
 *
 * http://hl7.org/fhir/high
 */
var high = 'http://hl7.org/fhir/high';
/**
 * _paymentStatus
 *
 * (Modified) PaymentNotice.paymentStatus
 *
 * http://hl7.org/fhir/_paymentStatus
 */
var _paymentStatus = 'http://hl7.org/fhir/_paymentStatus';
/**
 * TestScriptVariableComponent
 *
 * TestScriptVariableComponent: Variable is set based either on element value in response body or on header field value in the response headers.
 *
 * http://hl7.org/fhir/TestScriptVariableComponent
 */
var TestScriptVariableComponent = 'http://hl7.org/fhir/TestScriptVariableComponent';
/**
 * _comparator
 *
 * (Modified) SubstanceDefinition.relationship.comparator
 *
 * http://hl7.org/fhir/_comparator
 */
var _comparator = 'http://hl7.org/fhir/_comparator';
/**
 * _instantiatesCanonical
 *
 * (Modified) Transport.instantiatesCanonical
 *
 * http://hl7.org/fhir/_instantiatesCanonical
 */
var _instantiatesCanonical = 'http://hl7.org/fhir/_instantiatesCanonical';
/**
 * class
 *
 * EncounterHistory.class: Concepts representing classification of patient encounter such as ambulatory (outpatient), inpatient, emergency, home health or others due to local variations.
 * Note that `class` is a reserved Javascript keyword, and is therefore suffixed by `__workaround`.
 * For a list of reserved keywords, see https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Lexical_grammar#Keywords.
 *
 * http://hl7.org/fhir/class
 */
var class__workaround = 'http://hl7.org/fhir/class';
/**
 * _countryOfOrigin
 *
 * (Modified) SubstanceSourceMaterial.countryOfOrigin
 *
 * http://hl7.org/fhir/_countryOfOrigin
 */
var _countryOfOrigin = 'http://hl7.org/fhir/_countryOfOrigin';
/**
 * structuralRepresentation
 *
 * SubstancePolymer.repeat.repeatUnit.structuralRepresentation: A graphical structure for this SRU.
 *
 * http://hl7.org/fhir/structuralRepresentation
 */
var structuralRepresentation = 'http://hl7.org/fhir/structuralRepresentation';
/**
 * _communicationMethod
 *
 * (Modified) VerificationResult.attestation.communicationMethod
 *
 * http://hl7.org/fhir/_communicationMethod
 */
var _communicationMethod = 'http://hl7.org/fhir/_communicationMethod';
/**
 * _size
 *
 * (Modified) Attachment.size
 *
 * http://hl7.org/fhir/_size
 */
var _size = 'http://hl7.org/fhir/_size';
/**
 * _averageMolecularFormula
 *
 * (Modified) SubstancePolymer.repeat.averageMolecularFormula
 *
 * http://hl7.org/fhir/_averageMolecularFormula
 */
var _averageMolecularFormula = 'http://hl7.org/fhir/_averageMolecularFormula';
/**
 * _ingredientLabel
 *
 * (Modified) NutritionIntake.ingredientLabel
 *
 * http://hl7.org/fhir/_ingredientLabel
 */
var _ingredientLabel = 'http://hl7.org/fhir/_ingredientLabel';
/**
 * _landmarkDescription
 *
 * (Modified) BodyStructure.excludedStructure.bodyLandmarkOrientation.landmarkDescription
 *
 * http://hl7.org/fhir/_landmarkDescription
 */
var _landmarkDescription = 'http://hl7.org/fhir/_landmarkDescription';
/**
 * _criticalCodedValueSet
 *
 * (Modified) ObservationDefinition.component.qualifiedValue.criticalCodedValueSet
 *
 * http://hl7.org/fhir/_criticalCodedValueSet
 */
var _criticalCodedValueSet = 'http://hl7.org/fhir/_criticalCodedValueSet';
/**
 * unmapped
 *
 * ConceptMap.group.unmapped: What to do when there is no mapping to a target concept from the source concept and ConceptMap.group.element.noMap is not true. This provides the "default" to be applied when there is no target concept mapping specified or the expansion of ConceptMap.group.element.target.valueSet is empty.
 *
 * http://hl7.org/fhir/unmapped
 */
var unmapped = 'http://hl7.org/fhir/unmapped';
/**
 * _productCategory
 *
 * (Modified) BiologicallyDerivedProduct.productCategory
 *
 * http://hl7.org/fhir/_productCategory
 */
var _productCategory = 'http://hl7.org/fhir/_productCategory';
/**
 * SubstanceReferenceInformationTargetComponent
 *
 * SubstanceReferenceInformationTargetComponent: Todo.
 *
 * http://hl7.org/fhir/SubstanceReferenceInformationTargetComponent
 */
var SubstanceReferenceInformationTargetComponent = 'http://hl7.org/fhir/SubstanceReferenceInformationTargetComponent';
/**
 * _preferredReportName
 *
 * (Modified) ObservationDefinition.preferredReportName
 *
 * http://hl7.org/fhir/_preferredReportName
 */
var _preferredReportName = 'http://hl7.org/fhir/_preferredReportName';
/**
 * _maternalOrganismId
 *
 * (Modified) SubstanceSourceMaterial.organism.hybrid.maternalOrganismId
 *
 * http://hl7.org/fhir/_maternalOrganismId
 */
var _maternalOrganismId = 'http://hl7.org/fhir/_maternalOrganismId';
/**
 * _order
 *
 * (Modified) SubstanceSourceMaterial.organism.organismGeneral.order
 *
 * http://hl7.org/fhir/_order
 */
var _order = 'http://hl7.org/fhir/_order';
/**
 * qualifier
 *
 * BodyStructure.excludedStructure.qualifier: Code that represents the included structure qualifier.
 *
 * http://hl7.org/fhir/qualifier
 */
var qualifier = 'http://hl7.org/fhir/qualifier';
/**
 * recruitment
 *
 * ResearchStudy.recruitment: Target or actual group of participants enrolled in study.
 *
 * http://hl7.org/fhir/recruitment
 */
var recruitment = 'http://hl7.org/fhir/recruitment';
/**
 * mitigation
 *
 * RiskAssessment.mitigation: A description of the steps that might be taken to reduce the identified risk(s).
 *
 * http://hl7.org/fhir/mitigation
 */
var mitigation = 'http://hl7.org/fhir/mitigation';
/**
 * Procedure
 *
 * An action that is or was performed on or for a patient, practitioner, device, organization, or location. For example, this can be a physical intervention on a patient like an operation, or less invasive like long term services, counseling, or hypnotherapy.  This can be a quality or safety inspection for a location, organization, or device.  This can be an accreditation procedure on a practitioner for licensing.
 *
 * http://hl7.org/fhir/Procedure
 */
var Procedure = 'http://hl7.org/fhir/Procedure';
/**
 * material
 *
 * PackagedProductDefinition.packaging.material: Material type of the package item.
 *
 * http://hl7.org/fhir/material
 */
var material = 'http://hl7.org/fhir/material';
/**
 * _packageId
 *
 * (Modified) ImplementationGuide.dependsOn.packageId
 *
 * http://hl7.org/fhir/_packageId
 */
var _packageId = 'http://hl7.org/fhir/_packageId';
/**
 * address
 *
 * Practitioner.address: Address(es) of the practitioner that are not role specific (typically home address).
Work addresses are not typically entered in this property as they are usually role dependent.
 *
 * http://hl7.org/fhir/address
 */
var address = 'http://hl7.org/fhir/address';
/**
 * module
 *
 * GuidanceResponse.module
 *
 * http://hl7.org/fhir/module
 */
var module = 'http://hl7.org/fhir/module';
/**
 * SubstanceNucleicAcidSubunitComponent
 *
 * SubstanceNucleicAcidSubunitComponent: Subunits are listed in order of decreasing length; sequences of the same length will be ordered by molecular weight; subunits that have identical sequences will be repeated multiple times.
 *
 * http://hl7.org/fhir/SubstanceNucleicAcidSubunitComponent
 */
var SubstanceNucleicAcidSubunitComponent = 'http://hl7.org/fhir/SubstanceNucleicAcidSubunitComponent';
/**
 * _healthcareService
 *
 * (Modified) PractitionerRole.healthcareService
 *
 * http://hl7.org/fhir/_healthcareService
 */
var _healthcareService = 'http://hl7.org/fhir/_healthcareService';
/**
 * check
 *
 * StructureMap.group.rule.rule.source.check: FHIRPath expression  - must be true or the mapping engine throws an error instead of completing.
 *
 * http://hl7.org/fhir/check
 */
var check = 'http://hl7.org/fhir/check';
/**
 * _serviceProvisionCode
 *
 * (Modified) HealthcareService.serviceProvisionCode
 *
 * http://hl7.org/fhir/_serviceProvisionCode
 */
var _serviceProvisionCode = 'http://hl7.org/fhir/_serviceProvisionCode';
/**
 * DeviceDefinitionHasPartComponent
 *
 * DeviceDefinitionHasPartComponent: A device that is part (for example a component) of the present device.
 *
 * http://hl7.org/fhir/DeviceDefinitionHasPartComponent
 */
var DeviceDefinitionHasPartComponent = 'http://hl7.org/fhir/DeviceDefinitionHasPartComponent';
/**
 * hybrid
 *
 * SubstanceSourceMaterial.organism.hybrid: 4.9.13.8.1 Hybrid species maternal organism ID (Optional).
 *
 * http://hl7.org/fhir/hybrid
 */
var hybrid = 'http://hl7.org/fhir/hybrid';
/**
 * DeviceDefinitionPackagingComponentPackaging
 *
 * Allows packages within packages.
 *
 * http://hl7.org/fhir/DeviceDefinitionPackagingComponentPackaging
 */
var DeviceDefinitionPackagingComponentPackaging = 'http://hl7.org/fhir/DeviceDefinitionPackagingComponentPackaging';
/**
 * extends
 *
 * StructureMap.group.extends: Another group that this group adds rules to.
 * Note that `extends` is a reserved Javascript keyword, and is therefore suffixed by `__workaround`.
 * For a list of reserved keywords, see https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Lexical_grammar#Keywords.
 *
 * http://hl7.org/fhir/extends
 */
var extends__workaround = 'http://hl7.org/fhir/extends';
/**
 * AdverseEventSupportingInfoComponent
 *
 * AdverseEventSupportingInfoComponent: Supporting information relevant to the event.
 *
 * http://hl7.org/fhir/AdverseEventSupportingInfoComponent
 */
var AdverseEventSupportingInfoComponent = 'http://hl7.org/fhir/AdverseEventSupportingInfoComponent';
/**
 * _MedicationRequest
 *
 * (Modified) MedicationRequest
 *
 * http://hl7.org/fhir/_MedicationRequest
 */
var _MedicationRequest = 'http://hl7.org/fhir/_MedicationRequest';
/**
 * startingSequence
 *
 * MolecularSequence.relative.startingSequence: A sequence that is used as a starting sequence to describe variants that are present in a sequence analyzed.
 *
 * http://hl7.org/fhir/startingSequence
 */
var startingSequence = 'http://hl7.org/fhir/startingSequence';
/**
 * MedicationKnowledgeMonographComponent
 *
 * MedicationKnowledgeMonographComponent: Associated documentation about the medication.
 *
 * http://hl7.org/fhir/MedicationKnowledgeMonographComponent
 */
var MedicationKnowledgeMonographComponent = 'http://hl7.org/fhir/MedicationKnowledgeMonographComponent';
/**
 * DetectedIssue
 *
 * Indicates an actual or potential clinical issue with or between one or more active or proposed clinical actions for a patient; e.g. Drug-drug interaction, Ineffective treatment frequency, Procedure-condition conflict, gaps in care, etc.
 *
 * http://hl7.org/fhir/DetectedIssue
 */
var DetectedIssue = 'http://hl7.org/fhir/DetectedIssue';
/**
 * targetLocation
 *
 * VerificationResult.targetLocation: The fhirpath location(s) within the resource that was validated.
 *
 * http://hl7.org/fhir/targetLocation
 */
var targetLocation = 'http://hl7.org/fhir/targetLocation';
/**
 * MedicinalProductDefinitionCrossReferenceComponent
 *
 * MedicinalProductDefinitionCrossReferenceComponent: Reference to another product, e.g. for linking authorised to investigational product, or a virtual product.
 *
 * http://hl7.org/fhir/MedicinalProductDefinitionCrossReferenceComponent
 */
var MedicinalProductDefinitionCrossReferenceComponent = 'http://hl7.org/fhir/MedicinalProductDefinitionCrossReferenceComponent';
/**
 * _alternateMaterial
 *
 * (Modified) PackagedProductDefinition.packaging.packaging.alternateMaterial
 *
 * http://hl7.org/fhir/_alternateMaterial
 */
var _alternateMaterial = 'http://hl7.org/fhir/_alternateMaterial';
/**
 * _ordered
 *
 * (Modified) ElementDefinition.slicing.ordered
 *
 * http://hl7.org/fhir/_ordered
 */
var _ordered = 'http://hl7.org/fhir/_ordered';
/**
 * _List
 *
 * (Modified) List
 *
 * http://hl7.org/fhir/_List
 */
var _List = 'http://hl7.org/fhir/_List';
/**
 * _gateway
 *
 * (Modified) Device.gateway
 *
 * http://hl7.org/fhir/_gateway
 */
var _gateway = 'http://hl7.org/fhir/_gateway';
/**
 * _effect
 *
 * (Modified) ClinicalUseDefinition.interaction.effect
 *
 * http://hl7.org/fhir/_effect
 */
var _effect = 'http://hl7.org/fhir/_effect';
/**
 * _coordinate
 *
 * (Modified) ImagingSelection.instance.imageRegion3D.coordinate
 *
 * http://hl7.org/fhir/_coordinate
 */
var _coordinate = 'http://hl7.org/fhir/_coordinate';
/**
 * case
 *
 * RegulatedAuthorization.case: The case or regulatory procedure for granting or amending a regulated authorization. An authorization is granted in response to submissions/applications by those seeking authorization. A case is the administrative process that deals with the application(s) that relate to this and assesses them. Note: This area is subject to ongoing review and the workgroup is seeking implementer feedback on its use (see link at bottom of page).
 * Note that `case` is a reserved Javascript keyword, and is therefore suffixed by `__workaround`.
 * For a list of reserved keywords, see https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Lexical_grammar#Keywords.
 *
 * http://hl7.org/fhir/case
 */
var case__workaround = 'http://hl7.org/fhir/case';
/**
 * QuestionnaireItemComponentItem
 *
 * Text, questions and other groups to be nested beneath a question or group.
 *
 * http://hl7.org/fhir/QuestionnaireItemComponentItem
 */
var QuestionnaireItemComponentItem = 'http://hl7.org/fhir/QuestionnaireItemComponentItem';
/**
 * DeviceConformsToComponent
 *
 * DeviceConformsToComponent: Identifies the standards, specifications, or formal guidances for the capabilities supported by the device. The device may be certified as conformant to these specifications e.g., communication, performance, process, measurement, or specialization standards.
 *
 * http://hl7.org/fhir/DeviceConformsToComponent
 */
var DeviceConformsToComponent = 'http://hl7.org/fhir/DeviceConformsToComponent';
/**
 * PatientLinkComponent
 *
 * PatientLinkComponent: Link to a Patient or RelatedPerson resource that concerns the same actual individual.
 *
 * http://hl7.org/fhir/PatientLinkComponent
 */
var PatientLinkComponent = 'http://hl7.org/fhir/PatientLinkComponent';
/**
 * testData
 *
 * TestPlan.testCase.testData: The test data used in the test case.
 *
 * http://hl7.org/fhir/testData
 */
var testData = 'http://hl7.org/fhir/testData';
/**
 * ProcedureFocalDeviceComponent
 *
 * ProcedureFocalDeviceComponent: A device that is implanted, removed or otherwise manipulated (calibration, battery replacement, fitting a prosthesis, attaching a wound-vac, etc.) as a focal portion of the Procedure.
 *
 * http://hl7.org/fhir/ProcedureFocalDeviceComponent
 */
var ProcedureFocalDeviceComponent = 'http://hl7.org/fhir/ProcedureFocalDeviceComponent';
/**
 * _typeCanonical
 *
 * (Modified) RequestOrchestration.action.action.participant.typeCanonical
 *
 * http://hl7.org/fhir/_typeCanonical
 */
var _typeCanonical = 'http://hl7.org/fhir/_typeCanonical';
/**
 * nodeId
 *
 * GraphDefinition.node.nodeId: Internal ID of node - target for link references.
 *
 * http://hl7.org/fhir/nodeId
 */
var nodeId = 'http://hl7.org/fhir/nodeId';
/**
 * CapabilityStatementSoftwareComponent
 *
 * CapabilityStatementSoftwareComponent: Software that is covered by this capability statement.  It is used when the capability statement describes the capabilities of a particular software version, independent of an installation.
 *
 * http://hl7.org/fhir/CapabilityStatementSoftwareComponent
 */
var CapabilityStatementSoftwareComponent = 'http://hl7.org/fhir/CapabilityStatementSoftwareComponent';
/**
 * _preparation
 *
 * (Modified) SpecimenDefinition.typeTested.container.preparation
 *
 * http://hl7.org/fhir/_preparation
 */
var _preparation = 'http://hl7.org/fhir/_preparation';
/**
 * _subType
 *
 * (Modified) ExplanationOfBenefit.subType
 *
 * http://hl7.org/fhir/_subType
 */
var _subType = 'http://hl7.org/fhir/_subType';
/**
 * _definitionCodeableConcept
 *
 * (Modified) EvidenceVariable.characteristic.definitionByCombination.characteristic.definitionCodeableConcept
 *
 * http://hl7.org/fhir/_definitionCodeableConcept
 */
var _definitionCodeableConcept = 'http://hl7.org/fhir/_definitionCodeableConcept';
/**
 * benefitBalance
 *
 * ExplanationOfBenefit.benefitBalance: Balance by Benefit Category.
 *
 * http://hl7.org/fhir/benefitBalance
 */
var benefitBalance = 'http://hl7.org/fhir/benefitBalance';
/**
 * exclusionCriteria
 *
 * ValueSet.scope.exclusionCriteria: Criteria describing which concepts or codes should be excluded and why.
 *
 * http://hl7.org/fhir/exclusionCriteria
 */
var exclusionCriteria = 'http://hl7.org/fhir/exclusionCriteria';
/**
 * numberOfStudies
 *
 * Evidence.statistic.sampleSize.numberOfStudies: Number of participants in the population.
 *
 * http://hl7.org/fhir/numberOfStudies
 */
var numberOfStudies = 'http://hl7.org/fhir/numberOfStudies';
/**
 * start
 *
 * MolecularSequence.relative.edit.start: Start position of the edit on the starting sequence. If the coordinate system is either 0-based or 1-based, then start position is inclusive.
 *
 * http://hl7.org/fhir/start
 */
var start = 'http://hl7.org/fhir/start';
/**
 * AccountRelatedAccountComponent
 *
 * AccountRelatedAccountComponent: Other associated accounts related to this account.
 *
 * http://hl7.org/fhir/AccountRelatedAccountComponent
 */
var AccountRelatedAccountComponent = 'http://hl7.org/fhir/AccountRelatedAccountComponent';
/**
 * _OperationOutcome
 *
 * (Modified) OperationOutcome
 *
 * http://hl7.org/fhir/_OperationOutcome
 */
var _OperationOutcome = 'http://hl7.org/fhir/_OperationOutcome';
/**
 * orientation
 *
 * SubstancePolymer.repeat.repeatUnit.orientation: The orientation of the polymerisation, e.g. head-tail, head-head, random.
 *
 * http://hl7.org/fhir/orientation
 */
var orientation = 'http://hl7.org/fhir/orientation';
/**
 * holder
 *
 * RegulatedAuthorization.holder: The organization that has been granted this authorization, by some authoritative body (the 'regulator').
 *
 * http://hl7.org/fhir/holder
 */
var holder = 'http://hl7.org/fhir/holder';
/**
 * _mitigatingAction
 *
 * (Modified) AdverseEvent.mitigatingAction
 *
 * http://hl7.org/fhir/_mitigatingAction
 */
var _mitigatingAction = 'http://hl7.org/fhir/_mitigatingAction';
/**
 * include
 *
 * ValueSet.compose.include: Include one or more codes from a code system or other value set(s).
 *
 * http://hl7.org/fhir/include
 */
var include = 'http://hl7.org/fhir/include';
/**
 * _conditionalPatch
 *
 * (Modified) CapabilityStatement.rest.resource.conditionalPatch
 *
 * http://hl7.org/fhir/_conditionalPatch
 */
var _conditionalPatch = 'http://hl7.org/fhir/_conditionalPatch';
/**
 * NamingSystemUniqueIdComponent
 *
 * NamingSystemUniqueIdComponent: Indicates how the system may be identified when referenced in electronic exchange.
 *
 * http://hl7.org/fhir/NamingSystemUniqueIdComponent
 */
var NamingSystemUniqueIdComponent = 'http://hl7.org/fhir/NamingSystemUniqueIdComponent';
/**
 * _threshold
 *
 * (Modified) EvidenceVariable.characteristic.definitionByCombination.characteristic.definitionByCombination.threshold
 *
 * http://hl7.org/fhir/_threshold
 */
var _threshold = 'http://hl7.org/fhir/_threshold';
/**
 * Count
 *
 * A measured amount (or an amount that can potentially be measured). Note that measured amounts include amounts that are not precisely quantified, including amounts involving arbitrary units and floating currencies.
 *
 * http://hl7.org/fhir/Count
 */
var Count = 'http://hl7.org/fhir/Count';
/**
 * _instantiates
 *
 * (Modified) Observation.instantiates
 *
 * http://hl7.org/fhir/_instantiates
 */
var _instantiates = 'http://hl7.org/fhir/_instantiates';
/**
 * media
 *
 * DiagnosticReport.media: A list of key images or data associated with this report. The images or data are generally created during the diagnostic process, and may be directly of the patient, or of treated specimens (i.e. slides of interest).
 *
 * http://hl7.org/fhir/media
 */
var media = 'http://hl7.org/fhir/media';
/**
 * appliesTo
 *
 * Observation.component.referenceRange.appliesTo: Codes to indicate the target population this reference range applies to.  For example, a reference range may be based on the normal population or a particular sex or race.  Multiple `appliesTo`  are interpreted as an "AND" of the target populations.  For example, to represent a target population of African American females, both a code of female and a code for African American would be used.
 *
 * http://hl7.org/fhir/appliesTo
 */
var appliesTo = 'http://hl7.org/fhir/appliesTo';
/**
 * _implementationGuide
 *
 * (Modified) CapabilityStatement.implementationGuide
 *
 * http://hl7.org/fhir/_implementationGuide
 */
var _implementationGuide = 'http://hl7.org/fhir/_implementationGuide';
/**
 * RequestOrchestrationActionInputComponent
 *
 * RequestOrchestrationActionComponentAction.RequestOrchestrationActionInputComponent: Defines input data requirements for the action.
 *
 * http://hl7.org/fhir/RequestOrchestrationActionInputComponent
 */
var RequestOrchestrationActionInputComponent = 'http://hl7.org/fhir/RequestOrchestrationActionInputComponent';
/**
 * _discriminator
 *
 * (Modified) ElementDefinition.slicing.discriminator
 *
 * http://hl7.org/fhir/_discriminator
 */
var _discriminator = 'http://hl7.org/fhir/_discriminator';
/**
 * ClaimResponse
 *
 * This resource provides the adjudication details from the processing of a Claim resource.
 *
 * http://hl7.org/fhir/ClaimResponse
 */
var ClaimResponse = 'http://hl7.org/fhir/ClaimResponse';
/**
 * section
 *
 * EvidenceReport.section.section.section: A nested sub-section within this section.
 *
 * http://hl7.org/fhir/section
 */
var section = 'http://hl7.org/fhir/section';
/**
 * _workflowStatus
 *
 * (Modified) ArtifactAssessment.workflowStatus
 *
 * http://hl7.org/fhir/_workflowStatus
 */
var _workflowStatus = 'http://hl7.org/fhir/_workflowStatus';
/**
 * _DeviceMetric
 *
 * (Modified) DeviceMetric
 *
 * http://hl7.org/fhir/_DeviceMetric
 */
var _DeviceMetric = 'http://hl7.org/fhir/_DeviceMetric';
/**
 * diseaseSymptomProcedure
 *
 * ClinicalUseDefinition.indication.diseaseSymptomProcedure: The situation that is being documented as an indicaton for this item.
 *
 * http://hl7.org/fhir/diseaseSymptomProcedure
 */
var diseaseSymptomProcedure = 'http://hl7.org/fhir/diseaseSymptomProcedure';
/**
 * _keyword
 *
 * (Modified) StructureDefinition.keyword
 *
 * http://hl7.org/fhir/_keyword
 */
var _keyword = 'http://hl7.org/fhir/_keyword';
/**
 * _forecastStatus
 *
 * (Modified) ImmunizationRecommendation.recommendation.forecastStatus
 *
 * http://hl7.org/fhir/_forecastStatus
 */
var _forecastStatus = 'http://hl7.org/fhir/_forecastStatus';
/**
 * Bundle
 *
 * A container for a collection of resources.
 *
 * http://hl7.org/fhir/Bundle
 */
var Bundle = 'http://hl7.org/fhir/Bundle';
/**
 * _excluded
 *
 * (Modified) ExplanationOfBenefit.benefitBalance.excluded
 *
 * http://hl7.org/fhir/_excluded
 */
var _excluded = 'http://hl7.org/fhir/_excluded';
/**
 * _transform
 *
 * (Modified) StructureMap.group.rule.rule.target.transform
 *
 * http://hl7.org/fhir/_transform
 */
var _transform = 'http://hl7.org/fhir/_transform';
/**
 * intent
 *
 * CarePlan.intent: Indicates the level of authority/intentionality associated with the care plan and where the care plan fits into the workflow chain.
 *
 * http://hl7.org/fhir/intent
 */
var intent = 'http://hl7.org/fhir/intent';
/**
 * _slicing
 *
 * (Modified) ElementDefinition.slicing
 *
 * http://hl7.org/fhir/_slicing
 */
var _slicing = 'http://hl7.org/fhir/_slicing';
/**
 * generalPractitioner
 *
 * Patient.generalPractitioner: Patient's nominated care provider.
 *
 * http://hl7.org/fhir/generalPractitioner
 */
var generalPractitioner = 'http://hl7.org/fhir/generalPractitioner';
/**
 * gestationalAge
 *
 * ObservationDefinition.component.qualifiedValue.gestationalAge: The gestational age this  set of qualified values applies to.
 *
 * http://hl7.org/fhir/gestationalAge
 */
var gestationalAge = 'http://hl7.org/fhir/gestationalAge';
/**
 * _account
 *
 * (Modified) PaymentReconciliation.allocation.account
 *
 * http://hl7.org/fhir/_account
 */
var _account = 'http://hl7.org/fhir/_account';
/**
 * _administeredProduct
 *
 * (Modified) Immunization.administeredProduct
 *
 * http://hl7.org/fhir/_administeredProduct
 */
var _administeredProduct = 'http://hl7.org/fhir/_administeredProduct';
/**
 * answerOption
 *
 * Questionnaire.item.item.answerOption: One of the permitted answers for the question.
 *
 * http://hl7.org/fhir/answerOption
 */
var answerOption = 'http://hl7.org/fhir/answerOption';
/**
 * regionType
 *
 * ImagingSelection.instance.imageRegion3D.regionType: Specifies the type of image region.
 *
 * http://hl7.org/fhir/regionType
 */
var regionType = 'http://hl7.org/fhir/regionType';
/**
 * _association
 *
 * (Modified) InventoryItem.association
 *
 * http://hl7.org/fhir/_association
 */
var _association = 'http://hl7.org/fhir/_association';
/**
 * _messaging
 *
 * (Modified) CapabilityStatement.messaging
 *
 * http://hl7.org/fhir/_messaging
 */
var _messaging = 'http://hl7.org/fhir/_messaging';
/**
 * organismType
 *
 * SubstanceReferenceInformation.target.organismType: Todo.
 *
 * http://hl7.org/fhir/organismType
 */
var organismType = 'http://hl7.org/fhir/organismType';
/**
 * accept
 *
 * TestScript.teardown.action.operation.accept: The mime-type to use for RESTful operation in the 'Accept' header.
 *
 * http://hl7.org/fhir/accept
 */
var accept = 'http://hl7.org/fhir/accept';
/**
 * _methodType
 *
 * (Modified) GenomicStudy.analysis.methodType
 *
 * http://hl7.org/fhir/_methodType
 */
var _methodType = 'http://hl7.org/fhir/_methodType';
/**
 * _authorizationRequired
 *
 * (Modified) CoverageEligibilityResponse.insurance.item.authorizationRequired
 *
 * http://hl7.org/fhir/_authorizationRequired
 */
var _authorizationRequired = 'http://hl7.org/fhir/_authorizationRequired';
/**
 * includedStructure
 *
 * BodyStructure.includedStructure: The anatomical location(s) or region(s) of the specimen, lesion, or body structure.
 *
 * http://hl7.org/fhir/includedStructure
 */
var includedStructure = 'http://hl7.org/fhir/includedStructure';
/**
 * sourceIdentityCertificate
 *
 * VerificationResult.attestation.sourceIdentityCertificate: A digital identity certificate associated with the attestation source.
 *
 * http://hl7.org/fhir/sourceIdentityCertificate
 */
var sourceIdentityCertificate = 'http://hl7.org/fhir/sourceIdentityCertificate';
/**
 * foodType
 *
 * NutritionOrder.oralDiet.texture.foodType: The food type(s) (e.g. meats, all foods)  that the texture modification applies to.  This could be all foods types.
 *
 * http://hl7.org/fhir/foodType
 */
var foodType = 'http://hl7.org/fhir/foodType';
/**
 * temperatureRange
 *
 * SpecimenDefinition.typeTested.handling.temperatureRange: The temperature interval for this set of handling instructions.
 *
 * http://hl7.org/fhir/temperatureRange
 */
var temperatureRange = 'http://hl7.org/fhir/temperatureRange';
/**
 * ManifestPage
 *
 * ImplementationGuideManifestComponent.ManifestPage: Information about a page within the IG.
 *
 * http://hl7.org/fhir/ManifestPage
 */
var ManifestPage = 'http://hl7.org/fhir/ManifestPage';
/**
 * DeviceRequest
 *
 * Represents a request a device to be provided to a specific patient. The device may be an implantable device to be subsequently implanted, or an external assistive device, such as a walker, to be delivered and subsequently be used.
 *
 * http://hl7.org/fhir/DeviceRequest
 */
var DeviceRequest = 'http://hl7.org/fhir/DeviceRequest';
/**
 * _contextLinkId
 *
 * (Modified) Contract.term.group.action.contextLinkId
 *
 * http://hl7.org/fhir/_contextLinkId
 */
var _contextLinkId = 'http://hl7.org/fhir/_contextLinkId';
/**
 * ExampleScenarioProcessStepOperationComponent
 *
 * ExampleScenarioProcessComponent.ExampleScenarioProcessStepComponent.ExampleScenarioProcessStepOperationComponent: The step represents a single operation invoked on receiver by sender.
 *
 * http://hl7.org/fhir/ExampleScenarioProcessStepOperationComponent
 */
var ExampleScenarioProcessStepOperationComponent = 'http://hl7.org/fhir/ExampleScenarioProcessStepOperationComponent';
/**
 * SubstanceDefinitionStructureComponent
 *
 * SubstanceDefinitionStructureComponent: Structural information.
 *
 * http://hl7.org/fhir/SubstanceDefinitionStructureComponent
 */
var SubstanceDefinitionStructureComponent = 'http://hl7.org/fhir/SubstanceDefinitionStructureComponent';
/**
 * calculatedAt
 *
 * Account.calculatedAt: Time the balance amount was calculated.
 *
 * http://hl7.org/fhir/calculatedAt
 */
var calculatedAt = 'http://hl7.org/fhir/calculatedAt';
/**
 * MarketingStatus
 *
 * The marketing status describes the date when a medicinal product is actually put on the market or the date as of which it is no longer available.
 *
 * http://hl7.org/fhir/MarketingStatus
 */
var MarketingStatus = 'http://hl7.org/fhir/MarketingStatus';
/**
 * _emptyReason
 *
 * (Modified) List.emptyReason
 *
 * http://hl7.org/fhir/_emptyReason
 */
var _emptyReason = 'http://hl7.org/fhir/_emptyReason';
/**
 * _offsets
 *
 * (Modified) SampledData.offsets
 *
 * http://hl7.org/fhir/_offsets
 */
var _offsets = 'http://hl7.org/fhir/_offsets';
/**
 * _financial
 *
 * (Modified) ExplanationOfBenefit.benefitBalance.financial
 *
 * http://hl7.org/fhir/_financial
 */
var _financial = 'http://hl7.org/fhir/_financial';
/**
 * _exposureRoute
 *
 * (Modified) AllergyIntolerance.reaction.exposureRoute
 *
 * http://hl7.org/fhir/_exposureRoute
 */
var _exposureRoute = 'http://hl7.org/fhir/_exposureRoute';
/**
 * _policyHolder
 *
 * (Modified) Coverage.policyHolder
 *
 * http://hl7.org/fhir/_policyHolder
 */
var _policyHolder = 'http://hl7.org/fhir/_policyHolder';
/**
 * SupplyDeliverySuppliedItemComponent
 *
 * SupplyDeliverySuppliedItemComponent: The item that is being delivered or has been supplied.
 *
 * http://hl7.org/fhir/SupplyDeliverySuppliedItemComponent
 */
var SupplyDeliverySuppliedItemComponent = 'http://hl7.org/fhir/SupplyDeliverySuppliedItemComponent';
/**
 * intendedRoute
 *
 * MedicationKnowledge.definitional.intendedRoute: The intended or approved route of administration.
 *
 * http://hl7.org/fhir/intendedRoute
 */
var intendedRoute = 'http://hl7.org/fhir/intendedRoute';
/**
 * _paymentDate
 *
 * (Modified) PaymentNotice.paymentDate
 *
 * http://hl7.org/fhir/_paymentDate
 */
var _paymentDate = 'http://hl7.org/fhir/_paymentDate';
/**
 * GenomicStudyAnalysisDeviceComponent
 *
 * GenomicStudyAnalysisComponent.GenomicStudyAnalysisDeviceComponent: Devices used for the analysis (e.g., instruments, software), with settings and parameters.
 *
 * http://hl7.org/fhir/GenomicStudyAnalysisDeviceComponent
 */
var GenomicStudyAnalysisDeviceComponent = 'http://hl7.org/fhir/GenomicStudyAnalysisDeviceComponent';
/**
 * _informationProvider
 *
 * (Modified) CommunicationRequest.informationProvider
 *
 * http://hl7.org/fhir/_informationProvider
 */
var _informationProvider = 'http://hl7.org/fhir/_informationProvider';
/**
 * _outsideFoodAllowed
 *
 * (Modified) NutritionOrder.outsideFoodAllowed
 *
 * http://hl7.org/fhir/_outsideFoodAllowed
 */
var _outsideFoodAllowed = 'http://hl7.org/fhir/_outsideFoodAllowed';
/**
 * feature
 *
 * Specimen.feature: A physical feature or landmark on a specimen, highlighted for context by the collector of the specimen (e.g. surgeon), that identifies the type of feature as well as its meaning (e.g. the red ink indicating the resection margin of the right lobe of the excised prostate tissue or wire loop at radiologically suspected tumor location).
 *
 * http://hl7.org/fhir/feature
 */
var feature = 'http://hl7.org/fhir/feature';
/**
 * needsMap
 *
 * TerminologyCapabilities.translation.needsMap: Whether the client must identify the map.
 *
 * http://hl7.org/fhir/needsMap
 */
var needsMap = 'http://hl7.org/fhir/needsMap';
/**
 * _dataAbsentReason
 *
 * (Modified) Observation.component.dataAbsentReason
 *
 * http://hl7.org/fhir/_dataAbsentReason
 */
var _dataAbsentReason = 'http://hl7.org/fhir/_dataAbsentReason';
/**
 * _definition
 *
 * (Modified) CapabilityStatement.messaging.supportedMessage.definition
 *
 * http://hl7.org/fhir/_definition
 */
var _definition = 'http://hl7.org/fhir/_definition';
/**
 * creation
 *
 * Invoice.creation: Date/time(s) of when this Invoice was posted.
 *
 * http://hl7.org/fhir/creation
 */
var creation = 'http://hl7.org/fhir/creation';
/**
 * _minValue
 *
 * (Modified) ElementDefinition.minValue
 *
 * http://hl7.org/fhir/_minValue
 */
var _minValue = 'http://hl7.org/fhir/_minValue';
/**
 * width
 *
 * Attachment.width: Width of the image in pixels (photo/video).
 *
 * http://hl7.org/fhir/width
 */
var width = 'http://hl7.org/fhir/width';
/**
 * _Permission
 *
 * (Modified) Permission
 *
 * http://hl7.org/fhir/_Permission
 */
var _Permission = 'http://hl7.org/fhir/_Permission';
/**
 * AllergyIntolerance
 *
 * Risk of harmful or undesirable, physiological response which is unique to an individual and associated with exposure to a substance.
 *
 * http://hl7.org/fhir/AllergyIntolerance
 */
var AllergyIntolerance = 'http://hl7.org/fhir/AllergyIntolerance';
/**
 * _Encounter
 *
 * (Modified) Encounter
 *
 * http://hl7.org/fhir/_Encounter
 */
var _Encounter = 'http://hl7.org/fhir/_Encounter';
/**
 * targetNumber
 *
 * ResearchStudy.recruitment.targetNumber: Estimated total number of participants to be enrolled.
 *
 * http://hl7.org/fhir/targetNumber
 */
var targetNumber = 'http://hl7.org/fhir/targetNumber';
/**
 * severity
 *
 * AllergyIntolerance.reaction.severity: Clinical assessment of the severity of the reaction event as a whole, potentially considering multiple different manifestations.
 *
 * http://hl7.org/fhir/severity
 */
var severity = 'http://hl7.org/fhir/severity';
/**
 * ObservationDefinitionQualifiedValueComponent
 *
 * ObservationDefinitionQualifiedValueComponent: A set of qualified values associated with a context and a set of conditions -  provides a range for quantitative and ordinal observations and a collection of value sets for qualitative observations.
 *
 * http://hl7.org/fhir/ObservationDefinitionQualifiedValueComponent
 */
var ObservationDefinitionQualifiedValueComponent = 'http://hl7.org/fhir/ObservationDefinitionQualifiedValueComponent';
/**
 * filterBy
 *
 * Subscription.filterBy: The filter properties to be applied to narrow the subscription topic stream.  When multiple filters are applied, evaluates to true if all the conditions applicable to that resource are met; otherwise it returns false (i.e., logical AND).
 *
 * http://hl7.org/fhir/filterBy
 */
var filterBy = 'http://hl7.org/fhir/filterBy';
/**
 * packaging
 *
 * PackagedProductDefinition.packaging.packaging: Allows containers (and parts of containers) within containers, still as a part of a single packaged product. See also PackagedProductDefinition.packaging.containedItem.item(PackagedProductDefinition).
 *
 * http://hl7.org/fhir/packaging
 */
var packaging = 'http://hl7.org/fhir/packaging';
/**
 * endorser
 *
 * Citation.endorser: Who endorsed the citation record.
 *
 * http://hl7.org/fhir/endorser
 */
var endorser = 'http://hl7.org/fhir/endorser';
/**
 * _relatesTo
 *
 * (Modified) EvidenceReport.relatesTo
 *
 * http://hl7.org/fhir/_relatesTo
 */
var _relatesTo = 'http://hl7.org/fhir/_relatesTo';
/**
 * _sourceSignature
 *
 * (Modified) VerificationResult.attestation.sourceSignature
 *
 * http://hl7.org/fhir/_sourceSignature
 */
var _sourceSignature = 'http://hl7.org/fhir/_sourceSignature';
/**
 * abnormalCodedValueSet
 *
 * ObservationDefinition.component.qualifiedValue.abnormalCodedValueSet: The set of abnormal coded results for qualitative observations  that match the criteria of this set of qualified values.
 *
 * http://hl7.org/fhir/abnormalCodedValueSet
 */
var abnormalCodedValueSet = 'http://hl7.org/fhir/abnormalCodedValueSet';
/**
 * lastOccurrenceDate
 *
 * Appointment.recurrenceTemplate.lastOccurrenceDate: Recurring appointments will not occur after this date.
 *
 * http://hl7.org/fhir/lastOccurrenceDate
 */
var lastOccurrenceDate = 'http://hl7.org/fhir/lastOccurrenceDate';
/**
 * _securityLabelNumber
 *
 * (Modified) Contract.term.asset.valuedItem.securityLabelNumber
 *
 * http://hl7.org/fhir/_securityLabelNumber
 */
var _securityLabelNumber = 'http://hl7.org/fhir/_securityLabelNumber';
/**
 * _queryCriteria
 *
 * (Modified) SubscriptionTopic.resourceTrigger.queryCriteria
 *
 * http://hl7.org/fhir/_queryCriteria
 */
var _queryCriteria = 'http://hl7.org/fhir/_queryCriteria';
/**
 * _multipleResultsAllowed
 *
 * (Modified) ObservationDefinition.multipleResultsAllowed
 *
 * http://hl7.org/fhir/_multipleResultsAllowed
 */
var _multipleResultsAllowed = 'http://hl7.org/fhir/_multipleResultsAllowed';
/**
 * _allowed
 *
 * (Modified) MedicationRequest.substitution.allowed
 *
 * http://hl7.org/fhir/_allowed
 */
var _allowed = 'http://hl7.org/fhir/_allowed';
/**
 * _TestReport
 *
 * (Modified) TestReport
 *
 * http://hl7.org/fhir/_TestReport
 */
var _TestReport = 'http://hl7.org/fhir/_TestReport';
/**
 * _Location
 *
 * (Modified) Location
 *
 * http://hl7.org/fhir/_Location
 */
var _Location = 'http://hl7.org/fhir/_Location';
/**
 * deviceName
 *
 * DeviceDefinition.deviceName: The name or names of the device as given by the manufacturer.
 *
 * http://hl7.org/fhir/deviceName
 */
var deviceName = 'http://hl7.org/fhir/deviceName';
/**
 * ImmunizationReactionComponent
 *
 * ImmunizationReactionComponent: Categorical data indicating that an adverse event is associated in time to an immunization.
 *
 * http://hl7.org/fhir/ImmunizationReactionComponent
 */
var ImmunizationReactionComponent = 'http://hl7.org/fhir/ImmunizationReactionComponent';
/**
 * ConceptMap
 *
 * A statement of relationships from one set of concepts to one or more other concepts - either concepts in code systems, or data element/data element concepts, or classes in class models.
 *
 * http://hl7.org/fhir/ConceptMap
 */
var ConceptMap = 'http://hl7.org/fhir/ConceptMap';
/**
 * _daysOfWeek
 *
 * (Modified) Availability.availableTime.daysOfWeek
 *
 * http://hl7.org/fhir/_daysOfWeek
 */
var _daysOfWeek = 'http://hl7.org/fhir/_daysOfWeek';
/**
 * ParameterDefinition
 *
 * The parameters to the module. This collection specifies both the input and output parameters. Input parameters are provided by the caller as part of the $evaluate operation. Output parameters are included in the GuidanceResponse.
 *
 * http://hl7.org/fhir/ParameterDefinition
 */
var ParameterDefinition = 'http://hl7.org/fhir/ParameterDefinition';
/**
 * _packageCode
 *
 * (Modified) Account.procedure.packageCode
 *
 * http://hl7.org/fhir/_packageCode
 */
var _packageCode = 'http://hl7.org/fhir/_packageCode';
/**
 * Insurance
 *
 * ExplanationOfBenefit.Insurance: Financial instruments for reimbursement for the health care products and services specified on the claim.
 *
 * http://hl7.org/fhir/Insurance
 */
var Insurance = 'http://hl7.org/fhir/Insurance';
/**
 * lastPerformed
 *
 * VerificationResult.lastPerformed: The date/time validation was last completed (including failed validations).
 *
 * http://hl7.org/fhir/lastPerformed
 */
var lastPerformed = 'http://hl7.org/fhir/lastPerformed';
/**
 * IngredientManufacturerComponent
 *
 * IngredientManufacturerComponent: The organization(s) that manufacture this ingredient. Can be used to indicate:         1) Organizations we are aware of that manufacture this ingredient         2) Specific Manufacturer(s) currently being used         3) Set of organisations allowed to manufacture this ingredient for this product         Users must be clear on the application of context relevant to their use case.
 *
 * http://hl7.org/fhir/IngredientManufacturerComponent
 */
var IngredientManufacturerComponent = 'http://hl7.org/fhir/IngredientManufacturerComponent';
/**
 * nthWeekOfMonth
 *
 * Appointment.recurrenceTemplate.monthlyTemplate.nthWeekOfMonth: Indicates which week within a month the appointments in the series of recurring appointments should occur on.
 *
 * http://hl7.org/fhir/nthWeekOfMonth
 */
var nthWeekOfMonth = 'http://hl7.org/fhir/nthWeekOfMonth';
/**
 * targetSpecies
 *
 * AdministrableProductDefinition.routeOfAdministration.targetSpecies: A species for which this route applies.
 *
 * http://hl7.org/fhir/targetSpecies
 */
var targetSpecies = 'http://hl7.org/fhir/targetSpecies';
/**
 * authorization
 *
 * AuditEvent.entity.agent.authorization: The authorization (e.g., PurposeOfUse) that was used during the event being recorded.
 *
 * http://hl7.org/fhir/authorization
 */
var authorization = 'http://hl7.org/fhir/authorization';
/**
 * _RequestOrchestration
 *
 * (Modified) RequestOrchestration
 *
 * http://hl7.org/fhir/_RequestOrchestration
 */
var _RequestOrchestration = 'http://hl7.org/fhir/_RequestOrchestration';
/**
 * _endpoint
 *
 * (Modified) CapabilityStatement.messaging.endpoint
 *
 * http://hl7.org/fhir/_endpoint
 */
var _endpoint = 'http://hl7.org/fhir/_endpoint';
/**
 * triggeredBy
 *
 * Observation.triggeredBy: Identifies the observation(s) that triggered the performance of this observation.
 *
 * http://hl7.org/fhir/triggeredBy
 */
var triggeredBy = 'http://hl7.org/fhir/triggeredBy';
/**
 * _Dosage
 *
 * (Modified) Dosage
 *
 * http://hl7.org/fhir/_Dosage
 */
var _Dosage = 'http://hl7.org/fhir/_Dosage';
/**
 * _doNotPerform
 *
 * (Modified) Contract.term.group.action.doNotPerform
 *
 * http://hl7.org/fhir/_doNotPerform
 */
var _doNotPerform = 'http://hl7.org/fhir/_doNotPerform';
/**
 * careTeam
 *
 * ExplanationOfBenefit.careTeam: The members of the team who provided the products and services.
 *
 * http://hl7.org/fhir/careTeam
 */
var careTeam = 'http://hl7.org/fhir/careTeam';
/**
 * _meta
 *
 * (Modified) Resource.meta
 *
 * http://hl7.org/fhir/_meta
 */
var _meta = 'http://hl7.org/fhir/_meta';
/**
 * TerminologyCapabilitiesCodeSystemVersionComponent
 *
 * TerminologyCapabilitiesCodeSystemComponent.TerminologyCapabilitiesCodeSystemVersionComponent: For the code system, a list of versions that are supported by the server.
 *
 * http://hl7.org/fhir/TerminologyCapabilitiesCodeSystemVersionComponent
 */
var TerminologyCapabilitiesCodeSystemVersionComponent = 'http://hl7.org/fhir/TerminologyCapabilitiesCodeSystemVersionComponent';
/**
 * entryQuantity
 *
 * EvidenceReport.section.section.entryQuantity: Quantity as content.
 *
 * http://hl7.org/fhir/entryQuantity
 */
var entryQuantity = 'http://hl7.org/fhir/entryQuantity';
/**
 * CapabilityStatementMessagingEndpointComponent
 *
 * CapabilityStatementMessagingComponent.CapabilityStatementMessagingEndpointComponent: An endpoint (network accessible address) to which messages and/or replies are to be sent.
 *
 * http://hl7.org/fhir/CapabilityStatementMessagingEndpointComponent
 */
var CapabilityStatementMessagingEndpointComponent = 'http://hl7.org/fhir/CapabilityStatementMessagingEndpointComponent';
/**
 * nTerminalModification
 *
 * SubstanceProtein.subunit.nTerminalModification: The name of the fragment modified at the N-terminal of the SubstanceProtein shall be specified.
 *
 * http://hl7.org/fhir/nTerminalModification
 */
var nTerminalModification = 'http://hl7.org/fhir/nTerminalModification';
/**
 * _asNeededFor
 *
 * (Modified) NutritionOrder.enteralFormula.administration.schedule.asNeededFor
 *
 * http://hl7.org/fhir/_asNeededFor
 */
var _asNeededFor = 'http://hl7.org/fhir/_asNeededFor';
/**
 * _link
 *
 * (Modified) Bundle.link
 *
 * http://hl7.org/fhir/_link
 */
var _link = 'http://hl7.org/fhir/_link';
/**
 * attribute
 *
 * ConceptMap.group.element.target.product.attribute: A reference to the additional attribute that holds a value the map depends on.
 *
 * http://hl7.org/fhir/attribute
 */
var attribute = 'http://hl7.org/fhir/attribute';
/**
 * Note
 *
 * ExplanationOfBenefit.Note: A note that describes or explains adjudication results in a human readable form.
 *
 * http://hl7.org/fhir/Note
 */
var Note = 'http://hl7.org/fhir/Note';
/**
 * textFilter
 *
 * TerminologyCapabilities.expansion.textFilter: Documentation about text searching works.
 *
 * http://hl7.org/fhir/textFilter
 */
var textFilter = 'http://hl7.org/fhir/textFilter';
/**
 * disposition
 *
 * ExplanationOfBenefit.disposition: A human readable description of the status of the adjudication.
 *
 * http://hl7.org/fhir/disposition
 */
var disposition = 'http://hl7.org/fhir/disposition';
/**
 * PackagedProductDefinition
 *
 * A medically related item or items, in a container or package.
 *
 * http://hl7.org/fhir/PackagedProductDefinition
 */
var PackagedProductDefinition = 'http://hl7.org/fhir/PackagedProductDefinition';
/**
 * Accident
 *
 * ExplanationOfBenefit.Accident: Details of a accident which resulted in injuries which required the products and services listed in the claim.
 *
 * http://hl7.org/fhir/Accident
 */
var Accident = 'http://hl7.org/fhir/Accident';
/**
 * _reference
 *
 * (Modified) Consent.provision.provision.data.reference
 *
 * http://hl7.org/fhir/_reference
 */
var _reference = 'http://hl7.org/fhir/_reference';
/**
 * StructureMapGroupRuleTargetParameterComponent
 *
 * StructureMapGroupComponent.StructureMapGroupRuleComponentRule.StructureMapGroupRuleTargetComponent.StructureMapGroupRuleTargetParameterComponent: Parameters to the transform.
 *
 * http://hl7.org/fhir/StructureMapGroupRuleTargetParameterComponent
 */
var StructureMapGroupRuleTargetParameterComponent = 'http://hl7.org/fhir/StructureMapGroupRuleTargetParameterComponent';
/**
 * subscriber
 *
 * Coverage.subscriber: The party who has signed-up for or 'owns' the contractual relationship to the policy or to whom the benefit of the policy for services rendered to them or their family is due.
 *
 * http://hl7.org/fhir/subscriber
 */
var subscriber = 'http://hl7.org/fhir/subscriber';
/**
 * structureType
 *
 * ExampleScenario.instance.structureType: A code indicating the kind of data structure (FHIR resource or some other standard) this is an instance of.
 *
 * http://hl7.org/fhir/structureType
 */
var structureType = 'http://hl7.org/fhir/structureType';
/**
 * _detail
 *
 * (Modified) TestReport.setup.action.operation.detail
 *
 * http://hl7.org/fhir/_detail
 */
var _detail = 'http://hl7.org/fhir/_detail';
/**
 * meaningWhenMissing
 *
 * ElementDefinition.meaningWhenMissing: The Implicit meaning that is to be understood when this element is missing (e.g. 'when this element is missing, the period is ongoing').
 *
 * http://hl7.org/fhir/meaningWhenMissing
 */
var meaningWhenMissing = 'http://hl7.org/fhir/meaningWhenMissing';
/**
 * modelCharacteristic
 *
 * Evidence.statistic.modelCharacteristic: A component of the method to generate the statistic.
 *
 * http://hl7.org/fhir/modelCharacteristic
 */
var modelCharacteristic = 'http://hl7.org/fhir/modelCharacteristic';
/**
 * mapping
 *
 * StructureDefinition.mapping: An external specification that the content is mapped to.
 *
 * http://hl7.org/fhir/mapping
 */
var mapping = 'http://hl7.org/fhir/mapping';
/**
 * _Person
 *
 * (Modified) Person
 *
 * http://hl7.org/fhir/_Person
 */
var _Person = 'http://hl7.org/fhir/_Person';
/**
 * _eligibility
 *
 * (Modified) ResearchStudy.recruitment.eligibility
 *
 * http://hl7.org/fhir/_eligibility
 */
var _eligibility = 'http://hl7.org/fhir/_eligibility';
/**
 * SubstanceSourceMaterialFractionDescriptionComponent
 *
 * SubstanceSourceMaterialFractionDescriptionComponent: Many complex materials are fractions of parts of plants, animals, or minerals. Fraction elements are often necessary to define both Substances and Specified Group 1 Substances. For substances derived from Plants, fraction information will be captured at the Substance information level ( . Oils, Juices and Exudates). Additional information for Extracts, such as extraction solvent composition, will be captured at the Specified Substance Group 1 information level. For plasma-derived products fraction information will be captured at the Substance and the Specified Substance Group 1 levels.
 *
 * http://hl7.org/fhir/SubstanceSourceMaterialFractionDescriptionComponent
 */
var SubstanceSourceMaterialFractionDescriptionComponent = 'http://hl7.org/fhir/SubstanceSourceMaterialFractionDescriptionComponent';
/**
 * typeCollected
 *
 * SpecimenDefinition.typeCollected: The kind of material to be collected.
 *
 * http://hl7.org/fhir/typeCollected
 */
var typeCollected = 'http://hl7.org/fhir/typeCollected';
/**
 * timestamp
 *
 * ValueSet.expansion.timestamp: The time at which the expansion was produced by the expanding system.
 *
 * http://hl7.org/fhir/timestamp
 */
var timestamp = 'http://hl7.org/fhir/timestamp';
/**
 * _subpotentReason
 *
 * (Modified) Immunization.subpotentReason
 *
 * http://hl7.org/fhir/_subpotentReason
 */
var _subpotentReason = 'http://hl7.org/fhir/_subpotentReason';
/**
 * _relatedMedicationKnowledge
 *
 * (Modified) MedicationKnowledge.relatedMedicationKnowledge
 *
 * http://hl7.org/fhir/_relatedMedicationKnowledge
 */
var _relatedMedicationKnowledge = 'http://hl7.org/fhir/_relatedMedicationKnowledge';
/**
 * _inventoryStatus
 *
 * (Modified) InventoryItem.inventoryStatus
 *
 * http://hl7.org/fhir/_inventoryStatus
 */
var _inventoryStatus = 'http://hl7.org/fhir/_inventoryStatus';
/**
 * synonym
 *
 * SubstanceDefinition.name.translation.synonym: A synonym of this particular name, by which the substance is also known.
 *
 * http://hl7.org/fhir/synonym
 */
var synonym = 'http://hl7.org/fhir/synonym';
/**
 * _category
 *
 * (Modified) DeviceDefinition.conformsTo.category
 *
 * http://hl7.org/fhir/_category
 */
var _category = 'http://hl7.org/fhir/_category';
/**
 * _regulatory
 *
 * (Modified) MedicationKnowledge.regulatory
 *
 * http://hl7.org/fhir/_regulatory
 */
var _regulatory = 'http://hl7.org/fhir/_regulatory';
/**
 * birthDate
 *
 * Practitioner.birthDate: The date of birth for the practitioner.
 *
 * http://hl7.org/fhir/birthDate
 */
var birthDate = 'http://hl7.org/fhir/birthDate';
/**
 * _priorPrescription
 *
 * (Modified) MedicationRequest.priorPrescription
 *
 * http://hl7.org/fhir/_priorPrescription
 */
var _priorPrescription = 'http://hl7.org/fhir/_priorPrescription';
/**
 * Base
 *
 * Base definition for all types defined in FHIR type system.
 *
 * http://hl7.org/fhir/Base
 */
var Base = 'http://hl7.org/fhir/Base';
/**
 * _testTools
 *
 * (Modified) TestPlan.testTools
 *
 * http://hl7.org/fhir/_testTools
 */
var _testTools = 'http://hl7.org/fhir/_testTools';
/**
 * _targetLocation
 *
 * (Modified) VerificationResult.targetLocation
 *
 * http://hl7.org/fhir/_targetLocation
 */
var _targetLocation = 'http://hl7.org/fhir/_targetLocation';
/**
 * substanceDefinition
 *
 * SubstanceDefinition.relationship.substanceDefinition
 *
 * http://hl7.org/fhir/substanceDefinition
 */
var substanceDefinition = 'http://hl7.org/fhir/substanceDefinition';
/**
 * _medication
 *
 * (Modified) MedicationStatement.medication
 *
 * http://hl7.org/fhir/_medication
 */
var _medication = 'http://hl7.org/fhir/_medication';
/**
 * _vaccineCode
 *
 * (Modified) ImmunizationRecommendation.recommendation.vaccineCode
 *
 * http://hl7.org/fhir/_vaccineCode
 */
var _vaccineCode = 'http://hl7.org/fhir/_vaccineCode';
/**
 * _dateAsserted
 *
 * (Modified) MedicationStatement.dateAsserted
 *
 * http://hl7.org/fhir/_dateAsserted
 */
var _dateAsserted = 'http://hl7.org/fhir/_dateAsserted';
/**
 * DeviceDefinitionMaterialComponent
 *
 * DeviceDefinitionMaterialComponent: A substance used to create the material(s) of which the device is made.
 *
 * http://hl7.org/fhir/DeviceDefinitionMaterialComponent
 */
var DeviceDefinitionMaterialComponent = 'http://hl7.org/fhir/DeviceDefinitionMaterialComponent';
/**
 * _codeSearch
 *
 * (Modified) TerminologyCapabilities.codeSearch
 *
 * http://hl7.org/fhir/_codeSearch
 */
var _codeSearch = 'http://hl7.org/fhir/_codeSearch';
/**
 * range
 *
 * ObservationDefinition.qualifiedValue.range: The range of values defined for continuous or ordinal observations that match the criteria of this set of qualified values.
 *
 * http://hl7.org/fhir/range
 */
var range = 'http://hl7.org/fhir/range';
/**
 * NutritionOrder
 *
 * A request to supply a diet, formula feeding (enteral) or oral nutritional supplement to a patient/resident.
 *
 * http://hl7.org/fhir/NutritionOrder
 */
var NutritionOrder = 'http://hl7.org/fhir/NutritionOrder';
/**
 * _dispenserInstruction
 *
 * (Modified) MedicationRequest.dispenseRequest.dispenserInstruction
 *
 * http://hl7.org/fhir/_dispenserInstruction
 */
var _dispenserInstruction = 'http://hl7.org/fhir/_dispenserInstruction';
/**
 * _summary
 *
 * (Modified) Condition.stage.summary
 *
 * http://hl7.org/fhir/_summary
 */
var _summary = 'http://hl7.org/fhir/_summary';
/**
 * _synthesisType
 *
 * (Modified) Evidence.synthesisType
 *
 * http://hl7.org/fhir/_synthesisType
 */
var _synthesisType = 'http://hl7.org/fhir/_synthesisType';
/**
 * productName
 *
 * NutritionOrder.enteralFormula.additive.productName: The product or brand name of the type of modular component to be added to the formula.
 *
 * http://hl7.org/fhir/productName
 */
var productName = 'http://hl7.org/fhir/productName';
/**
 * _reviewOutcome
 *
 * (Modified) ExplanationOfBenefit.addItem.detail.subDetail.reviewOutcome
 *
 * http://hl7.org/fhir/_reviewOutcome
 */
var _reviewOutcome = 'http://hl7.org/fhir/_reviewOutcome';
/**
 * claimResponse
 *
 * ExplanationOfBenefit.claimResponse: The business identifier for the instance of the adjudication response: claim, predetermination or preauthorization response.
 *
 * http://hl7.org/fhir/claimResponse
 */
var claimResponse = 'http://hl7.org/fhir/claimResponse';
/**
 * path
 *
 * RequestOrchestration.action.dynamicValue.path: The path to the element to be customized. This is the path on the resource that will hold the result of the calculation defined by the expression. The specified path SHALL be a FHIRPath resolvable on the specified target type of the ActivityDefinition, and SHALL consist only of identifiers, constant indexers, and a restricted subset of functions. The path is allowed to contain qualifiers (.) to traverse sub-elements, as well as indexers ([x]) to traverse multiple-cardinality sub-elements (see the [Simple FHIRPath Profile](fhirpath.html#simple) for full details).
 *
 * http://hl7.org/fhir/path
 */
var path = 'http://hl7.org/fhir/path';
/**
 * additive
 *
 * Specimen.processing.additive: Material used in the processing step.
 *
 * http://hl7.org/fhir/additive
 */
var additive = 'http://hl7.org/fhir/additive';
/**
 * ElementDefinition
 *
 * Captures constraints on each element within the resource, profile, or extension.
 *
 * http://hl7.org/fhir/ElementDefinition
 */
var ElementDefinition = 'http://hl7.org/fhir/ElementDefinition';
/**
 * fundingSource
 *
 * Immunization.fundingSource: Indicates the source of the vaccine actually administered. This may be different than the patient eligibility (e.g. the patient may be eligible for a publically purchased vaccine but due to inventory issues, vaccine purchased with private funds was actually administered).
 *
 * http://hl7.org/fhir/fundingSource
 */
var fundingSource = 'http://hl7.org/fhir/fundingSource';
/**
 * instantiatesCanonical
 *
 * GenomicStudy.instantiatesCanonical: The defined protocol that describes the study.
 *
 * http://hl7.org/fhir/instantiatesCanonical
 */
var instantiatesCanonical = 'http://hl7.org/fhir/instantiatesCanonical';
/**
 * family
 *
 * SubstanceSourceMaterial.organism.family: The family of an organism shall be specified.
 *
 * http://hl7.org/fhir/family
 */
var family = 'http://hl7.org/fhir/family';
/**
 * NutritionIntake
 *
 * A record of food or fluid that is being consumed by a patient.  A NutritionIntake may indicate that the patient may be consuming the food or fluid now or has consumed the food or fluid in the past.  The source of this information can be the patient, significant other (such as a family member or spouse), or a clinician.  A common scenario where this information is captured is during the history taking process during a patient visit or stay or through an app that tracks food or fluids consumed.   The consumption information may come from sources such as the patient's memory, from a nutrition label,  or from a clinician documenting observed intake.
 *
 * http://hl7.org/fhir/NutritionIntake
 */
var NutritionIntake = 'http://hl7.org/fhir/NutritionIntake';
/**
 * EvidenceReport
 *
 * The EvidenceReport Resource is a specialized container for a collection of resources and codeable concepts, adapted to support compositions of Evidence, EvidenceVariable, and Citation resources and related concepts.
 *
 * http://hl7.org/fhir/EvidenceReport
 */
var EvidenceReport = 'http://hl7.org/fhir/EvidenceReport';
/**
 * billablePeriod
 *
 * ExplanationOfBenefit.billablePeriod: The period for which charges are being submitted.
 *
 * http://hl7.org/fhir/billablePeriod
 */
var billablePeriod = 'http://hl7.org/fhir/billablePeriod';
/**
 * _otherTherapy
 *
 * (Modified) ClinicalUseDefinition.indication.otherTherapy
 *
 * http://hl7.org/fhir/_otherTherapy
 */
var _otherTherapy = 'http://hl7.org/fhir/_otherTherapy';
/**
 * _dateOfService
 *
 * (Modified) Account.procedure.dateOfService
 *
 * http://hl7.org/fhir/_dateOfService
 */
var _dateOfService = 'http://hl7.org/fhir/_dateOfService';
/**
 * _benefitBalance
 *
 * (Modified) ExplanationOfBenefit.benefitBalance
 *
 * http://hl7.org/fhir/_benefitBalance
 */
var _benefitBalance = 'http://hl7.org/fhir/_benefitBalance';
/**
 * _information
 *
 * (Modified) CoverageEligibilityRequest.supportingInfo.information
 *
 * http://hl7.org/fhir/_information
 */
var _information = 'http://hl7.org/fhir/_information';
/**
 * _CareTeam
 *
 * (Modified) CareTeam
 *
 * http://hl7.org/fhir/_CareTeam
 */
var _CareTeam = 'http://hl7.org/fhir/_CareTeam';
/**
 * _aggregateMethod
 *
 * (Modified) Measure.group.population.aggregateMethod
 *
 * http://hl7.org/fhir/_aggregateMethod
 */
var _aggregateMethod = 'http://hl7.org/fhir/_aggregateMethod';
/**
 * generatedBy
 *
 * GenomicStudy.analysis.input.generatedBy
 *
 * http://hl7.org/fhir/generatedBy
 */
var generatedBy = 'http://hl7.org/fhir/generatedBy';
/**
 * _tag
 *
 * (Modified) Meta.tag
 *
 * http://hl7.org/fhir/_tag
 */
var _tag = 'http://hl7.org/fhir/_tag';
/**
 * asserter
 *
 * Permission.asserter: The person or entity that asserts the permission.
 *
 * http://hl7.org/fhir/asserter
 */
var asserter = 'http://hl7.org/fhir/asserter';
/**
 * _revInclude
 *
 * (Modified) SubscriptionTopic.notificationShape.revInclude
 *
 * http://hl7.org/fhir/_revInclude
 */
var _revInclude = 'http://hl7.org/fhir/_revInclude';
/**
 * onset
 *
 * FamilyMemberHistory.condition.onset
 *
 * http://hl7.org/fhir/onset
 */
var onset = 'http://hl7.org/fhir/onset';
/**
 * criticalCodedValueSet
 *
 * ObservationDefinition.component.qualifiedValue.criticalCodedValueSet: The set of critical coded results for qualitative observations  that match the criteria of this set of qualified values.
 *
 * http://hl7.org/fhir/criticalCodedValueSet
 */
var criticalCodedValueSet = 'http://hl7.org/fhir/criticalCodedValueSet';
/**
 * _mode
 *
 * (Modified) Device.mode
 *
 * http://hl7.org/fhir/_mode
 */
var _mode = 'http://hl7.org/fhir/_mode';
/**
 * anchor
 *
 * ImplementationGuide.manifest.page.anchor: The name of an anchor available on the page.
 *
 * http://hl7.org/fhir/anchor
 */
var anchor = 'http://hl7.org/fhir/anchor';
/**
 * _substitution
 *
 * (Modified) MedicationRequest.substitution
 *
 * http://hl7.org/fhir/_substitution
 */
var _substitution = 'http://hl7.org/fhir/_substitution';
/**
 * _consent
 *
 * (Modified) ResearchSubject.consent
 *
 * http://hl7.org/fhir/_consent
 */
var _consent = 'http://hl7.org/fhir/_consent';
/**
 * _candidate
 *
 * (Modified) EnrollmentRequest.candidate
 *
 * http://hl7.org/fhir/_candidate
 */
var _candidate = 'http://hl7.org/fhir/_candidate';
/**
 * _concept
 *
 * (Modified) ValueSet.compose.exclude.concept
 *
 * http://hl7.org/fhir/_concept
 */
var _concept = 'http://hl7.org/fhir/_concept';
/**
 * MeasureReportGroupStratifierStratumComponentComponent
 *
 * MeasureReportGroupComponent.MeasureReportGroupStratifierComponent.StratifierGroup.MeasureReportGroupStratifierStratumComponentComponent: A stratifier component value.
 *
 * http://hl7.org/fhir/MeasureReportGroupStratifierStratumComponentComponent
 */
var MeasureReportGroupStratifierStratumComponentComponent = 'http://hl7.org/fhir/MeasureReportGroupStratifierStratumComponentComponent';
/**
 * ifNoneExist
 *
 * Bundle.entry.request.ifNoneExist: Instruct the server not to perform the create if a specified resource already exists. For further information, see the API documentation for ["Conditional Create"](http.html#ccreate). This is just the query portion of the URL - what follows the "?" (not including the "?").
 *
 * http://hl7.org/fhir/ifNoneExist
 */
var ifNoneExist = 'http://hl7.org/fhir/ifNoneExist';
/**
 * GraphDefinitionNodeComponent
 *
 * GraphDefinitionNodeComponent: Potential target for the link.
 *
 * http://hl7.org/fhir/GraphDefinitionNodeComponent
 */
var GraphDefinitionNodeComponent = 'http://hl7.org/fhir/GraphDefinitionNodeComponent';
/**
 * _answer
 *
 * (Modified) Contract.term.group.asset.answer
 *
 * http://hl7.org/fhir/_answer
 */
var _answer = 'http://hl7.org/fhir/_answer';
/**
 * _schedule
 *
 * (Modified) Slot.schedule
 *
 * http://hl7.org/fhir/_schedule
 */
var _schedule = 'http://hl7.org/fhir/_schedule';
/**
 * administrationTreatment
 *
 * MedicationKnowledge.indicationGuideline.dosingGuideline.administrationTreatment: The type of the treatment that the guideline applies to, for example, long term therapy, first line treatment, etc.
 *
 * http://hl7.org/fhir/administrationTreatment
 */
var administrationTreatment = 'http://hl7.org/fhir/administrationTreatment';
/**
 * _baseFormulaProductName
 *
 * (Modified) NutritionOrder.enteralFormula.baseFormulaProductName
 *
 * http://hl7.org/fhir/_baseFormulaProductName
 */
var _baseFormulaProductName = 'http://hl7.org/fhir/_baseFormulaProductName';
/**
 * PermissionRuleDataResourceComponent
 *
 * Permission.Rule.PermissionRuleDataComponent.PermissionRuleDataResourceComponent: Explicit FHIR Resource references.
 *
 * http://hl7.org/fhir/PermissionRuleDataResourceComponent
 */
var PermissionRuleDataResourceComponent = 'http://hl7.org/fhir/PermissionRuleDataResourceComponent';
/**
 * _gestationalAge
 *
 * (Modified) ObservationDefinition.component.qualifiedValue.gestationalAge
 *
 * http://hl7.org/fhir/_gestationalAge
 */
var _gestationalAge = 'http://hl7.org/fhir/_gestationalAge';
/**
 * carrierAIDC
 *
 * Device.udiCarrier.carrierAIDC: The full UDI carrier of the Automatic Identification and Data Capture (AIDC) technology representation of the barcode string as printed on the packaging of the device - e.g., a barcode or RFID.   Because of limitations on character sets in XML and the need to round-trip JSON data through XML, AIDC Formats *SHALL* be base64 encoded.
 *
 * http://hl7.org/fhir/carrierAIDC
 */
var carrierAIDC = 'http://hl7.org/fhir/carrierAIDC';
/**
 * _capability
 *
 * (Modified) TestScript.metadata.capability
 *
 * http://hl7.org/fhir/_capability
 */
var _capability = 'http://hl7.org/fhir/_capability';
/**
 * usageStatus
 *
 * DeviceUsage.usageStatus: The status of the device usage, for example always, sometimes, never. This is not the same as the status of the statement.
 *
 * http://hl7.org/fhir/usageStatus
 */
var usageStatus = 'http://hl7.org/fhir/usageStatus';
/**
 * _knownAllergen
 *
 * (Modified) NutritionProduct.knownAllergen
 *
 * http://hl7.org/fhir/_knownAllergen
 */
var _knownAllergen = 'http://hl7.org/fhir/_knownAllergen';
/**
 * storageTempRequirements
 *
 * BiologicallyDerivedProduct.storageTempRequirements: The temperature requirements for storage of the biologically-derived product.
 *
 * http://hl7.org/fhir/storageTempRequirements
 */
var storageTempRequirements = 'http://hl7.org/fhir/storageTempRequirements';
/**
 * definitionReference
 *
 * EvidenceVariable.characteristic.definitionByCombination.characteristic.definitionReference: Defines the characteristic using a Reference.
 *
 * http://hl7.org/fhir/definitionReference
 */
var definitionReference = 'http://hl7.org/fhir/definitionReference';
/**
 * experimental
 *
 * SubscriptionTopic.experimental: A flag to indicate that this TopSubscriptionTopicic is authored for testing purposes (or education/evaluation/marketing), and is not intended to be used for genuine usage.
 *
 * http://hl7.org/fhir/experimental
 */
var experimental = 'http://hl7.org/fhir/experimental';
/**
 * _numberOfParticipants
 *
 * (Modified) Evidence.statistic.sampleSize.numberOfParticipants
 *
 * http://hl7.org/fhir/_numberOfParticipants
 */
var _numberOfParticipants = 'http://hl7.org/fhir/_numberOfParticipants';
/**
 * _repeat
 *
 * (Modified) SubstancePolymer.repeat
 *
 * http://hl7.org/fhir/_repeat
 */
var _repeat = 'http://hl7.org/fhir/_repeat';
/**
 * displayName
 *
 * Device.displayName: The name used to display by default when the device is referenced. Based on intent of use by the resource creator, this may reflect one of the names in Device.name, or may be another simple name.
 *
 * http://hl7.org/fhir/displayName
 */
var displayName = 'http://hl7.org/fhir/displayName';
/**
 * replaces
 *
 * ServiceRequest.replaces: The request takes the place of the referenced completed or terminated request(s).
 *
 * http://hl7.org/fhir/replaces
 */
var replaces = 'http://hl7.org/fhir/replaces';
/**
 * _distanceFromLandmark
 *
 * (Modified) BodyStructure.excludedStructure.bodyLandmarkOrientation.distanceFromLandmark
 *
 * http://hl7.org/fhir/_distanceFromLandmark
 */
var _distanceFromLandmark = 'http://hl7.org/fhir/_distanceFromLandmark';
/**
 * _frequency
 *
 * (Modified) VerificationResult.frequency
 *
 * http://hl7.org/fhir/_frequency
 */
var _frequency = 'http://hl7.org/fhir/_frequency';
/**
 * shortDoco
 *
 * ElementDefinition.binding.additional.shortDoco: Concise documentation - for summary tables.
 *
 * http://hl7.org/fhir/shortDoco
 */
var shortDoco = 'http://hl7.org/fhir/shortDoco';
/**
 * ImagingSelection
 *
 * A selection of DICOM SOP instances and/or frames within a single Study and Series. This might include additional specifics such as an image region, an Observation UID or a Segmentation Number, allowing linkage to an Observation Resource or transferring this information along with the ImagingStudy Resource.
 *
 * http://hl7.org/fhir/ImagingSelection
 */
var ImagingSelection = 'http://hl7.org/fhir/ImagingSelection';
/**
 * modality
 *
 * ImagingStudy.modality: A list of all the distinct values of series.modality. This may include both acquisition and non-acquisition modalities.
 *
 * http://hl7.org/fhir/modality
 */
var modality = 'http://hl7.org/fhir/modality';
/**
 * _targetId
 *
 * (Modified) TestScript.test.action.operation.targetId
 *
 * http://hl7.org/fhir/_targetId
 */
var _targetId = 'http://hl7.org/fhir/_targetId';
/**
 * _amount
 *
 * (Modified) ExplanationOfBenefit.adjudication.amount
 *
 * http://hl7.org/fhir/_amount
 */
var _amount = 'http://hl7.org/fhir/_amount';
/**
 * species
 *
 * SubstanceSourceMaterial.organism.species: The species of an organism shall be specified; refers to the Latin epithet of the species of the plant/animal; it is present in names for species and infraspecies.
 *
 * http://hl7.org/fhir/species
 */
var species = 'http://hl7.org/fhir/species';
/**
 * totalNet
 *
 * Invoice.totalNet: Invoice total , taxes excluded.
 *
 * http://hl7.org/fhir/totalNet
 */
var totalNet = 'http://hl7.org/fhir/totalNet';
/**
 * observationRequirement
 *
 * ActivityDefinition.observationRequirement: Defines observation requirements for the action to be performed, such as body weight or surface area.
 *
 * http://hl7.org/fhir/observationRequirement
 */
var observationRequirement = 'http://hl7.org/fhir/observationRequirement';
/**
 * InsurancePlanPlanGeneralCostComponent
 *
 * InsurancePlanPlanComponent.InsurancePlanPlanGeneralCostComponent: Overall costs associated with the plan.
 *
 * http://hl7.org/fhir/InsurancePlanPlanGeneralCostComponent
 */
var InsurancePlanPlanGeneralCostComponent = 'http://hl7.org/fhir/InsurancePlanPlanGeneralCostComponent';
/**
 * InvoiceLineItemComponent
 *
 * InvoiceLineItemComponent: Each line item represents one charge for goods and services rendered. Details such.ofType(date), code and amount are found in the referenced ChargeItem resource.
 *
 * http://hl7.org/fhir/InvoiceLineItemComponent
 */
var InvoiceLineItemComponent = 'http://hl7.org/fhir/InvoiceLineItemComponent';
/**
 * requestor
 *
 * ClaimResponse.requestor: The provider which is responsible for the claim, predetermination or preauthorization.
 *
 * http://hl7.org/fhir/requestor
 */
var requestor = 'http://hl7.org/fhir/requestor';
/**
 * dietPreference
 *
 * Encounter.dietPreference: Diet preferences reported by the patient.
 *
 * http://hl7.org/fhir/dietPreference
 */
var dietPreference = 'http://hl7.org/fhir/dietPreference';
/**
 * comparator
 *
 * SearchParameter.comparator: Comparators supported for the search parameter.
 *
 * http://hl7.org/fhir/comparator
 */
var comparator = 'http://hl7.org/fhir/comparator';
/**
 * _combinedPharmaceuticalDoseForm
 *
 * (Modified) MedicinalProductDefinition.combinedPharmaceuticalDoseForm
 *
 * http://hl7.org/fhir/_combinedPharmaceuticalDoseForm
 */
var _combinedPharmaceuticalDoseForm = 'http://hl7.org/fhir/_combinedPharmaceuticalDoseForm';
/**
 * servicePeriod
 *
 * Account.servicePeriod: The date range of services associated with this account.
 *
 * http://hl7.org/fhir/servicePeriod
 */
var servicePeriod = 'http://hl7.org/fhir/servicePeriod';
/**
 * _rater
 *
 * (Modified) Evidence.certainty.subcomponent.rater
 *
 * http://hl7.org/fhir/_rater
 */
var _rater = 'http://hl7.org/fhir/_rater';
/**
 * receiverActive
 *
 * ExampleScenario.process.step.process.step.alternative.step.operation.receiverActive: If false, the receiver is deactivated right after the operation.
 *
 * http://hl7.org/fhir/receiverActive
 */
var receiverActive = 'http://hl7.org/fhir/receiverActive';
/**
 * modification
 *
 * SubstancePolymer.modification: Todo - this is intended to connect to a repeating full modification structure, also used by Protein and Nucleic Acid . String is just a placeholder.
 *
 * http://hl7.org/fhir/modification
 */
var modification = 'http://hl7.org/fhir/modification';
/**
 * practitioner
 *
 * PractitionerRole.practitioner: Practitioner that is able to provide the defined services for the organization.
 *
 * http://hl7.org/fhir/practitioner
 */
var practitioner = 'http://hl7.org/fhir/practitioner';
/**
 * _normalCodedValueSet
 *
 * (Modified) ObservationDefinition.component.qualifiedValue.normalCodedValueSet
 *
 * http://hl7.org/fhir/_normalCodedValueSet
 */
var _normalCodedValueSet = 'http://hl7.org/fhir/_normalCodedValueSet';
/**
 * TestCaseDependency
 *
 * TestPlanTestCaseComponent.TestCaseDependency: The required criteria to execute the test case - e.g. preconditions, previous tests.
 *
 * http://hl7.org/fhir/TestCaseDependency
 */
var TestCaseDependency = 'http://hl7.org/fhir/TestCaseDependency';
/**
 * _costToBeneficiary
 *
 * (Modified) Coverage.costToBeneficiary
 *
 * http://hl7.org/fhir/_costToBeneficiary
 */
var _costToBeneficiary = 'http://hl7.org/fhir/_costToBeneficiary';
/**
 * MessageHeader
 *
 * The header for a message exchange that is either requesting or responding to an action.  The reference(s) that are the subject of the action as well as other information related to the action are typically transmitted in a bundle in which the MessageHeader resource instance is the first resource in the bundle.
 *
 * http://hl7.org/fhir/MessageHeader
 */
var MessageHeader = 'http://hl7.org/fhir/MessageHeader';
/**
 * ResearchStudyRecruitmentComponent
 *
 * ResearchStudyRecruitmentComponent: Target or actual group of participants enrolled in study.
 *
 * http://hl7.org/fhir/ResearchStudyRecruitmentComponent
 */
var ResearchStudyRecruitmentComponent = 'http://hl7.org/fhir/ResearchStudyRecruitmentComponent';
/**
 * _forenameInitials
 *
 * (Modified) Citation.citedArtifact.contributorship.entry.forenameInitials
 *
 * http://hl7.org/fhir/_forenameInitials
 */
var _forenameInitials = 'http://hl7.org/fhir/_forenameInitials';
/**
 * plannedStartDate
 *
 * EncounterHistory.plannedStartDate: The planned start date/time (or admission date) of the encounter.
 *
 * http://hl7.org/fhir/plannedStartDate
 */
var plannedStartDate = 'http://hl7.org/fhir/plannedStartDate';
/**
 * study
 *
 * ResearchSubject.study: Reference to the study the subject is participating in.
 *
 * http://hl7.org/fhir/study
 */
var study = 'http://hl7.org/fhir/study';
/**
 * groupIdentifier
 *
 * NutritionOrder.groupIdentifier: A shared identifier common to all nutrition orders that were authorized more or less simultaneously by a single author, representing the composite or group identifier.
 *
 * http://hl7.org/fhir/groupIdentifier
 */
var groupIdentifier = 'http://hl7.org/fhir/groupIdentifier';
/**
 * _participatingOrganization
 *
 * (Modified) OrganizationAffiliation.participatingOrganization
 *
 * http://hl7.org/fhir/_participatingOrganization
 */
var _participatingOrganization = 'http://hl7.org/fhir/_participatingOrganization';
/**
 * MeasureGroupStratifierComponent
 *
 * MeasureGroupComponent.MeasureGroupStratifierComponent: The stratifier criteria for the measure report, specified as either the name of a valid CQL expression defined within a referenced library or a valid FHIR Resource Path.
 *
 * http://hl7.org/fhir/MeasureGroupStratifierComponent
 */
var MeasureGroupStratifierComponent = 'http://hl7.org/fhir/MeasureGroupStratifierComponent';
/**
 * wednesday
 *
 * Appointment.recurrenceTemplate.weeklyTemplate.wednesday: Indicates that recurring appointments should occur on Wednesdays.
 *
 * http://hl7.org/fhir/wednesday
 */
var wednesday = 'http://hl7.org/fhir/wednesday';
/**
 * _diameter
 *
 * (Modified) VisionPrescription.lensSpecification.diameter
 *
 * http://hl7.org/fhir/_diameter
 */
var _diameter = 'http://hl7.org/fhir/_diameter';
/**
 * enteralFormula
 *
 * NutritionOrder.enteralFormula: Feeding provided through the gastrointestinal tract via a tube, catheter, or stoma that delivers nutrition distal to the oral cavity.
 *
 * http://hl7.org/fhir/enteralFormula
 */
var enteralFormula = 'http://hl7.org/fhir/enteralFormula';
/**
 * _stabilityDuration
 *
 * (Modified) MedicationKnowledge.storageGuideline.stabilityDuration
 *
 * http://hl7.org/fhir/_stabilityDuration
 */
var _stabilityDuration = 'http://hl7.org/fhir/_stabilityDuration';
/**
 * integer
 *
 * A whole number
 *
 * http://hl7.org/fhir/integer
 */
var integer = 'http://hl7.org/fhir/integer';
/**
 * domain
 *
 * SubstanceDefinition.name.translation.domain: The use context of this name for example if there is a different name a drug active ingredient as opposed to a food colour additive.
 *
 * http://hl7.org/fhir/domain
 */
var domain = 'http://hl7.org/fhir/domain';
/**
 * _periodType
 *
 * (Modified) Contract.term.group.asset.periodType
 *
 * http://hl7.org/fhir/_periodType
 */
var _periodType = 'http://hl7.org/fhir/_periodType';
/**
 * _ImagingStudy
 *
 * (Modified) ImagingStudy
 *
 * http://hl7.org/fhir/_ImagingStudy
 */
var _ImagingStudy = 'http://hl7.org/fhir/_ImagingStudy';
/**
 * searchRevInclude
 *
 * CapabilityStatement.rest.resource.searchRevInclude: A list of _revinclude (reverse include) values supported by the server.
 *
 * http://hl7.org/fhir/searchRevInclude
 */
var searchRevInclude = 'http://hl7.org/fhir/searchRevInclude';
/**
 * _relatedAction
 *
 * (Modified) RequestOrchestration.action.action.relatedAction
 *
 * http://hl7.org/fhir/_relatedAction
 */
var _relatedAction = 'http://hl7.org/fhir/_relatedAction';
/**
 * observed
 *
 * Evidence.variableDefinition.observed: Definition of the actual variable related to the statistic(s).
 *
 * http://hl7.org/fhir/observed
 */
var observed = 'http://hl7.org/fhir/observed';
/**
 * born
 *
 * FamilyMemberHistory.born
 *
 * http://hl7.org/fhir/born
 */
var born = 'http://hl7.org/fhir/born';
/**
 * _ImmunizationRecommendation
 *
 * (Modified) ImmunizationRecommendation
 *
 * http://hl7.org/fhir/_ImmunizationRecommendation
 */
var _ImmunizationRecommendation = 'http://hl7.org/fhir/_ImmunizationRecommendation';
/**
 * service
 *
 * ChargeItem.service: Indicated the rendered service that caused this charge.
 *
 * http://hl7.org/fhir/service
 */
var service = 'http://hl7.org/fhir/service';
/**
 * _requestIdentifier
 *
 * (Modified) GuidanceResponse.requestIdentifier
 *
 * http://hl7.org/fhir/_requestIdentifier
 */
var _requestIdentifier = 'http://hl7.org/fhir/_requestIdentifier';
/**
 * maxDosePerLifetime
 *
 * Dosage.maxDosePerLifetime: Upper limit on medication per lifetime of the patient.
 *
 * http://hl7.org/fhir/maxDosePerLifetime
 */
var maxDosePerLifetime = 'http://hl7.org/fhir/maxDosePerLifetime';
/**
 * format
 *
 * SubstancePolymer.repeat.repeatUnit.structuralRepresentation.format: The format of the representation e.g. InChI, SMILES, MOLFILE, CDX, SDF, PDB, mmCIF.
 *
 * http://hl7.org/fhir/format
 */
var format = 'http://hl7.org/fhir/format';
/**
 * _isSummary
 *
 * (Modified) ElementDefinition.isSummary
 *
 * http://hl7.org/fhir/_isSummary
 */
var _isSummary = 'http://hl7.org/fhir/_isSummary';
/**
 * supportingInfoSequence
 *
 * CoverageEligibilityRequest.item.supportingInfoSequence: Exceptions, special conditions and supporting information applicable for this service or product line.
 *
 * http://hl7.org/fhir/supportingInfoSequence
 */
var supportingInfoSequence = 'http://hl7.org/fhir/supportingInfoSequence';
/**
 * EvidenceStatisticModelCharacteristicVariableComponent
 *
 * EvidenceStatisticComponent.EvidenceStatisticModelCharacteristicComponent.EvidenceStatisticModelCharacteristicVariableComponent: A variable adjusted for in the adjusted analysis.
 *
 * http://hl7.org/fhir/EvidenceStatisticModelCharacteristicVariableComponent
 */
var EvidenceStatisticModelCharacteristicVariableComponent = 'http://hl7.org/fhir/EvidenceStatisticModelCharacteristicVariableComponent';
/**
 * ManufacturedItemDefinitionPropertyComponent
 *
 * ManufacturedItemDefinitionPropertyComponent: General characteristics of this item.
 *
 * http://hl7.org/fhir/ManufacturedItemDefinitionPropertyComponent
 */
var ManufacturedItemDefinitionPropertyComponent = 'http://hl7.org/fhir/ManufacturedItemDefinitionPropertyComponent';
/**
 * _concentration
 *
 * (Modified) Ingredient.substance.strength.concentration
 *
 * http://hl7.org/fhir/_concentration
 */
var _concentration = 'http://hl7.org/fhir/_concentration';
/**
 * coordinate
 *
 * ImagingSelection.instance.imageRegion3D.coordinate: The coordinates describing the image region. Encoded as an ordered set of (x,y,z) triplets (in mm and may be negative) that define a region of interest in the patient-relative Reference Coordinate System defined by ImagingSelection.frameOfReferenceUid element.
 *
 * http://hl7.org/fhir/coordinate
 */
var coordinate = 'http://hl7.org/fhir/coordinate';
/**
 * AddedItemDetailSubDetail
 *
 * ExplanationOfBenefit.AddedItem.AddedItemDetail.AddedItemDetailSubDetail: The third-tier service adjudications for payor added services.
 *
 * http://hl7.org/fhir/AddedItemDetailSubDetail
 */
var AddedItemDetailSubDetail = 'http://hl7.org/fhir/AddedItemDetailSubDetail';
/**
 * TerminologyCapabilitiesTranslationComponent
 *
 * TerminologyCapabilitiesTranslationComponent: Information about the [ConceptMap/$translate](conceptmap-operation-translate.html) operation.
 *
 * http://hl7.org/fhir/TerminologyCapabilitiesTranslationComponent
 */
var TerminologyCapabilitiesTranslationComponent = 'http://hl7.org/fhir/TerminologyCapabilitiesTranslationComponent';
/**
 * _generalPractitioner
 *
 * (Modified) Patient.generalPractitioner
 *
 * http://hl7.org/fhir/_generalPractitioner
 */
var _generalPractitioner = 'http://hl7.org/fhir/_generalPractitioner';
/**
 * _protocol
 *
 * (Modified) ResearchStudy.protocol
 *
 * http://hl7.org/fhir/_protocol
 */
var _protocol = 'http://hl7.org/fhir/_protocol';
/**
 * _exception
 *
 * (Modified) Coverage.costToBeneficiary.exception
 *
 * http://hl7.org/fhir/_exception
 */
var _exception = 'http://hl7.org/fhir/_exception';
/**
 * _complication
 *
 * (Modified) Procedure.complication
 *
 * http://hl7.org/fhir/_complication
 */
var _complication = 'http://hl7.org/fhir/_complication';
/**
 * value
 *
 * CodeSystem.filter.value: A description of what the value for the filter should be.
 *
 * http://hl7.org/fhir/value
 */
var value = 'http://hl7.org/fhir/value';
/**
 * _nthWeekOfMonth
 *
 * (Modified) Appointment.recurrenceTemplate.monthlyTemplate.nthWeekOfMonth
 *
 * http://hl7.org/fhir/_nthWeekOfMonth
 */
var _nthWeekOfMonth = 'http://hl7.org/fhir/_nthWeekOfMonth';
/**
 * _url
 *
 * (Modified) ActorDefinition.url
 *
 * http://hl7.org/fhir/_url
 */
var _url = 'http://hl7.org/fhir/_url';
/**
 * SubstanceSourceMaterialOrganismHybridComponent
 *
 * SubstanceSourceMaterialOrganismComponent.SubstanceSourceMaterialOrganismHybridComponent: 4.9.13.8.1 Hybrid species maternal organism ID (Optional).
 *
 * http://hl7.org/fhir/SubstanceSourceMaterialOrganismHybridComponent
 */
var SubstanceSourceMaterialOrganismHybridComponent = 'http://hl7.org/fhir/SubstanceSourceMaterialOrganismHybridComponent';
/**
 * SubscriptionTopicEventTriggerComponent
 *
 * SubscriptionTopicEventTriggerComponent: Event definition which can be used to trigger the SubscriptionTopic.
 *
 * http://hl7.org/fhir/SubscriptionTopicEventTriggerComponent
 */
var SubscriptionTopicEventTriggerComponent = 'http://hl7.org/fhir/SubscriptionTopicEventTriggerComponent';
/**
 * MedicinalProductDefinitionNameComponent
 *
 * MedicinalProductDefinitionNameComponent: The product's name, including full name and possibly coded parts.
 *
 * http://hl7.org/fhir/MedicinalProductDefinitionNameComponent
 */
var MedicinalProductDefinitionNameComponent = 'http://hl7.org/fhir/MedicinalProductDefinitionNameComponent';
/**
 * SubstanceSourceMaterialOrganismComponent
 *
 * SubstanceSourceMaterialOrganismComponent: This subclause describes the organism which the substance is derived from. For vaccines, the parent organism shall be specified based on these subclause elements. As an example, full taxonomy will be described for the Substance Name: ., Leaf.
 *
 * http://hl7.org/fhir/SubstanceSourceMaterialOrganismComponent
 */
var SubstanceSourceMaterialOrganismComponent = 'http://hl7.org/fhir/SubstanceSourceMaterialOrganismComponent';
/**
 * overrideReason
 *
 * ChargeItem.overrideReason: If the list price or the rule-based factor associated with the code is overridden, this attribute can capture a text to indicate the  reason for this action.
 *
 * http://hl7.org/fhir/overrideReason
 */
var overrideReason = 'http://hl7.org/fhir/overrideReason';
/**
 * pages
 *
 * Attachment.pages: The number of pages when printed.
 *
 * http://hl7.org/fhir/pages
 */
var pages = 'http://hl7.org/fhir/pages';
/**
 * _conclusion
 *
 * (Modified) DiagnosticReport.conclusion
 *
 * http://hl7.org/fhir/_conclusion
 */
var _conclusion = 'http://hl7.org/fhir/_conclusion';
/**
 * _combined
 *
 * (Modified) Specimen.combined
 *
 * http://hl7.org/fhir/_combined
 */
var _combined = 'http://hl7.org/fhir/_combined';
/**
 * _contains
 *
 * (Modified) ValueSet.expansion.contains.contains
 *
 * http://hl7.org/fhir/_contains
 */
var _contains = 'http://hl7.org/fhir/_contains';
/**
 * _documentType
 *
 * (Modified) Consent.provision.provision.documentType
 *
 * http://hl7.org/fhir/_documentType
 */
var _documentType = 'http://hl7.org/fhir/_documentType';
/**
 * MeasureGroupStratifierComponentComponent
 *
 * MeasureGroupComponent.MeasureGroupStratifierComponent.MeasureGroupStratifierComponentComponent: A component of the stratifier criteria for the measure report, specified as either the name of a valid CQL expression defined within a referenced library or a valid FHIR Resource Path.
 *
 * http://hl7.org/fhir/MeasureGroupStratifierComponentComponent
 */
var MeasureGroupStratifierComponentComponent = 'http://hl7.org/fhir/MeasureGroupStratifierComponentComponent';
/**
 * _numberOfInstances
 *
 * (Modified) ImagingStudy.series.numberOfInstances
 *
 * http://hl7.org/fhir/_numberOfInstances
 */
var _numberOfInstances = 'http://hl7.org/fhir/_numberOfInstances';
/**
 * PlanDefinitionActionComponent
 *
 * PlanDefinitionActionComponent: An action or group of actions to be taken as part of the plan. For example, in clinical care, an action would be to prescribe a particular indicated medication, or perform a particular test as appropriate. In pharmaceutical quality, an action would be the test that needs to be performed on a drug product as defined in the quality specification.
 *
 * http://hl7.org/fhir/PlanDefinitionActionComponent
 */
var PlanDefinitionActionComponent = 'http://hl7.org/fhir/PlanDefinitionActionComponent';
/**
 * _processor
 *
 * (Modified) PaymentReconciliation.processor
 *
 * http://hl7.org/fhir/_processor
 */
var _processor = 'http://hl7.org/fhir/_processor';
/**
 * actualNumber
 *
 * ResearchStudy.recruitment.actualNumber: Actual total number of participants enrolled in study.
 *
 * http://hl7.org/fhir/actualNumber
 */
var actualNumber = 'http://hl7.org/fhir/actualNumber';
/**
 * _network
 *
 * (Modified) AuditEvent.agent.network
 *
 * http://hl7.org/fhir/_network
 */
var _network = 'http://hl7.org/fhir/_network';
/**
 * effective
 *
 * Observation.effective
 *
 * http://hl7.org/fhir/effective
 */
var effective = 'http://hl7.org/fhir/effective';
/**
 * textEquivalent
 *
 * RequestOrchestration.action.textEquivalent: A text equivalent of the action to be performed. This provides a human-interpretable description of the action when the definition is consumed by a system that might not be capable of interpreting it dynamically.
 *
 * http://hl7.org/fhir/textEquivalent
 */
var textEquivalent = 'http://hl7.org/fhir/textEquivalent';
/**
 * preferred
 *
 * RelatedPerson.communication.preferred: Indicates whether or not the related person prefers this language (over other languages he or she masters up a certain level).
 *
 * http://hl7.org/fhir/preferred
 */
var preferred = 'http://hl7.org/fhir/preferred';
/**
 * ImplementationGuide
 *
 * A set of rules of how a particular interoperability or standards problem is solved - typically through the use of FHIR resources. This resource is used to gather all the parts of an implementation guide into a logical whole and to publish a computable definition of all the parts.
 *
 * http://hl7.org/fhir/ImplementationGuide
 */
var ImplementationGuide = 'http://hl7.org/fhir/ImplementationGuide';
/**
 * EvidenceReportRelatesToTargetComponent
 *
 * EvidenceReportRelatesToComponent.EvidenceReportRelatesToTargetComponent: The target composition/document of this relationship.
 *
 * http://hl7.org/fhir/EvidenceReportRelatesToTargetComponent
 */
var EvidenceReportRelatesToTargetComponent = 'http://hl7.org/fhir/EvidenceReportRelatesToTargetComponent';
/**
 * _applicability
 *
 * (Modified) InsurancePlan.plan.specificCost.benefit.cost.applicability
 *
 * http://hl7.org/fhir/_applicability
 */
var _applicability = 'http://hl7.org/fhir/_applicability';
/**
 * min
 *
 * GraphDefinition.link.min: Minimum occurrences for this link.
 *
 * http://hl7.org/fhir/min
 */
var min = 'http://hl7.org/fhir/min';
/**
 * DeviceNameComponent
 *
 * DeviceNameComponent: This represents the manufacturer's name of the device as provided by the device, from a UDI label, or by a person describing the Device.  This typically would be used when a person provides the name(s) or when the device represents one of the names available from DeviceDefinition.
 *
 * http://hl7.org/fhir/DeviceNameComponent
 */
var DeviceNameComponent = 'http://hl7.org/fhir/DeviceNameComponent';
/**
 * Payment
 *
 * ClaimResponse.Payment: Payment details for the adjudication of the claim.
 *
 * http://hl7.org/fhir/Payment
 */
var Payment = 'http://hl7.org/fhir/Payment';
/**
 * organismName
 *
 * SubstanceSourceMaterial.organismName: The organism accepted Scientific name shall be provided based on the organism taxonomy.
 *
 * http://hl7.org/fhir/organismName
 */
var organismName = 'http://hl7.org/fhir/organismName';
/**
 * relative
 *
 * MolecularSequence.relative: A sequence defined relative to another sequence.
 *
 * http://hl7.org/fhir/relative
 */
var relative = 'http://hl7.org/fhir/relative';
/**
 * Ratio
 *
 * A relationship of two Quantity values - expressed as a numerator and a denominator.
 *
 * http://hl7.org/fhir/Ratio
 */
var Ratio = 'http://hl7.org/fhir/Ratio';
/**
 * item
 *
 * ExplanationOfBenefit.item: A claim line. Either a simple (a product or service) or a 'group' of details which can also be a simple items or groups of sub-details.
 *
 * http://hl7.org/fhir/item
 */
var item = 'http://hl7.org/fhir/item';
/**
 * rating
 *
 * Evidence.certainty.subcomponent.rating: Assessment or judgement of the aspect.
 *
 * http://hl7.org/fhir/rating
 */
var rating = 'http://hl7.org/fhir/rating';
/**
 * _numerator
 *
 * (Modified) Ratio.numerator
 *
 * http://hl7.org/fhir/_numerator
 */
var _numerator = 'http://hl7.org/fhir/_numerator';
/**
 * TestScriptScopeComponent
 *
 * TestScriptScopeComponent: The scope indicates a conformance artifact that is tested by the test(s) within this test case and the expectation of the test outcome(s) as well as the intended test phase inclusion.
 *
 * http://hl7.org/fhir/TestScriptScopeComponent
 */
var TestScriptScopeComponent = 'http://hl7.org/fhir/TestScriptScopeComponent';
/**
 * _aggregation
 *
 * (Modified) ElementDefinition.type.aggregation
 *
 * http://hl7.org/fhir/_aggregation
 */
var _aggregation = 'http://hl7.org/fhir/_aggregation';
/**
 * minutesDuration
 *
 * Appointment.minutesDuration: Number of minutes that the appointment is to take. This can be less than the duration between the start and end times.  For example, where the actual time of appointment is only an estimate or if a 30 minute appointment is being requested, but any time would work.  Also, if there is, for example, a planned 15 minute break in the middle of a long appointment, the duration may be 15 minutes less than the difference between the start and end.
 *
 * http://hl7.org/fhir/minutesDuration
 */
var minutesDuration = 'http://hl7.org/fhir/minutesDuration';
/**
 * AuditEventEntityComponent
 *
 * AuditEventEntityComponent: Specific instances of data or objects that have been accessed.
 *
 * http://hl7.org/fhir/AuditEventEntityComponent
 */
var AuditEventEntityComponent = 'http://hl7.org/fhir/AuditEventEntityComponent';
/**
 * rate
 *
 * NutritionOrder.enteralFormula.administration.rate
 *
 * http://hl7.org/fhir/rate
 */
var rate = 'http://hl7.org/fhir/rate';
/**
 * CompartmentDefinition
 *
 * A compartment definition that defines how resources are accessed on a server.
 *
 * http://hl7.org/fhir/CompartmentDefinition
 */
var CompartmentDefinition = 'http://hl7.org/fhir/CompartmentDefinition';
/**
 * renderedDosageInstruction
 *
 * MedicationStatement.renderedDosageInstruction: The full representation of the dose of the medication included in all dosage instructions.  To be used when multiple dosage instructions are included to represent complex dosing such as increasing or tapering doses.
 *
 * http://hl7.org/fhir/renderedDosageInstruction
 */
var renderedDosageInstruction = 'http://hl7.org/fhir/renderedDosageInstruction';
/**
 * methodType
 *
 * GenomicStudy.analysis.methodType: Type of the methods used in the analysis, e.g., Fluorescence in situ hybridization (FISH), Karyotyping, or Microsatellite instability testing (MSI).
 *
 * http://hl7.org/fhir/methodType
 */
var methodType = 'http://hl7.org/fhir/methodType';
/**
 * parent
 *
 * MessageDefinition.parent: Identifies a protocol or workflow that this MessageDefinition represents a step in.
 *
 * http://hl7.org/fhir/parent
 */
var parent = 'http://hl7.org/fhir/parent';
/**
 * sourceId
 *
 * OperationDefinition.parameter.referencedFrom.sourceId: The id of the element in the referencing resource that is expected to resolve to this resource.
 *
 * http://hl7.org/fhir/sourceId
 */
var sourceId = 'http://hl7.org/fhir/sourceId';
/**
 * _requestedPeriod
 *
 * (Modified) Task.requestedPeriod
 *
 * http://hl7.org/fhir/_requestedPeriod
 */
var _requestedPeriod = 'http://hl7.org/fhir/_requestedPeriod';
/**
 * _chromosome
 *
 * (Modified) MolecularSequence.relative.startingSequence.chromosome
 *
 * http://hl7.org/fhir/_chromosome
 */
var _chromosome = 'http://hl7.org/fhir/_chromosome';
/**
 * isSubPotent
 *
 * MedicationAdministration.isSubPotent: An indication that the full dose was not administered.
 *
 * http://hl7.org/fhir/isSubPotent
 */
var isSubPotent = 'http://hl7.org/fhir/isSubPotent';
/**
 * presentedForm
 *
 * DiagnosticReport.presentedForm: Rich text representation of the entire result as issued by the diagnostic service. Multiple formats are allowed but they SHALL be semantically equivalent.
 *
 * http://hl7.org/fhir/presentedForm
 */
var presentedForm = 'http://hl7.org/fhir/presentedForm';
/**
 * repetitions
 *
 * Transport.restriction.repetitions: Indicates the number of times the requested action should occur.
 *
 * http://hl7.org/fhir/repetitions
 */
var repetitions = 'http://hl7.org/fhir/repetitions';
/**
 * aggregate
 *
 * Account.balance.aggregate: Who is expected to pay this part of the balance.
 *
 * http://hl7.org/fhir/aggregate
 */
var aggregate = 'http://hl7.org/fhir/aggregate';
/**
 * EvidenceStatisticComponent
 *
 * EvidenceStatisticComponent: Values and parameters for a single statistic.
 *
 * http://hl7.org/fhir/EvidenceStatisticComponent
 */
var EvidenceStatisticComponent = 'http://hl7.org/fhir/EvidenceStatisticComponent';
/**
 * ImplementationGuideDefinitionParameterComponent
 *
 * ImplementationGuideDefinitionComponent.ImplementationGuideDefinitionParameterComponent: A set of parameters that defines how the implementation guide is built. The parameters are defined by the relevant tools that build the implementation guides.
 *
 * http://hl7.org/fhir/ImplementationGuideDefinitionParameterComponent
 */
var ImplementationGuideDefinitionParameterComponent = 'http://hl7.org/fhir/ImplementationGuideDefinitionParameterComponent';
/**
 * CompositionEventComponent
 *
 * CompositionEventComponent: The clinical service, such as a colonoscopy or an appendectomy, being documented.
 *
 * http://hl7.org/fhir/CompositionEventComponent
 */
var CompositionEventComponent = 'http://hl7.org/fhir/CompositionEventComponent';
/**
 * _NutritionOrder
 *
 * (Modified) NutritionOrder
 *
 * http://hl7.org/fhir/_NutritionOrder
 */
var _NutritionOrder = 'http://hl7.org/fhir/_NutritionOrder';
/**
 * TaskInputComponent
 *
 * TaskInputComponent: Additional information that may be needed in the execution of the task.
 *
 * http://hl7.org/fhir/TaskInputComponent
 */
var TaskInputComponent = 'http://hl7.org/fhir/TaskInputComponent';
/**
 * rule
 *
 * StructureMap.group.rule.rule: Rules contained in this rule.
 *
 * http://hl7.org/fhir/rule
 */
var rule = 'http://hl7.org/fhir/rule';
/**
 * Specimen
 *
 * A sample to be used for analysis.
 *
 * http://hl7.org/fhir/Specimen
 */
var Specimen = 'http://hl7.org/fhir/Specimen';
/**
 * _MedicinalProductDefinition
 *
 * (Modified) MedicinalProductDefinition
 *
 * http://hl7.org/fhir/_MedicinalProductDefinition
 */
var _MedicinalProductDefinition = 'http://hl7.org/fhir/_MedicinalProductDefinition';
/**
 * OperationDefinition
 *
 * A formal computable definition of an operation (on the RESTful interface) or a named query (using the search interaction).
 *
 * http://hl7.org/fhir/OperationDefinition
 */
var OperationDefinition = 'http://hl7.org/fhir/OperationDefinition';
/**
 * process
 *
 * ExampleScenario.process: A group of operations that represents a significant step within a scenario.
 *
 * http://hl7.org/fhir/process
 */
var process = 'http://hl7.org/fhir/process';
/**
 * CitationCitedArtifactContributorshipEntryContributionInstanceComponent
 *
 * CitationCitedArtifactComponent.CitationCitedArtifactContributorshipComponent.CitationCitedArtifactContributorshipEntryComponent.CitationCitedArtifactContributorshipEntryContributionInstanceComponent: Contributions with accounting for time or number.
 *
 * http://hl7.org/fhir/CitationCitedArtifactContributorshipEntryContributionInstanceComponent
 */
var CitationCitedArtifactContributorshipEntryContributionInstanceComponent = 'http://hl7.org/fhir/CitationCitedArtifactContributorshipEntryContributionInstanceComponent';
/**
 * EncounterAdmissionComponent
 *
 * EncounterAdmissionComponent: Details about the stay during which a healthcare service is provided.

This does not describe the event of admitting the patient, but rather any information that is relevant from the time of admittance until the time of discharge.
 *
 * http://hl7.org/fhir/EncounterAdmissionComponent
 */
var EncounterAdmissionComponent = 'http://hl7.org/fhir/EncounterAdmissionComponent';
/**
 * _MedicationDispense
 *
 * (Modified) MedicationDispense
 *
 * http://hl7.org/fhir/_MedicationDispense
 */
var _MedicationDispense = 'http://hl7.org/fhir/_MedicationDispense';
/**
 * translation
 *
 * SubstanceDefinition.name.synonym.translation: A translation for this name into another human language.
 *
 * http://hl7.org/fhir/translation
 */
var translation = 'http://hl7.org/fhir/translation';
/**
 * ObservationTriggeredByComponent
 *
 * ObservationTriggeredByComponent: Identifies the observation(s) that triggered the performance of this observation.
 *
 * http://hl7.org/fhir/ObservationTriggeredByComponent
 */
var ObservationTriggeredByComponent = 'http://hl7.org/fhir/ObservationTriggeredByComponent';
/**
 * _etag
 *
 * (Modified) Bundle.entry.response.etag
 *
 * http://hl7.org/fhir/_etag
 */
var _etag = 'http://hl7.org/fhir/_etag';
/**
 * _dateCriterion
 *
 * (Modified) ImmunizationRecommendation.recommendation.dateCriterion
 *
 * http://hl7.org/fhir/_dateCriterion
 */
var _dateCriterion = 'http://hl7.org/fhir/_dateCriterion';
/**
 * _administrationInstruction
 *
 * (Modified) NutritionOrder.enteralFormula.administrationInstruction
 *
 * http://hl7.org/fhir/_administrationInstruction
 */
var _administrationInstruction = 'http://hl7.org/fhir/_administrationInstruction';
/**
 * part
 *
 * OperationDefinition.parameter.part.part: The parts of a nested Parameter.
 *
 * http://hl7.org/fhir/part
 */
var part = 'http://hl7.org/fhir/part';
/**
 * _billablePeriod
 *
 * (Modified) ExplanationOfBenefit.billablePeriod
 *
 * http://hl7.org/fhir/_billablePeriod
 */
var _billablePeriod = 'http://hl7.org/fhir/_billablePeriod';
/**
 * requestHeader
 *
 * TestScript.teardown.action.operation.requestHeader: Header elements would be used to set HTTP headers.
 *
 * http://hl7.org/fhir/requestHeader
 */
var requestHeader = 'http://hl7.org/fhir/requestHeader';
/**
 * _shortTitle
 *
 * (Modified) EvidenceVariable.shortTitle
 *
 * http://hl7.org/fhir/_shortTitle
 */
var _shortTitle = 'http://hl7.org/fhir/_shortTitle';
/**
 * _securityLabel
 *
 * (Modified) DocumentReference.securityLabel
 *
 * http://hl7.org/fhir/_securityLabel
 */
var _securityLabel = 'http://hl7.org/fhir/_securityLabel';
/**
 * _procedure
 *
 * (Modified) ExplanationOfBenefit.procedure.procedure
 *
 * http://hl7.org/fhir/_procedure
 */
var _procedure = 'http://hl7.org/fhir/_procedure';
/**
 * periodMax
 *
 * Timing.repeat.periodMax: If present, indicates that the period is a range from [period] to [periodMax], allowing expressing concepts such as "do this once every 3-5 days.
 *
 * http://hl7.org/fhir/periodMax
 */
var periodMax = 'http://hl7.org/fhir/periodMax';
/**
 * monograph
 *
 * MedicationKnowledge.monograph: Associated documentation about the medication.
 *
 * http://hl7.org/fhir/monograph
 */
var monograph = 'http://hl7.org/fhir/monograph';
/**
 * _eventsSinceSubscriptionStart
 *
 * (Modified) SubscriptionStatus.eventsSinceSubscriptionStart
 *
 * http://hl7.org/fhir/_eventsSinceSubscriptionStart
 */
var _eventsSinceSubscriptionStart = 'http://hl7.org/fhir/_eventsSinceSubscriptionStart';
/**
 * QuestionnaireResponseItemAnswerComponent
 *
 * QuestionnaireResponseItemComponent.QuestionnaireResponseItemAnswerComponent: The respondent's answer(s) to the question.
 *
 * http://hl7.org/fhir/QuestionnaireResponseItemAnswerComponent
 */
var QuestionnaireResponseItemAnswerComponent = 'http://hl7.org/fhir/QuestionnaireResponseItemAnswerComponent';
/**
 * formatted
 *
 * MolecularSequence.formatted: Sequence that was observed as file content. Can be an actual file contents, or referenced by a URL to an external system.
 *
 * http://hl7.org/fhir/formatted
 */
var formatted = 'http://hl7.org/fhir/formatted';
/**
 * restoreDate
 *
 * MarketingStatus.restoreDate: The date when the Medicinal Product is placed on the market by the Marketing Authorization Holder (or where applicable, the manufacturer/distributor) in a country and/or jurisdiction shall be provided A complete date consisting of day, month and year shall be specified using the ISO 8601 date format NOTE “Placed on the market” refers to the release of the Medicinal Product into the distribution chain.
 *
 * http://hl7.org/fhir/restoreDate
 */
var restoreDate = 'http://hl7.org/fhir/restoreDate';
/**
 * _grouping
 *
 * (Modified) ImplementationGuide.definition.grouping
 *
 * http://hl7.org/fhir/_grouping
 */
var _grouping = 'http://hl7.org/fhir/_grouping';
/**
 * definition
 *
 * QuestionnaireResponse.item.definition: A reference to an [ElementDefinition](elementdefinition.html) that provides the details for the item.
 *
 * http://hl7.org/fhir/definition
 */
var definition = 'http://hl7.org/fhir/definition';
/**
 * BodyStructureIncludedStructureBodyLandmarkOrientationDistanceFromLandmarkComponent
 *
 * BodyStructureIncludedStructureBodyLandmarkOrientationComponent.BodyStructureIncludedStructureBodyLandmarkOrientationDistanceFromLandmarkComponent: The distance in centimeters a certain observation is made from a body landmark.
 *
 * http://hl7.org/fhir/BodyStructureIncludedStructureBodyLandmarkOrientationDistanceFromLandmarkComponent
 */
var BodyStructureIncludedStructureBodyLandmarkOrientationDistanceFromLandmarkComponent = 'http://hl7.org/fhir/BodyStructureIncludedStructureBodyLandmarkOrientationDistanceFromLandmarkComponent';
/**
 * dayOfWeek
 *
 * Appointment.recurrenceTemplate.monthlyTemplate.dayOfWeek: Indicates which day of the week the recurring appointments should occur each nth week.
 *
 * http://hl7.org/fhir/dayOfWeek
 */
var dayOfWeek = 'http://hl7.org/fhir/dayOfWeek';
/**
 * _variableDefinition
 *
 * (Modified) Evidence.statistic.modelCharacteristic.variable.variableDefinition
 *
 * http://hl7.org/fhir/_variableDefinition
 */
var _variableDefinition = 'http://hl7.org/fhir/_variableDefinition';
/**
 * nodeRole
 *
 * http://hl7.org/fhir/nodeRole
 */
var nodeRole = 'http://hl7.org/fhir/nodeRole';
/**
 * Permission
 *
 * Permission resource holds access rules for a given data and context.
 *
 * http://hl7.org/fhir/Permission
 */
var Permission = 'http://hl7.org/fhir/Permission';
/**
 * dateWritten
 *
 * VisionPrescription.dateWritten: The date (and perhaps time) when the prescription was written.
 *
 * http://hl7.org/fhir/dateWritten
 */
var dateWritten = 'http://hl7.org/fhir/dateWritten';
/**
 * ratioHighLimitAmount
 *
 * SubstanceDefinition.relationship.ratioHighLimitAmount: For use when the numeric has an uncertain range.
 *
 * http://hl7.org/fhir/ratioHighLimitAmount
 */
var ratioHighLimitAmount = 'http://hl7.org/fhir/ratioHighLimitAmount';
/**
 * _relatedData
 *
 * (Modified) PlanDefinition.action.output.relatedData
 *
 * http://hl7.org/fhir/_relatedData
 */
var _relatedData = 'http://hl7.org/fhir/_relatedData';
/**
 * _inforce
 *
 * (Modified) CoverageEligibilityResponse.insurance.inforce
 *
 * http://hl7.org/fhir/_inforce
 */
var _inforce = 'http://hl7.org/fhir/_inforce';
/**
 * _reportingVendor
 *
 * (Modified) MeasureReport.reportingVendor
 *
 * http://hl7.org/fhir/_reportingVendor
 */
var _reportingVendor = 'http://hl7.org/fhir/_reportingVendor';
/**
 * _sequenceRange
 *
 * (Modified) MolecularSequence.relative.sequenceRange
 *
 * http://hl7.org/fhir/_sequenceRange
 */
var _sequenceRange = 'http://hl7.org/fhir/_sequenceRange';
/**
 * member
 *
 * Group.member: Identifies the resource instances that are members of the group.
 *
 * http://hl7.org/fhir/member
 */
var member = 'http://hl7.org/fhir/member';
/**
 * _versionAlgorithm
 *
 * (Modified) Library.versionAlgorithm
 *
 * http://hl7.org/fhir/_versionAlgorithm
 */
var _versionAlgorithm = 'http://hl7.org/fhir/_versionAlgorithm';
/**
 * _subject
 *
 * (Modified) Condition.subject
 *
 * http://hl7.org/fhir/_subject
 */
var _subject = 'http://hl7.org/fhir/_subject';
/**
 * _case
 *
 * (Modified) RegulatedAuthorization.case
 *
 * http://hl7.org/fhir/_case
 */
var _case = 'http://hl7.org/fhir/_case';
/**
 * _ClinicalUseDefinition
 *
 * (Modified) ClinicalUseDefinition
 *
 * http://hl7.org/fhir/_ClinicalUseDefinition
 */
var _ClinicalUseDefinition = 'http://hl7.org/fhir/_ClinicalUseDefinition';
/**
 * _cylinder
 *
 * (Modified) VisionPrescription.lensSpecification.cylinder
 *
 * http://hl7.org/fhir/_cylinder
 */
var _cylinder = 'http://hl7.org/fhir/_cylinder';
/**
 * _saturday
 *
 * (Modified) Appointment.recurrenceTemplate.weeklyTemplate.saturday
 *
 * http://hl7.org/fhir/_saturday
 */
var _saturday = 'http://hl7.org/fhir/_saturday';
/**
 * ConceptMapGroupUnmappedComponent
 *
 * ConceptMapGroupComponent.ConceptMapGroupUnmappedComponent: What to do when there is no mapping to a target concept from the source concept and ConceptMap.group.element.noMap is not true. This provides the "default" to be applied when there is no target concept mapping specified or the expansion of ConceptMap.group.element.target.valueSet is empty.
 *
 * http://hl7.org/fhir/ConceptMapGroupUnmappedComponent
 */
var ConceptMapGroupUnmappedComponent = 'http://hl7.org/fhir/ConceptMapGroupUnmappedComponent';
/**
 * Address
 *
 * An address expressed using postal conventions (as opposed to GPS or other location definition formats).  This data type may be used to convey addresses for use in delivering mail as well as for visiting locations which might not be valid for mail delivery.  There are a variety of postal address formats defined around the world.
 * The ISO21090-codedString may be used to provide a coded representation of the contents of strings in an Address.
 *
 * http://hl7.org/fhir/Address
 */
var Address = 'http://hl7.org/fhir/Address';
/**
 * _validateCode
 *
 * (Modified) TerminologyCapabilities.validateCode
 *
 * http://hl7.org/fhir/_validateCode
 */
var _validateCode = 'http://hl7.org/fhir/_validateCode';
/**
 * _dispenser
 *
 * (Modified) MedicationRequest.dispenseRequest.dispenser
 *
 * http://hl7.org/fhir/_dispenser
 */
var _dispenser = 'http://hl7.org/fhir/_dispenser';
/**
 * _issued
 *
 * (Modified) TestReport.issued
 *
 * http://hl7.org/fhir/_issued
 */
var _issued = 'http://hl7.org/fhir/_issued';
/**
 * TestReport
 *
 * A summary of information based on the results of executing a TestScript.
 *
 * http://hl7.org/fhir/TestReport
 */
var TestReport = 'http://hl7.org/fhir/TestReport';
/**
 * conditionalRead
 *
 * CapabilityStatement.rest.resource.conditionalRead: A code that indicates how the server supports conditional read.
 *
 * http://hl7.org/fhir/conditionalRead
 */
var conditionalRead = 'http://hl7.org/fhir/conditionalRead';
/**
 * fullUrl
 *
 * Bundle.entry.fullUrl: The Absolute URL for the resource. Except for transactions and batches, each entry in a Bundle must have a fullUrl. The fullUrl SHALL NOT disagree with the id in the resource - i.e. if the fullUrl is not a urn:uuid, the URL shall be version-independent URL consistent with the Resource.id. The fullUrl is a version independent reference to the resource. Even when not required, fullUrl MAY be set to a urn:uuid to allow referencing entries in a transaction. The fullUrl can be an arbitrary URI and is not limited to urn:uuid, urn:oid, http, and https. The fullUrl element SHALL have a value except when:
 * * invoking a create
 * * invoking or responding to an operation where the body is not a single identified resource
 * * invoking or returning the results of a search or history operation.
 *
 * http://hl7.org/fhir/fullUrl
 */
var fullUrl = 'http://hl7.org/fhir/fullUrl';
/**
 * parameterFocus
 *
 * ServiceRequest.orderDetail.parameterFocus: Indicates the context of the order details by reference.
 *
 * http://hl7.org/fhir/parameterFocus
 */
var parameterFocus = 'http://hl7.org/fhir/parameterFocus';
/**
 * _currentState
 *
 * (Modified) Citation.citedArtifact.currentState
 *
 * http://hl7.org/fhir/_currentState
 */
var _currentState = 'http://hl7.org/fhir/_currentState';
/**
 * ActivityDefinition
 *
 * This resource allows for the definition of some activity to be performed, independent of a particular patient, practitioner, or other performance context.
 *
 * http://hl7.org/fhir/ActivityDefinition
 */
var ActivityDefinition = 'http://hl7.org/fhir/ActivityDefinition';
/**
 * daysOfWeek
 *
 * Availability.availableTime.daysOfWeek: mon | tue | wed | thu | fri | sat | sun.
 *
 * http://hl7.org/fhir/daysOfWeek
 */
var daysOfWeek = 'http://hl7.org/fhir/daysOfWeek';
/**
 * containedInstance
 *
 * ExampleScenario.instance.containedInstance: References to other instances that can be found within this instance (e.g. the observations contained in a bundle).
 *
 * http://hl7.org/fhir/containedInstance
 */
var containedInstance = 'http://hl7.org/fhir/containedInstance';
/**
 * StructureMapGroupRuleSourceComponent
 *
 * StructureMapGroupComponent.StructureMapGroupRuleComponentRule.StructureMapGroupRuleSourceComponent: Source inputs to the mapping.
 *
 * http://hl7.org/fhir/StructureMapGroupRuleSourceComponent
 */
var StructureMapGroupRuleSourceComponent = 'http://hl7.org/fhir/StructureMapGroupRuleSourceComponent';
/**
 * application
 *
 * RegulatedAuthorization.case.application: A regulatory submission from an organization to a regulator, as part of an assessing case. Multiple applications may occur over time, with more or different information to support or modify the submission or the authorization. The applications can be considered as steps within the longer running case or procedure for this authorization process.
 *
 * http://hl7.org/fhir/application
 */
var application = 'http://hl7.org/fhir/application';
/**
 * received
 *
 * Communication.received: The time when this communication arrived at the destination.
 *
 * http://hl7.org/fhir/received
 */
var received = 'http://hl7.org/fhir/received';
/**
 * AuditEventEntityComponentAgent
 *
 * The entity is attributed to an agent to express the agent's responsibility for that entity in the activity. This is most used to indicate when persistence media (the entity) are used by an agent. For example when importing data from a device, the device would be described in an entity, and the user importing data from that media would be indicated as the entity.agent.
 *
 * http://hl7.org/fhir/AuditEventEntityComponentAgent
 */
var AuditEventEntityComponentAgent = 'http://hl7.org/fhir/AuditEventEntityComponentAgent';
/**
 * element
 *
 * StructureDefinition.differential.element: Captures constraints on each element within the resource.
 *
 * http://hl7.org/fhir/element
 */
var element = 'http://hl7.org/fhir/element';
/**
 * _compose
 *
 * (Modified) ValueSet.compose
 *
 * http://hl7.org/fhir/_compose
 */
var _compose = 'http://hl7.org/fhir/_compose';
/**
 * _environmentalSetting
 *
 * (Modified) MedicationKnowledge.storageGuideline.environmentalSetting
 *
 * http://hl7.org/fhir/_environmentalSetting
 */
var _environmentalSetting = 'http://hl7.org/fhir/_environmentalSetting';
/**
 * _payment
 *
 * (Modified) PaymentNotice.payment
 *
 * http://hl7.org/fhir/_payment
 */
var _payment = 'http://hl7.org/fhir/_payment';
/**
 * _preparedDate
 *
 * (Modified) DeviceDispense.preparedDate
 *
 * http://hl7.org/fhir/_preparedDate
 */
var _preparedDate = 'http://hl7.org/fhir/_preparedDate';
/**
 * ImagingSelectionInstanceComponent
 *
 * ImagingSelectionInstanceComponent: Each imaging selection includes one or more selected DICOM SOP instances.
 *
 * http://hl7.org/fhir/ImagingSelectionInstanceComponent
 */
var ImagingSelectionInstanceComponent = 'http://hl7.org/fhir/ImagingSelectionInstanceComponent';
/**
 * _responseRequired
 *
 * (Modified) MessageDefinition.responseRequired
 *
 * http://hl7.org/fhir/_responseRequired
 */
var _responseRequired = 'http://hl7.org/fhir/_responseRequired';
/**
 * _contraindication
 *
 * (Modified) DeviceDefinition.guideline.contraindication
 *
 * http://hl7.org/fhir/_contraindication
 */
var _contraindication = 'http://hl7.org/fhir/_contraindication';
/**
 * _operator
 *
 * (Modified) TestScript.test.action.assert.operator
 *
 * http://hl7.org/fhir/_operator
 */
var _operator = 'http://hl7.org/fhir/_operator';
/**
 * ActivityDefinitionParticipantComponent
 *
 * ActivityDefinitionParticipantComponent: Indicates who should participate in performing the action described.
 *
 * http://hl7.org/fhir/ActivityDefinitionParticipantComponent
 */
var ActivityDefinitionParticipantComponent = 'http://hl7.org/fhir/ActivityDefinitionParticipantComponent';
/**
 * _contraindicatedVaccineCode
 *
 * (Modified) ImmunizationRecommendation.recommendation.contraindicatedVaccineCode
 *
 * http://hl7.org/fhir/_contraindicatedVaccineCode
 */
var _contraindicatedVaccineCode = 'http://hl7.org/fhir/_contraindicatedVaccineCode';
/**
 * _membership
 *
 * (Modified) Group.membership
 *
 * http://hl7.org/fhir/_membership
 */
var _membership = 'http://hl7.org/fhir/_membership';
/**
 * _recordedDate
 *
 * (Modified) Condition.recordedDate
 *
 * http://hl7.org/fhir/_recordedDate
 */
var _recordedDate = 'http://hl7.org/fhir/_recordedDate';
/**
 * _provision
 *
 * (Modified) Consent.provision.provision
 *
 * http://hl7.org/fhir/_provision
 */
var _provision = 'http://hl7.org/fhir/_provision';
/**
 * _dietPreference
 *
 * (Modified) Encounter.dietPreference
 *
 * http://hl7.org/fhir/_dietPreference
 */
var _dietPreference = 'http://hl7.org/fhir/_dietPreference';
/**
 * _laterality
 *
 * (Modified) ImagingStudy.series.laterality
 *
 * http://hl7.org/fhir/_laterality
 */
var _laterality = 'http://hl7.org/fhir/_laterality';
/**
 * _parentSubstanceId
 *
 * (Modified) SubstanceSourceMaterial.parentSubstanceId
 *
 * http://hl7.org/fhir/_parentSubstanceId
 */
var _parentSubstanceId = 'http://hl7.org/fhir/_parentSubstanceId';
/**
 * _report
 *
 * (Modified) Procedure.report
 *
 * http://hl7.org/fhir/_report
 */
var _report = 'http://hl7.org/fhir/_report';
/**
 * MedicationDispensePerformerComponent
 *
 * MedicationDispensePerformerComponent: Indicates who or what performed the event.
 *
 * http://hl7.org/fhir/MedicationDispensePerformerComponent
 */
var MedicationDispensePerformerComponent = 'http://hl7.org/fhir/MedicationDispensePerformerComponent';
/**
 * FamilyMemberHistoryConditionComponent
 *
 * FamilyMemberHistoryConditionComponent: The significant Conditions (or condition) that the family member had. This is a repeating section to allow a system to represent more than one condition per resource, though there is nothing stopping multiple resources - one per condition.
 *
 * http://hl7.org/fhir/FamilyMemberHistoryConditionComponent
 */
var FamilyMemberHistoryConditionComponent = 'http://hl7.org/fhir/FamilyMemberHistoryConditionComponent';
/**
 * _editor
 *
 * (Modified) EvidenceVariable.editor
 *
 * http://hl7.org/fhir/_editor
 */
var _editor = 'http://hl7.org/fhir/_editor';
/**
 * instant
 *
 * An instant in time - known at least to the second
 *
 * http://hl7.org/fhir/instant
 */
var instant = 'http://hl7.org/fhir/instant';
/**
 * paging
 *
 * TerminologyCapabilities.expansion.paging: Whether the server supports paging on expansion.
 *
 * http://hl7.org/fhir/paging
 */
var paging = 'http://hl7.org/fhir/paging';
/**
 * _receiverActive
 *
 * (Modified) ExampleScenario.process.step.alternative.step.operation.receiverActive
 *
 * http://hl7.org/fhir/_receiverActive
 */
var _receiverActive = 'http://hl7.org/fhir/_receiverActive';
/**
 * publicationForm
 *
 * Citation.citedArtifact.publicationForm: If multiple, used to represent alternative forms of the article that are not separate citations.
 *
 * http://hl7.org/fhir/publicationForm
 */
var publicationForm = 'http://hl7.org/fhir/publicationForm';
/**
 * operation
 *
 * TestScript.teardown.action.operation: An operation would involve a REST request to a server.
 *
 * http://hl7.org/fhir/operation
 */
var operation = 'http://hl7.org/fhir/operation';
/**
 * organism
 *
 * SubstanceSourceMaterial.organism: This subclause describes the organism which the substance is derived from. For vaccines, the parent organism shall be specified based on these subclause elements. As an example, full taxonomy will be described for the Substance Name: ., Leaf.
 *
 * http://hl7.org/fhir/organism
 */
var organism = 'http://hl7.org/fhir/organism';
/**
 * focus
 *
 * Composition.section.focus: The actual focus of the section when it is not the subject of the composition, but instead represents something or someone associated with the subject such as (for a patient subject) a spouse, parent, fetus, or donor. If not focus is specified, the focus is assumed to be focus of the parent section, or, for a section in the Composition itself, the subject of the composition. Sections with a focus SHALL only include resources where the logical subject (patient, subject, focus, etc.) matches the section focus, or the resources have no logical subject (few resources).
 *
 * http://hl7.org/fhir/focus
 */
var focus = 'http://hl7.org/fhir/focus';
/**
 * _reviewer
 *
 * (Modified) EvidenceVariable.reviewer
 *
 * http://hl7.org/fhir/_reviewer
 */
var _reviewer = 'http://hl7.org/fhir/_reviewer';
/**
 * validCodedValueSet
 *
 * ObservationDefinition.component.qualifiedValue.validCodedValueSet: The set of valid coded results for qualitative observations  that match the criteria of this set of qualified values.
 *
 * http://hl7.org/fhir/validCodedValueSet
 */
var validCodedValueSet = 'http://hl7.org/fhir/validCodedValueSet';
/**
 * Signatory
 *
 * Contract.Signatory: Parties with legal standing in the Contract, including the principal parties, the grantor(s) and grantee(s), which are any person or organization bound by the contract, and any ancillary parties, which facilitate the execution of the contract such as a notary or witness.
 *
 * http://hl7.org/fhir/Signatory
 */
var Signatory = 'http://hl7.org/fhir/Signatory';
/**
 * clockFacePosition
 *
 * BodyStructure.excludedStructure.bodyLandmarkOrientation.clockFacePosition: An description of the direction away from a landmark something is located based on a radial clock dial.
 *
 * http://hl7.org/fhir/clockFacePosition
 */
var clockFacePosition = 'http://hl7.org/fhir/clockFacePosition';
/**
 * _instanceReference
 *
 * (Modified) ExampleScenario.process.step.operation.request.instanceReference
 *
 * http://hl7.org/fhir/_instanceReference
 */
var _instanceReference = 'http://hl7.org/fhir/_instanceReference';
/**
 * withdrawalPeriod
 *
 * AdministrableProductDefinition.routeOfAdministration.targetSpecies.withdrawalPeriod: A species specific time during which consumption of animal product is not appropriate.
 *
 * http://hl7.org/fhir/withdrawalPeriod
 */
var withdrawalPeriod = 'http://hl7.org/fhir/withdrawalPeriod';
/**
 * conformance
 *
 * TestScript.scope.conformance: The expectation of whether the test must pass for the system to be considered conformant with the artifact: required - all tests are expected to pass, optional - all test are expected to pass but non-pass status may be allowed, strict - all tests are expected to pass and warnings are treated as a failure.
 *
 * http://hl7.org/fhir/conformance
 */
var conformance = 'http://hl7.org/fhir/conformance';
/**
 * effectivePeriod
 *
 * EvidenceVariable.effectivePeriod: The period during which the resource content was or is planned to be in active use.
 *
 * http://hl7.org/fhir/effectivePeriod
 */
var effectivePeriod = 'http://hl7.org/fhir/effectivePeriod';
/**
 * _matchStatus
 *
 * (Modified) BiologicallyDerivedProductDispense.matchStatus
 *
 * http://hl7.org/fhir/_matchStatus
 */
var _matchStatus = 'http://hl7.org/fhir/_matchStatus';
/**
 * virtualService
 *
 * Location.virtualService: Connection details of a virtual service (e.g. shared conference call facility with dedicated number/details).
 *
 * http://hl7.org/fhir/virtualService
 */
var virtualService = 'http://hl7.org/fhir/virtualService';
/**
 * Communication
 *
 * A clinical or business level record of information being transmitted or shared; e.g. an alert that was sent to a responsible provider, a public health agency communication to a provider/reporter in response to a case report for a reportable condition.
 *
 * http://hl7.org/fhir/Communication
 */
var Communication = 'http://hl7.org/fhir/Communication';
/**
 * _enteralFormula
 *
 * (Modified) NutritionOrder.enteralFormula
 *
 * http://hl7.org/fhir/_enteralFormula
 */
var _enteralFormula = 'http://hl7.org/fhir/_enteralFormula';
/**
 * whenHandedOver
 *
 * MedicationDispense.whenHandedOver: The time the dispensed product was provided to the patient or their representative.
 *
 * http://hl7.org/fhir/whenHandedOver
 */
var whenHandedOver = 'http://hl7.org/fhir/whenHandedOver';
/**
 * EvidenceReportSubjectComponent
 *
 * EvidenceReportSubjectComponent: Specifies the subject or focus of the report. Answers "What is this report about?".
 *
 * http://hl7.org/fhir/EvidenceReportSubjectComponent
 */
var EvidenceReportSubjectComponent = 'http://hl7.org/fhir/EvidenceReportSubjectComponent';
/**
 * substance
 *
 * Ingredient.substance: The substance that comprises this ingredient.
 *
 * http://hl7.org/fhir/substance
 */
var substance = 'http://hl7.org/fhir/substance';
/**
 * Section
 *
 * EvidenceReport.Section: The root of the sections that make up the composition.
 *
 * http://hl7.org/fhir/Section
 */
var Section = 'http://hl7.org/fhir/Section';
/**
 * _valueRange
 *
 * (Modified) Evidence.statistic.modelCharacteristic.variable.valueRange
 *
 * http://hl7.org/fhir/_valueRange
 */
var _valueRange = 'http://hl7.org/fhir/_valueRange';
/**
 * regulatoryIdentifier
 *
 * DeviceDefinition.regulatoryIdentifier: Identifier associated with the regulatory documentation (certificates, technical documentation, post-market surveillance documentation and reports) of a set of device models sharing the same intended purpose, risk class and essential design and manufacturing characteristics. One example is the Basic UDI-DI in Europe.
 *
 * http://hl7.org/fhir/regulatoryIdentifier
 */
var regulatoryIdentifier = 'http://hl7.org/fhir/regulatoryIdentifier';
/**
 * kind
 *
 * NamingSystem.kind: Indicates the purpose for the naming system - what kinds of things does it make unique?
 *
 * http://hl7.org/fhir/kind
 */
var kind = 'http://hl7.org/fhir/kind';
/**
 * hasIngredient
 *
 * ManufacturedItemDefinition.component.component.constituent.hasIngredient: The ingredient that is the constituent of the given component.
 *
 * http://hl7.org/fhir/hasIngredient
 */
var hasIngredient = 'http://hl7.org/fhir/hasIngredient';
/**
 * detailSequence
 *
 * ClaimResponse.addItem.detailSequence: The sequence number of the details within the claim item which this line is intended to replace.
 *
 * http://hl7.org/fhir/detailSequence
 */
var detailSequence = 'http://hl7.org/fhir/detailSequence';
/**
 * NutritionProductNutrientComponent
 *
 * NutritionProductNutrientComponent: The product's nutritional information expressed by the nutrients.
 *
 * http://hl7.org/fhir/NutritionProductNutrientComponent
 */
var NutritionProductNutrientComponent = 'http://hl7.org/fhir/NutritionProductNutrientComponent';
/**
 * _fractionDescription
 *
 * (Modified) SubstanceSourceMaterial.fractionDescription
 *
 * http://hl7.org/fhir/_fractionDescription
 */
var _fractionDescription = 'http://hl7.org/fhir/_fractionDescription';
/**
 * _degreeOfPolymerisation
 *
 * (Modified) SubstancePolymer.repeat.repeatUnit.degreeOfPolymerisation
 *
 * http://hl7.org/fhir/_degreeOfPolymerisation
 */
var _degreeOfPolymerisation = 'http://hl7.org/fhir/_degreeOfPolymerisation';
/**
 * _Account
 *
 * (Modified) Account
 *
 * http://hl7.org/fhir/_Account
 */
var _Account = 'http://hl7.org/fhir/_Account';
/**
 * rangeCategory
 *
 * ObservationDefinition.component.qualifiedValue.rangeCategory: The category of range of values for continuous or ordinal observations that match the criteria of this set of qualified values.
 *
 * http://hl7.org/fhir/rangeCategory
 */
var rangeCategory = 'http://hl7.org/fhir/rangeCategory';
/**
 * _index
 *
 * (Modified) TestScript.destination.index
 *
 * http://hl7.org/fhir/_index
 */
var _index = 'http://hl7.org/fhir/_index';
/**
 * ValueSetComposeComponentInclude
 *
 * Exclude one or more codes from the value set based on code system filters and/or other value sets.
 *
 * http://hl7.org/fhir/ValueSetComposeComponentInclude
 */
var ValueSetComposeComponentInclude = 'http://hl7.org/fhir/ValueSetComposeComponentInclude';
/**
 * regulatory
 *
 * MedicationKnowledge.regulatory: Regulatory information about a medication.
 *
 * http://hl7.org/fhir/regulatory
 */
var regulatory = 'http://hl7.org/fhir/regulatory';
/**
 * _modifier
 *
 * (Modified) ExplanationOfBenefit.addItem.modifier
 *
 * http://hl7.org/fhir/_modifier
 */
var _modifier = 'http://hl7.org/fhir/_modifier';
/**
 * _short
 *
 * (Modified) ElementDefinition.short
 *
 * http://hl7.org/fhir/_short
 */
var _short = 'http://hl7.org/fhir/_short';
/**
 * medication
 *
 * MedicationRequest.medication: Identifies the medication being requested. This is a link to a resource that represents the medication which may be the details of the medication or simply an attribute carrying a code that identifies the medication from a known list of medications.
 *
 * http://hl7.org/fhir/medication
 */
var medication = 'http://hl7.org/fhir/medication';
/**
 * codeSearch
 *
 * TerminologyCapabilities.codeSearch: The degree to which the server supports the code search parameter on ValueSet, if it is supported.
 *
 * http://hl7.org/fhir/codeSearch
 */
var codeSearch = 'http://hl7.org/fhir/codeSearch';
/**
 * suffix
 *
 * HumanName.suffix: Part of the name that is acquired as a title due to academic, legal, employment or nobility status, etc. and that appears at the end of the name.
 *
 * http://hl7.org/fhir/suffix
 */
var suffix = 'http://hl7.org/fhir/suffix';
/**
 * MedicationDispenseSubstitutionComponent
 *
 * MedicationDispenseSubstitutionComponent: Indicates whether or not substitution was made as part of the dispense.  In some cases, substitution will be expected but does not happen, in other cases substitution is not expected but does happen.  This block explains what substitution did or did not happen and why.  If nothing is specified, substitution was not done.
 *
 * http://hl7.org/fhir/MedicationDispenseSubstitutionComponent
 */
var MedicationDispenseSubstitutionComponent = 'http://hl7.org/fhir/MedicationDispenseSubstitutionComponent';
/**
 * foodPreferenceModifier
 *
 * NutritionOrder.foodPreferenceModifier: This modifier is used to convey order-specific modifiers about the type of food that should be given. These can be derived from patient allergies, intolerances, or preferences such as Halal, Vegan or Kosher. This modifier applies to the entire nutrition order inclusive of the oral diet, nutritional supplements and enteral formula feedings.
 *
 * http://hl7.org/fhir/foodPreferenceModifier
 */
var foodPreferenceModifier = 'http://hl7.org/fhir/foodPreferenceModifier';
/**
 * Immunization
 *
 * Describes the event of a patient being administered a vaccine or a record of an immunization as reported by a patient, a clinician or another party.
 *
 * http://hl7.org/fhir/Immunization
 */
var Immunization = 'http://hl7.org/fhir/Immunization';
/**
 * AppointmentRecurrenceTemplateMonthlyTemplateComponent
 *
 * AppointmentRecurrenceTemplateComponent.AppointmentRecurrenceTemplateMonthlyTemplateComponent: Information about monthly recurring appointments.
 *
 * http://hl7.org/fhir/AppointmentRecurrenceTemplateMonthlyTemplateComponent
 */
var AppointmentRecurrenceTemplateMonthlyTemplateComponent = 'http://hl7.org/fhir/AppointmentRecurrenceTemplateMonthlyTemplateComponent';
/**
 * preventiveAction
 *
 * AdverseEvent.preventiveAction: Preventive actions that contributed to avoiding the adverse event.
 *
 * http://hl7.org/fhir/preventiveAction
 */
var preventiveAction = 'http://hl7.org/fhir/preventiveAction';
/**
 * _AdministrableProductDefinition
 *
 * (Modified) AdministrableProductDefinition
 *
 * http://hl7.org/fhir/_AdministrableProductDefinition
 */
var _AdministrableProductDefinition = 'http://hl7.org/fhir/_AdministrableProductDefinition';
/**
 * _deliverFrom
 *
 * (Modified) SupplyRequest.deliverFrom
 *
 * http://hl7.org/fhir/_deliverFrom
 */
var _deliverFrom = 'http://hl7.org/fhir/_deliverFrom';
/**
 * _address
 *
 * (Modified) RelatedPerson.address
 *
 * http://hl7.org/fhir/_address
 */
var _address = 'http://hl7.org/fhir/_address';
/**
 * intendedUse
 *
 * RegulatedAuthorization.intendedUse: The intended use of the product, e.g. prevention, treatment, diagnosis.
 *
 * http://hl7.org/fhir/intendedUse
 */
var intendedUse = 'http://hl7.org/fhir/intendedUse';
/**
 * ElementDefinitionSlicingDiscriminatorComponent
 *
 * ElementDefinitionSlicingComponent.ElementDefinitionSlicingDiscriminatorComponent: Designates which child elements are used to discriminate between the slices when processing an instance. If one or more discriminators are provided, the value of the child elements in the instance data SHALL completely distinguish which slice the element in the resource matches based on the allowed values for those elements in each of the slices.
 *
 * http://hl7.org/fhir/ElementDefinitionSlicingDiscriminatorComponent
 */
var ElementDefinitionSlicingDiscriminatorComponent = 'http://hl7.org/fhir/ElementDefinitionSlicingDiscriminatorComponent';
/**
 * SubscriptionTopic
 *
 * Describes a stream of resource state changes identified by trigger criteria and annotated with labels useful to filter projections from this topic.
 *
 * http://hl7.org/fhir/SubscriptionTopic
 */
var SubscriptionTopic = 'http://hl7.org/fhir/SubscriptionTopic';
/**
 * GenomicStudy
 *
 * A set of analyses performed to analyze and generate genomic data.
 *
 * http://hl7.org/fhir/GenomicStudy
 */
var GenomicStudy = 'http://hl7.org/fhir/GenomicStudy';
/**
 * _partLocation
 *
 * (Modified) SubstanceSourceMaterial.partDescription.partLocation
 *
 * http://hl7.org/fhir/_partLocation
 */
var _partLocation = 'http://hl7.org/fhir/_partLocation';
/**
 * _subsumption
 *
 * (Modified) TerminologyCapabilities.codeSystem.subsumption
 *
 * http://hl7.org/fhir/_subsumption
 */
var _subsumption = 'http://hl7.org/fhir/_subsumption';
/**
 * BenefitBalance
 *
 * ExplanationOfBenefit.BenefitBalance: Balance by Benefit Category.
 *
 * http://hl7.org/fhir/BenefitBalance
 */
var BenefitBalance = 'http://hl7.org/fhir/BenefitBalance';
/**
 * script
 *
 * TestPlan.testCase.testRun.script: The test cases in a structured language e.g. gherkin, Postman, or FHIR TestScript.
 *
 * http://hl7.org/fhir/script
 */
var script = 'http://hl7.org/fhir/script';
/**
 * _resourceReference
 *
 * (Modified) Citation.citedArtifact.relatesTo.resourceReference
 *
 * http://hl7.org/fhir/_resourceReference
 */
var _resourceReference = 'http://hl7.org/fhir/_resourceReference';
/**
 * lastReviewDate
 *
 * EventDefinition.lastReviewDate: The date on which the resource content was last reviewed. Review happens periodically after approval but does not change the original approval date.
 *
 * http://hl7.org/fhir/lastReviewDate
 */
var lastReviewDate = 'http://hl7.org/fhir/lastReviewDate';
/**
 * SubstanceDefinitionNameComponentNameName
 *
 * A translation for this name into another human language.
 *
 * http://hl7.org/fhir/SubstanceDefinitionNameComponentNameName
 */
var SubstanceDefinitionNameComponentNameName = 'http://hl7.org/fhir/SubstanceDefinitionNameComponentNameName';
/**
 * length
 *
 * Encounter.length: Actual quantity of time the encounter lasted. This excludes the time during leaves of absence.

When missing it is the time in between the start and end values.
 *
 * http://hl7.org/fhir/length
 */
var length = 'http://hl7.org/fhir/length';
/**
 * _overrideReason
 *
 * (Modified) ChargeItem.overrideReason
 *
 * http://hl7.org/fhir/_overrideReason
 */
var _overrideReason = 'http://hl7.org/fhir/_overrideReason';
/**
 * _period
 *
 * (Modified) Coverage.costToBeneficiary.exception.period
 *
 * http://hl7.org/fhir/_period
 */
var _period = 'http://hl7.org/fhir/_period';
/**
 * TerminologyCapabilities
 *
 * A TerminologyCapabilities resource documents a set of capabilities (behaviors) of a FHIR Terminology Server that may be used as a statement of actual server functionality or a statement of required or desired server implementation.
 *
 * http://hl7.org/fhir/TerminologyCapabilities
 */
var TerminologyCapabilities = 'http://hl7.org/fhir/TerminologyCapabilities';
/**
 * _supportingPatientInformation
 *
 * (Modified) ImmunizationRecommendation.recommendation.supportingPatientInformation
 *
 * http://hl7.org/fhir/_supportingPatientInformation
 */
var _supportingPatientInformation = 'http://hl7.org/fhir/_supportingPatientInformation';
/**
 * OperationDefinitionParameterBindingComponent
 *
 * OperationDefinitionParameterComponentParameter.OperationDefinitionParameterBindingComponent: Binds to a value set if this parameter is coded (code, Coding, CodeableConcept).
 *
 * http://hl7.org/fhir/OperationDefinitionParameterBindingComponent
 */
var OperationDefinitionParameterBindingComponent = 'http://hl7.org/fhir/OperationDefinitionParameterBindingComponent';
/**
 * Task
 *
 * A task to be performed.
 *
 * http://hl7.org/fhir/Task
 */
var Task = 'http://hl7.org/fhir/Task';
/**
 * MeasureReportGroupPopulationComponent
 *
 * MeasureReportGroupComponent.MeasureReportGroupPopulationComponent: The populations that make up the population group, one for each type of population appropriate for the measure.
 *
 * http://hl7.org/fhir/MeasureReportGroupPopulationComponent
 */
var MeasureReportGroupPopulationComponent = 'http://hl7.org/fhir/MeasureReportGroupPopulationComponent';
/**
 * revInclude
 *
 * SubscriptionTopic.notificationShape.revInclude: Search-style _revinclude directives, rooted in the resource for this shape. Servers SHOULD include resources listed here, if they exist and the user is authorized to receive them.  Clients SHOULD be prepared to receive these additional resources, but SHALL function properly without them.
 *
 * http://hl7.org/fhir/revInclude
 */
var revInclude = 'http://hl7.org/fhir/revInclude';
/**
 * _appliesTo
 *
 * (Modified) ObservationDefinition.component.qualifiedValue.appliesTo
 *
 * http://hl7.org/fhir/_appliesTo
 */
var _appliesTo = 'http://hl7.org/fhir/_appliesTo';
/**
 * MedicationKnowledgeDefinitionalComponent
 *
 * MedicationKnowledgeDefinitionalComponent: Along with the link to a Medicinal Product Definition resource, this information provides common definitional elements that are needed to understand the specific medication that is being described.
 *
 * http://hl7.org/fhir/MedicationKnowledgeDefinitionalComponent
 */
var MedicationKnowledgeDefinitionalComponent = 'http://hl7.org/fhir/MedicationKnowledgeDefinitionalComponent';
/**
 * usageInstruction
 *
 * DeviceDispense.usageInstruction: The full representation of the instructions.
 *
 * http://hl7.org/fhir/usageInstruction
 */
var usageInstruction = 'http://hl7.org/fhir/usageInstruction';
/**
 * trigger
 *
 * PlanDefinition.action.action.trigger: A description of when the action should be triggered. When multiple triggers are specified on an action, any triggering event invokes the action.
 *
 * http://hl7.org/fhir/trigger
 */
var trigger = 'http://hl7.org/fhir/trigger';
/**
 * mustSupport
 *
 * ElementDefinition.mustSupport: If true, implementations that produce or consume resources SHALL provide "support" for the element in some meaningful way. Note that this is being phased out and replaced by obligations (see below).  If false, the element may be ignored and not supported. If false, whether to populate or use the data element in any way is at the discretion of the implementation.
 *
 * http://hl7.org/fhir/mustSupport
 */
var mustSupport = 'http://hl7.org/fhir/mustSupport';
/**
 * TimingRepeatComponent
 *
 * TimingRepeatComponent: A set of rules that describe when the event is scheduled.
 *
 * http://hl7.org/fhir/TimingRepeatComponent
 */
var TimingRepeatComponent = 'http://hl7.org/fhir/TimingRepeatComponent';
/**
 * effectiveDosePeriod
 *
 * MedicationRequest.effectiveDosePeriod: The period over which the medication is to be taken.  Where there are multiple dosageInstruction lines (for example, tapering doses), this is the earliest date and the latest end date of the dosageInstructions.
 *
 * http://hl7.org/fhir/effectiveDosePeriod
 */
var effectiveDosePeriod = 'http://hl7.org/fhir/effectiveDosePeriod';
/**
 * _textEquivalent
 *
 * (Modified) RequestOrchestration.action.action.textEquivalent
 *
 * http://hl7.org/fhir/_textEquivalent
 */
var _textEquivalent = 'http://hl7.org/fhir/_textEquivalent';
/**
 * bodysite
 *
 * ChargeItem.bodysite: The anatomical location where the related service has been applied.
 *
 * http://hl7.org/fhir/bodysite
 */
var bodysite = 'http://hl7.org/fhir/bodysite';
/**
 * _appliesToAll
 *
 * (Modified) CoverageEligibilityRequest.supportingInfo.appliesToAll
 *
 * http://hl7.org/fhir/_appliesToAll
 */
var _appliesToAll = 'http://hl7.org/fhir/_appliesToAll';
/**
 * comorbidity
 *
 * ClinicalUseDefinition.indication.comorbidity: A comorbidity (concurrent condition) or coinfection as part of the indication.
 *
 * http://hl7.org/fhir/comorbidity
 */
var comorbidity = 'http://hl7.org/fhir/comorbidity';
/**
 * TestScriptFixtureComponent
 *
 * TestScriptFixtureComponent: Fixture in the test script - by reference (uri). All fixtures are required for the test script to execute.
 *
 * http://hl7.org/fhir/TestScriptFixtureComponent
 */
var TestScriptFixtureComponent = 'http://hl7.org/fhir/TestScriptFixtureComponent';
/**
 * oligoNucleotideType
 *
 * SubstanceNucleicAcid.oligoNucleotideType: (TBC).
 *
 * http://hl7.org/fhir/oligoNucleotideType
 */
var oligoNucleotideType = 'http://hl7.org/fhir/oligoNucleotideType';
/**
 * intendedEffect
 *
 * ClinicalUseDefinition.indication.intendedEffect: The intended effect, aim or strategy to be achieved.
 *
 * http://hl7.org/fhir/intendedEffect
 */
var intendedEffect = 'http://hl7.org/fhir/intendedEffect';
/**
 * _conformsTo
 *
 * (Modified) DeviceDefinition.conformsTo
 *
 * http://hl7.org/fhir/_conformsTo
 */
var _conformsTo = 'http://hl7.org/fhir/_conformsTo';
/**
 * copyright
 *
 * CapabilityStatement.copyright: A copyright statement relating to the capability statement and/or its contents. Copyright statements are generally legal restrictions on the use and publishing of the capability statement.
 *
 * http://hl7.org/fhir/copyright
 */
var copyright = 'http://hl7.org/fhir/copyright';
/**
 * _insurance
 *
 * (Modified) Task.insurance
 *
 * http://hl7.org/fhir/_insurance
 */
var _insurance = 'http://hl7.org/fhir/_insurance';
/**
 * _partDescription
 *
 * (Modified) SubstanceSourceMaterial.partDescription
 *
 * http://hl7.org/fhir/_partDescription
 */
var _partDescription = 'http://hl7.org/fhir/_partDescription';
/**
 * _genomeBuild
 *
 * (Modified) GenomicStudy.analysis.genomeBuild
 *
 * http://hl7.org/fhir/_genomeBuild
 */
var _genomeBuild = 'http://hl7.org/fhir/_genomeBuild';
/**
 * Slot
 *
 * A slot of time on a schedule that may be available for booking appointments.
 *
 * http://hl7.org/fhir/Slot
 */
var Slot = 'http://hl7.org/fhir/Slot';
/**
 * _medium
 *
 * (Modified) CommunicationRequest.medium
 *
 * http://hl7.org/fhir/_medium
 */
var _medium = 'http://hl7.org/fhir/_medium';
/**
 * followUp
 *
 * Procedure.followUp: If the procedure required specific follow up - e.g. removal of sutures. The follow up may be represented as a simple note or could potentially be more complex, in which case the CarePlan resource can be used.
 *
 * http://hl7.org/fhir/followUp
 */
var followUp = 'http://hl7.org/fhir/followUp';
/**
 * maxDuration
 *
 * SpecimenDefinition.typeTested.handling.maxDuration: The maximum time interval of preservation of the specimen with these conditions.
 *
 * http://hl7.org/fhir/maxDuration
 */
var maxDuration = 'http://hl7.org/fhir/maxDuration';
/**
 * lotNumber
 *
 * Medication.batch.lotNumber: The assigned lot number of a batch of the specified product.
 *
 * http://hl7.org/fhir/lotNumber
 */
var lotNumber = 'http://hl7.org/fhir/lotNumber';
/**
 * EncounterHistoryLocationComponent
 *
 * EncounterHistoryLocationComponent: The location of the patient at this point in the encounter, the multiple cardinality permits de-normalizing the levels of the location hierarchy, such as site/ward/room/bed.
 *
 * http://hl7.org/fhir/EncounterHistoryLocationComponent
 */
var EncounterHistoryLocationComponent = 'http://hl7.org/fhir/EncounterHistoryLocationComponent';
/**
 * _owner
 *
 * (Modified) Transport.owner
 *
 * http://hl7.org/fhir/_owner
 */
var _owner = 'http://hl7.org/fhir/_owner';
/**
 * InventoryItem
 *
 * functional description of an inventory item used in inventory and supply-related workflows.
 *
 * http://hl7.org/fhir/InventoryItem
 */
var InventoryItem = 'http://hl7.org/fhir/InventoryItem';
/**
 * content
 *
 * Library.content: The content of the library as an Attachment. The content may be a reference to a url, or may be directly embedded as a base-64 string. Either way, the contentType of the attachment determines how to interpret the content.
 *
 * http://hl7.org/fhir/content
 */
var content = 'http://hl7.org/fhir/content';
/**
 * DeviceDefinitionPropertyComponent
 *
 * DeviceDefinitionPropertyComponent: Static or essentially fixed characteristics or features of this kind of device that are otherwise not captured in more specific attributes, e.g., time or timing attributes, resolution, accuracy, and physical attributes.
 *
 * http://hl7.org/fhir/DeviceDefinitionPropertyComponent
 */
var DeviceDefinitionPropertyComponent = 'http://hl7.org/fhir/DeviceDefinitionPropertyComponent';
/**
 * enteredDate
 *
 * ChargeItem.enteredDate: Date the charge item was entered.
 *
 * http://hl7.org/fhir/enteredDate
 */
var enteredDate = 'http://hl7.org/fhir/enteredDate';
/**
 * _district
 *
 * (Modified) Address.district
 *
 * http://hl7.org/fhir/_district
 */
var _district = 'http://hl7.org/fhir/_district';
/**
 * QuestionnaireItemComponentItemItem
 *
 * Text, questions and other groups to be nested beneath a question or group.
 *
 * http://hl7.org/fhir/QuestionnaireItemComponentItemItem
 */
var QuestionnaireItemComponentItemItem = 'http://hl7.org/fhir/QuestionnaireItemComponentItemItem';
/**
 * eye
 *
 * VisionPrescription.lensSpecification.eye: The eye for which the lens specification applies.
 *
 * http://hl7.org/fhir/eye
 */
var eye = 'http://hl7.org/fhir/eye';
/**
 * facilityType
 *
 * DocumentReference.facilityType: The kind of facility where the patient was seen.
 *
 * http://hl7.org/fhir/facilityType
 */
var facilityType = 'http://hl7.org/fhir/facilityType';
/**
 * markdown
 *
 * A string that may contain Github Flavored Markdown syntax for optional processing by a mark down presentation engine
 *
 * http://hl7.org/fhir/markdown
 */
var markdown = 'http://hl7.org/fhir/markdown';
/**
 * _friendly
 *
 * (Modified) Contract.friendly
 *
 * http://hl7.org/fhir/_friendly
 */
var _friendly = 'http://hl7.org/fhir/_friendly';
/**
 * ManufacturedItemDefinitionComponentComponentComponent
 *
 * A component that this component contains or is made from.
 *
 * http://hl7.org/fhir/ManufacturedItemDefinitionComponentComponentComponent
 */
var ManufacturedItemDefinitionComponentComponentComponent = 'http://hl7.org/fhir/ManufacturedItemDefinitionComponentComponentComponent';
/**
 * basedOn
 *
 * NutritionOrder.basedOn: A plan or request that is fulfilled in whole or in part by this nutrition order.
 *
 * http://hl7.org/fhir/basedOn
 */
var basedOn = 'http://hl7.org/fhir/basedOn';
/**
 * assessmentMethod
 *
 * AdverseEvent.suspectEntity.causality.assessmentMethod: The method of evaluating the relatedness of the suspected entity to the event.
 *
 * http://hl7.org/fhir/assessmentMethod
 */
var assessmentMethod = 'http://hl7.org/fhir/assessmentMethod';
/**
 * _sourceMaterialClass
 *
 * (Modified) SubstanceSourceMaterial.sourceMaterialClass
 *
 * http://hl7.org/fhir/_sourceMaterialClass
 */
var _sourceMaterialClass = 'http://hl7.org/fhir/_sourceMaterialClass';
/**
 * CarePlanActivityComponent
 *
 * CarePlanActivityComponent: Identifies an action that has occurred or is a planned action to occur as part of the plan. For example, a medication to be used, lab tests to perform, self-monitoring that has occurred, education etc.
 *
 * http://hl7.org/fhir/CarePlanActivityComponent
 */
var CarePlanActivityComponent = 'http://hl7.org/fhir/CarePlanActivityComponent';
/**
 * response
 *
 * ExampleScenario.process.step.process.step.alternative.step.operation.response: A reference to the instance that is transmitted from receiver to requester as part of the operation's synchronous response (if any).
 *
 * http://hl7.org/fhir/response
 */
var response = 'http://hl7.org/fhir/response';
/**
 * _singleUse
 *
 * (Modified) SpecimenDefinition.typeTested.singleUse
 *
 * http://hl7.org/fhir/_singleUse
 */
var _singleUse = 'http://hl7.org/fhir/_singleUse';
/**
 * ProvenanceAgentComponent
 *
 * ProvenanceAgentComponent: An actor taking a role in an activity  for which it can be assigned some degree of responsibility for the activity taking place.
 *
 * http://hl7.org/fhir/ProvenanceAgentComponent
 */
var ProvenanceAgentComponent = 'http://hl7.org/fhir/ProvenanceAgentComponent';
/**
 * _kingdom
 *
 * (Modified) SubstanceSourceMaterial.organism.organismGeneral.kingdom
 *
 * http://hl7.org/fhir/_kingdom
 */
var _kingdom = 'http://hl7.org/fhir/_kingdom';
/**
 * error
 *
 * SubscriptionStatus.error: A record of errors that occurred when the server processed a notification.
 *
 * http://hl7.org/fhir/error
 */
var error = 'http://hl7.org/fhir/error';
/**
 * effect
 *
 * ClinicalUseDefinition.interaction.effect: The effect of the interaction, for example "reduced gastric absorption of primary medication".
 *
 * http://hl7.org/fhir/effect
 */
var effect = 'http://hl7.org/fhir/effect';
/**
 * verifiedWith
 *
 * Consent.verification.verifiedWith: Who verified the instruction (Patient, Relative or other Authorized Person).
 *
 * http://hl7.org/fhir/verifiedWith
 */
var verifiedWith = 'http://hl7.org/fhir/verifiedWith';
/**
 * _packaging
 *
 * (Modified) PackagedProductDefinition.packaging.packaging
 *
 * http://hl7.org/fhir/_packaging
 */
var _packaging = 'http://hl7.org/fhir/_packaging';
/**
 * position
 *
 * Location.position: The absolute geographic location of the Location, expressed using the WGS84 datum (This is the same co-ordinate system used in KML).
 *
 * http://hl7.org/fhir/position
 */
var position = 'http://hl7.org/fhir/position';
/**
 * EvidenceCertaintyComponentCertainty
 *
 * A domain or subdomain of certainty.
 *
 * http://hl7.org/fhir/EvidenceCertaintyComponentCertainty
 */
var EvidenceCertaintyComponentCertainty = 'http://hl7.org/fhir/EvidenceCertaintyComponentCertainty';
/**
 * low
 *
 * SubstancePolymer.repeat.repeatUnit.degreeOfPolymerisation.low: A low expected limit of the amount.
 *
 * http://hl7.org/fhir/low
 */
var low = 'http://hl7.org/fhir/low';
/**
 * _Device
 *
 * (Modified) Device
 *
 * http://hl7.org/fhir/_Device
 */
var _Device = 'http://hl7.org/fhir/_Device';
/**
 * AddedItemSubDetail
 *
 * ClaimResponse.AddedItem.AddedItemDetail.AddedItemSubDetail: The third-tier service adjudications for payor added services.
 *
 * http://hl7.org/fhir/AddedItemSubDetail
 */
var AddedItemSubDetail = 'http://hl7.org/fhir/AddedItemSubDetail';
/**
 * _responsible
 *
 * (Modified) PaymentReconciliation.allocation.responsible
 *
 * http://hl7.org/fhir/_responsible
 */
var _responsible = 'http://hl7.org/fhir/_responsible';
/**
 * excludingDate
 *
 * Appointment.recurrenceTemplate.excludingDate: Any dates, such as holidays, that should be excluded from the recurrence.
 *
 * http://hl7.org/fhir/excludingDate
 */
var excludingDate = 'http://hl7.org/fhir/excludingDate';
/**
 * _verified
 *
 * (Modified) Consent.verification.verified
 *
 * http://hl7.org/fhir/_verified
 */
var _verified = 'http://hl7.org/fhir/_verified';
/**
 * TestScriptMetadataCapabilityComponent
 *
 * TestScriptMetadataComponent.TestScriptMetadataCapabilityComponent: Capabilities that must exist and are assumed to function correctly on the FHIR server being tested.
 *
 * http://hl7.org/fhir/TestScriptMetadataCapabilityComponent
 */
var TestScriptMetadataCapabilityComponent = 'http://hl7.org/fhir/TestScriptMetadataCapabilityComponent';
/**
 * marketingStatus
 *
 * PackagedProductDefinition.marketingStatus: Allows specifying that an item is on the market for sale, or that it is not available, and the dates and locations associated.
 *
 * http://hl7.org/fhir/marketingStatus
 */
var marketingStatus = 'http://hl7.org/fhir/marketingStatus';
/**
 * _ClaimResponse
 *
 * (Modified) ClaimResponse
 *
 * http://hl7.org/fhir/_ClaimResponse
 */
var _ClaimResponse = 'http://hl7.org/fhir/_ClaimResponse';
/**
 * request
 *
 * PaymentReconciliation.request: Original request resource reference.
 *
 * http://hl7.org/fhir/request
 */
var request = 'http://hl7.org/fhir/request';
/**
 * MolecularSequenceRelativeEditComponent
 *
 * MolecularSequenceRelativeComponent.MolecularSequenceRelativeEditComponent: Changes in sequence from the starting sequence.
 *
 * http://hl7.org/fhir/MolecularSequenceRelativeEditComponent
 */
var MolecularSequenceRelativeEditComponent = 'http://hl7.org/fhir/MolecularSequenceRelativeEditComponent';
/**
 * periodType
 *
 * Contract.term.group.asset.periodType: Type of Asset availability for use or ownership.
 *
 * http://hl7.org/fhir/periodType
 */
var periodType = 'http://hl7.org/fhir/periodType';
/**
 * approvalDate
 *
 * EvidenceVariable.approvalDate: The date on which the resource content was approved by the publisher. Approval happens once when the content is officially approved for usage.
 *
 * See guidance around (not) making local changes to elements [here](canonicalresource.html#localization).
 *
 * http://hl7.org/fhir/approvalDate
 */
var approvalDate = 'http://hl7.org/fhir/approvalDate';
/**
 * _monomerSet
 *
 * (Modified) SubstancePolymer.monomerSet
 *
 * http://hl7.org/fhir/_monomerSet
 */
var _monomerSet = 'http://hl7.org/fhir/_monomerSet';
/**
 * _eventTrigger
 *
 * (Modified) SubscriptionTopic.eventTrigger
 *
 * http://hl7.org/fhir/_eventTrigger
 */
var _eventTrigger = 'http://hl7.org/fhir/_eventTrigger';
/**
 * _ingredient
 *
 * (Modified) Substance.ingredient
 *
 * http://hl7.org/fhir/_ingredient
 */
var _ingredient = 'http://hl7.org/fhir/_ingredient';
/**
 * _biologicalSourceEvent
 *
 * (Modified) NutritionProduct.instance.biologicalSourceEvent
 *
 * http://hl7.org/fhir/_biologicalSourceEvent
 */
var _biologicalSourceEvent = 'http://hl7.org/fhir/_biologicalSourceEvent';
/**
 * durationMax
 *
 * Timing.repeat.durationMax: If present, indicates that the duration is a range - so to perform the action between [duration] and [durationMax] time length.
 *
 * http://hl7.org/fhir/durationMax
 */
var durationMax = 'http://hl7.org/fhir/durationMax';
/**
 * _MolecularSequence
 *
 * (Modified) MolecularSequence
 *
 * http://hl7.org/fhir/_MolecularSequence
 */
var _MolecularSequence = 'http://hl7.org/fhir/_MolecularSequence';
/**
 * _permittedDataType
 *
 * (Modified) ObservationDefinition.component.permittedDataType
 *
 * http://hl7.org/fhir/_permittedDataType
 */
var _permittedDataType = 'http://hl7.org/fhir/_permittedDataType';
/**
 * subtitle
 *
 * Measure.subtitle: An explanatory or alternate title for the measure giving additional information about its content.
 *
 * http://hl7.org/fhir/subtitle
 */
var subtitle = 'http://hl7.org/fhir/subtitle';
/**
 * _SubscriptionStatus
 *
 * (Modified) SubscriptionStatus
 *
 * http://hl7.org/fhir/_SubscriptionStatus
 */
var _SubscriptionStatus = 'http://hl7.org/fhir/_SubscriptionStatus';
/**
 * maxTreatmentPeriod
 *
 * AdministrableProductDefinition.routeOfAdministration.maxTreatmentPeriod: The maximum treatment period during which the product can be administered.
 *
 * http://hl7.org/fhir/maxTreatmentPeriod
 */
var maxTreatmentPeriod = 'http://hl7.org/fhir/maxTreatmentPeriod';
/**
 * _relatedIdentifier
 *
 * (Modified) EvidenceReport.relatedIdentifier
 *
 * http://hl7.org/fhir/_relatedIdentifier
 */
var _relatedIdentifier = 'http://hl7.org/fhir/_relatedIdentifier';
/**
 * _feature
 *
 * (Modified) Specimen.feature
 *
 * http://hl7.org/fhir/_feature
 */
var _feature = 'http://hl7.org/fhir/_feature';
/**
 * ValueSetExpansionComponent
 *
 * ValueSetExpansionComponent: A value set can also be "expanded", where the value set is turned into a simple collection of enumerated codes. This element holds the expansion, if it has been performed.
 *
 * http://hl7.org/fhir/ValueSetExpansionComponent
 */
var ValueSetExpansionComponent = 'http://hl7.org/fhir/ValueSetExpansionComponent';
/**
 * _parameterFocus
 *
 * (Modified) ServiceRequest.orderDetail.parameterFocus
 *
 * http://hl7.org/fhir/_parameterFocus
 */
var _parameterFocus = 'http://hl7.org/fhir/_parameterFocus';
/**
 * _maxDosePerDay
 *
 * (Modified) AdministrableProductDefinition.routeOfAdministration.maxDosePerDay
 *
 * http://hl7.org/fhir/_maxDosePerDay
 */
var _maxDosePerDay = 'http://hl7.org/fhir/_maxDosePerDay';
/**
 * CapabilityStatementMessagingComponent
 *
 * CapabilityStatementMessagingComponent: A description of the messaging capabilities of the solution.
 *
 * http://hl7.org/fhir/CapabilityStatementMessagingComponent
 */
var CapabilityStatementMessagingComponent = 'http://hl7.org/fhir/CapabilityStatementMessagingComponent';
/**
 * ResearchStudyObjectiveComponent
 *
 * ResearchStudyObjectiveComponent: A goal that the study is aiming to achieve in terms of a scientific question to be answered by the analysis of data collected during the study.
 *
 * http://hl7.org/fhir/ResearchStudyObjectiveComponent
 */
var ResearchStudyObjectiveComponent = 'http://hl7.org/fhir/ResearchStudyObjectiveComponent';
/**
 * MedicationIngredientComponent
 *
 * MedicationIngredientComponent: Identifies a particular constituent of interest in the product.
 *
 * http://hl7.org/fhir/MedicationIngredientComponent
 */
var MedicationIngredientComponent = 'http://hl7.org/fhir/MedicationIngredientComponent';
/**
 * SourceElement
 *
 * ConceptMapGroupComponent.SourceElement: Mappings for an individual concept in the source to one or more concepts in the target.
 *
 * http://hl7.org/fhir/SourceElement
 */
var SourceElement = 'http://hl7.org/fhir/SourceElement';
/**
 * _sequence
 *
 * (Modified) ExplanationOfBenefit.diagnosis.sequence
 *
 * http://hl7.org/fhir/_sequence
 */
var _sequence = 'http://hl7.org/fhir/_sequence';
/**
 * _validateProfileId
 *
 * (Modified) TestScript.test.action.assert.validateProfileId
 *
 * http://hl7.org/fhir/_validateProfileId
 */
var _validateProfileId = 'http://hl7.org/fhir/_validateProfileId';
/**
 * responsibility
 *
 * Coverage.paymentBy.responsibility:  Description of the financial responsibility.
 *
 * http://hl7.org/fhir/responsibility
 */
var responsibility = 'http://hl7.org/fhir/responsibility';
/**
 * containedItem
 *
 * PackagedProductDefinition.packaging.packaging.containedItem: The item(s) within the packaging.
 *
 * http://hl7.org/fhir/containedItem
 */
var containedItem = 'http://hl7.org/fhir/containedItem';
/**
 * completionTime
 *
 * Transport.completionTime: Identifies the completion time of the event (the occurrence).
 *
 * http://hl7.org/fhir/completionTime
 */
var completionTime = 'http://hl7.org/fhir/completionTime';
/**
 * _identifier
 *
 * (Modified) Reference.identifier
 *
 * http://hl7.org/fhir/_identifier
 */
var _identifier = 'http://hl7.org/fhir/_identifier';
/**
 * _scope
 *
 * (Modified) Contract.term.asset.scope
 *
 * http://hl7.org/fhir/_scope
 */
var _scope = 'http://hl7.org/fhir/_scope';
/**
 * currency
 *
 * Account.currency: The default currency for the account.
 *
 * http://hl7.org/fhir/currency
 */
var currency = 'http://hl7.org/fhir/currency';
/**
 * _inputProfile
 *
 * (Modified) OperationDefinition.inputProfile
 *
 * http://hl7.org/fhir/_inputProfile
 */
var _inputProfile = 'http://hl7.org/fhir/_inputProfile';
/**
 * TestAction
 *
 * TestScriptTestComponent.TestAction: Action would contain either an operation or an assertion.
 *
 * http://hl7.org/fhir/TestAction
 */
var TestAction = 'http://hl7.org/fhir/TestAction';
/**
 * _performer
 *
 * (Modified) Procedure.performer
 *
 * http://hl7.org/fhir/_performer
 */
var _performer = 'http://hl7.org/fhir/_performer';
/**
 * QuestionnaireResponseItemComponentItemItem
 *
 * Sub-questions, sub-groups or display items nested beneath a group.
 *
 * http://hl7.org/fhir/QuestionnaireResponseItemComponentItemItem
 */
var QuestionnaireResponseItemComponentItemItem = 'http://hl7.org/fhir/QuestionnaireResponseItemComponentItemItem';
/**
 * _pushTypeAvailable
 *
 * (Modified) VerificationResult.primarySource.pushTypeAvailable
 *
 * http://hl7.org/fhir/_pushTypeAvailable
 */
var _pushTypeAvailable = 'http://hl7.org/fhir/_pushTypeAvailable';
/**
 * communication
 *
 * RelatedPerson.communication: A language which may be used to communicate with the related person about the patient's health.
 *
 * http://hl7.org/fhir/communication
 */
var communication = 'http://hl7.org/fhir/communication';
/**
 * interpretation
 *
 * Observation.component.interpretation: A categorical assessment of an observation value.  For example, high, low, normal.
 *
 * http://hl7.org/fhir/interpretation
 */
var interpretation = 'http://hl7.org/fhir/interpretation';
/**
 * _capacity
 *
 * (Modified) SpecimenDefinition.typeTested.container.capacity
 *
 * http://hl7.org/fhir/_capacity
 */
var _capacity = 'http://hl7.org/fhir/_capacity';
/**
 * topic
 *
 * ConceptMap.topic: Descriptions related to the content of the ConceptMap. Topics provide a high-level categorization as well as keywords for the ConceptMap that can be useful for filtering and searching.
 *
 * http://hl7.org/fhir/topic
 */
var topic = 'http://hl7.org/fhir/topic';
/**
 * _undesirableEffect
 *
 * (Modified) ClinicalUseDefinition.undesirableEffect
 *
 * http://hl7.org/fhir/_undesirableEffect
 */
var _undesirableEffect = 'http://hl7.org/fhir/_undesirableEffect';
/**
 * _noteNumber
 *
 * (Modified) ExplanationOfBenefit.addItem.detail.subDetail.noteNumber
 *
 * http://hl7.org/fhir/_noteNumber
 */
var _noteNumber = 'http://hl7.org/fhir/_noteNumber';
/**
 * _DeviceRequest
 *
 * (Modified) DeviceRequest
 *
 * http://hl7.org/fhir/_DeviceRequest
 */
var _DeviceRequest = 'http://hl7.org/fhir/_DeviceRequest';
/**
 * courseOfTherapyType
 *
 * MedicationRequest.courseOfTherapyType: The description of the overall pattern of the administration of the medication to the patient.
 *
 * http://hl7.org/fhir/courseOfTherapyType
 */
var courseOfTherapyType = 'http://hl7.org/fhir/courseOfTherapyType';
/**
 * ordinalPosition
 *
 * MolecularSequence.relative.ordinalPosition: Indicates the order in which the sequence should be considered when putting multiple 'relative' elements together.
 *
 * http://hl7.org/fhir/ordinalPosition
 */
var ordinalPosition = 'http://hl7.org/fhir/ordinalPosition';
/**
 * ObservationComponentComponentReferenceRange
 *
 * Guidance on how to interpret the value by comparison to a normal or recommended range.
 *
 * http://hl7.org/fhir/ObservationComponentComponentReferenceRange
 */
var ObservationComponentComponentReferenceRange = 'http://hl7.org/fhir/ObservationComponentComponentReferenceRange';
/**
 * _actorId
 *
 * (Modified) PlanDefinition.action.action.participant.actorId
 *
 * http://hl7.org/fhir/_actorId
 */
var _actorId = 'http://hl7.org/fhir/_actorId';
/**
 * conclusion
 *
 * DiagnosticReport.conclusion: Concise and clinically contextualized summary conclusion (interpretation/impression) of the diagnostic report.
 *
 * http://hl7.org/fhir/conclusion
 */
var conclusion = 'http://hl7.org/fhir/conclusion';
/**
 * Resource
 *
 * This is the base resource type for everything.
 *
 * http://hl7.org/fhir/Resource
 */
var Resource = 'http://hl7.org/fhir/Resource';
/**
 * accountNumber
 *
 * PaymentReconciliation.accountNumber: A portion of the account number, often the last 4 digits, used for verification not charging purposes.
 *
 * http://hl7.org/fhir/accountNumber
 */
var accountNumber = 'http://hl7.org/fhir/accountNumber';
/**
 * deliverTo
 *
 * SupplyRequest.deliverTo: Where the supply is destined to go.
 *
 * http://hl7.org/fhir/deliverTo
 */
var deliverTo = 'http://hl7.org/fhir/deliverTo';
/**
 * multipleResultsAllowed
 *
 * ObservationDefinition.multipleResultsAllowed: Multiple results allowed for observations conforming to this ObservationDefinition.
 *
 * http://hl7.org/fhir/multipleResultsAllowed
 */
var multipleResultsAllowed = 'http://hl7.org/fhir/multipleResultsAllowed';
/**
 * _asNeeded
 *
 * (Modified) NutritionOrder.supplement.schedule.asNeeded
 *
 * http://hl7.org/fhir/_asNeeded
 */
var _asNeeded = 'http://hl7.org/fhir/_asNeeded';
/**
 * _onHold
 *
 * (Modified) Account.guarantor.onHold
 *
 * http://hl7.org/fhir/_onHold
 */
var _onHold = 'http://hl7.org/fhir/_onHold';
/**
 * genomeAssembly
 *
 * MolecularSequence.relative.startingSequence.genomeAssembly: The genome assembly used for starting sequence, e.g. GRCh38.
 *
 * http://hl7.org/fhir/genomeAssembly
 */
var genomeAssembly = 'http://hl7.org/fhir/genomeAssembly';
/**
 * _preAuthRefPeriod
 *
 * (Modified) ExplanationOfBenefit.preAuthRefPeriod
 *
 * http://hl7.org/fhir/_preAuthRefPeriod
 */
var _preAuthRefPeriod = 'http://hl7.org/fhir/_preAuthRefPeriod';
/**
 * itemSequence
 *
 * ClaimResponse.item.itemSequence: A number to uniquely reference the claim item entries.
 *
 * http://hl7.org/fhir/itemSequence
 */
var itemSequence = 'http://hl7.org/fhir/itemSequence';
/**
 * _relatedClinicalInformation
 *
 * (Modified) MedicationStatement.relatedClinicalInformation
 *
 * http://hl7.org/fhir/_relatedClinicalInformation
 */
var _relatedClinicalInformation = 'http://hl7.org/fhir/_relatedClinicalInformation';
/**
 * ResearchStudy
 *
 * A scientific study of nature that sometimes includes processes involved in health and disease. For example, clinical trials are research studies that involve people. These studies may be related to new ways to screen, prevent, diagnose, and treat disease. They may also study certain outcomes and certain groups of people by looking at data collected in the past or future.
 *
 * http://hl7.org/fhir/ResearchStudy
 */
var ResearchStudy = 'http://hl7.org/fhir/ResearchStudy';
/**
 * _action
 *
 * (Modified) PlanDefinition.action.action
 *
 * http://hl7.org/fhir/_action
 */
var _action = 'http://hl7.org/fhir/_action';
/**
 * _DocumentReference
 *
 * (Modified) DocumentReference
 *
 * http://hl7.org/fhir/_DocumentReference
 */
var _DocumentReference = 'http://hl7.org/fhir/_DocumentReference';
/**
 * _coverageArea
 *
 * (Modified) InsurancePlan.plan.coverageArea
 *
 * http://hl7.org/fhir/_coverageArea
 */
var _coverageArea = 'http://hl7.org/fhir/_coverageArea';
/**
 * DataType
 *
 * The base class for all re-useable types defined as part of the FHIR Specification.
 *
 * http://hl7.org/fhir/DataType
 */
var DataType = 'http://hl7.org/fhir/DataType';
/**
 * Duration
 *
 * A length of time.
 *
 * http://hl7.org/fhir/Duration
 */
var Duration = 'http://hl7.org/fhir/Duration';
/**
 * _Consent
 *
 * (Modified) Consent
 *
 * http://hl7.org/fhir/_Consent
 */
var _Consent = 'http://hl7.org/fhir/_Consent';
/**
 * _referencePolicy
 *
 * (Modified) CapabilityStatement.rest.resource.referencePolicy
 *
 * http://hl7.org/fhir/_referencePolicy
 */
var _referencePolicy = 'http://hl7.org/fhir/_referencePolicy';
/**
 * _virtualService
 *
 * (Modified) Location.virtualService
 *
 * http://hl7.org/fhir/_virtualService
 */
var _virtualService = 'http://hl7.org/fhir/_virtualService';
/**
 * _lastModified
 *
 * (Modified) Transport.lastModified
 *
 * http://hl7.org/fhir/_lastModified
 */
var _lastModified = 'http://hl7.org/fhir/_lastModified';
/**
 * destination
 *
 * TestScript.test.action.operation.destination: The server where the request message is destined for.  Must be one of the server numbers listed in TestScript.destination section.
 *
 * http://hl7.org/fhir/destination
 */
var destination = 'http://hl7.org/fhir/destination';
/**
 * _whenHandedOver
 *
 * (Modified) MedicationDispense.whenHandedOver
 *
 * http://hl7.org/fhir/_whenHandedOver
 */
var _whenHandedOver = 'http://hl7.org/fhir/_whenHandedOver';
/**
 * _typeTested
 *
 * (Modified) SpecimenDefinition.typeTested
 *
 * http://hl7.org/fhir/_typeTested
 */
var _typeTested = 'http://hl7.org/fhir/_typeTested';
/**
 * product
 *
 * ActivityDefinition.product
 *
 * http://hl7.org/fhir/product
 */
var product = 'http://hl7.org/fhir/product';
/**
 * _referrer
 *
 * (Modified) ImagingStudy.referrer
 *
 * http://hl7.org/fhir/_referrer
 */
var _referrer = 'http://hl7.org/fhir/_referrer';
/**
 * plannedEndDate
 *
 * EncounterHistory.plannedEndDate: The planned end date/time (or discharge date) of the encounter.
 *
 * http://hl7.org/fhir/plannedEndDate
 */
var plannedEndDate = 'http://hl7.org/fhir/plannedEndDate';
/**
 * _birthDate
 *
 * (Modified) RelatedPerson.birthDate
 *
 * http://hl7.org/fhir/_birthDate
 */
var _birthDate = 'http://hl7.org/fhir/_birthDate';
/**
 * _mustHaveValue
 *
 * (Modified) ElementDefinition.mustHaveValue
 *
 * http://hl7.org/fhir/_mustHaveValue
 */
var _mustHaveValue = 'http://hl7.org/fhir/_mustHaveValue';
/**
 * ClinicalUseDefinition
 *
 * A single issue - either an indication, contraindication, interaction or an undesirable effect for a medicinal product, medication, device or procedure.
 *
 * http://hl7.org/fhir/ClinicalUseDefinition
 */
var ClinicalUseDefinition = 'http://hl7.org/fhir/ClinicalUseDefinition';
/**
 * dynamicValue
 *
 * PlanDefinition.action.dynamicValue: Customizations that should be applied to the statically defined resource. For example, if the dosage of a medication must be computed based on the patient's weight, a customization would be used to specify an expression that calculated the weight, and the path on the resource that would contain the result.
 *
 * http://hl7.org/fhir/dynamicValue
 */
var dynamicValue = 'http://hl7.org/fhir/dynamicValue';
/**
 * _detailSequence
 *
 * (Modified) ExplanationOfBenefit.addItem.detailSequence
 *
 * http://hl7.org/fhir/_detailSequence
 */
var _detailSequence = 'http://hl7.org/fhir/_detailSequence';
/**
 * SupportingInformation
 *
 * Claim.SupportingInformation: Additional information codes regarding exceptions, special considerations, the condition, situation, prior or concurrent issues.
 *
 * http://hl7.org/fhir/SupportingInformation
 */
var SupportingInformation = 'http://hl7.org/fhir/SupportingInformation';
/**
 * CitationStatusDateComponent
 *
 * CitationStatusDateComponent: The state or status of the citation record paired with an effective date or period for that state.
 *
 * http://hl7.org/fhir/CitationStatusDateComponent
 */
var CitationStatusDateComponent = 'http://hl7.org/fhir/CitationStatusDateComponent';
/**
 * subscriberId
 *
 * Coverage.subscriberId: The insurer assigned ID for the Subscriber.
 *
 * http://hl7.org/fhir/subscriberId
 */
var subscriberId = 'http://hl7.org/fhir/subscriberId';
/**
 * node
 *
 * GraphDefinition.node: Potential target for the link.
 *
 * http://hl7.org/fhir/node
 */
var node = 'http://hl7.org/fhir/node';
/**
 * details
 *
 * OperationOutcome.issue.details: Additional details about the error. This may be a text description of the error or a system code that identifies the error.
 *
 * http://hl7.org/fhir/details
 */
var details = 'http://hl7.org/fhir/details';
/**
 * GenomicStudyAnalysisInputComponent
 *
 * GenomicStudyAnalysisComponent.GenomicStudyAnalysisInputComponent: Inputs for the analysis event.
 *
 * http://hl7.org/fhir/GenomicStudyAnalysisInputComponent
 */
var GenomicStudyAnalysisInputComponent = 'http://hl7.org/fhir/GenomicStudyAnalysisInputComponent';
/**
 * contract
 *
 * Coverage.contract: The policy(s) which constitute this insurance coverage.
 *
 * http://hl7.org/fhir/contract
 */
var contract = 'http://hl7.org/fhir/contract';
/**
 * _paymentIssuer
 *
 * (Modified) PaymentReconciliation.paymentIssuer
 *
 * http://hl7.org/fhir/_paymentIssuer
 */
var _paymentIssuer = 'http://hl7.org/fhir/_paymentIssuer';
/**
 * _clinicalTrial
 *
 * (Modified) MedicinalProductDefinition.clinicalTrial
 *
 * http://hl7.org/fhir/_clinicalTrial
 */
var _clinicalTrial = 'http://hl7.org/fhir/_clinicalTrial';
/**
 * Adjudication
 *
 * ExplanationOfBenefit.Item.Adjudication: If this item is a group then the values here are a summary of the adjudication of the detail items. If this item is a simple product or service then this is the result of the adjudication of this item.
 *
 * http://hl7.org/fhir/Adjudication
 */
var Adjudication = 'http://hl7.org/fhir/Adjudication';
/**
 * AdverseEventMitigatingActionComponent
 *
 * AdverseEventMitigatingActionComponent: The ameliorating action taken after the adverse event occured in order to reduce the extent of harm.
 *
 * http://hl7.org/fhir/AdverseEventMitigatingActionComponent
 */
var AdverseEventMitigatingActionComponent = 'http://hl7.org/fhir/AdverseEventMitigatingActionComponent';
/**
 * ratioType
 *
 * SubstancePolymer.monomerSet.ratioType: Captures the type of ratio to the entire polymer, e.g. Monomer/Polymer ratio, SRU/Polymer Ratio.
 *
 * http://hl7.org/fhir/ratioType
 */
var ratioType = 'http://hl7.org/fhir/ratioType';
/**
 * authoritative
 *
 * NamingSystem.uniqueId.authoritative: Indicates whether this identifier ie endorsed by the official owner of the associated naming system.
 *
 * http://hl7.org/fhir/authoritative
 */
var authoritative = 'http://hl7.org/fhir/authoritative';
/**
 * chromosome
 *
 * MolecularSequence.relative.startingSequence.chromosome: Structural unit composed of a nucleic acid molecule which controls its own replication through the interaction of specific proteins at one or more origins of replication ([SO:0000340](http://www.sequenceontology.org/browser/current_svn/term/SO:0000340)).
 *
 * http://hl7.org/fhir/chromosome
 */
var chromosome = 'http://hl7.org/fhir/chromosome';
/**
 * referralMethod
 *
 * HealthcareService.referralMethod: Ways that the service accepts referrals, if this is not provided then it is implied that no referral is required.
 *
 * http://hl7.org/fhir/referralMethod
 */
var referralMethod = 'http://hl7.org/fhir/referralMethod';
/**
 * MedicationKnowledgeDefinitionalDrugCharacteristicComponent
 *
 * MedicationKnowledgeDefinitionalComponent.MedicationKnowledgeDefinitionalDrugCharacteristicComponent: Specifies descriptive properties of the medicine, such as color, shape, imprints, etc.
 *
 * http://hl7.org/fhir/MedicationKnowledgeDefinitionalDrugCharacteristicComponent
 */
var MedicationKnowledgeDefinitionalDrugCharacteristicComponent = 'http://hl7.org/fhir/MedicationKnowledgeDefinitionalDrugCharacteristicComponent';
/**
 * _filterParameter
 *
 * (Modified) SubscriptionTopic.canFilterBy.filterParameter
 *
 * http://hl7.org/fhir/_filterParameter
 */
var _filterParameter = 'http://hl7.org/fhir/_filterParameter';
/**
 * _costCenter
 *
 * (Modified) ChargeItem.costCenter
 *
 * http://hl7.org/fhir/_costCenter
 */
var _costCenter = 'http://hl7.org/fhir/_costCenter';
/**
 * _maternalOrganismName
 *
 * (Modified) SubstanceSourceMaterial.organism.hybrid.maternalOrganismName
 *
 * http://hl7.org/fhir/_maternalOrganismName
 */
var _maternalOrganismName = 'http://hl7.org/fhir/_maternalOrganismName';
/**
 * _CommunicationRequest
 *
 * (Modified) CommunicationRequest
 *
 * http://hl7.org/fhir/_CommunicationRequest
 */
var _CommunicationRequest = 'http://hl7.org/fhir/_CommunicationRequest';
/**
 * _mapping
 *
 * (Modified) StructureDefinition.mapping
 *
 * http://hl7.org/fhir/_mapping
 */
var _mapping = 'http://hl7.org/fhir/_mapping';
/**
 * _spatialReference
 *
 * (Modified) BodyStructure.excludedStructure.spatialReference
 *
 * http://hl7.org/fhir/_spatialReference
 */
var _spatialReference = 'http://hl7.org/fhir/_spatialReference';
/**
 * _AppointmentResponse
 *
 * (Modified) AppointmentResponse
 *
 * http://hl7.org/fhir/_AppointmentResponse
 */
var _AppointmentResponse = 'http://hl7.org/fhir/_AppointmentResponse';
/**
 * preparation
 *
 * SpecimenDefinition.typeTested.container.preparation: Special processing that should be applied to the container for this kind of specimen.
 *
 * http://hl7.org/fhir/preparation
 */
var preparation = 'http://hl7.org/fhir/preparation';
/**
 * _outcome
 *
 * (Modified) FamilyMemberHistory.condition.outcome
 *
 * http://hl7.org/fhir/_outcome
 */
var _outcome = 'http://hl7.org/fhir/_outcome';
/**
 * _policy
 *
 * (Modified) Provenance.policy
 *
 * http://hl7.org/fhir/_policy
 */
var _policy = 'http://hl7.org/fhir/_policy';
/**
 * planningHorizon
 *
 * Schedule.planningHorizon: The period of time that the slots that reference this Schedule resource cover (even if none exist). These  cover the amount of time that an organization's planning horizon; the interval for which they are currently accepting appointments. This does not define a "template" for planning outside these dates.
 *
 * http://hl7.org/fhir/planningHorizon
 */
var planningHorizon = 'http://hl7.org/fhir/planningHorizon';
/**
 * _targetSpecies
 *
 * (Modified) AdministrableProductDefinition.routeOfAdministration.targetSpecies
 *
 * http://hl7.org/fhir/_targetSpecies
 */
var _targetSpecies = 'http://hl7.org/fhir/_targetSpecies';
/**
 * EvidenceVariableCharacteristicComponent
 *
 * EvidenceVariableCharacteristicComponent: A defining factor of the EvidenceVariable. Multiple characteristics are applied with "and" semantics.
 *
 * http://hl7.org/fhir/EvidenceVariableCharacteristicComponent
 */
var EvidenceVariableCharacteristicComponent = 'http://hl7.org/fhir/EvidenceVariableCharacteristicComponent';
/**
 * _authorization
 *
 * (Modified) Provenance.authorization
 *
 * http://hl7.org/fhir/_authorization
 */
var _authorization = 'http://hl7.org/fhir/_authorization';
/**
 * software
 *
 * TerminologyCapabilities.software: Software that is covered by this terminology capability statement.  It is used when the statement describes the capabilities of a particular software version, independent of an installation.
 *
 * http://hl7.org/fhir/software
 */
var software = 'http://hl7.org/fhir/software';
/**
 * _lastReviewDate
 *
 * (Modified) ArtifactAssessment.lastReviewDate
 *
 * http://hl7.org/fhir/_lastReviewDate
 */
var _lastReviewDate = 'http://hl7.org/fhir/_lastReviewDate';
/**
 * _derivedFromCanonical
 *
 * (Modified) SpecimenDefinition.derivedFromCanonical
 *
 * http://hl7.org/fhir/_derivedFromCanonical
 */
var _derivedFromCanonical = 'http://hl7.org/fhir/_derivedFromCanonical';
/**
 * specialCourtesy
 *
 * Encounter.specialCourtesy: Special courtesies that may be provided to the patient during the encounter (VIP, board member, professional courtesy).
 *
 * http://hl7.org/fhir/specialCourtesy
 */
var specialCourtesy = 'http://hl7.org/fhir/specialCourtesy';
/**
 * intraspecificType
 *
 * SubstanceSourceMaterial.organism.intraspecificType: The Intraspecific type of an organism shall be specified.
 *
 * http://hl7.org/fhir/intraspecificType
 */
var intraspecificType = 'http://hl7.org/fhir/intraspecificType';
/**
 * shortTitle
 *
 * EvidenceVariable.shortTitle: The short title provides an alternate title for use in informal descriptive contexts where the full, formal title is not necessary.
 *
 * http://hl7.org/fhir/shortTitle
 */
var shortTitle = 'http://hl7.org/fhir/shortTitle';
/**
 * channelType
 *
 * Subscription.channelType: The type of channel to send notifications on.
 *
 * http://hl7.org/fhir/channelType
 */
var channelType = 'http://hl7.org/fhir/channelType';
/**
 * _subSite
 *
 * (Modified) ExplanationOfBenefit.addItem.bodySite.subSite
 *
 * http://hl7.org/fhir/_subSite
 */
var _subSite = 'http://hl7.org/fhir/_subSite';
/**
 * use
 *
 * ValueSet.compose.include.concept.designation.use: A code that represents types of uses of designations.
 *
 * http://hl7.org/fhir/use
 */
var use = 'http://hl7.org/fhir/use';
/**
 * webLocation
 *
 * Citation.citedArtifact.webLocation: Used for any URL for the article or artifact cited.
 *
 * http://hl7.org/fhir/webLocation
 */
var webLocation = 'http://hl7.org/fhir/webLocation';
/**
 * PlanDefinitionGoalTargetComponent
 *
 * PlanDefinitionGoalComponent.PlanDefinitionGoalTargetComponent: Indicates what should be done and within what timeframe.
 *
 * http://hl7.org/fhir/PlanDefinitionGoalTargetComponent
 */
var PlanDefinitionGoalTargetComponent = 'http://hl7.org/fhir/PlanDefinitionGoalTargetComponent';
/**
 * _entryQuantity
 *
 * (Modified) EvidenceReport.section.section.entryQuantity
 *
 * http://hl7.org/fhir/_entryQuantity
 */
var _entryQuantity = 'http://hl7.org/fhir/_entryQuantity';
/**
 * _seriousness
 *
 * (Modified) AdverseEvent.seriousness
 *
 * http://hl7.org/fhir/_seriousness
 */
var _seriousness = 'http://hl7.org/fhir/_seriousness';
/**
 * _born
 *
 * (Modified) FamilyMemberHistory.born
 *
 * http://hl7.org/fhir/_born
 */
var _born = 'http://hl7.org/fhir/_born';
/**
 * initiator
 *
 * ExampleScenario.process.step.process.step.alternative.step.operation.initiator: The system that invokes the action/transmits the data.
 *
 * http://hl7.org/fhir/initiator
 */
var initiator = 'http://hl7.org/fhir/initiator';
/**
 * geometry
 *
 * SubstancePolymer.geometry: Polymer geometry, e.g. linear, branched, cross-linked, network or dendritic.
 *
 * http://hl7.org/fhir/geometry
 */
var geometry = 'http://hl7.org/fhir/geometry';
/**
 * _organismGeneral
 *
 * (Modified) SubstanceSourceMaterial.organism.organismGeneral
 *
 * http://hl7.org/fhir/_organismGeneral
 */
var _organismGeneral = 'http://hl7.org/fhir/_organismGeneral';
/**
 * TestReportSetupComponent
 *
 * TestReportSetupComponent: The results of the series of required setup operations before the tests were executed.
 *
 * http://hl7.org/fhir/TestReportSetupComponent
 */
var TestReportSetupComponent = 'http://hl7.org/fhir/TestReportSetupComponent';
/**
 * message
 *
 * MessageDefinition.allowedResponse.message: A reference to the message definition that must be adhered to by this supported response.
 *
 * http://hl7.org/fhir/message
 */
var message = 'http://hl7.org/fhir/message';
/**
 * PlanDefinitionActionInputComponent
 *
 * PlanDefinitionActionComponentAction.PlanDefinitionActionInputComponent: Defines input data requirements for the action.
 *
 * http://hl7.org/fhir/PlanDefinitionActionInputComponent
 */
var PlanDefinitionActionInputComponent = 'http://hl7.org/fhir/PlanDefinitionActionInputComponent';
/**
 * Dosage
 *
 * Indicates how the medication is/was taken or should be taken by the patient.
 *
 * http://hl7.org/fhir/Dosage
 */
var Dosage = 'http://hl7.org/fhir/Dosage';
/**
 * _structureType
 *
 * (Modified) ExampleScenario.instance.structureType
 *
 * http://hl7.org/fhir/_structureType
 */
var _structureType = 'http://hl7.org/fhir/_structureType';
/**
 * onAdmission
 *
 * ExplanationOfBenefit.diagnosis.onAdmission: Indication of whether the diagnosis was present on admission to a facility.
 *
 * http://hl7.org/fhir/onAdmission
 */
var onAdmission = 'http://hl7.org/fhir/onAdmission';
/**
 * EncounterLocationComponent
 *
 * EncounterLocationComponent: List of locations where  the patient has been during this encounter.
 *
 * http://hl7.org/fhir/EncounterLocationComponent
 */
var EncounterLocationComponent = 'http://hl7.org/fhir/EncounterLocationComponent';
/**
 * statusHistory
 *
 * EpisodeOfCare.statusHistory: The history of statuses that the EpisodeOfCare has been through (without requiring processing the history of the resource).
 *
 * http://hl7.org/fhir/statusHistory
 */
var statusHistory = 'http://hl7.org/fhir/statusHistory';
/**
 * CitationCitedArtifactComponent
 *
 * CitationCitedArtifactComponent: The article or artifact being described.
 *
 * http://hl7.org/fhir/CitationCitedArtifactComponent
 */
var CitationCitedArtifactComponent = 'http://hl7.org/fhir/CitationCitedArtifactComponent';
/**
 * _paymentTerms
 *
 * (Modified) Invoice.paymentTerms
 *
 * http://hl7.org/fhir/_paymentTerms
 */
var _paymentTerms = 'http://hl7.org/fhir/_paymentTerms';
/**
 * _intendedEffect
 *
 * (Modified) ClinicalUseDefinition.indication.intendedEffect
 *
 * http://hl7.org/fhir/_intendedEffect
 */
var _intendedEffect = 'http://hl7.org/fhir/_intendedEffect';
/**
 * SubstanceSourceMaterialOrganismAuthorComponent
 *
 * SubstanceSourceMaterialOrganismComponent.SubstanceSourceMaterialOrganismAuthorComponent: 4.9.13.6.1 Author type (Conditional).
 *
 * http://hl7.org/fhir/SubstanceSourceMaterialOrganismAuthorComponent
 */
var SubstanceSourceMaterialOrganismAuthorComponent = 'http://hl7.org/fhir/SubstanceSourceMaterialOrganismAuthorComponent';
/**
 * listMode
 *
 * StructureMap.group.rule.source.listMode: How to handle the list mode for this element.
 *
 * http://hl7.org/fhir/listMode
 */
var listMode = 'http://hl7.org/fhir/listMode';
/**
 * _typeCollected
 *
 * (Modified) SpecimenDefinition.typeCollected
 *
 * http://hl7.org/fhir/_typeCollected
 */
var _typeCollected = 'http://hl7.org/fhir/_typeCollected';
/**
 * definitional
 *
 * MedicationKnowledge.definitional: Along with the link to a Medicinal Product Definition resource, this information provides common definitional elements that are needed to understand the specific medication that is being described.
 *
 * http://hl7.org/fhir/definitional
 */
var definitional = 'http://hl7.org/fhir/definitional';
/**
 * improvementNotation
 *
 * MeasureReport.improvementNotation: Whether improvement in the measure is noted by an increase or decrease in the measure score.
 *
 * http://hl7.org/fhir/improvementNotation
 */
var improvementNotation = 'http://hl7.org/fhir/improvementNotation';
/**
 * ValuedItem
 *
 * Contract.TermTerm.ContractAsset.ValuedItem: Contract Valued Item List.
 *
 * http://hl7.org/fhir/ValuedItem
 */
var ValuedItem = 'http://hl7.org/fhir/ValuedItem';
/**
 * ElementDefinitionBaseComponent
 *
 * ElementDefinitionBaseComponent: Information about the base definition of the element, provided to make it unnecessary for tools to trace the deviation of the element through the derived and related profiles. When the element definition is not the original definition of an element - e.g. either in a constraint on another type, or for elements from a super type in a snap shot - then the information in provided in the element definition may be different to the base definition. On the original definition of the element, it will be same.
 *
 * http://hl7.org/fhir/ElementDefinitionBaseComponent
 */
var ElementDefinitionBaseComponent = 'http://hl7.org/fhir/ElementDefinitionBaseComponent';
/**
 * Errors
 *
 * CoverageEligibilityResponse.Errors: Errors encountered during the processing of the request.
 *
 * http://hl7.org/fhir/Errors
 */
var Errors = 'http://hl7.org/fhir/Errors';
/**
 * pattern
 *
 * http://hl7.org/fhir/pattern
 */
var pattern = 'http://hl7.org/fhir/pattern';
/**
 * TestScriptDestinationComponent
 *
 * TestScriptDestinationComponent: An abstract server used in operations within this test script in the destination element.
 *
 * http://hl7.org/fhir/TestScriptDestinationComponent
 */
var TestScriptDestinationComponent = 'http://hl7.org/fhir/TestScriptDestinationComponent';
/**
 * CoveragePaymentByComponent
 *
 * CoveragePaymentByComponent: Link to the paying party and optionally what specifically they will be responsible to pay.
 *
 * http://hl7.org/fhir/CoveragePaymentByComponent
 */
var CoveragePaymentByComponent = 'http://hl7.org/fhir/CoveragePaymentByComponent';
/**
 * _AuditEvent
 *
 * (Modified) AuditEvent
 *
 * http://hl7.org/fhir/_AuditEvent
 */
var _AuditEvent = 'http://hl7.org/fhir/_AuditEvent';
/**
 * requirements
 *
 * ElementDefinition.constraint.requirements: Description of why this constraint is necessary or appropriate.
 *
 * http://hl7.org/fhir/requirements
 */
var requirements = 'http://hl7.org/fhir/requirements';
/**
 * authority
 *
 * SubstanceDefinition.name.synonym.official.authority: Which authority uses this official name.
 *
 * http://hl7.org/fhir/authority
 */
var authority = 'http://hl7.org/fhir/authority';
/**
 * _compareToSourceId
 *
 * (Modified) TestScript.test.action.assert.compareToSourceId
 *
 * http://hl7.org/fhir/_compareToSourceId
 */
var _compareToSourceId = 'http://hl7.org/fhir/_compareToSourceId';
/**
 * _Contract
 *
 * (Modified) Contract
 *
 * http://hl7.org/fhir/_Contract
 */
var _Contract = 'http://hl7.org/fhir/_Contract';
/**
 * _occurrenceChanged
 *
 * (Modified) Appointment.occurrenceChanged
 *
 * http://hl7.org/fhir/_occurrenceChanged
 */
var _occurrenceChanged = 'http://hl7.org/fhir/_occurrenceChanged';
/**
 * typeReference
 *
 * RequestOrchestration.action.action.participant.typeReference: The type of participant in the action.
 *
 * http://hl7.org/fhir/typeReference
 */
var typeReference = 'http://hl7.org/fhir/typeReference';
/**
 * detail
 *
 * TestReport.setup.action.assert.detail: A link to further details on the result.
 *
 * http://hl7.org/fhir/detail
 */
var detail = 'http://hl7.org/fhir/detail';
/**
 * _alternative
 *
 * (Modified) ExampleScenario.process.step.alternative.step.alternative
 *
 * http://hl7.org/fhir/_alternative
 */
var _alternative = 'http://hl7.org/fhir/_alternative';
/**
 * ClaimResponseAdjudication
 *
 * The adjudication results which are presented at the header level rather than at the line-item or add-item levels.
 *
 * http://hl7.org/fhir/ClaimResponseAdjudication
 */
var ClaimResponseAdjudication = 'http://hl7.org/fhir/ClaimResponseAdjudication';
/**
 * Person
 *
 * Demographics and administrative information about a person independent of a specific health-related context.
 *
 * http://hl7.org/fhir/Person
 */
var Person = 'http://hl7.org/fhir/Person';
/**
 * readHistory
 *
 * CapabilityStatement.rest.resource.readHistory: A flag for whether the server is able to return past versions as part of the vRead operation.
 *
 * http://hl7.org/fhir/readHistory
 */
var readHistory = 'http://hl7.org/fhir/readHistory';
/**
 * _subjects
 *
 * (Modified) MeasureReport.group.stratifier.stratum.population.subjects
 *
 * http://hl7.org/fhir/_subjects
 */
var _subjects = 'http://hl7.org/fhir/_subjects';
/**
 * membership
 *
 * Group.membership: Basis for membership in the Group:
 *
 * * 'definitional': The Group.characteristics specified are both necessary and sufficient to determine membership. All entities that meet the criteria are considered to be members of the group, whether referenced by the group or not. If members are present, they are individuals that happen to be known as meeting the Group.characteristics. The list cannot be presumed to be complete.
 * * 'enumerated': The Group.characteristics are necessary but not sufficient to determine membership. Membership is determined by being listed as one of the Group.member.
 *
 * http://hl7.org/fhir/membership
 */
var membership = 'http://hl7.org/fhir/membership';
/**
 * studyUid
 *
 * ImagingSelection.studyUid: The Study Instance UID for the DICOM Study from which the images were selected.
 *
 * http://hl7.org/fhir/studyUid
 */
var studyUid = 'http://hl7.org/fhir/studyUid';
/**
 * GraphDefinitionLinkCompartmentComponent
 *
 * GraphDefinitionLinkComponent.GraphDefinitionLinkCompartmentComponent: Compartment Consistency Rules.
 *
 * http://hl7.org/fhir/GraphDefinitionLinkCompartmentComponent
 */
var GraphDefinitionLinkCompartmentComponent = 'http://hl7.org/fhir/GraphDefinitionLinkCompartmentComponent';
/**
 * _occurrence
 *
 * (Modified) SupplyRequest.occurrence
 *
 * http://hl7.org/fhir/_occurrence
 */
var _occurrence = 'http://hl7.org/fhir/_occurrence';
/**
 * _dayOfMonth
 *
 * (Modified) Appointment.recurrenceTemplate.monthlyTemplate.dayOfMonth
 *
 * http://hl7.org/fhir/_dayOfMonth
 */
var _dayOfMonth = 'http://hl7.org/fhir/_dayOfMonth';
/**
 * Extension
 *
 * Optional Extension Element - found in all resources.
 *
 * http://hl7.org/fhir/Extension
 */
var Extension = 'http://hl7.org/fhir/Extension';
/**
 * _proxyIdentityCertificate
 *
 * (Modified) VerificationResult.attestation.proxyIdentityCertificate
 *
 * http://hl7.org/fhir/_proxyIdentityCertificate
 */
var _proxyIdentityCertificate = 'http://hl7.org/fhir/_proxyIdentityCertificate';
/**
 * emptyReason
 *
 * EvidenceReport.section.section.emptyReason: If the section is empty, why the list is empty. An empty section typically has some text explaining the empty reason.
 *
 * http://hl7.org/fhir/emptyReason
 */
var emptyReason = 'http://hl7.org/fhir/emptyReason';
/**
 * ConceptMapGroupComponent
 *
 * ConceptMapGroupComponent: A group of mappings that all have the same source and target system.
 *
 * http://hl7.org/fhir/ConceptMapGroupComponent
 */
var ConceptMapGroupComponent = 'http://hl7.org/fhir/ConceptMapGroupComponent';
/**
 * laterality
 *
 * BodyStructure.includedStructure.laterality: Code that represents the included structure laterality.
 *
 * http://hl7.org/fhir/laterality
 */
var laterality = 'http://hl7.org/fhir/laterality';
/**
 * _previous
 *
 * (Modified) SubscriptionTopic.resourceTrigger.queryCriteria.previous
 *
 * http://hl7.org/fhir/_previous
 */
var _previous = 'http://hl7.org/fhir/_previous';
/**
 * _claimResponse
 *
 * (Modified) ExplanationOfBenefit.claimResponse
 *
 * http://hl7.org/fhir/_claimResponse
 */
var _claimResponse = 'http://hl7.org/fhir/_claimResponse';
/**
 * dataUpdateType
 *
 * MeasureReport.dataUpdateType: Indicates whether the data submitted in a data-exchange report represents a snapshot or incremental update. A snapshot update replaces all previously submitted data for the receiver, whereas an incremental update represents only updated and/or changed data and should be applied as a differential update to the existing submitted data for the receiver.
 *
 * http://hl7.org/fhir/dataUpdateType
 */
var dataUpdateType = 'http://hl7.org/fhir/dataUpdateType';
/**
 * paymentDate
 *
 * PaymentNotice.paymentDate: The date when the above payment action occurred.
 *
 * http://hl7.org/fhir/paymentDate
 */
var paymentDate = 'http://hl7.org/fhir/paymentDate';
/**
 * baseFormulaProductName
 *
 * NutritionOrder.enteralFormula.baseFormulaProductName: The product or brand name of the enteral or infant formula product such as "ACME Adult Standard Formula".
 *
 * http://hl7.org/fhir/baseFormulaProductName
 */
var baseFormulaProductName = 'http://hl7.org/fhir/baseFormulaProductName';
/**
 * performed
 *
 * FamilyMemberHistory.procedure.performed
 *
 * http://hl7.org/fhir/performed
 */
var performed = 'http://hl7.org/fhir/performed';
/**
 * ServiceRequestOrderDetailComponent
 *
 * ServiceRequestOrderDetailComponent: Additional details and instructions about the how the services are to be delivered.   For example, and order for a urinary catheter may have an order detail for an external or indwelling catheter, or an order for a bandage may require additional instructions specifying how the bandage should be applied.
 *
 * http://hl7.org/fhir/ServiceRequestOrderDetailComponent
 */
var ServiceRequestOrderDetailComponent = 'http://hl7.org/fhir/ServiceRequestOrderDetailComponent';
/**
 * _informationSequence
 *
 * (Modified) ExplanationOfBenefit.item.informationSequence
 *
 * http://hl7.org/fhir/_informationSequence
 */
var _informationSequence = 'http://hl7.org/fhir/_informationSequence';
/**
 * _wednesday
 *
 * (Modified) Appointment.recurrenceTemplate.weeklyTemplate.wednesday
 *
 * http://hl7.org/fhir/_wednesday
 */
var _wednesday = 'http://hl7.org/fhir/_wednesday';
/**
 * _id
 *
 * (Modified) Resource.id
 *
 * http://hl7.org/fhir/_id
 */
var _id = 'http://hl7.org/fhir/_id';
/**
 * nucleicAcid
 *
 * SubstanceDefinition.nucleicAcid: Data items specific to nucleic acids.
 *
 * http://hl7.org/fhir/nucleicAcid
 */
var nucleicAcid = 'http://hl7.org/fhir/nucleicAcid';
/**
 * implementation
 *
 * TerminologyCapabilities.implementation: Identifies a specific implementation instance that is described by the terminology capability statement - i.e. a particular installation, rather than the capabilities of a software program.
 *
 * http://hl7.org/fhir/implementation
 */
var implementation = 'http://hl7.org/fhir/implementation';
/**
 * _species
 *
 * (Modified) SubstanceSourceMaterial.organism.species
 *
 * http://hl7.org/fhir/_species
 */
var _species = 'http://hl7.org/fhir/_species';
/**
 * _goalId
 *
 * (Modified) PlanDefinition.action.action.goalId
 *
 * http://hl7.org/fhir/_goalId
 */
var _goalId = 'http://hl7.org/fhir/_goalId';
/**
 * manager
 *
 * Consent.manager: The actor that manages the consent through its lifecycle.
 *
 * http://hl7.org/fhir/manager
 */
var manager = 'http://hl7.org/fhir/manager';
/**
 * Meta
 *
 * The metadata about a resource. This is content in the resource that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.
 *
 * http://hl7.org/fhir/Meta
 */
var Meta = 'http://hl7.org/fhir/Meta';
/**
 * interpreter
 *
 * GenomicStudy.interpreter: Healthcare professionals who interpreted the genomic study.
 *
 * http://hl7.org/fhir/interpreter
 */
var interpreter = 'http://hl7.org/fhir/interpreter';
/**
 * situation
 *
 * MessageDefinition.allowedResponse.situation: Provides a description of the circumstances in which this response should be used (as opposed to one of the alternative responses).
 *
 * http://hl7.org/fhir/situation
 */
var situation = 'http://hl7.org/fhir/situation';
/**
 * _recorded
 *
 * (Modified) Provenance.recorded
 *
 * http://hl7.org/fhir/_recorded
 */
var _recorded = 'http://hl7.org/fhir/_recorded';
/**
 * DiagnosticReport
 *
 * The findings and interpretation of diagnostic tests performed on patients, groups of patients, products, substances, devices, and locations, and/or specimens derived from these. The report includes clinical context such as requesting provider information, and some mix of atomic results, images, textual and coded interpretations, and formatted representation of diagnostic reports. The report also includes non-clinical context such as batch analysis and stability reporting of products and substances.
 *
 * http://hl7.org/fhir/DiagnosticReport
 */
var DiagnosticReport = 'http://hl7.org/fhir/DiagnosticReport';
/**
 * drugCharacteristic
 *
 * MedicationKnowledge.definitional.drugCharacteristic: Specifies descriptive properties of the medicine, such as color, shape, imprints, etc.
 *
 * http://hl7.org/fhir/drugCharacteristic
 */
var drugCharacteristic = 'http://hl7.org/fhir/drugCharacteristic';
/**
 * SubstanceDefinitionStructureRepresentationComponent
 *
 * SubstanceDefinitionStructureComponent.SubstanceDefinitionStructureRepresentationComponent: A depiction of the structure of the substance.
 *
 * http://hl7.org/fhir/SubstanceDefinitionStructureRepresentationComponent
 */
var SubstanceDefinitionStructureRepresentationComponent = 'http://hl7.org/fhir/SubstanceDefinitionStructureRepresentationComponent';
/**
 * RequestOrchestrationActionRelatedActionComponent
 *
 * RequestOrchestrationActionComponentAction.RequestOrchestrationActionRelatedActionComponent: A relationship to another action such as "before" or "30-60 minutes after start of".
 *
 * http://hl7.org/fhir/RequestOrchestrationActionRelatedActionComponent
 */
var RequestOrchestrationActionRelatedActionComponent = 'http://hl7.org/fhir/RequestOrchestrationActionRelatedActionComponent';
/**
 * variableRole
 *
 * Evidence.variableDefinition.variableRole: population | subpopulation | exposure | referenceExposure | measuredVariable | confounder.
 *
 * http://hl7.org/fhir/variableRole
 */
var variableRole = 'http://hl7.org/fhir/variableRole';
/**
 * failureAction
 *
 * VerificationResult.failureAction: The result if validation fails (fatal; warning; record only; none).
 *
 * http://hl7.org/fhir/failureAction
 */
var failureAction = 'http://hl7.org/fhir/failureAction';
/**
 * suppliedItem
 *
 * SupplyDelivery.suppliedItem: The item that is being delivered or has been supplied.
 *
 * http://hl7.org/fhir/suppliedItem
 */
var suppliedItem = 'http://hl7.org/fhir/suppliedItem';
/**
 * abstract
 *
 * StructureDefinition.abstract: Whether structure this definition describes is abstract or not  - that is, whether the structure is not intended to be instantiated. For Resources and Data types, abstract types will never be exchanged  between systems.
 *
 * http://hl7.org/fhir/abstract
 */
var abstract = 'http://hl7.org/fhir/abstract';
/**
 * valueRange
 *
 * Evidence.statistic.modelCharacteristic.variable.valueRange: Range of values for grouping of ordinal or polychotomous variables.
 *
 * http://hl7.org/fhir/valueRange
 */
var valueRange = 'http://hl7.org/fhir/valueRange';
/**
 * _query
 *
 * (Modified) AuditEvent.entity.query
 *
 * http://hl7.org/fhir/_query
 */
var _query = 'http://hl7.org/fhir/_query';
/**
 * sigFormat
 *
 * Signature.sigFormat: A mime type that indicates the technical format of the signature. Important mime types are application/signature+xml for X ML DigSig, application/jose for JWS, and image/* for a graphical image of a signature, etc.
 *
 * http://hl7.org/fhir/sigFormat
 */
var sigFormat = 'http://hl7.org/fhir/sigFormat';
/**
 * VirtualServiceDetail
 *
 * Virtual Service Contact Details.
 *
 * http://hl7.org/fhir/VirtualServiceDetail
 */
var VirtualServiceDetail = 'http://hl7.org/fhir/VirtualServiceDetail';
/**
 * _rest
 *
 * (Modified) CapabilityStatement.rest
 *
 * http://hl7.org/fhir/_rest
 */
var _rest = 'http://hl7.org/fhir/_rest';
/**
 * packageCode
 *
 * Account.procedure.packageCode: The package code can be used to group procedures that may be priced or delivered as a single product. Such as DRGs.
 *
 * http://hl7.org/fhir/packageCode
 */
var packageCode = 'http://hl7.org/fhir/packageCode';
/**
 * _reaction
 *
 * (Modified) Immunization.reaction
 *
 * http://hl7.org/fhir/_reaction
 */
var _reaction = 'http://hl7.org/fhir/_reaction';
/**
 * _contributor
 *
 * (Modified) Citation.citedArtifact.contributorship.entry.contributor
 *
 * http://hl7.org/fhir/_contributor
 */
var _contributor = 'http://hl7.org/fhir/_contributor';
/**
 * _normalValue
 *
 * (Modified) Observation.component.referenceRange.normalValue
 *
 * http://hl7.org/fhir/_normalValue
 */
var _normalValue = 'http://hl7.org/fhir/_normalValue';
/**
 * _resultsInterpreter
 *
 * (Modified) DiagnosticReport.resultsInterpreter
 *
 * http://hl7.org/fhir/_resultsInterpreter
 */
var _resultsInterpreter = 'http://hl7.org/fhir/_resultsInterpreter';
/**
 * _tester
 *
 * (Modified) TestReport.tester
 *
 * http://hl7.org/fhir/_tester
 */
var _tester = 'http://hl7.org/fhir/_tester';
/**
 * denominator
 *
 * RatioRange.denominator: The value of the denominator.
 *
 * http://hl7.org/fhir/denominator
 */
var denominator = 'http://hl7.org/fhir/denominator';
/**
 * uniqueId
 *
 * NamingSystem.uniqueId: Indicates how the system may be identified when referenced in electronic exchange.
 *
 * http://hl7.org/fhir/uniqueId
 */
var uniqueId = 'http://hl7.org/fhir/uniqueId';
/**
 * readOnly
 *
 * Questionnaire.item.item.readOnly: An indication, when true, that the value cannot be changed by a human respondent to the Questionnaire.
 *
 * http://hl7.org/fhir/readOnly
 */
var readOnly = 'http://hl7.org/fhir/readOnly';
/**
 * _effectiveDosePeriod
 *
 * (Modified) MedicationRequest.effectiveDosePeriod
 *
 * http://hl7.org/fhir/_effectiveDosePeriod
 */
var _effectiveDosePeriod = 'http://hl7.org/fhir/_effectiveDosePeriod';
/**
 * _patientInstruction
 *
 * (Modified) ServiceRequest.patientInstruction
 *
 * http://hl7.org/fhir/_patientInstruction
 */
var _patientInstruction = 'http://hl7.org/fhir/_patientInstruction';
/**
 * focusReference
 *
 * EvidenceReport.section.section.focusReference: A definitional Resource identifying the kind of content contained within the section. This should be consistent with the section title.
 *
 * http://hl7.org/fhir/focusReference
 */
var focusReference = 'http://hl7.org/fhir/focusReference';
/**
 * _sopClass
 *
 * (Modified) ImagingStudy.series.instance.sopClass
 *
 * http://hl7.org/fhir/_sopClass
 */
var _sopClass = 'http://hl7.org/fhir/_sopClass';
/**
 * _brand
 *
 * (Modified) VisionPrescription.lensSpecification.brand
 *
 * http://hl7.org/fhir/_brand
 */
var _brand = 'http://hl7.org/fhir/_brand';
/**
 * SubscriptionStatusNotificationEventComponent
 *
 * SubscriptionStatusNotificationEventComponent: Detailed information about events relevant to this subscription notification.
 *
 * http://hl7.org/fhir/SubscriptionStatusNotificationEventComponent
 */
var SubscriptionStatusNotificationEventComponent = 'http://hl7.org/fhir/SubscriptionStatusNotificationEventComponent';
/**
 * specialArrangement
 *
 * Encounter.specialArrangement: Any special requests that have been made for this encounter, such as the provision of specific equipment or other things.
 *
 * http://hl7.org/fhir/specialArrangement
 */
var specialArrangement = 'http://hl7.org/fhir/specialArrangement';
/**
 * _autocreate
 *
 * (Modified) TestScript.fixture.autocreate
 *
 * http://hl7.org/fhir/_autocreate
 */
var _autocreate = 'http://hl7.org/fhir/_autocreate';
/**
 * _responsibility
 *
 * (Modified) Coverage.paymentBy.responsibility
 *
 * http://hl7.org/fhir/_responsibility
 */
var _responsibility = 'http://hl7.org/fhir/_responsibility';
/**
 * any
 *
 * ElementDefinition.binding.additional.any: Whether the binding applies to all repeats, or just to any one of them. This is only relevant for elements that can repeat.
 *
 * http://hl7.org/fhir/any
 */
var any = 'http://hl7.org/fhir/any';
/**
 * protocolApplied
 *
 * Immunization.protocolApplied: The protocol (set of recommendations) being followed by the provider who administered the dose.
 *
 * http://hl7.org/fhir/protocolApplied
 */
var protocolApplied = 'http://hl7.org/fhir/protocolApplied';
/**
 * PaymentNotice
 *
 * This resource provides the status of the payment for goods and services rendered, and the request and response resource references.
 *
 * http://hl7.org/fhir/PaymentNotice
 */
var PaymentNotice = 'http://hl7.org/fhir/PaymentNotice';
/**
 * _completionTime
 *
 * (Modified) Transport.completionTime
 *
 * http://hl7.org/fhir/_completionTime
 */
var _completionTime = 'http://hl7.org/fhir/_completionTime';
/**
 * _preAdmissionIdentifier
 *
 * (Modified) Encounter.admission.preAdmissionIdentifier
 *
 * http://hl7.org/fhir/_preAdmissionIdentifier
 */
var _preAdmissionIdentifier = 'http://hl7.org/fhir/_preAdmissionIdentifier';
/**
 * _interpretation
 *
 * (Modified) Observation.component.interpretation
 *
 * http://hl7.org/fhir/_interpretation
 */
var _interpretation = 'http://hl7.org/fhir/_interpretation';
/**
 * testingDestination
 *
 * SpecimenDefinition.typeTested.testingDestination: Where the specimen will be tested: e.g., lab, sector, device or any combination of these.
 *
 * http://hl7.org/fhir/testingDestination
 */
var testingDestination = 'http://hl7.org/fhir/testingDestination';
/**
 * ExtendedContactDetail
 *
 * Specifies contact information for a specific purpose over a period of time, might be handled/monitored by a specific named person or organization.
 *
 * http://hl7.org/fhir/ExtendedContactDetail
 */
var ExtendedContactDetail = 'http://hl7.org/fhir/ExtendedContactDetail';
/**
 * administrableDoseForm
 *
 * AdministrableProductDefinition.administrableDoseForm: The dose form of the final product after necessary reconstitution or processing. Contrasts to the manufactured dose form (see ManufacturedItemDefinition). If the manufactured form was 'powder for solution for injection', the administrable dose form could be 'solution for injection' (once mixed with another item having manufactured form 'solvent for solution for injection').
 *
 * http://hl7.org/fhir/administrableDoseForm
 */
var administrableDoseForm = 'http://hl7.org/fhir/administrableDoseForm';
/**
 * repeat
 *
 * SubstancePolymer.repeat: Specifies and quantifies the repeated units and their configuration.
 *
 * http://hl7.org/fhir/repeat
 */
var repeat = 'http://hl7.org/fhir/repeat';
/**
 * CapabilityStatementRestResourceSearchParamComponent
 *
 * CapabilityStatementRestComponent.CapabilityStatementRestResourceComponent.CapabilityStatementRestResourceSearchParamComponent: Search parameters for implementations to support and/or make use of - either references to ones defined in the specification, or additional ones defined for/by the implementation.
 *
 * http://hl7.org/fhir/CapabilityStatementRestResourceSearchParamComponent
 */
var CapabilityStatementRestResourceSearchParamComponent = 'http://hl7.org/fhir/CapabilityStatementRestResourceSearchParamComponent';
/**
 * interactant
 *
 * ClinicalUseDefinition.interaction.interactant: The specific medication, product, food, substance etc. or laboratory test that interacts.
 *
 * http://hl7.org/fhir/interactant
 */
var interactant = 'http://hl7.org/fhir/interactant';
/**
 * _groupDefinition
 *
 * (Modified) Measure.group.stratifier.component.groupDefinition
 *
 * http://hl7.org/fhir/_groupDefinition
 */
var _groupDefinition = 'http://hl7.org/fhir/_groupDefinition';
/**
 * _effective
 *
 * (Modified) Observation.effective
 *
 * http://hl7.org/fhir/_effective
 */
var _effective = 'http://hl7.org/fhir/_effective';
/**
 * _service
 *
 * (Modified) ChargeItem.service
 *
 * http://hl7.org/fhir/_service
 */
var _service = 'http://hl7.org/fhir/_service';
/**
 * admitSource
 *
 * Encounter.admission.admitSource: From where patient was admitted (physician referral, transfer).
 *
 * http://hl7.org/fhir/admitSource
 */
var admitSource = 'http://hl7.org/fhir/admitSource';
/**
 * _cap
 *
 * (Modified) SpecimenDefinition.typeTested.container.cap
 *
 * http://hl7.org/fhir/_cap
 */
var _cap = 'http://hl7.org/fhir/_cap';
/**
 * _structure
 *
 * (Modified) SubstanceDefinition.structure
 *
 * http://hl7.org/fhir/_structure
 */
var _structure = 'http://hl7.org/fhir/_structure';
/**
 * _preferred
 *
 * (Modified) SubstanceDefinition.name.translation.preferred
 *
 * http://hl7.org/fhir/_preferred
 */
var _preferred = 'http://hl7.org/fhir/_preferred';
/**
 * human
 *
 * ElementDefinition.constraint.human: Text that can be used to describe the constraint in messages identifying that the constraint has been violated.
 *
 * http://hl7.org/fhir/human
 */
var human = 'http://hl7.org/fhir/human';
/**
 * _genomeAssembly
 *
 * (Modified) MolecularSequence.relative.startingSequence.genomeAssembly
 *
 * http://hl7.org/fhir/_genomeAssembly
 */
var _genomeAssembly = 'http://hl7.org/fhir/_genomeAssembly';
/**
 * _dimensions
 *
 * (Modified) SampledData.dimensions
 *
 * http://hl7.org/fhir/_dimensions
 */
var _dimensions = 'http://hl7.org/fhir/_dimensions';
/**
 * Reason
 *
 * Encounter.Reason: The list of medical reasons that are expected to be addressed during the episode of care.
 *
 * http://hl7.org/fhir/Reason
 */
var Reason = 'http://hl7.org/fhir/Reason';
/**
 * eligibility
 *
 * ResearchStudy.recruitment.eligibility: Inclusion and exclusion criteria.
 *
 * http://hl7.org/fhir/eligibility
 */
var eligibility = 'http://hl7.org/fhir/eligibility';
/**
 * resultForCreate
 *
 * SubscriptionTopic.resourceTrigger.queryCriteria.resultForCreate: For `create` interactions, should the `previous` criteria count as an automatic pass or an automatic fail. If not present, the testing behavior during `create` interactions is unspecified (server discretion).
 *
 * http://hl7.org/fhir/resultForCreate
 */
var resultForCreate = 'http://hl7.org/fhir/resultForCreate';
/**
 * PersonLinkComponent
 *
 * PersonLinkComponent: Link to a resource that concerns the same actual person.
 *
 * http://hl7.org/fhir/PersonLinkComponent
 */
var PersonLinkComponent = 'http://hl7.org/fhir/PersonLinkComponent';
/**
 * EvidenceCertaintyComponent
 *
 * EvidenceCertaintyComponent: Assessment of certainty, confidence in the estimates, or quality of the evidence.
 *
 * http://hl7.org/fhir/EvidenceCertaintyComponent
 */
var EvidenceCertaintyComponent = 'http://hl7.org/fhir/EvidenceCertaintyComponent';
/**
 * texture
 *
 * NutritionOrder.oralDiet.texture: Class that describes any texture modifications required for the patient to safely consume various types of solid foods.
 *
 * http://hl7.org/fhir/texture
 */
var texture = 'http://hl7.org/fhir/texture';
/**
 * characterization
 *
 * SubstanceDefinition.characterization: General specifications for this substance.
 *
 * http://hl7.org/fhir/characterization
 */
var characterization = 'http://hl7.org/fhir/characterization';
/**
 * TerminologyCapabilitiesExpansionComponent
 *
 * TerminologyCapabilitiesExpansionComponent: Information about the [ValueSet/$expand](valueset-operation-expand.html) operation.
 *
 * http://hl7.org/fhir/TerminologyCapabilitiesExpansionComponent
 */
var TerminologyCapabilitiesExpansionComponent = 'http://hl7.org/fhir/TerminologyCapabilitiesExpansionComponent';
/**
 * DataRequirementCodeFilterComponent
 *
 * DataRequirementCodeFilterComponent: Code filters specify additional constraints on the data, specifying the value set of interest for a particular element of the data. Each code filter defines an additional constraint on the data, i.e. code filters are AND'ed, not OR'ed.
 *
 * http://hl7.org/fhir/DataRequirementCodeFilterComponent
 */
var DataRequirementCodeFilterComponent = 'http://hl7.org/fhir/DataRequirementCodeFilterComponent';
/**
 * _derivedFrom
 *
 * (Modified) Requirements.statement.derivedFrom
 *
 * http://hl7.org/fhir/_derivedFrom
 */
var _derivedFrom = 'http://hl7.org/fhir/_derivedFrom';
/**
 * _doseAdministrationAid
 *
 * (Modified) MedicationRequest.dispenseRequest.doseAdministrationAid
 *
 * http://hl7.org/fhir/_doseAdministrationAid
 */
var _doseAdministrationAid = 'http://hl7.org/fhir/_doseAdministrationAid';
/**
 * productOrService
 *
 * ExplanationOfBenefit.item.detail.subDetail.productOrService: When the value is a group code then this item collects a set of related item details, otherwise this contains the product, service, drug or other billing code for the item. This element may be the start of a range of .productOrService codes used in conjunction with .productOrServiceEnd or it may be a solo element where .productOrServiceEnd is not used.
 *
 * http://hl7.org/fhir/productOrService
 */
var productOrService = 'http://hl7.org/fhir/productOrService';
/**
 * _plannedEndDate
 *
 * (Modified) EncounterHistory.plannedEndDate
 *
 * http://hl7.org/fhir/_plannedEndDate
 */
var _plannedEndDate = 'http://hl7.org/fhir/_plannedEndDate';
/**
 * conformsTo
 *
 * DeviceDefinition.conformsTo: Identifies the standards, specifications, or formal guidances for the capabilities supported by the device. The device may be certified as conformant to these specifications e.g., communication, performance, process, measurement, or specialization standards.
 *
 * http://hl7.org/fhir/conformsTo
 */
var conformsTo = 'http://hl7.org/fhir/conformsTo';
/**
 * _detected
 *
 * (Modified) AdverseEvent.detected
 *
 * http://hl7.org/fhir/_detected
 */
var _detected = 'http://hl7.org/fhir/_detected';
/**
 * _threePrime
 *
 * (Modified) SubstanceNucleicAcid.subunit.threePrime
 *
 * http://hl7.org/fhir/_threePrime
 */
var _threePrime = 'http://hl7.org/fhir/_threePrime';
/**
 * referencedFrom
 *
 * OperationDefinition.parameter.part.referencedFrom: Identifies other resource parameters within the operation invocation that are expected to resolve to this resource.
 *
 * http://hl7.org/fhir/referencedFrom
 */
var referencedFrom = 'http://hl7.org/fhir/referencedFrom';
/**
 * targetFormat
 *
 * Signature.targetFormat: A mime type that indicates the technical format of the target resources signed by the signature.
 *
 * http://hl7.org/fhir/targetFormat
 */
var targetFormat = 'http://hl7.org/fhir/targetFormat';
/**
 * _characteristicType
 *
 * (Modified) InventoryItem.characteristic.characteristicType
 *
 * http://hl7.org/fhir/_characteristicType
 */
var _characteristicType = 'http://hl7.org/fhir/_characteristicType';
/**
 * StructureDefinitionMappingComponent
 *
 * StructureDefinitionMappingComponent: An external specification that the content is mapped to.
 *
 * http://hl7.org/fhir/StructureDefinitionMappingComponent
 */
var StructureDefinitionMappingComponent = 'http://hl7.org/fhir/StructureDefinitionMappingComponent';
/**
 * _initiatorActive
 *
 * (Modified) ExampleScenario.process.step.alternative.step.operation.initiatorActive
 *
 * http://hl7.org/fhir/_initiatorActive
 */
var _initiatorActive = 'http://hl7.org/fhir/_initiatorActive';
/**
 * supportedInteraction
 *
 * SubscriptionTopic.resourceTrigger.supportedInteraction: The FHIR RESTful interaction which can be used to trigger a notification for the SubscriptionTopic. Multiple values are considered OR joined (e.g., CREATE or UPDATE). If not present, all supported interactions are assumed.
 *
 * http://hl7.org/fhir/supportedInteraction
 */
var supportedInteraction = 'http://hl7.org/fhir/supportedInteraction';
/**
 * vaccineCode
 *
 * ImmunizationRecommendation.recommendation.vaccineCode: Vaccine(s) or vaccine group that pertain to the recommendation.
 *
 * http://hl7.org/fhir/vaccineCode
 */
var vaccineCode = 'http://hl7.org/fhir/vaccineCode';
/**
 * seriesNumber
 *
 * ImagingSelection.seriesNumber: The Series Number for the DICOM Series from which the images were selected.
 *
 * http://hl7.org/fhir/seriesNumber
 */
var seriesNumber = 'http://hl7.org/fhir/seriesNumber';
/**
 * pageCount
 *
 * Citation.citedArtifact.publicationForm.pageCount: Actual or approximate number of pages or screens. Distinct from reporting the page numbers.
 *
 * http://hl7.org/fhir/pageCount
 */
var pageCount = 'http://hl7.org/fhir/pageCount';
/**
 * _who
 *
 * (Modified) VerificationResult.attestation.who
 *
 * http://hl7.org/fhir/_who
 */
var _who = 'http://hl7.org/fhir/_who';
/**
 * PermissionRuleActivityComponent
 *
 * Permission.Rule.PermissionRuleActivityComponent: A description or definition of which activities are allowed to be done on the data.
 *
 * http://hl7.org/fhir/PermissionRuleActivityComponent
 */
var PermissionRuleActivityComponent = 'http://hl7.org/fhir/PermissionRuleActivityComponent';
/**
 * careManager
 *
 * EpisodeOfCare.careManager: The practitioner that is the care manager/care coordinator for this patient.
 *
 * http://hl7.org/fhir/careManager
 */
var careManager = 'http://hl7.org/fhir/careManager';
/**
 * CodeSystem
 *
 * The CodeSystem resource is used to declare the existence of and describe a code system or code system supplement and its key properties, and optionally define a part or all of its content.
 *
 * http://hl7.org/fhir/CodeSystem
 */
var CodeSystem = 'http://hl7.org/fhir/CodeSystem';
/**
 * MedicinalProductDefinitionNamePartComponent
 *
 * MedicinalProductDefinitionNameComponent.MedicinalProductDefinitionNamePartComponent: Coding words or phrases of the name.
 *
 * http://hl7.org/fhir/MedicinalProductDefinitionNamePartComponent
 */
var MedicinalProductDefinitionNamePartComponent = 'http://hl7.org/fhir/MedicinalProductDefinitionNamePartComponent';
/**
 * _requestingOrganization
 *
 * (Modified) ChargeItem.requestingOrganization
 *
 * http://hl7.org/fhir/_requestingOrganization
 */
var _requestingOrganization = 'http://hl7.org/fhir/_requestingOrganization';
/**
 * _referralMethod
 *
 * (Modified) HealthcareService.referralMethod
 *
 * http://hl7.org/fhir/_referralMethod
 */
var _referralMethod = 'http://hl7.org/fhir/_referralMethod';
/**
 * _suspectEntity
 *
 * (Modified) AdverseEvent.suspectEntity
 *
 * http://hl7.org/fhir/_suspectEntity
 */
var _suspectEntity = 'http://hl7.org/fhir/_suspectEntity';
/**
 * _exclusionCriteria
 *
 * (Modified) ValueSet.scope.exclusionCriteria
 *
 * http://hl7.org/fhir/_exclusionCriteria
 */
var _exclusionCriteria = 'http://hl7.org/fhir/_exclusionCriteria';
/**
 * ObservationComponentComponent
 *
 * ObservationComponentComponent: Some observations have multiple component observations.  These component observations are expressed as separate code value pairs that share the same attributes.  Examples include systolic and diastolic component observations for blood pressure measurement and multiple component observations for genetics observations.
 *
 * http://hl7.org/fhir/ObservationComponentComponent
 */
var ObservationComponentComponent = 'http://hl7.org/fhir/ObservationComponentComponent';
/**
 * _testScript
 *
 * (Modified) TestReport.testScript
 *
 * http://hl7.org/fhir/_testScript
 */
var _testScript = 'http://hl7.org/fhir/_testScript';
/**
 * manufactureDate
 *
 * Device.manufactureDate: The date and time when the device was manufactured.
 *
 * http://hl7.org/fhir/manufactureDate
 */
var manufactureDate = 'http://hl7.org/fhir/manufactureDate';
/**
 * _textPresentation
 *
 * (Modified) Ingredient.substance.strength.textPresentation
 *
 * http://hl7.org/fhir/_textPresentation
 */
var _textPresentation = 'http://hl7.org/fhir/_textPresentation';
/**
 * TestReportSetupActionOperationComponent
 *
 * TestReportSetupComponent.SetupAction.TestReportSetupActionOperationComponent: The operation performed.
 *
 * http://hl7.org/fhir/TestReportSetupActionOperationComponent
 */
var TestReportSetupActionOperationComponent = 'http://hl7.org/fhir/TestReportSetupActionOperationComponent';
/**
 * legal
 *
 * Contract.legal: List of Legal expressions or representations of this Contract.
 *
 * http://hl7.org/fhir/legal
 */
var legal = 'http://hl7.org/fhir/legal';
/**
 * provider
 *
 * ExplanationOfBenefit.addItem.provider: The providers who are authorized for the services rendered to the patient.
 *
 * http://hl7.org/fhir/provider
 */
var provider = 'http://hl7.org/fhir/provider';
/**
 * exitCriteria
 *
 * TestPlan.exitCriteria: The threshold or criteria for the test plan to be considered successfully executed - narrative.
 *
 * http://hl7.org/fhir/exitCriteria
 */
var exitCriteria = 'http://hl7.org/fhir/exitCriteria';
/**
 * image
 *
 * ImplementationGuide.manifest.image: Indicates a relative path to an image that exists within the IG.
 *
 * http://hl7.org/fhir/image
 */
var image = 'http://hl7.org/fhir/image';
/**
 * SupplyRequest
 *
 * A record of a non-patient specific request for a medication, substance, device, certain types of biologically derived product, and nutrition product used in the healthcare setting.
 *
 * http://hl7.org/fhir/SupplyRequest
 */
var SupplyRequest = 'http://hl7.org/fhir/SupplyRequest';
/**
 * _periodMax
 *
 * (Modified) Timing.repeat.periodMax
 *
 * http://hl7.org/fhir/_periodMax
 */
var _periodMax = 'http://hl7.org/fhir/_periodMax';
/**
 * _monograph
 *
 * (Modified) MedicationKnowledge.monograph
 *
 * http://hl7.org/fhir/_monograph
 */
var _monograph = 'http://hl7.org/fhir/_monograph';
/**
 * _decision
 *
 * (Modified) ExplanationOfBenefit.item.detail.subDetail.reviewOutcome.decision
 *
 * http://hl7.org/fhir/_decision
 */
var _decision = 'http://hl7.org/fhir/_decision';
/**
 * _diagnostics
 *
 * (Modified) OperationOutcome.issue.diagnostics
 *
 * http://hl7.org/fhir/_diagnostics
 */
var _diagnostics = 'http://hl7.org/fhir/_diagnostics';
/**
 * _origin
 *
 * (Modified) TestScript.teardown.action.operation.origin
 *
 * http://hl7.org/fhir/_origin
 */
var _origin = 'http://hl7.org/fhir/_origin';
/**
 * _durationUnit
 *
 * (Modified) Timing.repeat.durationUnit
 *
 * http://hl7.org/fhir/_durationUnit
 */
var _durationUnit = 'http://hl7.org/fhir/_durationUnit';
/**
 * contact
 *
 * MessageHeader.source.contact: An e-mail, phone, website or other contact point to use to resolve issues with message communications.
 *
 * http://hl7.org/fhir/contact
 */
var contact = 'http://hl7.org/fhir/contact';
/**
 * _disabledDisplay
 *
 * (Modified) Questionnaire.item.item.disabledDisplay
 *
 * http://hl7.org/fhir/_disabledDisplay
 */
var _disabledDisplay = 'http://hl7.org/fhir/_disabledDisplay';
/**
 * _attestation
 *
 * (Modified) VerificationResult.attestation
 *
 * http://hl7.org/fhir/_attestation
 */
var _attestation = 'http://hl7.org/fhir/_attestation';
/**
 * PackagedProductDefinitionPackagingComponentPackaging
 *
 * Allows containers (and parts of containers) within containers, still as a part of a single packaged product. See also PackagedProductDefinition.packaging.containedItem.item(PackagedProductDefinition).
 *
 * http://hl7.org/fhir/PackagedProductDefinitionPackagingComponentPackaging
 */
var PackagedProductDefinitionPackagingComponentPackaging = 'http://hl7.org/fhir/PackagedProductDefinitionPackagingComponentPackaging';
/**
 * OperationOutcomeIssueComponent
 *
 * OperationOutcomeIssueComponent: An error, warning, or information message that results from a system action.
 *
 * http://hl7.org/fhir/OperationOutcomeIssueComponent
 */
var OperationOutcomeIssueComponent = 'http://hl7.org/fhir/OperationOutcomeIssueComponent';
/**
 * _hash
 *
 * (Modified) Attachment.hash
 *
 * http://hl7.org/fhir/_hash
 */
var _hash = 'http://hl7.org/fhir/_hash';
/**
 * _pageString
 *
 * (Modified) Citation.citedArtifact.publicationForm.pageString
 *
 * http://hl7.org/fhir/_pageString
 */
var _pageString = 'http://hl7.org/fhir/_pageString';
/**
 * _constituent
 *
 * (Modified) ManufacturedItemDefinition.component.component.constituent
 *
 * http://hl7.org/fhir/_constituent
 */
var _constituent = 'http://hl7.org/fhir/_constituent';
/**
 * DeviceAssociation
 *
 * A record of association of a device.
 *
 * http://hl7.org/fhir/DeviceAssociation
 */
var DeviceAssociation = 'http://hl7.org/fhir/DeviceAssociation';
/**
 * _dayOfWeek
 *
 * (Modified) Appointment.recurrenceTemplate.monthlyTemplate.dayOfWeek
 *
 * http://hl7.org/fhir/_dayOfWeek
 */
var _dayOfWeek = 'http://hl7.org/fhir/_dayOfWeek';
/**
 * _inventoryListing
 *
 * (Modified) InventoryReport.inventoryListing
 *
 * http://hl7.org/fhir/_inventoryListing
 */
var _inventoryListing = 'http://hl7.org/fhir/_inventoryListing';
/**
 * _hierarchyMeaning
 *
 * (Modified) CodeSystem.hierarchyMeaning
 *
 * http://hl7.org/fhir/_hierarchyMeaning
 */
var _hierarchyMeaning = 'http://hl7.org/fhir/_hierarchyMeaning';
/**
 * _dispenseRequest
 *
 * (Modified) MedicationRequest.dispenseRequest
 *
 * http://hl7.org/fhir/_dispenseRequest
 */
var _dispenseRequest = 'http://hl7.org/fhir/_dispenseRequest';
/**
 * legallyBinding
 *
 * Contract.legallyBinding
 *
 * http://hl7.org/fhir/legallyBinding
 */
var legallyBinding = 'http://hl7.org/fhir/legallyBinding';
/**
 * _manufacturer
 *
 * (Modified) SubstanceDefinition.manufacturer
 *
 * http://hl7.org/fhir/_manufacturer
 */
var _manufacturer = 'http://hl7.org/fhir/_manufacturer';
/**
 * _answerConstraint
 *
 * (Modified) Questionnaire.item.item.answerConstraint
 *
 * http://hl7.org/fhir/_answerConstraint
 */
var _answerConstraint = 'http://hl7.org/fhir/_answerConstraint';
/**
 * _when
 *
 * (Modified) ClaimResponse.event.when
 *
 * http://hl7.org/fhir/_when
 */
var _when = 'http://hl7.org/fhir/_when';
/**
 * _form
 *
 * (Modified) SubstanceDefinition.characterization.form
 *
 * http://hl7.org/fhir/_form
 */
var _form = 'http://hl7.org/fhir/_form';
/**
 * businessStatus
 *
 * Task.businessStatus: Contains business-specific nuances of the business state.
 *
 * http://hl7.org/fhir/businessStatus
 */
var businessStatus = 'http://hl7.org/fhir/businessStatus';
/**
 * comparisonGroup
 *
 * ResearchStudy.comparisonGroup: Describes an expected event or sequence of events for one of the subjects of a study. E.g. for a living subject: exposure to drug A, wash-out, exposure to drug B, wash-out, follow-up. E.g. for a stability study: {store sample from lot A at 25 degrees for 1 month}, {store sample from lot A at 40 degrees for 1 month}.
 *
 * http://hl7.org/fhir/comparisonGroup
 */
var comparisonGroup = 'http://hl7.org/fhir/comparisonGroup';
/**
 * _instance
 *
 * (Modified) ExampleScenario.instance
 *
 * http://hl7.org/fhir/_instance
 */
var _instance = 'http://hl7.org/fhir/_instance';
/**
 * _itemStatus
 *
 * (Modified) InventoryReport.inventoryListing.itemStatus
 *
 * http://hl7.org/fhir/_itemStatus
 */
var _itemStatus = 'http://hl7.org/fhir/_itemStatus';
/**
 * _conditionalDelete
 *
 * (Modified) CapabilityStatement.rest.resource.conditionalDelete
 *
 * http://hl7.org/fhir/_conditionalDelete
 */
var _conditionalDelete = 'http://hl7.org/fhir/_conditionalDelete';
/**
 * _grade
 *
 * (Modified) SubstanceDefinition.grade
 *
 * http://hl7.org/fhir/_grade
 */
var _grade = 'http://hl7.org/fhir/_grade';
/**
 * _process
 *
 * (Modified) ExampleScenario.process.step.alternative.step.process
 *
 * http://hl7.org/fhir/_process
 */
var _process = 'http://hl7.org/fhir/_process';
/**
 * _articleDate
 *
 * (Modified) Citation.citedArtifact.publicationForm.articleDate
 *
 * http://hl7.org/fhir/_articleDate
 */
var _articleDate = 'http://hl7.org/fhir/_articleDate';
/**
 * additionalMonitoringIndicator
 *
 * MedicinalProductDefinition.additionalMonitoringIndicator: Whether the Medicinal Product is subject to additional monitoring for regulatory reasons, such as heightened reporting requirements.
 *
 * http://hl7.org/fhir/additionalMonitoringIndicator
 */
var additionalMonitoringIndicator = 'http://hl7.org/fhir/additionalMonitoringIndicator';
/**
 * title
 *
 * ValueSet.title: A short, descriptive, user-friendly title for the value set.
 *
 * http://hl7.org/fhir/title
 */
var title = 'http://hl7.org/fhir/title';
/**
 * _courseOfTherapyType
 *
 * (Modified) MedicationRequest.courseOfTherapyType
 *
 * http://hl7.org/fhir/_courseOfTherapyType
 */
var _courseOfTherapyType = 'http://hl7.org/fhir/_courseOfTherapyType';
/**
 * _identity
 *
 * (Modified) StructureDefinition.mapping.identity
 *
 * http://hl7.org/fhir/_identity
 */
var _identity = 'http://hl7.org/fhir/_identity';
/**
 * CapabilityStatementRestComponent
 *
 * CapabilityStatementRestComponent: A definition of the restful capabilities of the solution, if any.
 *
 * http://hl7.org/fhir/CapabilityStatementRestComponent
 */
var CapabilityStatementRestComponent = 'http://hl7.org/fhir/CapabilityStatementRestComponent';
/**
 * additionalAttribute
 *
 * ConceptMap.additionalAttribute: An additionalAttribute defines an additional data element found in the source or target data model where the data will come from or be mapped to. Some mappings are based on data in addition to the source data element, where codes in multiple fields are combined to a single field (or vice versa).
 *
 * http://hl7.org/fhir/additionalAttribute
 */
var additionalAttribute = 'http://hl7.org/fhir/additionalAttribute';
/**
 * monomerSet
 *
 * SubstancePolymer.monomerSet: Todo.
 *
 * http://hl7.org/fhir/monomerSet
 */
var monomerSet = 'http://hl7.org/fhir/monomerSet';
/**
 * ingredient
 *
 * Medication.ingredient: Identifies a particular constituent of interest in the product.
 *
 * http://hl7.org/fhir/ingredient
 */
var ingredient = 'http://hl7.org/fhir/ingredient';
/**
 * _subPotentReason
 *
 * (Modified) MedicationAdministration.subPotentReason
 *
 * http://hl7.org/fhir/_subPotentReason
 */
var _subPotentReason = 'http://hl7.org/fhir/_subPotentReason';
/**
 * _supportedMessage
 *
 * (Modified) CapabilityStatement.messaging.supportedMessage
 *
 * http://hl7.org/fhir/_supportedMessage
 */
var _supportedMessage = 'http://hl7.org/fhir/_supportedMessage';
/**
 * DataRequirementDateFilterComponent
 *
 * DataRequirementDateFilterComponent: Date filters specify additional constraints on the data in terms of the applicable date range for specific elements. Each date filter specifies an additional constraint on the data, i.e. date filters are AND'ed, not OR'ed.
 *
 * http://hl7.org/fhir/DataRequirementDateFilterComponent
 */
var DataRequirementDateFilterComponent = 'http://hl7.org/fhir/DataRequirementDateFilterComponent';
/**
 * _performedActivity
 *
 * (Modified) CarePlan.activity.performedActivity
 *
 * http://hl7.org/fhir/_performedActivity
 */
var _performedActivity = 'http://hl7.org/fhir/_performedActivity';
/**
 * _specialty
 *
 * (Modified) Claim.careTeam.specialty
 *
 * http://hl7.org/fhir/_specialty
 */
var _specialty = 'http://hl7.org/fhir/_specialty';
/**
 * _weekInterval
 *
 * (Modified) Appointment.recurrenceTemplate.weeklyTemplate.weekInterval
 *
 * http://hl7.org/fhir/_weekInterval
 */
var _weekInterval = 'http://hl7.org/fhir/_weekInterval';
/**
 * publicationDate
 *
 * Contract.contentDefinition.publicationDate: The date (and optionally time) when the contract was last significantly changed. The date must change when the business version changes and it must change if the status code changes. In addition, it should change when the substantive content of the contract changes.
 *
 * http://hl7.org/fhir/publicationDate
 */
var publicationDate = 'http://hl7.org/fhir/publicationDate';
/**
 * administrationInstruction
 *
 * NutritionOrder.enteralFormula.administrationInstruction: Free text formula administration, feeding instructions or additional instructions or information.
 *
 * http://hl7.org/fhir/administrationInstruction
 */
var administrationInstruction = 'http://hl7.org/fhir/administrationInstruction';
/**
 * fivePrime
 *
 * SubstanceNucleicAcid.subunit.fivePrime: The nucleotide present at the 5’ terminal shall be specified based on a controlled vocabulary. Since the sequence is represented from the 5' to the 3' end, the 5’ prime nucleotide is the letter at the first position in the sequence. A separate representation would be redundant.
 *
 * http://hl7.org/fhir/fivePrime
 */
var fivePrime = 'http://hl7.org/fhir/fivePrime';
/**
 * _points
 *
 * (Modified) Contract.term.group.asset.valuedItem.points
 *
 * http://hl7.org/fhir/_points
 */
var _points = 'http://hl7.org/fhir/_points';
/**
 * TestScriptSetupActionAssertComponent
 *
 * TestScriptSetupComponent.SetupAction.TestScriptSetupActionAssertComponent: Evaluates the results of previous operations to determine if the server under test behaves appropriately.
 *
 * http://hl7.org/fhir/TestScriptSetupActionAssertComponent
 */
var TestScriptSetupActionAssertComponent = 'http://hl7.org/fhir/TestScriptSetupActionAssertComponent';
/**
 * referralRequest
 *
 * EpisodeOfCare.referralRequest: Referral Request(s) that are fulfilled by this EpisodeOfCare, incoming referrals.
 *
 * http://hl7.org/fhir/referralRequest
 */
var referralRequest = 'http://hl7.org/fhir/referralRequest';
/**
 * _timeAspect
 *
 * (Modified) SpecimenDefinition.timeAspect
 *
 * http://hl7.org/fhir/_timeAspect
 */
var _timeAspect = 'http://hl7.org/fhir/_timeAspect';
/**
 * _presentedForm
 *
 * (Modified) DiagnosticReport.presentedForm
 *
 * http://hl7.org/fhir/_presentedForm
 */
var _presentedForm = 'http://hl7.org/fhir/_presentedForm';
/**
 * _seriesDoses
 *
 * (Modified) ImmunizationRecommendation.recommendation.seriesDoses
 *
 * http://hl7.org/fhir/_seriesDoses
 */
var _seriesDoses = 'http://hl7.org/fhir/_seriesDoses';
/**
 * milestone
 *
 * ResearchSubject.progress.milestone: The milestones the subject has passed through.
 *
 * http://hl7.org/fhir/milestone
 */
var milestone = 'http://hl7.org/fhir/milestone';
/**
 * MedicationAdministrationPerformerComponent
 *
 * MedicationAdministrationPerformerComponent: The performer of the medication treatment.  For devices this is the device that performed the administration of the medication.  An IV Pump would be an example of a device that is performing the administration. Both the IV Pump and the practitioner that set the rate or bolus on the pump can be listed as performers.
 *
 * http://hl7.org/fhir/MedicationAdministrationPerformerComponent
 */
var MedicationAdministrationPerformerComponent = 'http://hl7.org/fhir/MedicationAdministrationPerformerComponent';
/**
 * Invoice
 *
 * Invoice containing collected ChargeItems from an Account with calculated individual and total price for Billing purpose.
 *
 * http://hl7.org/fhir/Invoice
 */
var Invoice = 'http://hl7.org/fhir/Invoice';
/**
 * additionalContext
 *
 * SubscriptionStatus.notificationEvent.additionalContext: Additional context information for this event. Generally, this will contain references to additional resources included with the event (e.g., the Patient relevant to an Encounter), however it MAY refer to non-FHIR objects.
 *
 * http://hl7.org/fhir/additionalContext
 */
var additionalContext = 'http://hl7.org/fhir/additionalContext';
/**
 * _satisfiedBy
 *
 * (Modified) Requirements.statement.satisfiedBy
 *
 * http://hl7.org/fhir/_satisfiedBy
 */
var _satisfiedBy = 'http://hl7.org/fhir/_satisfiedBy';
/**
 * identifier
 *
 * ImplementationGuide.identifier: A formal identifier that is used to identify this implementation guide when it is represented in other formats, or referenced in a specification, model, design or an instance.
 *
 * http://hl7.org/fhir/identifier
 */
var identifier = 'http://hl7.org/fhir/identifier';
/**
 * SubstanceNucleicAcid
 *
 * Nucleic acids are defined by three distinct elements: the base, sugar and linkage. Individual substance/moiety IDs will be created for each of these elements. The nucleotide sequence will be always entered in the 5’-3’ direction.
 *
 * http://hl7.org/fhir/SubstanceNucleicAcid
 */
var SubstanceNucleicAcid = 'http://hl7.org/fhir/SubstanceNucleicAcid';
/**
 * resourceTrigger
 *
 * SubscriptionTopic.resourceTrigger: A definition of a resource-based event that triggers a notification based on the SubscriptionTopic. The criteria may be just a human readable description and/or a full FHIR search string or FHIRPath expression. Multiple triggers are considered OR joined (e.g., a resource update matching ANY of the definitions will trigger a notification).
 *
 * http://hl7.org/fhir/resourceTrigger
 */
var resourceTrigger = 'http://hl7.org/fhir/resourceTrigger';
/**
 * _overload
 *
 * (Modified) OperationDefinition.overload
 *
 * http://hl7.org/fhir/_overload
 */
var _overload = 'http://hl7.org/fhir/_overload';
/**
 * organization
 *
 * VerificationResult.validator.organization: Reference to the organization validating information.
 *
 * http://hl7.org/fhir/organization
 */
var organization = 'http://hl7.org/fhir/organization';
/**
 * PlanDefinitionActionConditionComponent
 *
 * PlanDefinitionActionComponentAction.PlanDefinitionActionConditionComponent: An expression that describes applicability criteria or start/stop conditions for the action.
 *
 * http://hl7.org/fhir/PlanDefinitionActionConditionComponent
 */
var PlanDefinitionActionConditionComponent = 'http://hl7.org/fhir/PlanDefinitionActionConditionComponent';
/**
 * RegulatedAuthorizationCaseComponentCaseCase
 *
 * A regulatory submission from an organization to a regulator, as part of an assessing case. Multiple applications may occur over time, with more or different information to support or modify the submission or the authorization. The applications can be considered as steps within the longer running case or procedure for this authorization process.
 *
 * http://hl7.org/fhir/RegulatedAuthorizationCaseComponentCaseCase
 */
var RegulatedAuthorizationCaseComponentCaseCase = 'http://hl7.org/fhir/RegulatedAuthorizationCaseComponentCaseCase';
/**
 * sliceIsConstraining
 *
 * ElementDefinition.sliceIsConstraining: If true, indicates that this slice definition is constraining a slice definition with the same name in an inherited profile. If false, the slice is not overriding any slice in an inherited profile. If missing, the slice might or might not be overriding a slice in an inherited profile, depending on the sliceName.
 *
 * http://hl7.org/fhir/sliceIsConstraining
 */
var sliceIsConstraining = 'http://hl7.org/fhir/sliceIsConstraining';
/**
 * _dataUpdateType
 *
 * (Modified) MeasureReport.dataUpdateType
 *
 * http://hl7.org/fhir/_dataUpdateType
 */
var _dataUpdateType = 'http://hl7.org/fhir/_dataUpdateType';
/**
 * noteNumber
 *
 * ClaimResponse.item.detail.noteNumber: The numbers associated with notes below which apply to the adjudication of this item.
 *
 * http://hl7.org/fhir/noteNumber
 */
var noteNumber = 'http://hl7.org/fhir/noteNumber';
/**
 * installDate
 *
 * Device.version.installDate: The date the version was installed on the device.
 *
 * http://hl7.org/fhir/installDate
 */
var installDate = 'http://hl7.org/fhir/installDate';
/**
 * cardBrand
 *
 * PaymentReconciliation.cardBrand: The card brand such as debit, Visa, Amex etc. used if a card is the method of payment.
 *
 * http://hl7.org/fhir/cardBrand
 */
var cardBrand = 'http://hl7.org/fhir/cardBrand';
/**
 * _fullUrl
 *
 * (Modified) Bundle.entry.fullUrl
 *
 * http://hl7.org/fhir/_fullUrl
 */
var _fullUrl = 'http://hl7.org/fhir/_fullUrl';
/**
 * codeMap
 *
 * SampledData.codeMap: Reference to ConceptMap that defines the codes used in the data.
 *
 * http://hl7.org/fhir/codeMap
 */
var codeMap = 'http://hl7.org/fhir/codeMap';
/**
 * ConditionDefinitionObservationComponent
 *
 * ConditionDefinitionObservationComponent: Observations particularly relevant to this condition.
 *
 * http://hl7.org/fhir/ConditionDefinitionObservationComponent
 */
var ConditionDefinitionObservationComponent = 'http://hl7.org/fhir/ConditionDefinitionObservationComponent';
/**
 * FamilyMemberHistory
 *
 * Significant health conditions for a person related to the patient relevant in the context of care for the patient.
 *
 * http://hl7.org/fhir/FamilyMemberHistory
 */
var FamilyMemberHistory = 'http://hl7.org/fhir/FamilyMemberHistory';
/**
 * operationTypeReason
 *
 * InventoryReport.operationTypeReason: The reason for this count - regular count, ad-hoc count, new arrivals, etc.
 *
 * http://hl7.org/fhir/operationTypeReason
 */
var operationTypeReason = 'http://hl7.org/fhir/operationTypeReason';
/**
 * SpecimenDefinitionTypeTestedContainerAdditiveComponent
 *
 * SpecimenDefinitionTypeTestedComponent.SpecimenDefinitionTypeTestedContainerComponent.SpecimenDefinitionTypeTestedContainerAdditiveComponent: Substance introduced in the kind of container to preserve, maintain or enhance the specimen. Examples: Formalin, Citrate, EDTA.
 *
 * http://hl7.org/fhir/SpecimenDefinitionTypeTestedContainerAdditiveComponent
 */
var SpecimenDefinitionTypeTestedContainerAdditiveComponent = 'http://hl7.org/fhir/SpecimenDefinitionTypeTestedContainerAdditiveComponent';
/**
 * _element
 *
 * (Modified) StructureDefinition.differential.element
 *
 * http://hl7.org/fhir/_element
 */
var _element = 'http://hl7.org/fhir/_element';
/**
 * _attachedDocument
 *
 * (Modified) RegulatedAuthorization.attachedDocument
 *
 * http://hl7.org/fhir/_attachedDocument
 */
var _attachedDocument = 'http://hl7.org/fhir/_attachedDocument';
/**
 * _implementation
 *
 * (Modified) TerminologyCapabilities.implementation
 *
 * http://hl7.org/fhir/_implementation
 */
var _implementation = 'http://hl7.org/fhir/_implementation';
/**
 * sourceMaterialType
 *
 * SubstanceSourceMaterial.sourceMaterialType: The type of the source material shall be specified based on a controlled vocabulary. For vaccines, this subclause refers to the class of infectious agent.
 *
 * http://hl7.org/fhir/sourceMaterialType
 */
var sourceMaterialType = 'http://hl7.org/fhir/sourceMaterialType';
/**
 * _substance
 *
 * (Modified) Substance.ingredient.substance
 *
 * http://hl7.org/fhir/_substance
 */
var _substance = 'http://hl7.org/fhir/_substance';
/**
 * _qualification
 *
 * (Modified) Practitioner.qualification
 *
 * http://hl7.org/fhir/_qualification
 */
var _qualification = 'http://hl7.org/fhir/_qualification';
/**
 * _countType
 *
 * (Modified) InventoryReport.countType
 *
 * http://hl7.org/fhir/_countType
 */
var _countType = 'http://hl7.org/fhir/_countType';
/**
 * sourceMaterialState
 *
 * SubstanceSourceMaterial.sourceMaterialState: The state of the source material when extracted.
 *
 * http://hl7.org/fhir/sourceMaterialState
 */
var sourceMaterialState = 'http://hl7.org/fhir/sourceMaterialState';
/**
 * _observationResultRequirement
 *
 * (Modified) ActivityDefinition.observationResultRequirement
 *
 * http://hl7.org/fhir/_observationResultRequirement
 */
var _observationResultRequirement = 'http://hl7.org/fhir/_observationResultRequirement';
/**
 * attestationSignature
 *
 * VerificationResult.validator.attestationSignature: Signed assertion by the validator that they have validated the information.
 *
 * http://hl7.org/fhir/attestationSignature
 */
var attestationSignature = 'http://hl7.org/fhir/attestationSignature';
/**
 * PackagedProductDefinitionPackagingComponentPackagingPackaging
 *
 * Allows containers (and parts of containers) within containers, still as a part of a single packaged product. See also PackagedProductDefinition.packaging.containedItem.item(PackagedProductDefinition).
 *
 * http://hl7.org/fhir/PackagedProductDefinitionPackagingComponentPackagingPackaging
 */
var PackagedProductDefinitionPackagingComponentPackagingPackaging = 'http://hl7.org/fhir/PackagedProductDefinitionPackagingComponentPackagingPackaging';
/**
 * _marketingAuthorizationHolder
 *
 * (Modified) Medication.marketingAuthorizationHolder
 *
 * http://hl7.org/fhir/_marketingAuthorizationHolder
 */
var _marketingAuthorizationHolder = 'http://hl7.org/fhir/_marketingAuthorizationHolder';
/**
 * _decisionMode
 *
 * (Modified) Contract.term.group.offer.decisionMode
 *
 * http://hl7.org/fhir/_decisionMode
 */
var _decisionMode = 'http://hl7.org/fhir/_decisionMode';
/**
 * repeats
 *
 * Questionnaire.item.item.repeats: An indication, if true, that a QuestionnaireResponse for this item may include multiple answers associated with a single instance of this item (for question-type items) or multiple repetitions of the item (for group-type items).
 *
 * http://hl7.org/fhir/repeats
 */
var repeats = 'http://hl7.org/fhir/repeats';
/**
 * typeTested
 *
 * SpecimenDefinition.typeTested: Specimen conditioned in a container as expected by the testing laboratory.
 *
 * http://hl7.org/fhir/typeTested
 */
var typeTested = 'http://hl7.org/fhir/typeTested';
/**
 * _rankingOrder
 *
 * (Modified) Citation.citedArtifact.contributorship.entry.rankingOrder
 *
 * http://hl7.org/fhir/_rankingOrder
 */
var _rankingOrder = 'http://hl7.org/fhir/_rankingOrder';
/**
 * end
 *
 * MolecularSequence.relative.edit.end: End position of the edit on the starting sequence. If the coordinate system is 0-based then end is exclusive and does not include the last position. If the coordinate system is 1-base, then end is inclusive and includes the last position.
 *
 * http://hl7.org/fhir/end
 */
var end = 'http://hl7.org/fhir/end';
/**
 * GenomicStudyAnalysisComponent
 *
 * GenomicStudyAnalysisComponent: The details about a specific analysis that was performed in this GenomicStudy.
 *
 * http://hl7.org/fhir/GenomicStudyAnalysisComponent
 */
var GenomicStudyAnalysisComponent = 'http://hl7.org/fhir/GenomicStudyAnalysisComponent';
/**
 * excluded
 *
 * ExplanationOfBenefit.benefitBalance.excluded: True if the indicated class of service is excluded from the plan, missing or False indicates the product or service is included in the coverage.
 *
 * http://hl7.org/fhir/excluded
 */
var excluded = 'http://hl7.org/fhir/excluded';
/**
 * BundleEntryRequestComponent
 *
 * BundleEntryComponent.BundleEntryRequestComponent: Additional information about how this entry should be processed as part of a transaction or batch.  For history, it shows how the entry was processed to create the version contained in the entry.
 *
 * http://hl7.org/fhir/BundleEntryRequestComponent
 */
var BundleEntryRequestComponent = 'http://hl7.org/fhir/BundleEntryRequestComponent';
/**
 * DeviceDefinitionDeviceNameComponent
 *
 * DeviceDefinitionDeviceNameComponent: The name or names of the device as given by the manufacturer.
 *
 * http://hl7.org/fhir/DeviceDefinitionDeviceNameComponent
 */
var DeviceDefinitionDeviceNameComponent = 'http://hl7.org/fhir/DeviceDefinitionDeviceNameComponent';
/**
 * _eventNumber
 *
 * (Modified) SubscriptionStatus.notificationEvent.eventNumber
 *
 * http://hl7.org/fhir/_eventNumber
 */
var _eventNumber = 'http://hl7.org/fhir/_eventNumber';
/**
 * FormularyItem
 *
 * This resource describes a product or service that is available through a program and includes the conditions and constraints of availability.  All of the information in this resource is specific to the inclusion of the item in the formulary and is not inherent to the item itself.
 *
 * http://hl7.org/fhir/FormularyItem
 */
var FormularyItem = 'http://hl7.org/fhir/FormularyItem';
/**
 * _marketDistribution
 *
 * (Modified) DeviceDefinition.packaging.packaging.udiDeviceIdentifier.marketDistribution
 *
 * http://hl7.org/fhir/_marketDistribution
 */
var _marketDistribution = 'http://hl7.org/fhir/_marketDistribution';
/**
 * _searchParam
 *
 * (Modified) CapabilityStatement.rest.searchParam
 *
 * http://hl7.org/fhir/_searchParam
 */
var _searchParam = 'http://hl7.org/fhir/_searchParam';
/**
 * countryOfOrigin
 *
 * SubstanceSourceMaterial.countryOfOrigin: The country where the plant material is harvested or the countries where the plasma is sourced from as laid down in accordance with the Plasma Master File. For “Plasma-derived substances” the attribute country of origin provides information about the countries used for the manufacturing of the Cryopoor plama or Crioprecipitate.
 *
 * http://hl7.org/fhir/countryOfOrigin
 */
var countryOfOrigin = 'http://hl7.org/fhir/countryOfOrigin';
/**
 * AuditEventAgentComponent
 *
 * AuditEventAgentComponent: An actor taking an active role in the event or activity that is logged.
 *
 * http://hl7.org/fhir/AuditEventAgentComponent
 */
var AuditEventAgentComponent = 'http://hl7.org/fhir/AuditEventAgentComponent';
/**
 * _regulatoryAuthority
 *
 * (Modified) MedicationKnowledge.regulatory.regulatoryAuthority
 *
 * http://hl7.org/fhir/_regulatoryAuthority
 */
var _regulatoryAuthority = 'http://hl7.org/fhir/_regulatoryAuthority';
/**
 * _subjectState
 *
 * (Modified) ResearchSubject.progress.subjectState
 *
 * http://hl7.org/fhir/_subjectState
 */
var _subjectState = 'http://hl7.org/fhir/_subjectState';
/**
 * actualComparisonGroup
 *
 * ResearchSubject.actualComparisonGroup: The name of the arm in the study the subject actually followed as part of this study.
 *
 * http://hl7.org/fhir/actualComparisonGroup
 */
var actualComparisonGroup = 'http://hl7.org/fhir/actualComparisonGroup';
/**
 * _focusReference
 *
 * (Modified) EvidenceReport.section.section.focusReference
 *
 * http://hl7.org/fhir/_focusReference
 */
var _focusReference = 'http://hl7.org/fhir/_focusReference';
/**
 * _statusReason
 *
 * (Modified) Transport.statusReason
 *
 * http://hl7.org/fhir/_statusReason
 */
var _statusReason = 'http://hl7.org/fhir/_statusReason';
/**
 * ingredientLabel
 *
 * NutritionIntake.ingredientLabel: Total nutrient amounts for the whole meal, product, serving, etc.
 *
 * http://hl7.org/fhir/ingredientLabel
 */
var ingredientLabel = 'http://hl7.org/fhir/ingredientLabel';
/**
 * _whenPrepared
 *
 * (Modified) MedicationDispense.whenPrepared
 *
 * http://hl7.org/fhir/_whenPrepared
 */
var _whenPrepared = 'http://hl7.org/fhir/_whenPrepared';
/**
 * costCenter
 *
 * ChargeItem.costCenter: The financial cost center permits the tracking of charge attribution.
 *
 * http://hl7.org/fhir/costCenter
 */
var costCenter = 'http://hl7.org/fhir/costCenter';
/**
 * outputParameters
 *
 * GuidanceResponse.outputParameters: The output parameters of the evaluation, if any. Many modules will result in the return of specific resources such as procedure or communication requests that are returned as part of the operation result. However, modules may define specific outputs that would be returned as the result of the evaluation, and these would be returned in this element.
 *
 * http://hl7.org/fhir/outputParameters
 */
var outputParameters = 'http://hl7.org/fhir/outputParameters';
/**
 * DevicePropertyComponent
 *
 * DevicePropertyComponent: Static or essentially fixed characteristics or features of the device (e.g., time or timing attributes, resolution, accuracy, intended use or instructions for use, and physical attributes) that are not otherwise captured in more specific attributes.
 *
 * http://hl7.org/fhir/DevicePropertyComponent
 */
var DevicePropertyComponent = 'http://hl7.org/fhir/DevicePropertyComponent';
/**
 * productCategory
 *
 * BiologicallyDerivedProduct.productCategory: Broad category of this product.
 *
 * http://hl7.org/fhir/productCategory
 */
var productCategory = 'http://hl7.org/fhir/productCategory';
/**
 * serviceType
 *
 * Schedule.serviceType: The specific service that is to be performed during this appointment.
 *
 * http://hl7.org/fhir/serviceType
 */
var serviceType = 'http://hl7.org/fhir/serviceType';
/**
 * _verification
 *
 * (Modified) Consent.verification
 *
 * http://hl7.org/fhir/_verification
 */
var _verification = 'http://hl7.org/fhir/_verification';
/**
 * reliableCache
 *
 * CapabilityStatement.messaging.reliableCache: Length if the receiver's reliable messaging cache in minutes (if a receiver) or how long the cache length on the receiver should be (if a sender).
 *
 * http://hl7.org/fhir/reliableCache
 */
var reliableCache = 'http://hl7.org/fhir/reliableCache';
/**
 * _Flag
 *
 * (Modified) Flag
 *
 * http://hl7.org/fhir/_Flag
 */
var _Flag = 'http://hl7.org/fhir/_Flag';
/**
 * numberAffected
 *
 * Evidence.statistic.numberAffected: The number of participants affected where the unit of analysis is the same as sampleSize.knownDataCount and sampleSize.numberOfParticipants.
 *
 * http://hl7.org/fhir/numberAffected
 */
var numberAffected = 'http://hl7.org/fhir/numberAffected';
/**
 * StructureMapGroupRuleDependentComponent
 *
 * StructureMapGroupComponent.StructureMapGroupRuleComponentRule.StructureMapGroupRuleDependentComponent: Which other rules to apply in the context of this rule.
 *
 * http://hl7.org/fhir/StructureMapGroupRuleDependentComponent
 */
var StructureMapGroupRuleDependentComponent = 'http://hl7.org/fhir/StructureMapGroupRuleDependentComponent';
/**
 * relationshipType
 *
 * ClinicalUseDefinition.indication.otherTherapy.relationshipType: The type of relationship between the medicinal product indication or contraindication and another therapy.
 *
 * http://hl7.org/fhir/relationshipType
 */
var relationshipType = 'http://hl7.org/fhir/relationshipType';
/**
 * _statement
 *
 * (Modified) Requirements.statement
 *
 * http://hl7.org/fhir/_statement
 */
var _statement = 'http://hl7.org/fhir/_statement';
/**
 * _Goal
 *
 * (Modified) Goal
 *
 * http://hl7.org/fhir/_Goal
 */
var _Goal = 'http://hl7.org/fhir/_Goal';
/**
 * issued
 *
 * TestReport.issued: When the TestScript was executed and this TestReport was generated.
 *
 * http://hl7.org/fhir/issued
 */
var issued = 'http://hl7.org/fhir/issued';
/**
 * _instruction
 *
 * (Modified) SpecimenDefinition.typeTested.handling.instruction
 *
 * http://hl7.org/fhir/_instruction
 */
var _instruction = 'http://hl7.org/fhir/_instruction';
/**
 * inclusionCriteria
 *
 * ValueSet.scope.inclusionCriteria: Criteria describing which concepts or codes should be included and why.
 *
 * http://hl7.org/fhir/inclusionCriteria
 */
var inclusionCriteria = 'http://hl7.org/fhir/inclusionCriteria';
/**
 * about
 *
 * CommunicationRequest.about: Other resources that pertain to this communication request and to which this communication request should be associated.
 *
 * http://hl7.org/fhir/about
 */
var about = 'http://hl7.org/fhir/about';
/**
 * Practitioner
 *
 * A person who is directly or indirectly involved in the provisioning of healthcare or related services.
 *
 * http://hl7.org/fhir/Practitioner
 */
var Practitioner = 'http://hl7.org/fhir/Practitioner';
/**
 * prognosisCodeableConcept
 *
 * ClinicalImpression.prognosisCodeableConcept: Estimate of likely outcome.
 *
 * http://hl7.org/fhir/prognosisCodeableConcept
 */
var prognosisCodeableConcept = 'http://hl7.org/fhir/prognosisCodeableConcept';
/**
 * AdverseEventParticipantComponent
 *
 * AdverseEventParticipantComponent: Indicates who or what participated in the adverse event and how they were involved.
 *
 * http://hl7.org/fhir/AdverseEventParticipantComponent
 */
var AdverseEventParticipantComponent = 'http://hl7.org/fhir/AdverseEventParticipantComponent';
/**
 * _maxValue
 *
 * (Modified) ElementDefinition.maxValue
 *
 * http://hl7.org/fhir/_maxValue
 */
var _maxValue = 'http://hl7.org/fhir/_maxValue';
/**
 * ItemDetail
 *
 * ClaimResponse.Item.ItemDetail: A claim detail. Either a simple (a product or service) or a 'group' of sub-details which are simple items.
 *
 * http://hl7.org/fhir/ItemDetail
 */
var ItemDetail = 'http://hl7.org/fhir/ItemDetail';
/**
 * _hasBodySite
 *
 * (Modified) ConditionDefinition.hasBodySite
 *
 * http://hl7.org/fhir/_hasBodySite
 */
var _hasBodySite = 'http://hl7.org/fhir/_hasBodySite';
/**
 * _metadata
 *
 * (Modified) TestScript.metadata
 *
 * http://hl7.org/fhir/_metadata
 */
var _metadata = 'http://hl7.org/fhir/_metadata';
/**
 * rejectionCriterion
 *
 * SpecimenDefinition.typeTested.rejectionCriterion: Criterion for rejection of the specimen in its container by the laboratory.
 *
 * http://hl7.org/fhir/rejectionCriterion
 */
var rejectionCriterion = 'http://hl7.org/fhir/rejectionCriterion';
/**
 * cors
 *
 * CapabilityStatement.rest.security.cors: Server adds CORS headers when responding to requests - this enables Javascript applications to use the server.
 *
 * http://hl7.org/fhir/cors
 */
var cors = 'http://hl7.org/fhir/cors';
/**
 * _option
 *
 * (Modified) PlanDefinition.actor.option
 *
 * http://hl7.org/fhir/_option
 */
var _option = 'http://hl7.org/fhir/_option';
/**
 * TypeRefComponent
 *
 * ElementDefinition.TypeRefComponent: The data type or resource that the value of this element is permitted to be.
 *
 * http://hl7.org/fhir/TypeRefComponent
 */
var TypeRefComponent = 'http://hl7.org/fhir/TypeRefComponent';
/**
 * minValue
 *
 * ElementDefinition.minValue
 *
 * http://hl7.org/fhir/minValue
 */
var minValue = 'http://hl7.org/fhir/minValue';
/**
 * _tuesday
 *
 * (Modified) Appointment.recurrenceTemplate.weeklyTemplate.tuesday
 *
 * http://hl7.org/fhir/_tuesday
 */
var _tuesday = 'http://hl7.org/fhir/_tuesday';
/**
 * _offset
 *
 * (Modified) ValueSet.expansion.offset
 *
 * http://hl7.org/fhir/_offset
 */
var _offset = 'http://hl7.org/fhir/_offset';
/**
 * report
 *
 * Procedure.report: This could be a histology result, pathology report, surgical report, etc.
 *
 * http://hl7.org/fhir/report
 */
var report = 'http://hl7.org/fhir/report';
/**
 * _fhirPathCriteria
 *
 * (Modified) SubscriptionTopic.resourceTrigger.fhirPathCriteria
 *
 * http://hl7.org/fhir/_fhirPathCriteria
 */
var _fhirPathCriteria = 'http://hl7.org/fhir/_fhirPathCriteria';
/**
 * editor
 *
 * ValueSet.editor: An individual or organization primarily responsible for internal coherence of the ValueSet.
 *
 * http://hl7.org/fhir/editor
 */
var editor = 'http://hl7.org/fhir/editor';
/**
 * _firstDose
 *
 * (Modified) AdministrableProductDefinition.routeOfAdministration.firstDose
 *
 * http://hl7.org/fhir/_firstDose
 */
var _firstDose = 'http://hl7.org/fhir/_firstDose';
/**
 * procedureSequence
 *
 * ExplanationOfBenefit.item.procedureSequence: Procedures applicable for this service or product.
 *
 * http://hl7.org/fhir/procedureSequence
 */
var procedureSequence = 'http://hl7.org/fhir/procedureSequence';
/**
 * MedicinalProductDefinitionContactComponent
 *
 * MedicinalProductDefinitionContactComponent: A product specific contact, person (in a role), or an organization.
 *
 * http://hl7.org/fhir/MedicinalProductDefinitionContactComponent
 */
var MedicinalProductDefinitionContactComponent = 'http://hl7.org/fhir/MedicinalProductDefinitionContactComponent';
/**
 * _Communication
 *
 * (Modified) Communication
 *
 * http://hl7.org/fhir/_Communication
 */
var _Communication = 'http://hl7.org/fhir/_Communication';
/**
 * _controller
 *
 * (Modified) Consent.controller
 *
 * http://hl7.org/fhir/_controller
 */
var _controller = 'http://hl7.org/fhir/_controller';
/**
 * TestScriptSetupActionAssertRequirementComponent
 *
 * TestScriptTestComponent.TestActionAssert.TestScriptSetupActionAssertRequirementComponent: Links or references providing traceability to the testing requirements for this assert.
 *
 * http://hl7.org/fhir/TestScriptSetupActionAssertRequirementComponent
 */
var TestScriptSetupActionAssertRequirementComponent = 'http://hl7.org/fhir/TestScriptSetupActionAssertRequirementComponent';
/**
 * _allocation
 *
 * (Modified) PaymentReconciliation.allocation
 *
 * http://hl7.org/fhir/_allocation
 */
var _allocation = 'http://hl7.org/fhir/_allocation';
/**
 * otherTherapy
 *
 * ClinicalUseDefinition.indication.otherTherapy: Information about the use of the medicinal product in relation to other therapies described as part of the indication.
 *
 * http://hl7.org/fhir/otherTherapy
 */
var otherTherapy = 'http://hl7.org/fhir/otherTherapy';
/**
 * _requestedLocation
 *
 * (Modified) Transport.requestedLocation
 *
 * http://hl7.org/fhir/_requestedLocation
 */
var _requestedLocation = 'http://hl7.org/fhir/_requestedLocation';
/**
 * _referencedFrom
 *
 * (Modified) OperationDefinition.parameter.part.referencedFrom
 *
 * http://hl7.org/fhir/_referencedFrom
 */
var _referencedFrom = 'http://hl7.org/fhir/_referencedFrom';
/**
 * eventsSinceSubscriptionStart
 *
 * SubscriptionStatus.eventsSinceSubscriptionStart: The total number of actual events which have been generated since the Subscription was created (inclusive of this notification) - regardless of how many have been successfully communicated.  This number is NOT incremented for handshake and heartbeat notifications.
 *
 * http://hl7.org/fhir/eventsSinceSubscriptionStart
 */
var eventsSinceSubscriptionStart = 'http://hl7.org/fhir/eventsSinceSubscriptionStart';
/**
 * _question
 *
 * (Modified) Questionnaire.item.item.enableWhen.question
 *
 * http://hl7.org/fhir/_question
 */
var _question = 'http://hl7.org/fhir/_question';
/**
 * _drugCharacteristic
 *
 * (Modified) MedicationKnowledge.definitional.drugCharacteristic
 *
 * http://hl7.org/fhir/_drugCharacteristic
 */
var _drugCharacteristic = 'http://hl7.org/fhir/_drugCharacteristic';
/**
 * _total
 *
 * (Modified) ValueSet.expansion.total
 *
 * http://hl7.org/fhir/_total
 */
var _total = 'http://hl7.org/fhir/_total';
/**
 * AuditEvent
 *
 * A record of an event relevant for purposes such as operations, privacy, security, maintenance, and performance analysis.
 *
 * http://hl7.org/fhir/AuditEvent
 */
var AuditEvent = 'http://hl7.org/fhir/AuditEvent';
/**
 * _environmentType
 *
 * (Modified) Endpoint.environmentType
 *
 * http://hl7.org/fhir/_environmentType
 */
var _environmentType = 'http://hl7.org/fhir/_environmentType';
/**
 * AssetContext
 *
 * Contract.TermTerm.ContractAsset.AssetContext: Circumstance of the asset.
 *
 * http://hl7.org/fhir/AssetContext
 */
var AssetContext = 'http://hl7.org/fhir/AssetContext';
/**
 * _rangeCategory
 *
 * (Modified) ObservationDefinition.component.qualifiedValue.rangeCategory
 *
 * http://hl7.org/fhir/_rangeCategory
 */
var _rangeCategory = 'http://hl7.org/fhir/_rangeCategory';
/**
 * Location
 *
 * Details and position information for a place where services are provided and resources and participants may be stored, found, contained, or accommodated.
 *
 * http://hl7.org/fhir/Location
 */
var Location = 'http://hl7.org/fhir/Location';
/**
 * rank
 *
 * ContactPoint.rank: Specifies a preferred order in which to use a set of contacts. ContactPoints with lower rank values are more preferred than those with higher rank values.
 *
 * http://hl7.org/fhir/rank
 */
var rank = 'http://hl7.org/fhir/rank';
/**
 * PlanDefinitionActionComponentActionAction
 *
 * Sub actions that are contained within the action. The behavior of this action determines the functionality of the sub-actions. For example, a selection behavior of at-most-one indicates that of the sub-actions, at most one may be chosen as part of realizing the action definition.
 *
 * http://hl7.org/fhir/PlanDefinitionActionComponentActionAction
 */
var PlanDefinitionActionComponentActionAction = 'http://hl7.org/fhir/PlanDefinitionActionComponentActionAction';
/**
 * _occurrenceCount
 *
 * (Modified) Appointment.recurrenceTemplate.occurrenceCount
 *
 * http://hl7.org/fhir/_occurrenceCount
 */
var _occurrenceCount = 'http://hl7.org/fhir/_occurrenceCount';
/**
 * entryType
 *
 * Device.udiCarrier.entryType: A coded entry to indicate how the data was entered.
 *
 * http://hl7.org/fhir/entryType
 */
var entryType = 'http://hl7.org/fhir/entryType';
/**
 * _trigger
 *
 * (Modified) PlanDefinition.action.action.trigger
 *
 * http://hl7.org/fhir/_trigger
 */
var _trigger = 'http://hl7.org/fhir/_trigger';
/**
 * _contextInvariant
 *
 * (Modified) StructureDefinition.contextInvariant
 *
 * http://hl7.org/fhir/_contextInvariant
 */
var _contextInvariant = 'http://hl7.org/fhir/_contextInvariant';
/**
 * id
 *
 * Element.id: Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.
 *
 * http://hl7.org/fhir/id
 */
var id = 'http://hl7.org/fhir/id';
/**
 * _productionIdentifierInUDI
 *
 * (Modified) DeviceDefinition.productionIdentifierInUDI
 *
 * http://hl7.org/fhir/_productionIdentifierInUDI
 */
var _productionIdentifierInUDI = 'http://hl7.org/fhir/_productionIdentifierInUDI';
/**
 * _variable
 *
 * (Modified) TestScript.variable
 *
 * http://hl7.org/fhir/_variable
 */
var _variable = 'http://hl7.org/fhir/_variable';
/**
 * occurrence
 *
 * Immunization.occurrence
 *
 * http://hl7.org/fhir/occurrence
 */
var occurrence = 'http://hl7.org/fhir/occurrence';
/**
 * dayOfMonth
 *
 * Appointment.recurrenceTemplate.monthlyTemplate.dayOfMonth: Indicates that appointments in the series of recurring appointments should occur on a specific day of the month.
 *
 * http://hl7.org/fhir/dayOfMonth
 */
var dayOfMonth = 'http://hl7.org/fhir/dayOfMonth';
/**
 * _maxDosePerPeriod
 *
 * (Modified) Dosage.maxDosePerPeriod
 *
 * http://hl7.org/fhir/_maxDosePerPeriod
 */
var _maxDosePerPeriod = 'http://hl7.org/fhir/_maxDosePerPeriod';
/**
 * _MeasureReport
 *
 * (Modified) MeasureReport
 *
 * http://hl7.org/fhir/_MeasureReport
 */
var _MeasureReport = 'http://hl7.org/fhir/_MeasureReport';
/**
 * MedicationKnowledgeCostComponent
 *
 * MedicationKnowledgeCostComponent: The price of the medication.
 *
 * http://hl7.org/fhir/MedicationKnowledgeCostComponent
 */
var MedicationKnowledgeCostComponent = 'http://hl7.org/fhir/MedicationKnowledgeCostComponent';
/**
 * uuid
 *
 * A UUID, represented as a URI
 *
 * http://hl7.org/fhir/uuid
 */
var uuid = 'http://hl7.org/fhir/uuid';
/**
 * _range
 *
 * (Modified) ObservationDefinition.component.qualifiedValue.range
 *
 * http://hl7.org/fhir/_range
 */
var _range = 'http://hl7.org/fhir/_range';
/**
 * related
 *
 * ExplanationOfBenefit.related: Other claims which are related to this claim such as prior submissions or claims for related services or for the same event.
 *
 * http://hl7.org/fhir/related
 */
var related = 'http://hl7.org/fhir/related';
/**
 * endpoint
 *
 * ImagingStudy.endpoint: The network service providing access (e.g., query, view, or retrieval) for the study. See implementation notes for information about using DICOM endpoints. A study-level endpoint applies to each series in the study, unless overridden by a series-level endpoint with the same Endpoint.connectionType.
 *
 * http://hl7.org/fhir/endpoint
 */
var endpoint = 'http://hl7.org/fhir/endpoint';
/**
 * ValueSetExpansionParameterComponent
 *
 * ValueSetExpansionComponent.ValueSetExpansionParameterComponent: A parameter that controlled the expansion process. These parameters may be used by users of expanded value sets to check whether the expansion is suitable for a particular purpose, or to pick the correct expansion.
 *
 * http://hl7.org/fhir/ValueSetExpansionParameterComponent
 */
var ValueSetExpansionParameterComponent = 'http://hl7.org/fhir/ValueSetExpansionParameterComponent';
/**
 * _logMessage
 *
 * (Modified) StructureMap.group.rule.rule.source.logMessage
 *
 * http://hl7.org/fhir/_logMessage
 */
var _logMessage = 'http://hl7.org/fhir/_logMessage';
/**
 * SubscriptionTopicResourceTriggerQueryCriteriaComponent
 *
 * SubscriptionTopicResourceTriggerComponent.SubscriptionTopicResourceTriggerQueryCriteriaComponent: The FHIR query based rules that the server should use to determine when to trigger a notification for this subscription topic.
 *
 * http://hl7.org/fhir/SubscriptionTopicResourceTriggerQueryCriteriaComponent
 */
var SubscriptionTopicResourceTriggerQueryCriteriaComponent = 'http://hl7.org/fhir/SubscriptionTopicResourceTriggerQueryCriteriaComponent';
/**
 * _supportingImmunization
 *
 * (Modified) ImmunizationRecommendation.recommendation.supportingImmunization
 *
 * http://hl7.org/fhir/_supportingImmunization
 */
var _supportingImmunization = 'http://hl7.org/fhir/_supportingImmunization';
/**
 * StructureMapConstComponent
 *
 * StructureMapConstComponent: Definition of a constant value used in the map rules.
 *
 * http://hl7.org/fhir/StructureMapConstComponent
 */
var StructureMapConstComponent = 'http://hl7.org/fhir/StructureMapConstComponent';
/**
 * NutritionIntakeConsumedItemComponent
 *
 * NutritionIntakeConsumedItemComponent: What food or fluid product or item was consumed.
 *
 * http://hl7.org/fhir/NutritionIntakeConsumedItemComponent
 */
var NutritionIntakeConsumedItemComponent = 'http://hl7.org/fhir/NutritionIntakeConsumedItemComponent';
/**
 * PlanDefinitionGoalComponent
 *
 * PlanDefinitionGoalComponent: A goal describes an expected outcome that activities within the plan are intended to achieve. For example, weight loss, restoring an activity of daily living, obtaining herd immunity via immunization, meeting a process improvement objective, meeting the acceptance criteria for a test as specified by a quality specification, etc.
 *
 * http://hl7.org/fhir/PlanDefinitionGoalComponent
 */
var PlanDefinitionGoalComponent = 'http://hl7.org/fhir/PlanDefinitionGoalComponent';
/**
 * precondition
 *
 * ConditionDefinition.precondition: An observation that suggests that this condition applies.
 *
 * http://hl7.org/fhir/precondition
 */
var precondition = 'http://hl7.org/fhir/precondition';
/**
 * _CoverageEligibilityResponse
 *
 * (Modified) CoverageEligibilityResponse
 *
 * http://hl7.org/fhir/_CoverageEligibilityResponse
 */
var _CoverageEligibilityResponse = 'http://hl7.org/fhir/_CoverageEligibilityResponse';
/**
 * _duration
 *
 * (Modified) Attachment.duration
 *
 * http://hl7.org/fhir/_duration
 */
var _duration = 'http://hl7.org/fhir/_duration';
/**
 * _routeOfAdministration
 *
 * (Modified) NutritionOrder.enteralFormula.routeOfAdministration
 *
 * http://hl7.org/fhir/_routeOfAdministration
 */
var _routeOfAdministration = 'http://hl7.org/fhir/_routeOfAdministration';
/**
 * _legallyBinding
 *
 * (Modified) Contract.legallyBinding
 *
 * http://hl7.org/fhir/_legallyBinding
 */
var _legallyBinding = 'http://hl7.org/fhir/_legallyBinding';
/**
 * rendering
 *
 * ImplementationGuide.manifest.rendering: A pointer to official web page, PDF or other rendering of the implementation guide.
 *
 * http://hl7.org/fhir/rendering
 */
var rendering = 'http://hl7.org/fhir/rendering';
/**
 * _hierarchical
 *
 * (Modified) TerminologyCapabilities.expansion.hierarchical
 *
 * http://hl7.org/fhir/_hierarchical
 */
var _hierarchical = 'http://hl7.org/fhir/_hierarchical';
/**
 * _nameType
 *
 * (Modified) InventoryItem.name.nameType
 *
 * http://hl7.org/fhir/_nameType
 */
var _nameType = 'http://hl7.org/fhir/_nameType';
/**
 * _businessStatus
 *
 * (Modified) Task.businessStatus
 *
 * http://hl7.org/fhir/_businessStatus
 */
var _businessStatus = 'http://hl7.org/fhir/_businessStatus';
/**
 * _maxLength
 *
 * (Modified) Questionnaire.item.item.maxLength
 *
 * http://hl7.org/fhir/_maxLength
 */
var _maxLength = 'http://hl7.org/fhir/_maxLength';
/**
 * SubstancePolymerRepeatComponent
 *
 * SubstancePolymerRepeatComponent: Specifies and quantifies the repeated units and their configuration.
 *
 * http://hl7.org/fhir/SubstancePolymerRepeatComponent
 */
var SubstancePolymerRepeatComponent = 'http://hl7.org/fhir/SubstancePolymerRepeatComponent';
/**
 * responsibleParty
 *
 * MedicationDispense.substitution.responsibleParty: The person or organization that has primary responsibility for the substitution.
 *
 * http://hl7.org/fhir/responsibleParty
 */
var responsibleParty = 'http://hl7.org/fhir/responsibleParty';
/**
 * BundleEntryComponent
 *
 * BundleEntryComponent: An entry in a bundle resource - will either contain a resource or information about a resource (transactions and history only).
 *
 * http://hl7.org/fhir/BundleEntryComponent
 */
var BundleEntryComponent = 'http://hl7.org/fhir/BundleEntryComponent';
/**
 * _input
 *
 * (Modified) RequestOrchestration.action.input
 *
 * http://hl7.org/fhir/_input
 */
var _input = 'http://hl7.org/fhir/_input';
/**
 * _languageCode
 *
 * (Modified) DeviceDefinition.languageCode
 *
 * http://hl7.org/fhir/_languageCode
 */
var _languageCode = 'http://hl7.org/fhir/_languageCode';
/**
 * _patient
 *
 * (Modified) SupplyDelivery.patient
 *
 * http://hl7.org/fhir/_patient
 */
var _patient = 'http://hl7.org/fhir/_patient';
/**
 * direction
 *
 * TestScript.test.action.assert.direction: The direction to use for the assertion.
 *
 * http://hl7.org/fhir/direction
 */
var direction = 'http://hl7.org/fhir/direction';
/**
 * _publicationDateSeason
 *
 * (Modified) Citation.citedArtifact.publicationForm.publicationDateSeason
 *
 * http://hl7.org/fhir/_publicationDateSeason
 */
var _publicationDateSeason = 'http://hl7.org/fhir/_publicationDateSeason';
/**
 * maritalStatus
 *
 * Person.maritalStatus: This field contains a person's most recent marital (civil) status.
 *
 * http://hl7.org/fhir/maritalStatus
 */
var maritalStatus = 'http://hl7.org/fhir/maritalStatus';
/**
 * AllergyIntoleranceReactionComponent
 *
 * AllergyIntoleranceReactionComponent: Details about each adverse reaction event linked to exposure to the identified substance.
 *
 * http://hl7.org/fhir/AllergyIntoleranceReactionComponent
 */
var AllergyIntoleranceReactionComponent = 'http://hl7.org/fhir/AllergyIntoleranceReactionComponent';
/**
 * _observer
 *
 * (Modified) AuditEvent.source.observer
 *
 * http://hl7.org/fhir/_observer
 */
var _observer = 'http://hl7.org/fhir/_observer';
/**
 * SubscriptionParameterComponent
 *
 * SubscriptionParameterComponent: Channel-dependent information to send as part of the notification (e.g., HTTP Headers).
 *
 * http://hl7.org/fhir/SubscriptionParameterComponent
 */
var SubscriptionParameterComponent = 'http://hl7.org/fhir/SubscriptionParameterComponent';
/**
 * doseAdministrationAid
 *
 * MedicationRequest.dispenseRequest.doseAdministrationAid: Provides information about the type of adherence packaging to be supplied for the medication dispense.
 *
 * http://hl7.org/fhir/doseAdministrationAid
 */
var doseAdministrationAid = 'http://hl7.org/fhir/doseAdministrationAid';
/**
 * DeviceDefinitionClassificationComponent
 *
 * DeviceDefinitionClassificationComponent: What kind of device or device system this is.
 *
 * http://hl7.org/fhir/DeviceDefinitionClassificationComponent
 */
var DeviceDefinitionClassificationComponent = 'http://hl7.org/fhir/DeviceDefinitionClassificationComponent';
/**
 * _measure
 *
 * (Modified) PlanDefinition.goal.target.measure
 *
 * http://hl7.org/fhir/_measure
 */
var _measure = 'http://hl7.org/fhir/_measure';
/**
 * _maxDosePerAdministration
 *
 * (Modified) Dosage.maxDosePerAdministration
 *
 * http://hl7.org/fhir/_maxDosePerAdministration
 */
var _maxDosePerAdministration = 'http://hl7.org/fhir/_maxDosePerAdministration';
/**
 * CompositionAttesterComponent
 *
 * CompositionAttesterComponent: A participant who has attested to the accuracy of the composition/document.
 *
 * http://hl7.org/fhir/CompositionAttesterComponent
 */
var CompositionAttesterComponent = 'http://hl7.org/fhir/CompositionAttesterComponent';
/**
 * _valueFilter
 *
 * (Modified) DataRequirement.valueFilter
 *
 * http://hl7.org/fhir/_valueFilter
 */
var _valueFilter = 'http://hl7.org/fhir/_valueFilter';
/**
 * studyDesign
 *
 * ResearchStudy.studyDesign: Codes categorizing the type of study such as investigational vs. observational, type of blinding, type of randomization, safety vs. efficacy, etc.
 *
 * http://hl7.org/fhir/studyDesign
 */
var studyDesign = 'http://hl7.org/fhir/studyDesign';
/**
 * _relation
 *
 * (Modified) DeviceDefinition.link.relation
 *
 * http://hl7.org/fhir/_relation
 */
var _relation = 'http://hl7.org/fhir/_relation';
/**
 * _priority
 *
 * (Modified) ExplanationOfBenefit.priority
 *
 * http://hl7.org/fhir/_priority
 */
var _priority = 'http://hl7.org/fhir/_priority';
/**
 * MessageDefinition
 *
 * Defines the characteristics of a message that can be shared between systems, including the type of event that initiates the message, the content to be transmitted and what response(s), if any, are permitted.
 *
 * http://hl7.org/fhir/MessageDefinition
 */
var MessageDefinition = 'http://hl7.org/fhir/MessageDefinition';
/**
 * _description
 *
 * (Modified) RequestOrchestration.action.action.description
 *
 * http://hl7.org/fhir/_description
 */
var _description = 'http://hl7.org/fhir/_description';
/**
 * TestPlanTestCaseTestDataComponent
 *
 * TestPlanTestCaseComponent.TestPlanTestCaseTestDataComponent: The test data used in the test case.
 *
 * http://hl7.org/fhir/TestPlanTestCaseTestDataComponent
 */
var TestPlanTestCaseTestDataComponent = 'http://hl7.org/fhir/TestPlanTestCaseTestDataComponent';
/**
 * HealthcareServiceEligibilityComponent
 *
 * HealthcareServiceEligibilityComponent: Does this service have specific eligibility requirements that need to be met in order to use the service?
 *
 * http://hl7.org/fhir/HealthcareServiceEligibilityComponent
 */
var HealthcareServiceEligibilityComponent = 'http://hl7.org/fhir/HealthcareServiceEligibilityComponent';
/**
 * category
 *
 * Flag.category: Allows a flag to be divided into different categories like clinical, administrative etc. Intended to be used as a means of filtering which flags are displayed to particular user or in a given context.
 *
 * http://hl7.org/fhir/category
 */
var category = 'http://hl7.org/fhir/category';
/**
 * Details
 *
 * CoverageEligibilityRequest.Details: Service categories or billable services for which benefit details and/or an authorization prior to service delivery may be required by the payor.
 *
 * http://hl7.org/fhir/Details
 */
var Details = 'http://hl7.org/fhir/Details';
/**
 * verificationDate
 *
 * Consent.verification.verificationDate: Date(s) verification was collected.
 *
 * http://hl7.org/fhir/verificationDate
 */
var verificationDate = 'http://hl7.org/fhir/verificationDate';
/**
 * ExampleScenarioActorComponent
 *
 * ExampleScenarioActorComponent: A system or person who shares or receives an instance within the scenario.
 *
 * http://hl7.org/fhir/ExampleScenarioActorComponent
 */
var ExampleScenarioActorComponent = 'http://hl7.org/fhir/ExampleScenarioActorComponent';
/**
 * _specimenQuantity
 *
 * (Modified) Specimen.container.specimenQuantity
 *
 * http://hl7.org/fhir/_specimenQuantity
 */
var _specimenQuantity = 'http://hl7.org/fhir/_specimenQuantity';
/**
 * DeviceDefinitionPackagingComponent
 *
 * DeviceDefinitionPackagingComponent: Information about the packaging of the device, i.e. how the device is packaged.
 *
 * http://hl7.org/fhir/DeviceDefinitionPackagingComponent
 */
var DeviceDefinitionPackagingComponent = 'http://hl7.org/fhir/DeviceDefinitionPackagingComponent';
/**
 * autocreate
 *
 * TestScript.fixture.autocreate: Whether or not to implicitly create the fixture during setup. If true, the fixture is automatically created on each server being tested during setup, therefore no create operation is required for this fixture in the TestScript.setup section.
 *
 * http://hl7.org/fhir/autocreate
 */
var autocreate = 'http://hl7.org/fhir/autocreate';
/**
 * _structuralRepresentation
 *
 * (Modified) SubstancePolymer.repeat.repeatUnit.structuralRepresentation
 *
 * http://hl7.org/fhir/_structuralRepresentation
 */
var _structuralRepresentation = 'http://hl7.org/fhir/_structuralRepresentation';
/**
 * agent
 *
 * AuditEvent.entity.agent: The entity is attributed to an agent to express the agent's responsibility for that entity in the activity. This is most used to indicate when persistence media (the entity) are used by an agent. For example when importing data from a device, the device would be described in an entity, and the user importing data from that media would be indicated as the entity.agent.
 *
 * http://hl7.org/fhir/agent
 */
var agent = 'http://hl7.org/fhir/agent';
/**
 * _request
 *
 * (Modified) ExplanationOfBenefit.item.request
 *
 * http://hl7.org/fhir/_request
 */
var _request = 'http://hl7.org/fhir/_request';
/**
 * _deliverTo
 *
 * (Modified) SupplyRequest.deliverTo
 *
 * http://hl7.org/fhir/_deliverTo
 */
var _deliverTo = 'http://hl7.org/fhir/_deliverTo';
/**
 * _textConcentration
 *
 * (Modified) Ingredient.substance.strength.textConcentration
 *
 * http://hl7.org/fhir/_textConcentration
 */
var _textConcentration = 'http://hl7.org/fhir/_textConcentration';
/**
 * benefitPeriod
 *
 * ExplanationOfBenefit.benefitPeriod: The term of the benefits documented in this response.
 *
 * http://hl7.org/fhir/benefitPeriod
 */
var benefitPeriod = 'http://hl7.org/fhir/benefitPeriod';
/**
 * SpecimenDefinitionTypeTestedContainerComponent
 *
 * SpecimenDefinitionTypeTestedComponent.SpecimenDefinitionTypeTestedContainerComponent: The specimen's container.
 *
 * http://hl7.org/fhir/SpecimenDefinitionTypeTestedContainerComponent
 */
var SpecimenDefinitionTypeTestedContainerComponent = 'http://hl7.org/fhir/SpecimenDefinitionTypeTestedContainerComponent';
/**
 * ServiceRequestPatientInstructionComponent
 *
 * ServiceRequestPatientInstructionComponent: Instructions in terms that are understood by the patient or consumer.
 *
 * http://hl7.org/fhir/ServiceRequestPatientInstructionComponent
 */
var ServiceRequestPatientInstructionComponent = 'http://hl7.org/fhir/ServiceRequestPatientInstructionComponent';
/**
 * _adjustment
 *
 * (Modified) ExplanationOfBenefit.payment.adjustment
 *
 * http://hl7.org/fhir/_adjustment
 */
var _adjustment = 'http://hl7.org/fhir/_adjustment';
/**
 * _guidance
 *
 * (Modified) Measure.guidance
 *
 * http://hl7.org/fhir/_guidance
 */
var _guidance = 'http://hl7.org/fhir/_guidance';
/**
 * productReference
 *
 * InventoryItem.productReference: Link to a product resource used in clinical workflows.
 *
 * http://hl7.org/fhir/productReference
 */
var productReference = 'http://hl7.org/fhir/productReference';
/**
 * _for
 *
 * (Modified) Transport.for
 *
 * http://hl7.org/fhir/_for
 */
var _for = 'http://hl7.org/fhir/_for';
/**
 * _intended
 *
 * (Modified) Evidence.variableDefinition.intended
 *
 * http://hl7.org/fhir/_intended
 */
var _intended = 'http://hl7.org/fhir/_intended';
/**
 * _additionalUse
 *
 * (Modified) ValueSet.expansion.contains.contains.designation.additionalUse
 *
 * http://hl7.org/fhir/_additionalUse
 */
var _additionalUse = 'http://hl7.org/fhir/_additionalUse';
/**
 * MetadataResource
 *
 * Common Interface declaration for conformance and knowledge artifact resources.
 *
 * http://hl7.org/fhir/MetadataResource
 */
var MetadataResource = 'http://hl7.org/fhir/MetadataResource';
/**
 * _startingSequence
 *
 * (Modified) MolecularSequence.relative.startingSequence
 *
 * http://hl7.org/fhir/_startingSequence
 */
var _startingSequence = 'http://hl7.org/fhir/_startingSequence';
/**
 * MedicationStatement
 *
 * A record of a medication that is being consumed by a patient.   A MedicationStatement may indicate that the patient may be taking the medication now or has taken the medication in the past or will be taking the medication in the future.  The source of this information can be the patient, significant other (such as a family member or spouse), or a clinician.  A common scenario where this information is captured is during the history taking process during a patient visit or stay.   The medication information may come from sources such as the patient's memory, from a prescription bottle,  or from a list of medications the patient, clinician or other party maintains.
 *
 * The primary difference between a medicationstatement and a medicationadministration is that the medication administration has complete administration information and is based on actual administration information from the person who administered the medication.  A medicationstatement is often, if not always, less specific.  There is no required date/time when the medication was administered, in fact we only know that a source has reported the patient is taking this medication, where details such as time, quantity, or rate or even medication product may be incomplete or missing or less precise.  As stated earlier, the Medication Statement information may come from the patient's memory, from a prescription bottle or from a list of medications the patient, clinician or other party maintains.  Medication administration is more formal and is not missing detailed information.
 *
 * http://hl7.org/fhir/MedicationStatement
 */
var MedicationStatement = 'http://hl7.org/fhir/MedicationStatement';
/**
 * medium
 *
 * CommunicationRequest.medium: A channel that was used for this communication (e.g. email, fax).
 *
 * http://hl7.org/fhir/medium
 */
var medium = 'http://hl7.org/fhir/medium';
/**
 * _baseUnit
 *
 * (Modified) InventoryItem.baseUnit
 *
 * http://hl7.org/fhir/_baseUnit
 */
var _baseUnit = 'http://hl7.org/fhir/_baseUnit';
/**
 * _doseStatusReason
 *
 * (Modified) ImmunizationEvaluation.doseStatusReason
 *
 * http://hl7.org/fhir/_doseStatusReason
 */
var _doseStatusReason = 'http://hl7.org/fhir/_doseStatusReason';
/**
 * unitOfPresentation
 *
 * ManufacturedItemDefinition.unitOfPresentation: The “real-world” units in which the quantity of the manufactured item is described.
 *
 * http://hl7.org/fhir/unitOfPresentation
 */
var unitOfPresentation = 'http://hl7.org/fhir/unitOfPresentation';
/**
 * CareTeam
 *
 * ExplanationOfBenefit.CareTeam: The members of the team who provided the products and services.
 *
 * http://hl7.org/fhir/CareTeam
 */
var CareTeam = 'http://hl7.org/fhir/CareTeam';
/**
 * sourceSignature
 *
 * VerificationResult.attestation.sourceSignature: Signed assertion by the attestation source that they have attested to the information.
 *
 * http://hl7.org/fhir/sourceSignature
 */
var sourceSignature = 'http://hl7.org/fhir/sourceSignature';
/**
 * availableStartTime
 *
 * Availability.availableTime.availableStartTime: Opening time of day (ignored if allDay = true).
 *
 * http://hl7.org/fhir/availableStartTime
 */
var availableStartTime = 'http://hl7.org/fhir/availableStartTime';
/**
 * _effectiveDate
 *
 * (Modified) MedicinalProductDefinition.operation.effectiveDate
 *
 * http://hl7.org/fhir/_effectiveDate
 */
var _effectiveDate = 'http://hl7.org/fhir/_effectiveDate';
/**
 * _relevantHistory
 *
 * (Modified) Transport.relevantHistory
 *
 * http://hl7.org/fhir/_relevantHistory
 */
var _relevantHistory = 'http://hl7.org/fhir/_relevantHistory';
/**
 * ParametersParameterComponent
 *
 * ParametersParameterComponent: A parameter passed to or received from the operation.
 *
 * http://hl7.org/fhir/ParametersParameterComponent
 */
var ParametersParameterComponent = 'http://hl7.org/fhir/ParametersParameterComponent';
/**
 * MessageDefinitionFocusComponent
 *
 * MessageDefinitionFocusComponent: Identifies the resource (or resources) that are being addressed by the event.  For example, the Encounter for an admit message or two Account records for a merge.
 *
 * http://hl7.org/fhir/MessageDefinitionFocusComponent
 */
var MessageDefinitionFocusComponent = 'http://hl7.org/fhir/MessageDefinitionFocusComponent';
/**
 * EnrollmentResponse
 *
 * This resource provides enrollment and plan details from the processing of an EnrollmentRequest resource.
 *
 * http://hl7.org/fhir/EnrollmentResponse
 */
var EnrollmentResponse = 'http://hl7.org/fhir/EnrollmentResponse';
/**
 * ListEntryComponent
 *
 * ListEntryComponent: Entries in this list.
 *
 * http://hl7.org/fhir/ListEntryComponent
 */
var ListEntryComponent = 'http://hl7.org/fhir/ListEntryComponent';
/**
 * _subset
 *
 * (Modified) ImagingSelection.instance.subset
 *
 * http://hl7.org/fhir/_subset
 */
var _subset = 'http://hl7.org/fhir/_subset';
/**
 * dimensions
 *
 * SampledData.dimensions: The number of sample points at each time point. If this value is greater than one, then the dimensions will be interlaced - all the sample points for a point in time will be recorded at once.
 *
 * http://hl7.org/fhir/dimensions
 */
var dimensions = 'http://hl7.org/fhir/dimensions';
/**
 * _function
 *
 * (Modified) ManufacturedItemDefinition.component.component.function
 *
 * http://hl7.org/fhir/_function
 */
var _function = 'http://hl7.org/fhir/_function';
/**
 * recommendation
 *
 * ImmunizationRecommendation.recommendation: Vaccine administration recommendations.
 *
 * http://hl7.org/fhir/recommendation
 */
var recommendation = 'http://hl7.org/fhir/recommendation';
/**
 * _prescription
 *
 * (Modified) ExplanationOfBenefit.prescription
 *
 * http://hl7.org/fhir/_prescription
 */
var _prescription = 'http://hl7.org/fhir/_prescription';
/**
 * prognosisReference
 *
 * ClinicalImpression.prognosisReference: RiskAssessment expressing likely outcome.
 *
 * http://hl7.org/fhir/prognosisReference
 */
var prognosisReference = 'http://hl7.org/fhir/prognosisReference';
/**
 * _hint
 *
 * (Modified) TestScript.variable.hint
 *
 * http://hl7.org/fhir/_hint
 */
var _hint = 'http://hl7.org/fhir/_hint';
/**
 * _ownedBy
 *
 * (Modified) InsurancePlan.ownedBy
 *
 * http://hl7.org/fhir/_ownedBy
 */
var _ownedBy = 'http://hl7.org/fhir/_ownedBy';
/**
 * measurementFrequency
 *
 * DeviceMetric.measurementFrequency: The frequency at which the metric is taken or recorded. Devices measure metrics at a wide range of frequencies; for example, an ECG might sample measurements in the millisecond range, while an NIBP might trigger only once an hour. Less often, the measurementFrequency may be based on a unit other than time, such as distance (e.g. for a measuring wheel). The update period may be different than the measurement frequency, if the device does not update the published observed value with the same frequency as it was measured.
 *
 * http://hl7.org/fhir/measurementFrequency
 */
var measurementFrequency = 'http://hl7.org/fhir/measurementFrequency';
/**
 * _traceNumber
 *
 * (Modified) ClaimResponse.addItem.detail.traceNumber
 *
 * http://hl7.org/fhir/_traceNumber
 */
var _traceNumber = 'http://hl7.org/fhir/_traceNumber';
/**
 * _excludingDate
 *
 * (Modified) Appointment.recurrenceTemplate.excludingDate
 *
 * http://hl7.org/fhir/_excludingDate
 */
var _excludingDate = 'http://hl7.org/fhir/_excludingDate';
/**
 * _required
 *
 * (Modified) TestScript.metadata.capability.required
 *
 * http://hl7.org/fhir/_required
 */
var _required = 'http://hl7.org/fhir/_required';
/**
 * correctiveAction
 *
 * DeviceDefinition.correctiveAction: Tracking of latest field safety corrective action.
 *
 * http://hl7.org/fhir/correctiveAction
 */
var correctiveAction = 'http://hl7.org/fhir/correctiveAction';
/**
 * schedule
 *
 * MedicationKnowledge.regulatory.schedule: Specifies the schedule of a medication in jurisdiction.
 *
 * http://hl7.org/fhir/schedule
 */
var schedule = 'http://hl7.org/fhir/schedule';
/**
 * _referral
 *
 * (Modified) ExplanationOfBenefit.referral
 *
 * http://hl7.org/fhir/_referral
 */
var _referral = 'http://hl7.org/fhir/_referral';
/**
 * alternate
 *
 * DeviceDefinition.material.alternate: Indicates an alternative material of the device.
 *
 * http://hl7.org/fhir/alternate
 */
var alternate = 'http://hl7.org/fhir/alternate';
/**
 * intendedExposure
 *
 * ResearchStudy.comparisonGroup.intendedExposure: Interventions or exposures in this comparisonGroup or cohort.
 *
 * http://hl7.org/fhir/intendedExposure
 */
var intendedExposure = 'http://hl7.org/fhir/intendedExposure';
/**
 * threePrime
 *
 * SubstanceNucleicAcid.subunit.threePrime: The nucleotide present at the 3’ terminal shall be specified based on a controlled vocabulary. Since the sequence is represented from the 5' to the 3' end, the 5’ prime nucleotide is the letter at the last position in the sequence. A separate representation would be redundant.
 *
 * http://hl7.org/fhir/threePrime
 */
var threePrime = 'http://hl7.org/fhir/threePrime';
/**
 * param
 *
 * CompartmentDefinition.resource.param: The name of a search parameter that represents the link to the compartment. More than one may be listed because a resource may be linked to a compartment in more than one way,.
 *
 * http://hl7.org/fhir/param
 */
var param = 'http://hl7.org/fhir/param';
/**
 * _proposedNewTime
 *
 * (Modified) AppointmentResponse.proposedNewTime
 *
 * http://hl7.org/fhir/_proposedNewTime
 */
var _proposedNewTime = 'http://hl7.org/fhir/_proposedNewTime';
/**
 * power
 *
 * VisionPrescription.lensSpecification.power: Contact lens power measured in dioptres (0.25 units).
 *
 * http://hl7.org/fhir/power
 */
var power = 'http://hl7.org/fhir/power';
/**
 * cardinalityBehavior
 *
 * RequestOrchestration.action.action.cardinalityBehavior: Defines whether the action can be selected multiple times.
 *
 * http://hl7.org/fhir/cardinalityBehavior
 */
var cardinalityBehavior = 'http://hl7.org/fhir/cardinalityBehavior';
/**
 * supportingPatientInformation
 *
 * ImmunizationRecommendation.recommendation.supportingPatientInformation: Patient Information that supports the status and recommendation.  This includes patient observations, adverse reactions and allergy/intolerance information.
 *
 * http://hl7.org/fhir/supportingPatientInformation
 */
var supportingPatientInformation = 'http://hl7.org/fhir/supportingPatientInformation';
/**
 * _predecessor
 *
 * (Modified) TestPlan.testCase.dependency.predecessor
 *
 * http://hl7.org/fhir/_predecessor
 */
var _predecessor = 'http://hl7.org/fhir/_predecessor';
/**
 * allergenicIndicator
 *
 * Ingredient.allergenicIndicator: If the ingredient is a known or suspected allergen. Note that this is a property of the substance, so if a reference to a SubstanceDefinition is used to decribe that (rather than just a code), the allergen information should go there, not here.
 *
 * http://hl7.org/fhir/allergenicIndicator
 */
var allergenicIndicator = 'http://hl7.org/fhir/allergenicIndicator';
/**
 * _regulator
 *
 * (Modified) RegulatedAuthorization.regulator
 *
 * http://hl7.org/fhir/_regulator
 */
var _regulator = 'http://hl7.org/fhir/_regulator';
/**
 * issue
 *
 * OperationOutcome.issue: An error, warning, or information message that results from a system action.
 *
 * http://hl7.org/fhir/issue
 */
var issue = 'http://hl7.org/fhir/issue';
/**
 * _admission
 *
 * (Modified) Encounter.admission
 *
 * http://hl7.org/fhir/_admission
 */
var _admission = 'http://hl7.org/fhir/_admission';
/**
 * _extension
 *
 * (Modified) DomainResource.extension
 *
 * http://hl7.org/fhir/_extension
 */
var _extension = 'http://hl7.org/fhir/_extension';
/**
 * _notificationShape
 *
 * (Modified) SubscriptionTopic.notificationShape
 *
 * http://hl7.org/fhir/_notificationShape
 */
var _notificationShape = 'http://hl7.org/fhir/_notificationShape';
/**
 * Device
 *
 * This resource describes the properties (regulated, has real time clock, etc.), adminstrative (manufacturer name, model number, serial number, firmware, etc.), and type (knee replacement, blood pressure cuff, MRI, etc.) of a physical unit (these values do not change much within a given module, for example the serail number, manufacturer name, and model number). An actual unit may consist of several modules in a distinct hierarchy and these are represented by multiple Device resources and bound through the 'parent' element.
 *
 * http://hl7.org/fhir/Device
 */
var Device = 'http://hl7.org/fhir/Device';
/**
 * Range
 *
 * A set of ordered Quantities defined by a low and high limit.
 *
 * http://hl7.org/fhir/Range
 */
var Range = 'http://hl7.org/fhir/Range';
/**
 * ItemBodySite
 *
 * ExplanationOfBenefit.Item.ItemBodySite: Physical location where the service is performed or applies.
 *
 * http://hl7.org/fhir/ItemBodySite
 */
var ItemBodySite = 'http://hl7.org/fhir/ItemBodySite';
/**
 * average
 *
 * SubstancePolymer.repeat.repeatUnit.degreeOfPolymerisation.average: An average amount of polymerisation.
 *
 * http://hl7.org/fhir/average
 */
var average = 'http://hl7.org/fhir/average';
/**
 * SubstanceNucleicAcidSubunitSugarComponent
 *
 * SubstanceNucleicAcidSubunitComponent.SubstanceNucleicAcidSubunitSugarComponent: 5.3.6.8.1 Sugar ID (Mandatory).
 *
 * http://hl7.org/fhir/SubstanceNucleicAcidSubunitSugarComponent
 */
var SubstanceNucleicAcidSubunitSugarComponent = 'http://hl7.org/fhir/SubstanceNucleicAcidSubunitSugarComponent';
/**
 * Composition
 *
 * A set of healthcare-related information that is assembled together into a single logical package that provides a single coherent statement of meaning, establishes its own context and that has clinical attestation with regard to who is making the statement. A Composition defines the structure and narrative content necessary for a document. However, a Composition alone does not constitute a document. Rather, the Composition must be the first entry in a Bundle where Bundle.type=document, and any other resources referenced from Composition must be included as subsequent entries in the Bundle (for example Patient, Practitioner, Encounter, etc.).
 *
 * http://hl7.org/fhir/Composition
 */
var Composition = 'http://hl7.org/fhir/Composition';
/**
 * _otherMap
 *
 * (Modified) ConceptMap.group.unmapped.otherMap
 *
 * http://hl7.org/fhir/_otherMap
 */
var _otherMap = 'http://hl7.org/fhir/_otherMap';
/**
 * Rule
 *
 * Permission.Rule: A set of rules.
 *
 * http://hl7.org/fhir/Rule
 */
var Rule = 'http://hl7.org/fhir/Rule';
/**
 * testScript
 *
 * TestReport.testScript: Ideally this is an absolute URL that is used to identify the version-specific TestScript that was executed, matching the `TestScript.url`.
 *
 * http://hl7.org/fhir/testScript
 */
var testScript = 'http://hl7.org/fhir/testScript';
/**
 * targetId
 *
 * GraphDefinition.link.targetId: The target node for this link.
 *
 * http://hl7.org/fhir/targetId
 */
var targetId = 'http://hl7.org/fhir/targetId';
/**
 * _additionalAttribute
 *
 * (Modified) ConceptMap.additionalAttribute
 *
 * http://hl7.org/fhir/_additionalAttribute
 */
var _additionalAttribute = 'http://hl7.org/fhir/_additionalAttribute';
/**
 * _validity
 *
 * (Modified) Permission.validity
 *
 * http://hl7.org/fhir/_validity
 */
var _validity = 'http://hl7.org/fhir/_validity';
/**
 * _product
 *
 * (Modified) VisionPrescription.lensSpecification.product
 *
 * http://hl7.org/fhir/_product
 */
var _product = 'http://hl7.org/fhir/_product';
/**
 * objective
 *
 * ResearchStudy.objective: A goal that the study is aiming to achieve in terms of a scientific question to be answered by the analysis of data collected during the study.
 *
 * http://hl7.org/fhir/objective
 */
var objective = 'http://hl7.org/fhir/objective';
/**
 * _containedItem
 *
 * (Modified) PackagedProductDefinition.packaging.packaging.containedItem
 *
 * http://hl7.org/fhir/_containedItem
 */
var _containedItem = 'http://hl7.org/fhir/_containedItem';
/**
 * MedicationKnowledgePackagingComponentCost
 *
 * The cost of the packaged medication.
 *
 * http://hl7.org/fhir/MedicationKnowledgePackagingComponentCost
 */
var MedicationKnowledgePackagingComponentCost = 'http://hl7.org/fhir/MedicationKnowledgePackagingComponentCost';
/**
 * relatedDevice
 *
 * DeviceDefinition.link.relatedDevice: A reference to the linked device.
 *
 * http://hl7.org/fhir/relatedDevice
 */
var relatedDevice = 'http://hl7.org/fhir/relatedDevice';
/**
 * QuestionnaireItemEnableWhenComponent
 *
 * QuestionnaireItemComponentItem.QuestionnaireItemEnableWhenComponent: A constraint indicating that this item should only be enabled (displayed/allow answers to be captured) when the specified condition is true.
 *
 * http://hl7.org/fhir/QuestionnaireItemEnableWhenComponent
 */
var QuestionnaireItemEnableWhenComponent = 'http://hl7.org/fhir/QuestionnaireItemEnableWhenComponent';
/**
 * _numberAffected
 *
 * (Modified) Evidence.statistic.numberAffected
 *
 * http://hl7.org/fhir/_numberAffected
 */
var _numberAffected = 'http://hl7.org/fhir/_numberAffected';
/**
 * _batch
 *
 * (Modified) Medication.batch
 *
 * http://hl7.org/fhir/_batch
 */
var _batch = 'http://hl7.org/fhir/_batch';
/**
 * preparationInstruction
 *
 * MedicationKnowledge.preparationInstruction: The instructions for preparing the medication.
 *
 * http://hl7.org/fhir/preparationInstruction
 */
var preparationInstruction = 'http://hl7.org/fhir/preparationInstruction';
/**
 * EpisodeOfCare
 *
 * An association between a patient and an organization / healthcare provider(s) during which time encounters may occur. The managing organization assumes a level of responsibility for the patient during this time.
 *
 * http://hl7.org/fhir/EpisodeOfCare
 */
var EpisodeOfCare = 'http://hl7.org/fhir/EpisodeOfCare';
/**
 * _entity
 *
 * (Modified) Provenance.entity
 *
 * http://hl7.org/fhir/_entity
 */
var _entity = 'http://hl7.org/fhir/_entity';
/**
 * _initiator
 *
 * (Modified) ExampleScenario.process.step.alternative.step.operation.initiator
 *
 * http://hl7.org/fhir/_initiator
 */
var _initiator = 'http://hl7.org/fhir/_initiator';
/**
 * _communication
 *
 * (Modified) RelatedPerson.communication
 *
 * http://hl7.org/fhir/_communication
 */
var _communication = 'http://hl7.org/fhir/_communication';
/**
 * programEligibility
 *
 * Immunization.programEligibility: Indicates a patient's eligibility for a funding program.
 *
 * http://hl7.org/fhir/programEligibility
 */
var programEligibility = 'http://hl7.org/fhir/programEligibility';
/**
 * addItem
 *
 * ExplanationOfBenefit.addItem: The first-tier service adjudications for payor added product or service lines.
 *
 * http://hl7.org/fhir/addItem
 */
var addItem = 'http://hl7.org/fhir/addItem';
/**
 * _details
 *
 * (Modified) OperationOutcome.issue.details
 *
 * http://hl7.org/fhir/_details
 */
var _details = 'http://hl7.org/fhir/_details';
/**
 * pageString
 *
 * Citation.citedArtifact.publicationForm.pageString: Used for full display of pagination.
 *
 * http://hl7.org/fhir/pageString
 */
var pageString = 'http://hl7.org/fhir/pageString';
/**
 * expansion
 *
 * ValueSet.expansion: A value set can also be "expanded", where the value set is turned into a simple collection of enumerated codes. This element holds the expansion, if it has been performed.
 *
 * http://hl7.org/fhir/expansion
 */
var expansion = 'http://hl7.org/fhir/expansion';
/**
 * MedicationKnowledgeRegulatoryComponent
 *
 * MedicationKnowledgeRegulatoryComponent: Regulatory information about a medication.
 *
 * http://hl7.org/fhir/MedicationKnowledgeRegulatoryComponent
 */
var MedicationKnowledgeRegulatoryComponent = 'http://hl7.org/fhir/MedicationKnowledgeRegulatoryComponent';
/**
 * _affiliation
 *
 * (Modified) Citation.citedArtifact.contributorship.entry.affiliation
 *
 * http://hl7.org/fhir/_affiliation
 */
var _affiliation = 'http://hl7.org/fhir/_affiliation';
/**
 * _contentDefinition
 *
 * (Modified) Contract.contentDefinition
 *
 * http://hl7.org/fhir/_contentDefinition
 */
var _contentDefinition = 'http://hl7.org/fhir/_contentDefinition';
/**
 * marketPeriod
 *
 * DeviceDefinition.packaging.packaging.udiDeviceIdentifier.marketDistribution.marketPeriod: Begin and end dates for the commercial distribution of the device.
 *
 * http://hl7.org/fhir/marketPeriod
 */
var marketPeriod = 'http://hl7.org/fhir/marketPeriod';
/**
 * _reportingPeriod
 *
 * (Modified) InventoryReport.reportingPeriod
 *
 * http://hl7.org/fhir/_reportingPeriod
 */
var _reportingPeriod = 'http://hl7.org/fhir/_reportingPeriod';
/**
 * _accountNumber
 *
 * (Modified) PaymentReconciliation.accountNumber
 *
 * http://hl7.org/fhir/_accountNumber
 */
var _accountNumber = 'http://hl7.org/fhir/_accountNumber';
/**
 * _geneSequenceOrigin
 *
 * (Modified) SubstanceReferenceInformation.gene.geneSequenceOrigin
 *
 * http://hl7.org/fhir/_geneSequenceOrigin
 */
var _geneSequenceOrigin = 'http://hl7.org/fhir/_geneSequenceOrigin';
/**
 * subpotentReason
 *
 * Immunization.subpotentReason: Reason why a dose is considered to be subpotent.
 *
 * http://hl7.org/fhir/subpotentReason
 */
var subpotentReason = 'http://hl7.org/fhir/subpotentReason';
/**
 * inventoryStatus
 *
 * InventoryItem.inventoryStatus: The usage status e.g. recalled, in use, discarded... This can be used to indicate that the items have been taken out of inventory, or are in use, etc.
 *
 * http://hl7.org/fhir/inventoryStatus
 */
var inventoryStatus = 'http://hl7.org/fhir/inventoryStatus';
/**
 * subunit
 *
 * SubstanceProtein.subunit: This subclause refers to the description of each subunit constituting the SubstanceProtein. A subunit is a linear sequence of amino acids linked through peptide bonds. The Subunit information shall be provided when the finished SubstanceProtein is a complex of multiple sequences; subunits are not used to delineate domains within a single sequence. Subunits are listed in order of decreasing length; sequences of the same length will be ordered by decreasing molecular weight; subunits that have identical sequences will be repeated multiple times.
 *
 * http://hl7.org/fhir/subunit
 */
var subunit = 'http://hl7.org/fhir/subunit';
/**
 * orderer
 *
 * NutritionOrder.orderer: The practitioner that holds legal responsibility for ordering the diet, nutritional supplement, or formula feedings.
 *
 * http://hl7.org/fhir/orderer
 */
var orderer = 'http://hl7.org/fhir/orderer';
/**
 * ExampleScenarioInstanceVersionComponent
 *
 * ExampleScenarioInstanceComponent.ExampleScenarioInstanceVersionComponent: Represents the instance as it was at a specific time-point.
 *
 * http://hl7.org/fhir/ExampleScenarioInstanceVersionComponent
 */
var ExampleScenarioInstanceVersionComponent = 'http://hl7.org/fhir/ExampleScenarioInstanceVersionComponent';
/**
 * itemStatus
 *
 * InventoryReport.inventoryListing.itemStatus: The status of the items.
 *
 * http://hl7.org/fhir/itemStatus
 */
var itemStatus = 'http://hl7.org/fhir/itemStatus';
/**
 * _ResearchStudy
 *
 * (Modified) ResearchStudy
 *
 * http://hl7.org/fhir/_ResearchStudy
 */
var _ResearchStudy = 'http://hl7.org/fhir/_ResearchStudy';
/**
 * resourceType
 *
 * Subscription.filterBy.resourceType: A resource listed in the `SubscriptionTopic` this `Subscription` references (`SubscriptionTopic.canFilterBy.resource`). This element can be used to differentiate filters for topics that include more than one resource type.
 *
 * http://hl7.org/fhir/resourceType
 */
var resourceType = 'http://hl7.org/fhir/resourceType';
/**
 * Quantity
 *
 * A measured amount (or an amount that can potentially be measured). Note that measured amounts include amounts that are not precisely quantified, including amounts involving arbitrary units and floating currencies.
 *
 * http://hl7.org/fhir/Quantity
 */
var Quantity = 'http://hl7.org/fhir/Quantity';
/**
 * contained
 *
 * DomainResource.contained: These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, nor can they have their own independent transaction scope. This is allowed to be a Parameters resource if and only if it is referenced by a resource that provides context/meaning.
 *
 * http://hl7.org/fhir/contained
 */
var contained = 'http://hl7.org/fhir/contained';
/**
 * _appointmentType
 *
 * (Modified) Slot.appointmentType
 *
 * http://hl7.org/fhir/_appointmentType
 */
var _appointmentType = 'http://hl7.org/fhir/_appointmentType';
/**
 * SpecimenDefinitionTypeTestedComponent
 *
 * SpecimenDefinitionTypeTestedComponent: Specimen conditioned in a container as expected by the testing laboratory.
 *
 * http://hl7.org/fhir/SpecimenDefinitionTypeTestedComponent
 */
var SpecimenDefinitionTypeTestedComponent = 'http://hl7.org/fhir/SpecimenDefinitionTypeTestedComponent';
/**
 * _actual
 *
 * (Modified) ResearchStudy.progressStatus.actual
 *
 * http://hl7.org/fhir/_actual
 */
var _actual = 'http://hl7.org/fhir/_actual';
/**
 * CostToBeneficiary
 *
 * Coverage.CostToBeneficiary: A suite of codes indicating the cost category and associated amount which have been detailed in the policy and may have been  included on the health card.
 *
 * http://hl7.org/fhir/CostToBeneficiary
 */
var CostToBeneficiary = 'http://hl7.org/fhir/CostToBeneficiary';
/**
 * _Schedule
 *
 * (Modified) Schedule
 *
 * http://hl7.org/fhir/_Schedule
 */
var _Schedule = 'http://hl7.org/fhir/_Schedule';
/**
 * programCode
 *
 * ExplanationOfBenefit.addItem.programCode: Identifies the program under which this may be recovered.
 *
 * http://hl7.org/fhir/programCode
 */
var programCode = 'http://hl7.org/fhir/programCode';
/**
 * _PractitionerRole
 *
 * (Modified) PractitionerRole
 *
 * http://hl7.org/fhir/_PractitionerRole
 */
var _PractitionerRole = 'http://hl7.org/fhir/_PractitionerRole';
/**
 * guarantor
 *
 * Account.guarantor: The parties responsible for balancing the account if other payment options fall short.
 *
 * http://hl7.org/fhir/guarantor
 */
var guarantor = 'http://hl7.org/fhir/guarantor';
/**
 * _FamilyMemberHistory
 *
 * (Modified) FamilyMemberHistory
 *
 * http://hl7.org/fhir/_FamilyMemberHistory
 */
var _FamilyMemberHistory = 'http://hl7.org/fhir/_FamilyMemberHistory';
/**
 * _operationTypeReason
 *
 * (Modified) InventoryReport.operationTypeReason
 *
 * http://hl7.org/fhir/_operationTypeReason
 */
var _operationTypeReason = 'http://hl7.org/fhir/_operationTypeReason';
/**
 * _programStatus
 *
 * (Modified) Immunization.programEligibility.programStatus
 *
 * http://hl7.org/fhir/_programStatus
 */
var _programStatus = 'http://hl7.org/fhir/_programStatus';
/**
 * _performerLinkId
 *
 * (Modified) Contract.term.group.action.performerLinkId
 *
 * http://hl7.org/fhir/_performerLinkId
 */
var _performerLinkId = 'http://hl7.org/fhir/_performerLinkId';
/**
 * onHold
 *
 * Account.guarantor.onHold: A guarantor may be placed on credit hold or otherwise have their role temporarily suspended.
 *
 * http://hl7.org/fhir/onHold
 */
var onHold = 'http://hl7.org/fhir/onHold';
/**
 * _copackagedIndicator
 *
 * (Modified) PackagedProductDefinition.copackagedIndicator
 *
 * http://hl7.org/fhir/_copackagedIndicator
 */
var _copackagedIndicator = 'http://hl7.org/fhir/_copackagedIndicator';
/**
 * storageGuideline
 *
 * MedicationKnowledge.storageGuideline: Information on how the medication should be stored, for example, refrigeration temperatures and length of stability at a given temperature.
 *
 * http://hl7.org/fhir/storageGuideline
 */
var storageGuideline = 'http://hl7.org/fhir/storageGuideline';
/**
 * _receiver
 *
 * (Modified) SupplyDelivery.receiver
 *
 * http://hl7.org/fhir/_receiver
 */
var _receiver = 'http://hl7.org/fhir/_receiver';
/**
 * _whyStopped
 *
 * (Modified) ResearchStudy.whyStopped
 *
 * http://hl7.org/fhir/_whyStopped
 */
var _whyStopped = 'http://hl7.org/fhir/_whyStopped';
/**
 * _packageFor
 *
 * (Modified) PackagedProductDefinition.packageFor
 *
 * http://hl7.org/fhir/_packageFor
 */
var _packageFor = 'http://hl7.org/fhir/_packageFor';
/**
 * action
 *
 * RequestOrchestration.action.action: Sub actions.
 *
 * http://hl7.org/fhir/action
 */
var action = 'http://hl7.org/fhir/action';
/**
 * _sourceMaterialState
 *
 * (Modified) SubstanceSourceMaterial.sourceMaterialState
 *
 * http://hl7.org/fhir/_sourceMaterialState
 */
var _sourceMaterialState = 'http://hl7.org/fhir/_sourceMaterialState';
/**
 * indicationGuideline
 *
 * MedicationKnowledge.indicationGuideline: Guidelines or protocols that are applicable for the administration of the medication based on indication.
 *
 * http://hl7.org/fhir/indicationGuideline
 */
var indicationGuideline = 'http://hl7.org/fhir/indicationGuideline';
/**
 * _interaction
 *
 * (Modified) SubstanceReferenceInformation.target.interaction
 *
 * http://hl7.org/fhir/_interaction
 */
var _interaction = 'http://hl7.org/fhir/_interaction';
/**
 * aggregateMethod
 *
 * Measure.group.population.aggregateMethod: Specifies which method should be used to aggregate measure observation values. For most scoring types, this is implied by scoring (e.g. a proportion measure counts members of the populations). For continuous variables, however, this information must be specified to ensure correct calculation.
 *
 * http://hl7.org/fhir/aggregateMethod
 */
var aggregateMethod = 'http://hl7.org/fhir/aggregateMethod';
/**
 * _authorizingPrescription
 *
 * (Modified) MedicationDispense.authorizingPrescription
 *
 * http://hl7.org/fhir/_authorizingPrescription
 */
var _authorizingPrescription = 'http://hl7.org/fhir/_authorizingPrescription';
/**
 * _authoritative
 *
 * (Modified) NamingSystem.uniqueId.authoritative
 *
 * http://hl7.org/fhir/_authoritative
 */
var _authoritative = 'http://hl7.org/fhir/_authoritative';
/**
 * timeAspect
 *
 * SpecimenDefinition.timeAspect: Time aspect of specimen collection (duration or offset).
 *
 * http://hl7.org/fhir/timeAspect
 */
var timeAspect = 'http://hl7.org/fhir/timeAspect';
/**
 * _valueSet
 *
 * (Modified) ElementDefinition.binding.additional.valueSet
 *
 * http://hl7.org/fhir/_valueSet
 */
var _valueSet = 'http://hl7.org/fhir/_valueSet';
/**
 * OperationOutcome
 *
 * A collection of error, warning, or information messages that result from a system action.
 *
 * http://hl7.org/fhir/OperationOutcome
 */
var OperationOutcome = 'http://hl7.org/fhir/OperationOutcome';
/**
 * Contributor
 *
 * A contributor to the content of a knowledge asset, including authors, editors, reviewers, and endorsers.
 *
 * http://hl7.org/fhir/Contributor
 */
var Contributor = 'http://hl7.org/fhir/Contributor';
/**
 * _message
 *
 * (Modified) TestReport.teardown.action.operation.message
 *
 * http://hl7.org/fhir/_message
 */
var _message = 'http://hl7.org/fhir/_message';
/**
 * import
 *
 * StructureMap.import: Other maps used by this map (canonical URLs).
 * Note that `import` is a reserved Javascript keyword, and is therefore suffixed by `__workaround`.
 * For a list of reserved keywords, see https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Lexical_grammar#Keywords.
 *
 * http://hl7.org/fhir/import
 */
var import__workaround = 'http://hl7.org/fhir/import';
/**
 * definitionByTypeAndValue
 *
 * EvidenceVariable.characteristic.definitionByCombination.characteristic.definitionByTypeAndValue: Defines the characteristic using both a type and value[x] elements.
 *
 * http://hl7.org/fhir/definitionByTypeAndValue
 */
var definitionByTypeAndValue = 'http://hl7.org/fhir/definitionByTypeAndValue';
/**
 * TestScriptSetupActionOperationComponent
 *
 * TestScriptSetupComponent.SetupAction.TestScriptSetupActionOperationComponent: The operation to perform.
 *
 * http://hl7.org/fhir/TestScriptSetupActionOperationComponent
 */
var TestScriptSetupActionOperationComponent = 'http://hl7.org/fhir/TestScriptSetupActionOperationComponent';
/**
 * mitigatingAction
 *
 * AdverseEvent.mitigatingAction: The ameliorating action taken after the adverse event occured in order to reduce the extent of harm.
 *
 * http://hl7.org/fhir/mitigatingAction
 */
var mitigatingAction = 'http://hl7.org/fhir/mitigatingAction';
/**
 * validationDate
 *
 * VerificationResult.primarySource.validationDate: When the target was validated against the primary source.
 *
 * http://hl7.org/fhir/validationDate
 */
var validationDate = 'http://hl7.org/fhir/validationDate';
/**
 * healthcareService
 *
 * PractitionerRole.healthcareService: The list of healthcare services that this worker provides for this role's Organization/Location(s).
 *
 * http://hl7.org/fhir/healthcareService
 */
var healthcareService = 'http://hl7.org/fhir/healthcareService';
/**
 * conditionalPatch
 *
 * CapabilityStatement.rest.resource.conditionalPatch: A flag that indicates that the server supports conditional patch.
 *
 * http://hl7.org/fhir/conditionalPatch
 */
var conditionalPatch = 'http://hl7.org/fhir/conditionalPatch';
/**
 * minimumVolume
 *
 * SpecimenDefinition.typeTested.container.minimumVolume
 *
 * http://hl7.org/fhir/minimumVolume
 */
var minimumVolume = 'http://hl7.org/fhir/minimumVolume';
/**
 * _practiceSetting
 *
 * (Modified) DocumentReference.practiceSetting
 *
 * http://hl7.org/fhir/_practiceSetting
 */
var _practiceSetting = 'http://hl7.org/fhir/_practiceSetting';
/**
 * protocol
 *
 * ResearchStudy.protocol: The set of steps expected to be performed as part of the execution of the study.
 *
 * http://hl7.org/fhir/protocol
 */
var protocol = 'http://hl7.org/fhir/protocol';
/**
 * _structureProfile
 *
 * (Modified) ExampleScenario.instance.structureProfile
 *
 * http://hl7.org/fhir/_structureProfile
 */
var _structureProfile = 'http://hl7.org/fhir/_structureProfile';
/**
 * _Coverage
 *
 * (Modified) Coverage
 *
 * http://hl7.org/fhir/_Coverage
 */
var _Coverage = 'http://hl7.org/fhir/_Coverage';
/**
 * _issuerType
 *
 * (Modified) PaymentReconciliation.issuerType
 *
 * http://hl7.org/fhir/_issuerType
 */
var _issuerType = 'http://hl7.org/fhir/_issuerType';
/**
 * MedicationRequest
 *
 * An order or request for both supply of the medication and the instructions for administration of the medication to a patient. The resource is called "MedicationRequest" rather than "MedicationPrescription" or "MedicationOrder" to generalize the use across inpatient and outpatient settings, including care plans, etc., and to harmonize with workflow patterns.
 *
 * http://hl7.org/fhir/MedicationRequest
 */
var MedicationRequest = 'http://hl7.org/fhir/MedicationRequest';
/**
 * _pattern
 *
 * (Modified) ElementDefinition.pattern
 *
 * http://hl7.org/fhir/_pattern
 */
var _pattern = 'http://hl7.org/fhir/_pattern';
/**
 * processingFacility
 *
 * BiologicallyDerivedProduct.processingFacility: Processing facilities responsible for the labeling and distribution of this biologically derived product.
 *
 * http://hl7.org/fhir/processingFacility
 */
var processingFacility = 'http://hl7.org/fhir/processingFacility';
/**
 * _situation
 *
 * (Modified) MessageDefinition.allowedResponse.situation
 *
 * http://hl7.org/fhir/_situation
 */
var _situation = 'http://hl7.org/fhir/_situation';
/**
 * _patchFormat
 *
 * (Modified) CapabilityStatement.patchFormat
 *
 * http://hl7.org/fhir/_patchFormat
 */
var _patchFormat = 'http://hl7.org/fhir/_patchFormat';
/**
 * alternateMaterial
 *
 * PackagedProductDefinition.packaging.packaging.alternateMaterial: A possible alternate material for this part of the packaging, that is allowed to be used instead of the usual material (e.g. different types of plastic for a blister sleeve).
 *
 * http://hl7.org/fhir/alternateMaterial
 */
var alternateMaterial = 'http://hl7.org/fhir/alternateMaterial';
/**
 * responsible
 *
 * NamingSystem.responsible: The name of the organization that is responsible for issuing identifiers or codes for this namespace and ensuring their non-collision.
 *
 * http://hl7.org/fhir/responsible
 */
var responsible = 'http://hl7.org/fhir/responsible';
/**
 * PlanDefinitionActionRelatedActionComponent
 *
 * PlanDefinitionActionComponent.PlanDefinitionActionRelatedActionComponent: A relationship to another action such as "before" or "30-60 minutes after start of".
 *
 * http://hl7.org/fhir/PlanDefinitionActionRelatedActionComponent
 */
var PlanDefinitionActionRelatedActionComponent = 'http://hl7.org/fhir/PlanDefinitionActionRelatedActionComponent';
/**
 * _security
 *
 * (Modified) Permission.rule.data.security
 *
 * http://hl7.org/fhir/_security
 */
var _security = 'http://hl7.org/fhir/_security';
/**
 * combined
 *
 * Specimen.combined: This element signifies if the specimen is part of a group or pooled.
 *
 * http://hl7.org/fhir/combined
 */
var combined = 'http://hl7.org/fhir/combined';
/**
 * contains
 *
 * ValueSet.expansion.contains: The codes that are contained in the value set expansion.
 *
 * http://hl7.org/fhir/contains
 */
var contains = 'http://hl7.org/fhir/contains';
/**
 * _addresses
 *
 * (Modified) PlanDefinition.goal.addresses
 *
 * http://hl7.org/fhir/_addresses
 */
var _addresses = 'http://hl7.org/fhir/_addresses';
/**
 * expirationDate
 *
 * Immunization.expirationDate: Date vaccine batch expires.
 *
 * http://hl7.org/fhir/expirationDate
 */
var expirationDate = 'http://hl7.org/fhir/expirationDate';
/**
 * compartment
 *
 * GraphDefinition.link.compartment: Compartment Consistency Rules.
 *
 * http://hl7.org/fhir/compartment
 */
var compartment = 'http://hl7.org/fhir/compartment';
/**
 * _scoring
 *
 * (Modified) MeasureReport.scoring
 *
 * http://hl7.org/fhir/_scoring
 */
var _scoring = 'http://hl7.org/fhir/_scoring';
/**
 * policy
 *
 * AuditEvent.agent.policy: Where the policy(ies) are known that authorized the agent participation in the event. Typically, a single activity may have multiple applicable policies, such as patient consent, guarantor funding, etc. The policy would also indicate the security token used.
 *
 * http://hl7.org/fhir/policy
 */
var policy = 'http://hl7.org/fhir/policy';
/**
 * recordedDate
 *
 * AdverseEvent.recordedDate: The date on which the existence of the AdverseEvent was first recorded.
 *
 * http://hl7.org/fhir/recordedDate
 */
var recordedDate = 'http://hl7.org/fhir/recordedDate';
/**
 * _sourceScope
 *
 * (Modified) ConceptMap.sourceScope
 *
 * http://hl7.org/fhir/_sourceScope
 */
var _sourceScope = 'http://hl7.org/fhir/_sourceScope';
/**
 * _chain
 *
 * (Modified) SearchParameter.chain
 *
 * http://hl7.org/fhir/_chain
 */
var _chain = 'http://hl7.org/fhir/_chain';
/**
 * ImplementationGuideManifestComponent
 *
 * ImplementationGuideManifestComponent: Information about an assembled implementation guide, created by the publication tooling.
 *
 * http://hl7.org/fhir/ImplementationGuideManifestComponent
 */
var ImplementationGuideManifestComponent = 'http://hl7.org/fhir/ImplementationGuideManifestComponent';
/**
 * _contributedToDeath
 *
 * (Modified) FamilyMemberHistory.procedure.contributedToDeath
 *
 * http://hl7.org/fhir/_contributedToDeath
 */
var _contributedToDeath = 'http://hl7.org/fhir/_contributedToDeath';
/**
 * _diagnosisRelatedGroup
 *
 * (Modified) ExplanationOfBenefit.diagnosisRelatedGroup
 *
 * http://hl7.org/fhir/_diagnosisRelatedGroup
 */
var _diagnosisRelatedGroup = 'http://hl7.org/fhir/_diagnosisRelatedGroup';
/**
 * _referenceNumber
 *
 * (Modified) PaymentReconciliation.referenceNumber
 *
 * http://hl7.org/fhir/_referenceNumber
 */
var _referenceNumber = 'http://hl7.org/fhir/_referenceNumber';
/**
 * _template
 *
 * (Modified) ImplementationGuide.definition.template
 *
 * http://hl7.org/fhir/_template
 */
var _template = 'http://hl7.org/fhir/_template';
/**
 * _preConditions
 *
 * (Modified) ExampleScenario.process.step.alternative.step.process.preConditions
 *
 * http://hl7.org/fhir/_preConditions
 */
var _preConditions = 'http://hl7.org/fhir/_preConditions';
/**
 * _score
 *
 * (Modified) TestReport.score
 *
 * http://hl7.org/fhir/_score
 */
var _score = 'http://hl7.org/fhir/_score';
/**
 * SubstancePolymerMonomerSetComponent
 *
 * SubstancePolymerMonomerSetComponent: Todo.
 *
 * http://hl7.org/fhir/SubstancePolymerMonomerSetComponent
 */
var SubstancePolymerMonomerSetComponent = 'http://hl7.org/fhir/SubstancePolymerMonomerSetComponent';
/**
 * _requiredBehavior
 *
 * (Modified) RequestOrchestration.action.action.requiredBehavior
 *
 * http://hl7.org/fhir/_requiredBehavior
 */
var _requiredBehavior = 'http://hl7.org/fhir/_requiredBehavior';
/**
 * _statusHistory
 *
 * (Modified) EpisodeOfCare.statusHistory
 *
 * http://hl7.org/fhir/_statusHistory
 */
var _statusHistory = 'http://hl7.org/fhir/_statusHistory';
/**
 * replacementSequence
 *
 * MolecularSequence.relative.edit.replacementSequence: Allele that was observed. Nucleotide(s)/amino acids from start position of sequence to stop position of sequence on the positive (+) strand of the observed sequence. When the sequence type is DNA, it should be the sequence on the positive (+) strand. This will lay in the range between variant.start and variant.end.
 *
 * http://hl7.org/fhir/replacementSequence
 */
var replacementSequence = 'http://hl7.org/fhir/replacementSequence';
/**
 * _file
 *
 * (Modified) SubstanceDefinition.characterization.file
 *
 * http://hl7.org/fhir/_file
 */
var _file = 'http://hl7.org/fhir/_file';
/**
 * _height
 *
 * (Modified) Attachment.height
 *
 * http://hl7.org/fhir/_height
 */
var _height = 'http://hl7.org/fhir/_height';
/**
 * _groupSize
 *
 * (Modified) InsurancePlan.plan.generalCost.groupSize
 *
 * http://hl7.org/fhir/_groupSize
 */
var _groupSize = 'http://hl7.org/fhir/_groupSize';
/**
 * observedGroup
 *
 * ResearchStudy.comparisonGroup.observedGroup: Group of participants who were enrolled in study comparisonGroup.
 *
 * http://hl7.org/fhir/observedGroup
 */
var observedGroup = 'http://hl7.org/fhir/observedGroup';
/**
 * receivedTime
 *
 * Specimen.receivedTime: Time when specimen is received by the testing laboratory for processing or testing.
 *
 * http://hl7.org/fhir/receivedTime
 */
var receivedTime = 'http://hl7.org/fhir/receivedTime';
/**
 * _doseAndRate
 *
 * (Modified) Dosage.doseAndRate
 *
 * http://hl7.org/fhir/_doseAndRate
 */
var _doseAndRate = 'http://hl7.org/fhir/_doseAndRate';
/**
 * definitionCanonical
 *
 * EvidenceVariable.characteristic.definitionByCombination.characteristic.definitionCanonical: Defines the characteristic using Canonical.
 *
 * http://hl7.org/fhir/definitionCanonical
 */
var definitionCanonical = 'http://hl7.org/fhir/definitionCanonical';
/**
 * QuestionnaireResponseItemComponent
 *
 * QuestionnaireResponseItemComponent: A group or question item from the original questionnaire for which answers are provided.
 *
 * http://hl7.org/fhir/QuestionnaireResponseItemComponent
 */
var QuestionnaireResponseItemComponent = 'http://hl7.org/fhir/QuestionnaireResponseItemComponent';
/**
 * _typeReference
 *
 * (Modified) PlanDefinition.actor.option.typeReference
 *
 * http://hl7.org/fhir/_typeReference
 */
var _typeReference = 'http://hl7.org/fhir/_typeReference';
/**
 * PractitionerQualificationComponent
 *
 * PractitionerQualificationComponent: The official qualifications, certifications, accreditations, training, licenses (and other types of educations/skills/capabilities) that authorize or otherwise pertain to the provision of care by the practitioner.

For example, a medical license issued by a medical board of licensure authorizing the practitioner to practice medicine within a certain locality.
 *
 * http://hl7.org/fhir/PractitionerQualificationComponent
 */
var PractitionerQualificationComponent = 'http://hl7.org/fhir/PractitionerQualificationComponent';
/**
 * cTerminalModificationId
 *
 * SubstanceProtein.subunit.cTerminalModificationId: Unique identifier for molecular fragment modification based on the ISO 11238 Substance ID.
 *
 * http://hl7.org/fhir/cTerminalModificationId
 */
var cTerminalModificationId = 'http://hl7.org/fhir/cTerminalModificationId';
/**
 * _requireBoth
 *
 * (Modified) SubscriptionTopic.resourceTrigger.queryCriteria.requireBoth
 *
 * http://hl7.org/fhir/_requireBoth
 */
var _requireBoth = 'http://hl7.org/fhir/_requireBoth';
/**
 * dataAbsentReason
 *
 * Observation.component.dataAbsentReason: Provides a reason why the expected value in the element Observation.component.value[x] is missing.
 *
 * http://hl7.org/fhir/dataAbsentReason
 */
var dataAbsentReason = 'http://hl7.org/fhir/dataAbsentReason';
/**
 * _criticality
 *
 * (Modified) AllergyIntolerance.criticality
 *
 * http://hl7.org/fhir/_criticality
 */
var _criticality = 'http://hl7.org/fhir/_criticality';
/**
 * _subjectStatus
 *
 * (Modified) EncounterHistory.subjectStatus
 *
 * http://hl7.org/fhir/_subjectStatus
 */
var _subjectStatus = 'http://hl7.org/fhir/_subjectStatus';
/**
 * _expiry
 *
 * (Modified) Substance.expiry
 *
 * http://hl7.org/fhir/_expiry
 */
var _expiry = 'http://hl7.org/fhir/_expiry';
/**
 * usage
 *
 * ActivityDefinition.usage: A detailed description of how the activity definition is used from a clinical perspective.
 *
 * http://hl7.org/fhir/usage
 */
var usage = 'http://hl7.org/fhir/usage';
/**
 * city
 *
 * Address.city: The name of the city, town, suburb, village or other community or delivery center.
 *
 * http://hl7.org/fhir/city
 */
var city = 'http://hl7.org/fhir/city';
/**
 * _instances
 *
 * (Modified) EvidenceVariable.characteristic.instances
 *
 * http://hl7.org/fhir/_instances
 */
var _instances = 'http://hl7.org/fhir/_instances';
/**
 * stratum
 *
 * MeasureReport.group.stratifier.stratum: This element contains the results for a single stratum within the stratifier. For example, when stratifying on administrative gender, there will be four strata, one for each possible gender value.
 *
 * http://hl7.org/fhir/stratum
 */
var stratum = 'http://hl7.org/fhir/stratum';
/**
 * MeasureReportGroupStratifierComponent
 *
 * MeasureReportGroupComponent.MeasureReportGroupStratifierComponent: When a measure includes multiple stratifiers, there will be a stratifier group for each stratifier defined by the measure.
 *
 * http://hl7.org/fhir/MeasureReportGroupStratifierComponent
 */
var MeasureReportGroupStratifierComponent = 'http://hl7.org/fhir/MeasureReportGroupStratifierComponent';
/**
 * _ratioHighLimitAmount
 *
 * (Modified) SubstanceDefinition.relationship.ratioHighLimitAmount
 *
 * http://hl7.org/fhir/_ratioHighLimitAmount
 */
var _ratioHighLimitAmount = 'http://hl7.org/fhir/_ratioHighLimitAmount';
/**
 * route
 *
 * Dosage.route: How drug should enter body.
 *
 * http://hl7.org/fhir/route
 */
var route = 'http://hl7.org/fhir/route';
/**
 * TestScriptMetadataLinkComponent
 *
 * TestScriptMetadataComponent.TestScriptMetadataLinkComponent: A link to the FHIR specification that this test is covering.
 *
 * http://hl7.org/fhir/TestScriptMetadataLinkComponent
 */
var TestScriptMetadataLinkComponent = 'http://hl7.org/fhir/TestScriptMetadataLinkComponent';
/**
 * DeviceDispensePerformerComponent
 *
 * DeviceDispensePerformerComponent: Indicates who or what performed the event.
 *
 * http://hl7.org/fhir/DeviceDispensePerformerComponent
 */
var DeviceDispensePerformerComponent = 'http://hl7.org/fhir/DeviceDispensePerformerComponent';
/**
 * frequencyMax
 *
 * Timing.repeat.frequencyMax: If present, indicates that the frequency is a range - so to repeat between [frequency] and [frequencyMax] times within the period or period range.
 *
 * http://hl7.org/fhir/frequencyMax
 */
var frequencyMax = 'http://hl7.org/fhir/frequencyMax';
/**
 * _number
 *
 * (Modified) ExampleScenario.process.step.process.step.number
 *
 * http://hl7.org/fhir/_number
 */
var _number = 'http://hl7.org/fhir/_number';
/**
 * QuestionnaireResponse
 *
 * A structured set of questions and their answers. The questions are ordered and grouped into coherent subsets, corresponding to the structure of the grouping of the questionnaire being responded to.
 *
 * http://hl7.org/fhir/QuestionnaireResponse
 */
var QuestionnaireResponse = 'http://hl7.org/fhir/QuestionnaireResponse';
/**
 * MappingProperty
 *
 * ConceptMapGroupComponent.SourceElement.TargetElement.MappingProperty: A property value for this source -> target mapping.
 *
 * http://hl7.org/fhir/MappingProperty
 */
var MappingProperty = 'http://hl7.org/fhir/MappingProperty';
/**
 * _securityContext
 *
 * (Modified) Binary.securityContext
 *
 * http://hl7.org/fhir/_securityContext
 */
var _securityContext = 'http://hl7.org/fhir/_securityContext';
/**
 * display
 *
 * TestReport.participant.display: The display name of the participant.
 *
 * http://hl7.org/fhir/display
 */
var display = 'http://hl7.org/fhir/display';
/**
 * yearlyTemplate
 *
 * Appointment.recurrenceTemplate.yearlyTemplate: Information about yearly recurring appointments.
 *
 * http://hl7.org/fhir/yearlyTemplate
 */
var yearlyTemplate = 'http://hl7.org/fhir/yearlyTemplate';
/**
 * ChargeItemPerformerComponent
 *
 * ChargeItemPerformerComponent: Indicates who or what performed or participated in the charged service.
 *
 * http://hl7.org/fhir/ChargeItemPerformerComponent
 */
var ChargeItemPerformerComponent = 'http://hl7.org/fhir/ChargeItemPerformerComponent';
/**
 * Contact
 *
 * Patient.Contact: A contact party (e.g. guardian, partner, friend) for the patient.
 *
 * http://hl7.org/fhir/Contact
 */
var Contact = 'http://hl7.org/fhir/Contact';
/**
 * EndpointPayloadComponent
 *
 * EndpointPayloadComponent: The set of payloads that are provided/available at this endpoint.
 *
 * http://hl7.org/fhir/EndpointPayloadComponent
 */
var EndpointPayloadComponent = 'http://hl7.org/fhir/EndpointPayloadComponent';
/**
 * _relatedArtifact
 *
 * (Modified) ChargeItemDefinition.propertyGroup.applicability.relatedArtifact
 *
 * http://hl7.org/fhir/_relatedArtifact
 */
var _relatedArtifact = 'http://hl7.org/fhir/_relatedArtifact';
/**
 * updateCreate
 *
 * CapabilityStatement.rest.resource.updateCreate: A flag to indicate that the server allows or needs to allow the client to create new identities on the server (that is, the client PUTs to a location where there is no existing resource). Allowing this operation means that the server allows the client to create new identities on the server.
 *
 * http://hl7.org/fhir/updateCreate
 */
var updateCreate = 'http://hl7.org/fhir/updateCreate';
/**
 * _subtype
 *
 * (Modified) Contract.term.group.asset.subtype
 *
 * http://hl7.org/fhir/_subtype
 */
var _subtype = 'http://hl7.org/fhir/_subtype';
/**
 * _stereochemistry
 *
 * (Modified) SubstanceDefinition.structure.stereochemistry
 *
 * http://hl7.org/fhir/_stereochemistry
 */
var _stereochemistry = 'http://hl7.org/fhir/_stereochemistry';
/**
 * _upperLimit
 *
 * (Modified) SampledData.upperLimit
 *
 * http://hl7.org/fhir/_upperLimit
 */
var _upperLimit = 'http://hl7.org/fhir/_upperLimit';
/**
 * routeOfAdministration
 *
 * NutritionOrder.enteralFormula.routeOfAdministration: The route or physiological path of administration into the patient's gastrointestinal  tract for purposes of providing the formula feeding, e.g. nasogastric tube.
 *
 * http://hl7.org/fhir/routeOfAdministration
 */
var routeOfAdministration = 'http://hl7.org/fhir/routeOfAdministration';
/**
 * _amountType
 *
 * (Modified) SubstanceReferenceInformation.target.amountType
 *
 * http://hl7.org/fhir/_amountType
 */
var _amountType = 'http://hl7.org/fhir/_amountType';
/**
 * _organismType
 *
 * (Modified) SubstanceReferenceInformation.target.organismType
 *
 * http://hl7.org/fhir/_organismType
 */
var _organismType = 'http://hl7.org/fhir/_organismType';
/**
 * bodySite
 *
 * Specimen.collection.bodySite: Anatomical location from which the specimen was collected (if subject is a patient). This is the target site.  This element is not used for environmental specimens.
 *
 * http://hl7.org/fhir/bodySite
 */
var bodySite = 'http://hl7.org/fhir/bodySite';
/**
 * _moiety
 *
 * (Modified) SubstanceDefinition.moiety
 *
 * http://hl7.org/fhir/_moiety
 */
var _moiety = 'http://hl7.org/fhir/_moiety';
/**
 * _recommendation
 *
 * (Modified) ImmunizationRecommendation.recommendation
 *
 * http://hl7.org/fhir/_recommendation
 */
var _recommendation = 'http://hl7.org/fhir/_recommendation';
/**
 * grouping
 *
 * ImplementationGuide.definition.grouping: A logical group of resources. Logical groups can be used when building pages.
 *
 * http://hl7.org/fhir/grouping
 */
var grouping = 'http://hl7.org/fhir/grouping';
/**
 * _pause
 *
 * (Modified) ExampleScenario.process.step.pause
 *
 * http://hl7.org/fhir/_pause
 */
var _pause = 'http://hl7.org/fhir/_pause';
/**
 * _primaryPurposeType
 *
 * (Modified) ResearchStudy.primaryPurposeType
 *
 * http://hl7.org/fhir/_primaryPurposeType
 */
var _primaryPurposeType = 'http://hl7.org/fhir/_primaryPurposeType';
/**
 * ConceptSubProperty
 *
 * ValueSetExpansionComponent.ValueSetExpansionContainsComponentContains.ConceptProperty.ConceptSubProperty: A subproperty value for this concept.
 *
 * http://hl7.org/fhir/ConceptSubProperty
 */
var ConceptSubProperty = 'http://hl7.org/fhir/ConceptSubProperty';
/**
 * subscription
 *
 * SubscriptionStatus.subscription: The reference to the Subscription which generated this notification.
 *
 * http://hl7.org/fhir/subscription
 */
var subscription = 'http://hl7.org/fhir/subscription';
/**
 * _lastPage
 *
 * (Modified) Citation.citedArtifact.publicationForm.lastPage
 *
 * http://hl7.org/fhir/_lastPage
 */
var _lastPage = 'http://hl7.org/fhir/_lastPage';
/**
 * partLocation
 *
 * SubstanceSourceMaterial.partDescription.partLocation: The detailed anatomic location when the part can be extracted from different anatomical locations of the organism. Multiple alternative locations may apply.
 *
 * http://hl7.org/fhir/partLocation
 */
var partLocation = 'http://hl7.org/fhir/partLocation';
/**
 * controller
 *
 * Consent.controller: The actor that controls/enforces the access according to the consent.
 *
 * http://hl7.org/fhir/controller
 */
var controller = 'http://hl7.org/fhir/controller';
/**
 * publicationDateSeason
 *
 * Citation.citedArtifact.publicationForm.publicationDateSeason: Spring, Summer, Fall/Autumn, Winter.
 *
 * http://hl7.org/fhir/publicationDateSeason
 */
var publicationDateSeason = 'http://hl7.org/fhir/publicationDateSeason';
/**
 * imports
 *
 * CapabilityStatement.imports: Reference to a canonical URL of another CapabilityStatement that this software adds to. The capability statement automatically includes everything in the other statement, and it is not duplicated, though the server may repeat the same resources, interactions and operations to add additional details to them.
 *
 * http://hl7.org/fhir/imports
 */
var imports = 'http://hl7.org/fhir/imports';
/**
 * allocation
 *
 * PaymentReconciliation.allocation: Distribution of the payment amount for a previously acknowledged payable.
 *
 * http://hl7.org/fhir/allocation
 */
var allocation = 'http://hl7.org/fhir/allocation';
/**
 * _pageCount
 *
 * (Modified) Citation.citedArtifact.publicationForm.pageCount
 *
 * http://hl7.org/fhir/_pageCount
 */
var _pageCount = 'http://hl7.org/fhir/_pageCount';
/**
 * _failureAction
 *
 * (Modified) VerificationResult.failureAction
 *
 * http://hl7.org/fhir/_failureAction
 */
var _failureAction = 'http://hl7.org/fhir/_failureAction';
/**
 * profile
 *
 * ImplementationGuide.global.profile: A reference to the profile that all instances must conform to.
 *
 * http://hl7.org/fhir/profile
 */
var profile = 'http://hl7.org/fhir/profile';
/**
 * cylinder
 *
 * VisionPrescription.lensSpecification.cylinder: Power adjustment for astigmatism measured in dioptres (0.25 units).
 *
 * http://hl7.org/fhir/cylinder
 */
var cylinder = 'http://hl7.org/fhir/cylinder';
/**
 * deleted
 *
 * List.entry.deleted: True if this item is marked as deleted in the list.
 *
 * http://hl7.org/fhir/deleted
 */
var deleted = 'http://hl7.org/fhir/deleted';
/**
 * episodeOfCare
 *
 * Encounter.episodeOfCare: Where a specific encounter should be classified as a part of a specific episode(s) of care this field should be used. This association can facilitate grouping of related encounters together for a specific purpose, such as government reporting, issue tracking, association via a common problem.  The association is recorded on the encounter as these are typically created after the episode of care and grouped on entry rather than editing the episode of care to append another encounter to it (the episode of care could span years).
 *
 * http://hl7.org/fhir/episodeOfCare
 */
var episodeOfCare = 'http://hl7.org/fhir/episodeOfCare';
/**
 * saturday
 *
 * Appointment.recurrenceTemplate.weeklyTemplate.saturday: Indicates that recurring appointments should occur on Saturdays.
 *
 * http://hl7.org/fhir/saturday
 */
var saturday = 'http://hl7.org/fhir/saturday';
/**
 * _expectedInResearchStudy
 *
 * (Modified) AdverseEvent.expectedInResearchStudy
 *
 * http://hl7.org/fhir/_expectedInResearchStudy
 */
var _expectedInResearchStudy = 'http://hl7.org/fhir/_expectedInResearchStudy';
/**
 * CommunicationRequestPayloadComponent
 *
 * CommunicationRequestPayloadComponent: Text, attachment(s), or resource(s) to be communicated to the recipient.
 *
 * http://hl7.org/fhir/CommunicationRequestPayloadComponent
 */
var CommunicationRequestPayloadComponent = 'http://hl7.org/fhir/CommunicationRequestPayloadComponent';
/**
 * _calculatedAt
 *
 * (Modified) Account.calculatedAt
 *
 * http://hl7.org/fhir/_calculatedAt
 */
var _calculatedAt = 'http://hl7.org/fhir/_calculatedAt';
/**
 * _impurity
 *
 * (Modified) MedicinalProductDefinition.impurity
 *
 * http://hl7.org/fhir/_impurity
 */
var _impurity = 'http://hl7.org/fhir/_impurity';
/**
 * type
 *
 * NamingSystem.type: Categorizes a naming system for easier search by grouping related naming systems.
 *
 * http://hl7.org/fhir/type
 */
var type = 'http://hl7.org/fhir/type';
/**
 * goalId
 *
 * PlanDefinition.action.action.goalId: Identifies goals that this action supports. The reference must be to a goal element defined within this plan definition. In pharmaceutical quality, a goal represents acceptance criteria (Goal) for a given action (Test), so the goalId would be the unique id of a defined goal element establishing the acceptance criteria for the action.
 *
 * http://hl7.org/fhir/goalId
 */
var goalId = 'http://hl7.org/fhir/goalId';
/**
 * ObservationDefinitionComponentComponent
 *
 * ObservationDefinitionComponentComponent: Some observations have multiple component observations, expressed as separate code value pairs.
 *
 * http://hl7.org/fhir/ObservationDefinitionComponentComponent
 */
var ObservationDefinitionComponentComponent = 'http://hl7.org/fhir/ObservationDefinitionComponentComponent';
/**
 * TestScriptSetupComponent
 *
 * TestScriptSetupComponent: A series of required setup operations before tests are executed.
 *
 * http://hl7.org/fhir/TestScriptSetupComponent
 */
var TestScriptSetupComponent = 'http://hl7.org/fhir/TestScriptSetupComponent';
/**
 * Appointment
 *
 * A booking of a healthcare event among patient(s), practitioner(s), related person(s) and/or device(s) for a specific date/time. This may result in one or more Encounter(s).
 *
 * http://hl7.org/fhir/Appointment
 */
var Appointment = 'http://hl7.org/fhir/Appointment';
/**
 * _groupIdentifier
 *
 * (Modified) Transport.groupIdentifier
 *
 * http://hl7.org/fhir/_groupIdentifier
 */
var _groupIdentifier = 'http://hl7.org/fhir/_groupIdentifier';
/**
 * _countMax
 *
 * (Modified) Timing.repeat.countMax
 *
 * http://hl7.org/fhir/_countMax
 */
var _countMax = 'http://hl7.org/fhir/_countMax';
/**
 * patientCharacteristic
 *
 * MedicationKnowledge.indicationGuideline.dosingGuideline.patientCharacteristic: Characteristics of the patient that are relevant to the administration guidelines (for example, height, weight, gender, etc.).
 *
 * http://hl7.org/fhir/patientCharacteristic
 */
var patientCharacteristic = 'http://hl7.org/fhir/patientCharacteristic';
/**
 * lowNumerator
 *
 * RatioRange.lowNumerator: The value of the low limit numerator.
 *
 * http://hl7.org/fhir/lowNumerator
 */
var lowNumerator = 'http://hl7.org/fhir/lowNumerator';
/**
 * _texture
 *
 * (Modified) NutritionOrder.oralDiet.texture
 *
 * http://hl7.org/fhir/_texture
 */
var _texture = 'http://hl7.org/fhir/_texture';
/**
 * _causality
 *
 * (Modified) AdverseEvent.suspectEntity.causality
 *
 * http://hl7.org/fhir/_causality
 */
var _causality = 'http://hl7.org/fhir/_causality';
/**
 * operator
 *
 * CodeSystem.filter.operator: A list of operators that can be used with the filter.
 *
 * http://hl7.org/fhir/operator
 */
var operator = 'http://hl7.org/fhir/operator';
/**
 * fixed
 *
 * http://hl7.org/fhir/fixed
 */
var fixed = 'http://hl7.org/fhir/fixed';
/**
 * nTerminalModificationId
 *
 * SubstanceProtein.subunit.nTerminalModificationId: Unique identifier for molecular fragment modification based on the ISO 11238 Substance ID.
 *
 * http://hl7.org/fhir/nTerminalModificationId
 */
var nTerminalModificationId = 'http://hl7.org/fhir/nTerminalModificationId';
/**
 * InventoryItemNameComponent
 *
 * InventoryItemNameComponent: The item name(s) - the brand name, or common name, functional name, generic name.
 *
 * http://hl7.org/fhir/InventoryItemNameComponent
 */
var InventoryItemNameComponent = 'http://hl7.org/fhir/InventoryItemNameComponent';
/**
 * _minimumId
 *
 * (Modified) TestScript.test.action.assert.minimumId
 *
 * http://hl7.org/fhir/_minimumId
 */
var _minimumId = 'http://hl7.org/fhir/_minimumId';
/**
 * verificationStatus
 *
 * Condition.verificationStatus: The verification status to support the clinical status of the condition.  The verification status pertains to the condition, itself, not to any specific condition attribute.
 *
 * http://hl7.org/fhir/verificationStatus
 */
var verificationStatus = 'http://hl7.org/fhir/verificationStatus';
/**
 * _PaymentNotice
 *
 * (Modified) PaymentNotice
 *
 * http://hl7.org/fhir/_PaymentNotice
 */
var _PaymentNotice = 'http://hl7.org/fhir/_PaymentNotice';
/**
 * _dateAccessed
 *
 * (Modified) Citation.citedArtifact.dateAccessed
 *
 * http://hl7.org/fhir/_dateAccessed
 */
var _dateAccessed = 'http://hl7.org/fhir/_dateAccessed';
/**
 * logMessage
 *
 * StructureMap.group.rule.rule.source.logMessage: A FHIRPath expression which specifies a message to put in the transform log when content matching the source rule is found.
 *
 * http://hl7.org/fhir/logMessage
 */
var logMessage = 'http://hl7.org/fhir/logMessage';
/**
 * ResearchStudyProgressStatusComponent
 *
 * ResearchStudyProgressStatusComponent: Status of study with time for that status.
 *
 * http://hl7.org/fhir/ResearchStudyProgressStatusComponent
 */
var ResearchStudyProgressStatusComponent = 'http://hl7.org/fhir/ResearchStudyProgressStatusComponent';
/**
 * _residueSite
 *
 * (Modified) SubstanceNucleicAcid.subunit.sugar.residueSite
 *
 * http://hl7.org/fhir/_residueSite
 */
var _residueSite = 'http://hl7.org/fhir/_residueSite';
/**
 * MonetaryComponent
 *
 * Availability data for an {item}.
 *
 * http://hl7.org/fhir/MonetaryComponent
 */
var MonetaryComponent = 'http://hl7.org/fhir/MonetaryComponent';
/**
 * TeardownAction
 *
 * TestScriptTeardownComponent.TeardownAction: The teardown action will only contain an operation.
 *
 * http://hl7.org/fhir/TeardownAction
 */
var TeardownAction = 'http://hl7.org/fhir/TeardownAction';
/**
 * clinicalUseIssue
 *
 * MedicationKnowledge.clinicalUseIssue: Potential clinical issue with or between medication(s) (for example, drug-drug interaction, drug-disease contraindication, drug-allergy interaction, etc.).
 *
 * http://hl7.org/fhir/clinicalUseIssue
 */
var clinicalUseIssue = 'http://hl7.org/fhir/clinicalUseIssue';
/**
 * classification
 *
 * MedicinalProductDefinition.classification: Allows the product to be classified by various systems, commonly WHO ATC.
 *
 * http://hl7.org/fhir/classification
 */
var classification = 'http://hl7.org/fhir/classification';
/**
 * _lifecycleStatus
 *
 * (Modified) Goal.lifecycleStatus
 *
 * http://hl7.org/fhir/_lifecycleStatus
 */
var _lifecycleStatus = 'http://hl7.org/fhir/_lifecycleStatus';
/**
 * signature
 *
 * Bundle.signature: Digital Signature - base64 encoded. XML-DSig or a JWS.
 *
 * http://hl7.org/fhir/signature
 */
var signature = 'http://hl7.org/fhir/signature';
/**
 * reviewer
 *
 * EvidenceVariable.reviewer: An individual or organization asserted by the publisher to be primarily responsible for review of some aspect of the content.
 *
 * http://hl7.org/fhir/reviewer
 */
var reviewer = 'http://hl7.org/fhir/reviewer';
/**
 * _usePeriod
 *
 * (Modified) Contract.term.group.asset.usePeriod
 *
 * http://hl7.org/fhir/_usePeriod
 */
var _usePeriod = 'http://hl7.org/fhir/_usePeriod';
/**
 * BodyStructureIncludedStructureComponent
 *
 * BodyStructureIncludedStructureComponent: The anatomical location(s) or region(s) of the specimen, lesion, or body structure.
 *
 * http://hl7.org/fhir/BodyStructureIncludedStructureComponent
 */
var BodyStructureIncludedStructureComponent = 'http://hl7.org/fhir/BodyStructureIncludedStructureComponent';
/**
 * next
 *
 * ValueSet.expansion.next: As per paging Search results, the next URLs are opaque to the client, have no dictated structure, and only the server understands them.
 *
 * http://hl7.org/fhir/next
 */
var next = 'http://hl7.org/fhir/next';
/**
 * _changeType
 *
 * (Modified) GenomicStudy.analysis.changeType
 *
 * http://hl7.org/fhir/_changeType
 */
var _changeType = 'http://hl7.org/fhir/_changeType';
/**
 * _ImmunizationEvaluation
 *
 * (Modified) ImmunizationEvaluation
 *
 * http://hl7.org/fhir/_ImmunizationEvaluation
 */
var _ImmunizationEvaluation = 'http://hl7.org/fhir/_ImmunizationEvaluation';
/**
 * requestingOrganization
 *
 * ChargeItem.requestingOrganization: The organization requesting the service.
 *
 * http://hl7.org/fhir/requestingOrganization
 */
var requestingOrganization = 'http://hl7.org/fhir/requestingOrganization';
/**
 * _unitOfPresentation
 *
 * (Modified) ManufacturedItemDefinition.unitOfPresentation
 *
 * http://hl7.org/fhir/_unitOfPresentation
 */
var _unitOfPresentation = 'http://hl7.org/fhir/_unitOfPresentation';
/**
 * requestedPeriod
 *
 * Task.requestedPeriod: Indicates the start and/or end of the period of time when completion of the task is desired to take place.
 *
 * http://hl7.org/fhir/requestedPeriod
 */
var requestedPeriod = 'http://hl7.org/fhir/requestedPeriod';
/**
 * Answer
 *
 * Contract.TermTerm.ContractOffer.Answer: Response to offer text.
 *
 * http://hl7.org/fhir/Answer
 */
var Answer = 'http://hl7.org/fhir/Answer';
/**
 * count
 *
 * MeasureReport.group.stratifier.stratum.population.count: The number of members of the population in this stratum.
 *
 * http://hl7.org/fhir/count
 */
var count = 'http://hl7.org/fhir/count';
/**
 * ContractOffer
 *
 * Contract.TermTerm.ContractOffer: The matter of concern in the context of this provision of the agrement.
 *
 * http://hl7.org/fhir/ContractOffer
 */
var ContractOffer = 'http://hl7.org/fhir/ContractOffer';
/**
 * composition
 *
 * DiagnosticReport.composition: Reference to a Composition resource instance that provides structure for organizing the contents of the DiagnosticReport.
 *
 * http://hl7.org/fhir/composition
 */
var composition = 'http://hl7.org/fhir/composition';
/**
 * _EnrollmentResponse
 *
 * (Modified) EnrollmentResponse
 *
 * http://hl7.org/fhir/_EnrollmentResponse
 */
var _EnrollmentResponse = 'http://hl7.org/fhir/_EnrollmentResponse';
/**
 * ConditionStageComponent
 *
 * ConditionStageComponent: A simple summary of the stage such as "Stage 3" or "Early Onset". The determination of the stage is disease-specific, such as cancer, retinopathy of prematurity, kidney diseases, Alzheimer's, or Parkinson disease.
 *
 * http://hl7.org/fhir/ConditionStageComponent
 */
var ConditionStageComponent = 'http://hl7.org/fhir/ConditionStageComponent';
/**
 * ResearchSubjectProgressComponent
 *
 * ResearchSubjectProgressComponent: The current state (status) of the subject and resons for status change where appropriate.
 *
 * http://hl7.org/fhir/ResearchSubjectProgressComponent
 */
var ResearchSubjectProgressComponent = 'http://hl7.org/fhir/ResearchSubjectProgressComponent';
/**
 * key
 *
 * ExampleScenario.instance.key: A unique string within the scenario that is used to reference the instance.
 *
 * http://hl7.org/fhir/key
 */
var key = 'http://hl7.org/fhir/key';
/**
 * assertion
 *
 * TestPlan.testCase.assertion: The test assertions - the expectations of test results from the execution of the test case.
 *
 * http://hl7.org/fhir/assertion
 */
var assertion = 'http://hl7.org/fhir/assertion';
/**
 * MedicationKnowledgeIndicationGuidelineDosingGuidelinePatientCharacteristicComponent
 *
 * MedicationKnowledgeIndicationGuidelineComponent.MedicationKnowledgeIndicationGuidelineDosingGuidelineComponent.MedicationKnowledgeIndicationGuidelineDosingGuidelinePatientCharacteristicComponent: Characteristics of the patient that are relevant to the administration guidelines (for example, height, weight, gender, etc.).
 *
 * http://hl7.org/fhir/MedicationKnowledgeIndicationGuidelineDosingGuidelinePatientCharacteristicComponent
 */
var MedicationKnowledgeIndicationGuidelineDosingGuidelinePatientCharacteristicComponent = 'http://hl7.org/fhir/MedicationKnowledgeIndicationGuidelineDosingGuidelinePatientCharacteristicComponent';
/**
 * alternative
 *
 * ExampleScenario.process.step.alternative: Indicates an alternative step that can be taken instead of the sub-process, scenario or operation.  E.g. to represent non-happy-path/exceptional/atypical circumstances.
 *
 * http://hl7.org/fhir/alternative
 */
var alternative = 'http://hl7.org/fhir/alternative';
/**
 * plan
 *
 * InsurancePlan.plan: Details about an insurance plan.
 *
 * http://hl7.org/fhir/plan
 */
var plan = 'http://hl7.org/fhir/plan';
/**
 * _criteria
 *
 * (Modified) Measure.supplementalData.criteria
 *
 * http://hl7.org/fhir/_criteria
 */
var _criteria = 'http://hl7.org/fhir/_criteria';
/**
 * cycle
 *
 * Device.cycle: The series of occurrences that repeats during the operation of the device.
 *
 * http://hl7.org/fhir/cycle
 */
var cycle = 'http://hl7.org/fhir/cycle';
/**
 * _latitude
 *
 * (Modified) Location.position.latitude
 *
 * http://hl7.org/fhir/_latitude
 */
var _latitude = 'http://hl7.org/fhir/_latitude';
/**
 * modifier
 *
 * SubscriptionTopic.canFilterBy.modifier: Modifiers allowed for the filter parameter.
 *
 * http://hl7.org/fhir/modifier
 */
var modifier = 'http://hl7.org/fhir/modifier';
/**
 * _scoringUnit
 *
 * (Modified) Measure.group.scoringUnit
 *
 * http://hl7.org/fhir/_scoringUnit
 */
var _scoringUnit = 'http://hl7.org/fhir/_scoringUnit';
/**
 * subJurisdiction
 *
 * DeviceDefinition.packaging.packaging.udiDeviceIdentifier.marketDistribution.subJurisdiction: National state or territory to which the marketDistribution recers, typically where the device is commercialized.
 *
 * http://hl7.org/fhir/subJurisdiction
 */
var subJurisdiction = 'http://hl7.org/fhir/subJurisdiction';
/**
 * _search
 *
 * (Modified) CompartmentDefinition.search
 *
 * http://hl7.org/fhir/_search
 */
var _search = 'http://hl7.org/fhir/_search';
/**
 * assignedComparisonGroup
 *
 * ResearchSubject.assignedComparisonGroup: The name of the arm in the study the subject is expected to follow as part of this study.
 *
 * http://hl7.org/fhir/assignedComparisonGroup
 */
var assignedComparisonGroup = 'http://hl7.org/fhir/assignedComparisonGroup';
/**
 * _alias
 *
 * (Modified) StructureMap.structure.alias
 *
 * http://hl7.org/fhir/_alias
 */
var _alias = 'http://hl7.org/fhir/_alias';
/**
 * _status
 *
 * (Modified) ActorDefinition.status
 *
 * http://hl7.org/fhir/_status
 */
var _status = 'http://hl7.org/fhir/_status';
/**
 * recurring
 *
 * AppointmentResponse.recurring: Indicates that this AppointmentResponse applies to all occurrences in a recurring request.
 *
 * http://hl7.org/fhir/recurring
 */
var recurring = 'http://hl7.org/fhir/recurring';
/**
 * InventoryItemInstanceComponent
 *
 * InventoryItemInstanceComponent: Instances or occurrences of the product.
 *
 * http://hl7.org/fhir/InventoryItemInstanceComponent
 */
var InventoryItemInstanceComponent = 'http://hl7.org/fhir/InventoryItemInstanceComponent';
/**
 * frameOfReferenceUid
 *
 * ImagingSelection.frameOfReferenceUid: The Frame of Reference UID identifying the coordinate system that conveys spatial and/or temporal information for the selected images or frames.
 *
 * http://hl7.org/fhir/frameOfReferenceUid
 */
var frameOfReferenceUid = 'http://hl7.org/fhir/frameOfReferenceUid';
/**
 * _validationDate
 *
 * (Modified) VerificationResult.primarySource.validationDate
 *
 * http://hl7.org/fhir/_validationDate
 */
var _validationDate = 'http://hl7.org/fhir/_validationDate';
/**
 * NutritionOrderEnteralFormulaComponent
 *
 * NutritionOrderEnteralFormulaComponent: Feeding provided through the gastrointestinal tract via a tube, catheter, or stoma that delivers nutrition distal to the oral cavity.
 *
 * http://hl7.org/fhir/NutritionOrderEnteralFormulaComponent
 */
var NutritionOrderEnteralFormulaComponent = 'http://hl7.org/fhir/NutritionOrderEnteralFormulaComponent';
/**
 * deliveryDevice
 *
 * NutritionOrder.enteralFormula.deliveryDevice: The intended type of device that is to be used for the administration of the enteral formula.
 *
 * http://hl7.org/fhir/deliveryDevice
 */
var deliveryDevice = 'http://hl7.org/fhir/deliveryDevice';
/**
 * _cardBrand
 *
 * (Modified) PaymentReconciliation.cardBrand
 *
 * http://hl7.org/fhir/_cardBrand
 */
var _cardBrand = 'http://hl7.org/fhir/_cardBrand';
/**
 * adjustment
 *
 * ExplanationOfBenefit.payment.adjustment: Total amount of all adjustments to this payment included in this transaction which are not related to this claim's adjudication.
 *
 * http://hl7.org/fhir/adjustment
 */
var adjustment = 'http://hl7.org/fhir/adjustment';
/**
 * _cors
 *
 * (Modified) CapabilityStatement.rest.security.cors
 *
 * http://hl7.org/fhir/_cors
 */
var _cors = 'http://hl7.org/fhir/_cors';
/**
 * _allergenicIndicator
 *
 * (Modified) Ingredient.allergenicIndicator
 *
 * http://hl7.org/fhir/_allergenicIndicator
 */
var _allergenicIndicator = 'http://hl7.org/fhir/_allergenicIndicator';
/**
 * _timezone
 *
 * (Modified) Appointment.recurrenceTemplate.timezone
 *
 * http://hl7.org/fhir/_timezone
 */
var _timezone = 'http://hl7.org/fhir/_timezone';
/**
 * _actor
 *
 * (Modified) Consent.provision.actor
 *
 * http://hl7.org/fhir/_actor
 */
var _actor = 'http://hl7.org/fhir/_actor';
/**
 * valueQuantity
 *
 * Evidence.statistic.modelCharacteristic.variable.valueQuantity: Discrete value for grouping of ordinal or polychotomous variables.
 *
 * http://hl7.org/fhir/valueQuantity
 */
var valueQuantity = 'http://hl7.org/fhir/valueQuantity';
/**
 * _versionId
 *
 * (Modified) Meta.versionId
 *
 * http://hl7.org/fhir/_versionId
 */
var _versionId = 'http://hl7.org/fhir/_versionId';
/**
 * requester
 *
 * SupplyRequest.requester: The device, practitioner, etc. who initiated the request.
 *
 * http://hl7.org/fhir/requester
 */
var requester = 'http://hl7.org/fhir/requester';
/**
 * _SupplyRequest
 *
 * (Modified) SupplyRequest
 *
 * http://hl7.org/fhir/_SupplyRequest
 */
var _SupplyRequest = 'http://hl7.org/fhir/_SupplyRequest';
/**
 * MeasureTermComponent
 *
 * MeasureTermComponent: Provides a description of an individual term used within the measure.
 *
 * http://hl7.org/fhir/MeasureTermComponent
 */
var MeasureTermComponent = 'http://hl7.org/fhir/MeasureTermComponent';
/**
 * _containedItemQuantity
 *
 * (Modified) PackagedProductDefinition.containedItemQuantity
 *
 * http://hl7.org/fhir/_containedItemQuantity
 */
var _containedItemQuantity = 'http://hl7.org/fhir/_containedItemQuantity';
/**
 * _daysSupply
 *
 * (Modified) MedicationDispense.daysSupply
 *
 * http://hl7.org/fhir/_daysSupply
 */
var _daysSupply = 'http://hl7.org/fhir/_daysSupply';
/**
 * reportingVendor
 *
 * MeasureReport.reportingVendor: A reference to the vendor who queried the data, calculated results and/or generated the report. The ‘reporting vendor’ is intended to represent the submitting entity when it is not the same as the reporting entity. This extension is used when the Receiver is interested in getting vendor information in the report.
 *
 * http://hl7.org/fhir/reportingVendor
 */
var reportingVendor = 'http://hl7.org/fhir/reportingVendor';
/**
 * current
 *
 * SubscriptionTopic.resourceTrigger.queryCriteria.current: The FHIR query based rules are applied to the current resource state (e.g., state after an update).
 *
 * http://hl7.org/fhir/current
 */
var current = 'http://hl7.org/fhir/current';
/**
 * uid
 *
 * ImagingStudy.series.instance.uid: The DICOM SOP Instance UID for this image or other DICOM content.
 *
 * http://hl7.org/fhir/uid
 */
var uid = 'http://hl7.org/fhir/uid';
/**
 * order
 *
 * SubstanceSourceMaterial.organism.organismGeneral.order: The order of an organism shall be specified,.
 *
 * http://hl7.org/fhir/order
 */
var order = 'http://hl7.org/fhir/order';
/**
 * priorPrescription
 *
 * MedicationRequest.priorPrescription: Reference to an order/prescription that is being replaced by this MedicationRequest.
 *
 * http://hl7.org/fhir/priorPrescription
 */
var priorPrescription = 'http://hl7.org/fhir/priorPrescription';
/**
 * distanceFromLandmark
 *
 * BodyStructure.excludedStructure.bodyLandmarkOrientation.distanceFromLandmark: The distance in centimeters a certain observation is made from a body landmark.
 *
 * http://hl7.org/fhir/distanceFromLandmark
 */
var distanceFromLandmark = 'http://hl7.org/fhir/distanceFromLandmark';
/**
 * VerificationResultValidatorComponent
 *
 * VerificationResultValidatorComponent: Information about the entity validating information.
 *
 * http://hl7.org/fhir/VerificationResultValidatorComponent
 */
var VerificationResultValidatorComponent = 'http://hl7.org/fhir/VerificationResultValidatorComponent';
/**
 * _recurrenceTemplate
 *
 * (Modified) Appointment.recurrenceTemplate
 *
 * http://hl7.org/fhir/_recurrenceTemplate
 */
var _recurrenceTemplate = 'http://hl7.org/fhir/_recurrenceTemplate';
/**
 * tenderedAmount
 *
 * PaymentReconciliation.tenderedAmount: The amount offered by the issuer, typically applies to cash when the issuer provides an amount in bank note denominations equal to or excess of the amount actually being paid.
 *
 * http://hl7.org/fhir/tenderedAmount
 */
var tenderedAmount = 'http://hl7.org/fhir/tenderedAmount';
/**
 * _diseaseStatus
 *
 * (Modified) ClinicalUseDefinition.indication.diseaseStatus
 *
 * http://hl7.org/fhir/_diseaseStatus
 */
var _diseaseStatus = 'http://hl7.org/fhir/_diseaseStatus';
/**
 * _expirationDate
 *
 * (Modified) PaymentReconciliation.expirationDate
 *
 * http://hl7.org/fhir/_expirationDate
 */
var _expirationDate = 'http://hl7.org/fhir/_expirationDate';
/**
 * _dataPeriod
 *
 * (Modified) Consent.provision.provision.dataPeriod
 *
 * http://hl7.org/fhir/_dataPeriod
 */
var _dataPeriod = 'http://hl7.org/fhir/_dataPeriod';
/**
 * note
 *
 * GenomicStudy.note: Comments related to the genomic study.
 *
 * http://hl7.org/fhir/note
 */
var note = 'http://hl7.org/fhir/note';
/**
 * _manipulated
 *
 * (Modified) Procedure.focalDevice.manipulated
 *
 * http://hl7.org/fhir/_manipulated
 */
var _manipulated = 'http://hl7.org/fhir/_manipulated';
/**
 * _Invoice
 *
 * (Modified) Invoice
 *
 * http://hl7.org/fhir/_Invoice
 */
var _Invoice = 'http://hl7.org/fhir/_Invoice';
/**
 * RatioRange
 *
 * A range of ratios expressed as a low and high numerator and a denominator.
 *
 * http://hl7.org/fhir/RatioRange
 */
var RatioRange = 'http://hl7.org/fhir/RatioRange';
/**
 * _requisition
 *
 * (Modified) ServiceRequest.requisition
 *
 * http://hl7.org/fhir/_requisition
 */
var _requisition = 'http://hl7.org/fhir/_requisition';
/**
 * ClinicalImpression
 *
 * A record of a clinical assessment performed to determine what problem(s) may affect the patient and before planning the treatments or management strategies that are best to manage a patient's condition. Assessments are often 1:1 with a clinical consultation / encounter,  but this varies greatly depending on the clinical workflow. This resource is called "ClinicalImpression" rather than "ClinicalAssessment" to avoid confusion with the recording of assessment tools such as Apgar score.
 *
 * http://hl7.org/fhir/ClinicalImpression
 */
var ClinicalImpression = 'http://hl7.org/fhir/ClinicalImpression';
/**
 * _claim
 *
 * (Modified) ExplanationOfBenefit.claim
 *
 * http://hl7.org/fhir/_claim
 */
var _claim = 'http://hl7.org/fhir/_claim';
/**
 * need
 *
 * VerificationResult.need: The frequency with which the target must be validated (none; initial; periodic).
 *
 * http://hl7.org/fhir/need
 */
var need = 'http://hl7.org/fhir/need';
/**
 * contributor
 *
 * Citation.citedArtifact.contributorship.entry.contributor: The identity of the individual contributor.
 *
 * http://hl7.org/fhir/contributor
 */
var contributor = 'http://hl7.org/fhir/contributor';
/**
 * ConceptProperty
 *
 * ValueSetExpansionComponent.ValueSetExpansionContainsComponent.ConceptProperty: A property value for this concept.
 *
 * http://hl7.org/fhir/ConceptProperty
 */
var ConceptProperty = 'http://hl7.org/fhir/ConceptProperty';
/**
 * ConsentVerificationComponent
 *
 * ConsentVerificationComponent: Whether a treatment instruction (e.g. artificial respiration: yes or no) was verified with the patient, his/her family or another authorized person.
 *
 * http://hl7.org/fhir/ConsentVerificationComponent
 */
var ConsentVerificationComponent = 'http://hl7.org/fhir/ConsentVerificationComponent';
/**
 * TestReportTeardownComponent
 *
 * TestReportTeardownComponent: The results of the series of operations required to clean up after all the tests were executed (successfully or otherwise).
 *
 * http://hl7.org/fhir/TestReportTeardownComponent
 */
var TestReportTeardownComponent = 'http://hl7.org/fhir/TestReportTeardownComponent';
/**
 * _genus
 *
 * (Modified) SubstanceSourceMaterial.organism.genus
 *
 * http://hl7.org/fhir/_genus
 */
var _genus = 'http://hl7.org/fhir/_genus';
/**
 * extraDetails
 *
 * HealthcareService.extraDetails: Extra details about the service that can't be placed in the other fields.
 *
 * http://hl7.org/fhir/extraDetails
 */
var extraDetails = 'http://hl7.org/fhir/extraDetails';
/**
 * _location
 *
 * (Modified) InventoryItem.instance.location
 *
 * http://hl7.org/fhir/_location
 */
var _location = 'http://hl7.org/fhir/_location';
/**
 * _reported
 *
 * (Modified) Procedure.reported
 *
 * http://hl7.org/fhir/_reported
 */
var _reported = 'http://hl7.org/fhir/_reported';
/**
 * _codeMap
 *
 * (Modified) SampledData.codeMap
 *
 * http://hl7.org/fhir/_codeMap
 */
var _codeMap = 'http://hl7.org/fhir/_codeMap';
/**
 * firstPage
 *
 * Citation.citedArtifact.publicationForm.firstPage: Used for isolated representation of first page.
 *
 * http://hl7.org/fhir/firstPage
 */
var firstPage = 'http://hl7.org/fhir/firstPage';
/**
 * _setup
 *
 * (Modified) TestScript.setup
 *
 * http://hl7.org/fhir/_setup
 */
var _setup = 'http://hl7.org/fhir/_setup';
/**
 * _paymentBy
 *
 * (Modified) Coverage.paymentBy
 *
 * http://hl7.org/fhir/_paymentBy
 */
var _paymentBy = 'http://hl7.org/fhir/_paymentBy';
/**
 * custodian
 *
 * DocumentReference.custodian: Identifies the organization or group who is responsible for ongoing maintenance of and access to the document.
 *
 * http://hl7.org/fhir/custodian
 */
var custodian = 'http://hl7.org/fhir/custodian';
/**
 * estimatedAge
 *
 * FamilyMemberHistory.estimatedAge: If true, indicates that the age value specified is an estimated value.
 *
 * http://hl7.org/fhir/estimatedAge
 */
var estimatedAge = 'http://hl7.org/fhir/estimatedAge';
/**
 * _observation
 *
 * (Modified) Observation.triggeredBy.observation
 *
 * http://hl7.org/fhir/_observation
 */
var _observation = 'http://hl7.org/fhir/_observation';
/**
 * technique
 *
 * SubstanceDefinition.structure.technique: The method used to elucidate the structure of the drug substance. Examples: X-ray, NMR, Peptide mapping, Ligand binding assay.
 *
 * http://hl7.org/fhir/technique
 */
var technique = 'http://hl7.org/fhir/technique';
/**
 * Requirements
 *
 * The Requirements resource is used to describe an actor - a human or an application that plays a role in data exchange, and that may have obligations associated with the role the actor plays.
 *
 * http://hl7.org/fhir/Requirements
 */
var Requirements = 'http://hl7.org/fhir/Requirements';
/**
 * supplementalData
 *
 * MeasureReport.supplementalData: A reference to a Resource that represents additional information collected for the report. If the value of the supplemental data is not a Resource (i.e. evaluating the supplementalData expression for this case in the measure results in a value that is not a FHIR Resource), it is reported as a reference to a contained Observation resource.
 *
 * http://hl7.org/fhir/supplementalData
 */
var supplementalData = 'http://hl7.org/fhir/supplementalData';
/**
 * SimpleQuantity
 *
 * The comparator is not used on a SimpleQuantity
 *
 * http://hl7.org/fhir/SimpleQuantity
 */
var SimpleQuantity = 'http://hl7.org/fhir/SimpleQuantity';
/**
 * ProvenanceEntityComponent
 *
 * ProvenanceEntityComponent: An entity used in this activity.
 *
 * http://hl7.org/fhir/ProvenanceEntityComponent
 */
var ProvenanceEntityComponent = 'http://hl7.org/fhir/ProvenanceEntityComponent';
/**
 * condition
 *
 * ObservationDefinition.component.qualifiedValue.condition: Text based condition for which the the set of qualified values is valid.
 *
 * http://hl7.org/fhir/condition
 */
var condition = 'http://hl7.org/fhir/condition';
/**
 * excludeFoodModifier
 *
 * NutritionOrder.excludeFoodModifier: This modifier is used to convey Order-specific modifier about the type of oral food or oral fluids that should not be given. These can be derived from patient allergies, intolerances, or preferences such as No Red Meat, No Soy or No Wheat or  Gluten-Free.  While it should not be necessary to repeat allergy or intolerance information captured in the referenced AllergyIntolerance resource in the excludeFoodModifier, this element may be used to convey additional specificity related to foods that should be eliminated from the patient’s diet for any reason.  This modifier applies to the entire nutrition order inclusive of the oral diet, nutritional supplements and enteral formula feedings.
 *
 * http://hl7.org/fhir/excludeFoodModifier
 */
var excludeFoodModifier = 'http://hl7.org/fhir/excludeFoodModifier';
/**
 * coverageArea
 *
 * InsurancePlan.plan.coverageArea: The geographic region in which a health insurance plan's benefits apply.
 *
 * http://hl7.org/fhir/coverageArea
 */
var coverageArea = 'http://hl7.org/fhir/coverageArea';
/**
 * contributionInstance
 *
 * Citation.citedArtifact.contributorship.entry.contributionInstance: Contributions with accounting for time or number.
 *
 * http://hl7.org/fhir/contributionInstance
 */
var contributionInstance = 'http://hl7.org/fhir/contributionInstance';
/**
 * _productCode
 *
 * (Modified) BiologicallyDerivedProduct.productCode
 *
 * http://hl7.org/fhir/_productCode
 */
var _productCode = 'http://hl7.org/fhir/_productCode';
/**
 * _language
 *
 * (Modified) Attachment.language
 *
 * http://hl7.org/fhir/_language
 */
var _language = 'http://hl7.org/fhir/_language';
/**
 * base
 *
 * VisionPrescription.lensSpecification.prism.base: The relative base, or reference lens edge, for the prism.
 *
 * http://hl7.org/fhir/base
 */
var base = 'http://hl7.org/fhir/base';
/**
 * _windowStart
 *
 * (Modified) MolecularSequence.relative.startingSequence.windowStart
 *
 * http://hl7.org/fhir/_windowStart
 */
var _windowStart = 'http://hl7.org/fhir/_windowStart';
/**
 * district
 *
 * Address.district: The name of the administrative area (county).
 *
 * http://hl7.org/fhir/district
 */
var district = 'http://hl7.org/fhir/district';
/**
 * forenameInitials
 *
 * Citation.citedArtifact.contributorship.entry.forenameInitials: For citation styles that use initials.
 *
 * http://hl7.org/fhir/forenameInitials
 */
var forenameInitials = 'http://hl7.org/fhir/forenameInitials';
/**
 * _state
 *
 * (Modified) ResearchStudy.progressStatus.state
 *
 * http://hl7.org/fhir/_state
 */
var _state = 'http://hl7.org/fhir/_state';
/**
 * friendly
 *
 * Contract.friendly: The "patient friendly language" versionof the Contract in whole or in parts. "Patient friendly language" means the representation of the Contract and Contract Provisions in a manner that is readily accessible and understandable by a layperson in accordance with best practices for communication styles that ensure that those agreeing to or signing the Contract understand the roles, actions, obligations, responsibilities, and implication of the agreement.
 *
 * http://hl7.org/fhir/friendly
 */
var friendly = 'http://hl7.org/fhir/friendly';
/**
 * AdditionalAttribute
 *
 * ConceptMap.AdditionalAttribute: An additionalAttribute defines an additional data element found in the source or target data model where the data will come from or be mapped to. Some mappings are based on data in addition to the source data element, where codes in multiple fields are combined to a single field (or vice versa).
 *
 * http://hl7.org/fhir/AdditionalAttribute
 */
var AdditionalAttribute = 'http://hl7.org/fhir/AdditionalAttribute';
/**
 * _Transport
 *
 * (Modified) Transport
 *
 * http://hl7.org/fhir/_Transport
 */
var _Transport = 'http://hl7.org/fhir/_Transport';
/**
 * xhtml
 *
 * http://hl7.org/fhir/xhtml
 */
var xhtml = 'http://hl7.org/fhir/xhtml';
/**
 * _official
 *
 * (Modified) SubstanceDefinition.name.official
 *
 * http://hl7.org/fhir/_official
 */
var _official = 'http://hl7.org/fhir/_official';
/**
 * CodeSystemConceptDesignationComponent
 *
 * CodeSystem.ConceptDefinition.CodeSystemConceptDesignationComponent: Additional representations for the concept - other languages, aliases, specialized purposes, used for particular purposes, etc.
 *
 * http://hl7.org/fhir/CodeSystemConceptDesignationComponent
 */
var CodeSystemConceptDesignationComponent = 'http://hl7.org/fhir/CodeSystemConceptDesignationComponent';
/**
 * _precedence
 *
 * (Modified) ExplanationOfBenefit.precedence
 *
 * http://hl7.org/fhir/_precedence
 */
var _precedence = 'http://hl7.org/fhir/_precedence';
/**
 * _result
 *
 * (Modified) TestPlan.testCase.assertion.result
 *
 * http://hl7.org/fhir/_result
 */
var _result = 'http://hl7.org/fhir/_result';
/**
 * _sliceName
 *
 * (Modified) GraphDefinition.link.sliceName
 *
 * http://hl7.org/fhir/_sliceName
 */
var _sliceName = 'http://hl7.org/fhir/_sliceName';
/**
 * points
 *
 * Contract.term.group.asset.valuedItem.points: An amount that expresses the weighting (based on difficulty, cost and/or resource intensiveness) associated with the Contract Valued Item delivered. The concept of Points allows for assignment of point values for a Contract Valued Item, such that a monetary amount can be assigned to each point.
 *
 * http://hl7.org/fhir/points
 */
var points = 'http://hl7.org/fhir/points';
/**
 * finding
 *
 * ClinicalImpression.finding: Specific findings or diagnoses that were considered likely or relevant to ongoing treatment.
 *
 * http://hl7.org/fhir/finding
 */
var finding = 'http://hl7.org/fhir/finding';
/**
 * _yearlyTemplate
 *
 * (Modified) Appointment.recurrenceTemplate.yearlyTemplate
 *
 * http://hl7.org/fhir/_yearlyTemplate
 */
var _yearlyTemplate = 'http://hl7.org/fhir/_yearlyTemplate';
/**
 * _isModifierReason
 *
 * (Modified) ElementDefinition.isModifierReason
 *
 * http://hl7.org/fhir/_isModifierReason
 */
var _isModifierReason = 'http://hl7.org/fhir/_isModifierReason';
/**
 * _experimental
 *
 * (Modified) StructureDefinition.experimental
 *
 * http://hl7.org/fhir/_experimental
 */
var _experimental = 'http://hl7.org/fhir/_experimental';
/**
 * _overbooked
 *
 * (Modified) Slot.overbooked
 *
 * http://hl7.org/fhir/_overbooked
 */
var _overbooked = 'http://hl7.org/fhir/_overbooked';
/**
 * ExampleScenario
 *
 * A walkthrough of a workflow showing the interaction between systems and the instances shared, possibly including the evolution of instances over time.
 *
 * http://hl7.org/fhir/ExampleScenario
 */
var ExampleScenario = 'http://hl7.org/fhir/ExampleScenario';
/**
 * AvailabilityNotAvailableTimeComponent
 *
 * AvailabilityNotAvailableTimeComponent: Not available during this time due to provided reason.
 *
 * http://hl7.org/fhir/AvailabilityNotAvailableTimeComponent
 */
var AvailabilityNotAvailableTimeComponent = 'http://hl7.org/fhir/AvailabilityNotAvailableTimeComponent';
/**
 * derivedFrom
 *
 * DeviceUsage.derivedFrom: Allows linking the DeviceUsage to the underlying Request, or to other information that supports or is used to derive the DeviceUsage.
 *
 * http://hl7.org/fhir/derivedFrom
 */
var derivedFrom = 'http://hl7.org/fhir/derivedFrom';
/**
 * _postalCode
 *
 * (Modified) Address.postalCode
 *
 * http://hl7.org/fhir/_postalCode
 */
var _postalCode = 'http://hl7.org/fhir/_postalCode';
/**
 * _endorser
 *
 * (Modified) EvidenceVariable.endorser
 *
 * http://hl7.org/fhir/_endorser
 */
var _endorser = 'http://hl7.org/fhir/_endorser';
/**
 * modifierExtension
 *
 * DomainResource.modifierExtension: May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and managable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.
 *
 * Modifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself).
 *
 * http://hl7.org/fhir/modifierExtension
 */
var modifierExtension = 'http://hl7.org/fhir/modifierExtension';
/**
 * verified
 *
 * Consent.verification.verified: Has the instruction been verified.
 *
 * http://hl7.org/fhir/verified
 */
var verified = 'http://hl7.org/fhir/verified';
/**
 * warning
 *
 * DeviceDefinition.guideline.warning: Specific hazard alert information that a user needs to know before using the device.
 *
 * http://hl7.org/fhir/warning
 */
var warning = 'http://hl7.org/fhir/warning';
/**
 * _color
 *
 * (Modified) VisionPrescription.lensSpecification.color
 *
 * http://hl7.org/fhir/_color
 */
var _color = 'http://hl7.org/fhir/_color';
/**
 * _global
 *
 * (Modified) ImplementationGuide.global
 *
 * http://hl7.org/fhir/_global
 */
var _global = 'http://hl7.org/fhir/_global';
/**
 * _policyBasis
 *
 * (Modified) Consent.policyBasis
 *
 * http://hl7.org/fhir/_policyBasis
 */
var _policyBasis = 'http://hl7.org/fhir/_policyBasis';
/**
 * timeFromEvent
 *
 * EvidenceVariable.characteristic.timeFromEvent: Timing in which the characteristic is determined.
 *
 * http://hl7.org/fhir/timeFromEvent
 */
var timeFromEvent = 'http://hl7.org/fhir/timeFromEvent';
/**
 * costToBeneficiary
 *
 * Coverage.costToBeneficiary: A suite of codes indicating the cost category and associated amount which have been detailed in the policy and may have been  included on the health card.
 *
 * http://hl7.org/fhir/costToBeneficiary
 */
var costToBeneficiary = 'http://hl7.org/fhir/costToBeneficiary';
/**
 * Questionnaire
 *
 * A structured set of questions intended to guide the collection of answers from end-users. Questionnaires provide detailed control over order, presentation, phraseology and grouping to allow coherent, consistent data collection.
 *
 * http://hl7.org/fhir/Questionnaire
 */
var Questionnaire = 'http://hl7.org/fhir/Questionnaire';
/**
 * _FormularyItem
 *
 * (Modified) FormularyItem
 *
 * http://hl7.org/fhir/_FormularyItem
 */
var _FormularyItem = 'http://hl7.org/fhir/_FormularyItem';
/**
 * _permittedUnit
 *
 * (Modified) ObservationDefinition.component.permittedUnit
 *
 * http://hl7.org/fhir/_permittedUnit
 */
var _permittedUnit = 'http://hl7.org/fhir/_permittedUnit';
/**
 * data
 *
 * Signature.data: The base64 encoding of the Signature content. When signature is not recorded electronically this element would be empty.
 *
 * http://hl7.org/fhir/data
 */
var data = 'http://hl7.org/fhir/data';
/**
 * _targetItem
 *
 * (Modified) PaymentReconciliation.allocation.targetItem
 *
 * http://hl7.org/fhir/_targetItem
 */
var _targetItem = 'http://hl7.org/fhir/_targetItem';
/**
 * whyStopped
 *
 * ResearchStudy.whyStopped: A description and/or code explaining the premature termination of the study.
 *
 * http://hl7.org/fhir/whyStopped
 */
var whyStopped = 'http://hl7.org/fhir/whyStopped';
/**
 * _practitioner
 *
 * (Modified) PractitionerRole.practitioner
 *
 * http://hl7.org/fhir/_practitioner
 */
var _practitioner = 'http://hl7.org/fhir/_practitioner';
/**
 * packageFor
 *
 * PackagedProductDefinition.packageFor: The product this package model relates to, not the contents of the package (for which see package.containedItem).
 *
 * http://hl7.org/fhir/packageFor
 */
var packageFor = 'http://hl7.org/fhir/packageFor';
/**
 * _informationSource
 *
 * (Modified) SubstanceDefinition.informationSource
 *
 * http://hl7.org/fhir/_informationSource
 */
var _informationSource = 'http://hl7.org/fhir/_informationSource';
/**
 * hasMember
 *
 * ObservationDefinition.hasMember: This ObservationDefinition defines a group  observation (e.g. a battery, a panel of tests, a set of vital sign measurements) that includes the target as a member of the group.
 *
 * http://hl7.org/fhir/hasMember
 */
var hasMember = 'http://hl7.org/fhir/hasMember';
/**
 * _paymentIdentifier
 *
 * (Modified) PaymentReconciliation.paymentIdentifier
 *
 * http://hl7.org/fhir/_paymentIdentifier
 */
var _paymentIdentifier = 'http://hl7.org/fhir/_paymentIdentifier';
/**
 * allowedType
 *
 * OperationDefinition.parameter.part.allowedType: Support for polymorphic types. If the parameter type is abstract, this element lists allowed sub-types for the parameter.
 *
 * http://hl7.org/fhir/allowedType
 */
var allowedType = 'http://hl7.org/fhir/allowedType';
/**
 * _intraspecificType
 *
 * (Modified) SubstanceSourceMaterial.organism.intraspecificType
 *
 * http://hl7.org/fhir/_intraspecificType
 */
var _intraspecificType = 'http://hl7.org/fhir/_intraspecificType';
/**
 * _isDefault
 *
 * (Modified) TerminologyCapabilities.codeSystem.version.isDefault
 *
 * http://hl7.org/fhir/_isDefault
 */
var _isDefault = 'http://hl7.org/fhir/_isDefault';
/**
 * _supportedProfile
 *
 * (Modified) CapabilityStatement.rest.resource.supportedProfile
 *
 * http://hl7.org/fhir/_supportedProfile
 */
var _supportedProfile = 'http://hl7.org/fhir/_supportedProfile';
/**
 * _authored
 *
 * (Modified) QuestionnaireResponse.authored
 *
 * http://hl7.org/fhir/_authored
 */
var _authored = 'http://hl7.org/fhir/_authored';
/**
 * stabilityDuration
 *
 * MedicationKnowledge.storageGuideline.stabilityDuration: Duration that the medication remains stable if the environmentalSetting is respected.
 *
 * http://hl7.org/fhir/stabilityDuration
 */
var stabilityDuration = 'http://hl7.org/fhir/stabilityDuration';
/**
 * InsurancePlanCoverageBenefitLimitComponent
 *
 * InsurancePlanCoverageComponent.CoverageBenefit.InsurancePlanCoverageBenefitLimitComponent: The specific limits on the benefit.
 *
 * http://hl7.org/fhir/InsurancePlanCoverageBenefitLimitComponent
 */
var InsurancePlanCoverageBenefitLimitComponent = 'http://hl7.org/fhir/InsurancePlanCoverageBenefitLimitComponent';
/**
 * compareToSourcePath
 *
 * TestScript.test.action.assert.compareToSourcePath: XPath or JSONPath expression to evaluate against the source fixture. When compareToSourceId is defined, either compareToSourceExpression or compareToSourcePath must be defined, but not both.
 *
 * http://hl7.org/fhir/compareToSourcePath
 */
var compareToSourcePath = 'http://hl7.org/fhir/compareToSourcePath';
/**
 * _dosageInstruction
 *
 * (Modified) MedicationRequest.dosageInstruction
 *
 * http://hl7.org/fhir/_dosageInstruction
 */
var _dosageInstruction = 'http://hl7.org/fhir/_dosageInstruction';
/**
 * sequence
 *
 * SubstanceNucleicAcid.subunit.sequence: Actual nucleotide sequence notation from 5' to 3' end using standard single letter codes. In addition to the base sequence, sugar and type of phosphate or non-phosphate linkage should also be captured.
 *
 * http://hl7.org/fhir/sequence
 */
var sequence = 'http://hl7.org/fhir/sequence';
/**
 * revenue
 *
 * ExplanationOfBenefit.item.revenue: The type of revenue or cost center providing the product and/or service.
 *
 * http://hl7.org/fhir/revenue
 */
var revenue = 'http://hl7.org/fhir/revenue';
/**
 * SystemInteraction
 *
 * CapabilityStatementRestComponent.SystemInteraction: A specification of restful operations supported by the system.
 *
 * http://hl7.org/fhir/SystemInteraction
 */
var SystemInteraction = 'http://hl7.org/fhir/SystemInteraction';
/**
 * SubscriptionFilterByComponent
 *
 * SubscriptionFilterByComponent: The filter properties to be applied to narrow the subscription topic stream.  When multiple filters are applied, evaluates to true if all the conditions applicable to that resource are met; otherwise it returns false (i.e., logical AND).
 *
 * http://hl7.org/fhir/SubscriptionFilterByComponent
 */
var SubscriptionFilterByComponent = 'http://hl7.org/fhir/SubscriptionFilterByComponent';
/**
 * _requirement
 *
 * (Modified) TestReport.setup.action.assert.requirement
 *
 * http://hl7.org/fhir/_requirement
 */
var _requirement = 'http://hl7.org/fhir/_requirement';
/**
 * _reliableCache
 *
 * (Modified) CapabilityStatement.messaging.reliableCache
 *
 * http://hl7.org/fhir/_reliableCache
 */
var _reliableCache = 'http://hl7.org/fhir/_reliableCache';
/**
 * nextScheduled
 *
 * VerificationResult.nextScheduled: The date when target is next validated, if appropriate.
 *
 * http://hl7.org/fhir/nextScheduled
 */
var nextScheduled = 'http://hl7.org/fhir/nextScheduled';
/**
 * MeasureGroupComponent
 *
 * MeasureGroupComponent: A group of population criteria for the measure.
 *
 * http://hl7.org/fhir/MeasureGroupComponent
 */
var MeasureGroupComponent = 'http://hl7.org/fhir/MeasureGroupComponent';
/**
 * processNote
 *
 * PaymentReconciliation.processNote: A note that describes or explains the processing in a human readable form.
 *
 * http://hl7.org/fhir/processNote
 */
var processNote = 'http://hl7.org/fhir/processNote';
/**
 * StratifierGroupPopulation
 *
 * MeasureReportGroupComponent.MeasureReportGroupStratifierComponent.StratifierGroup.StratifierGroupPopulation: The populations that make up the stratum, one for each type of population appropriate to the measure.
 *
 * http://hl7.org/fhir/StratifierGroupPopulation
 */
var StratifierGroupPopulation = 'http://hl7.org/fhir/StratifierGroupPopulation';
/**
 * issuerType
 *
 * PaymentReconciliation.issuerType: The type of the source such as patient or insurance.
 *
 * http://hl7.org/fhir/issuerType
 */
var issuerType = 'http://hl7.org/fhir/issuerType';
/**
 * capacity
 *
 * SpecimenDefinition.typeTested.container.capacity: The capacity (volume or other measure) of this kind of container.
 *
 * http://hl7.org/fhir/capacity
 */
var capacity = 'http://hl7.org/fhir/capacity';
/**
 * _rendering
 *
 * (Modified) ImplementationGuide.manifest.rendering
 *
 * http://hl7.org/fhir/_rendering
 */
var _rendering = 'http://hl7.org/fhir/_rendering';
/**
 * TestScriptTeardownComponent
 *
 * TestScriptTeardownComponent: A series of operations required to clean up after all the tests are executed (successfully or otherwise).
 *
 * http://hl7.org/fhir/TestScriptTeardownComponent
 */
var TestScriptTeardownComponent = 'http://hl7.org/fhir/TestScriptTeardownComponent';
/**
 * requestIdentifier
 *
 * GuidanceResponse.requestIdentifier: The identifier of the request associated with this response. If an identifier was given as part of the request, it will be reproduced here to enable the requester to more easily identify the response in a multi-request scenario.
 *
 * http://hl7.org/fhir/requestIdentifier
 */
var requestIdentifier = 'http://hl7.org/fhir/requestIdentifier';
/**
 * _definitionCanonical
 *
 * (Modified) EvidenceVariable.characteristic.definitionByCombination.characteristic.definitionCanonical
 *
 * http://hl7.org/fhir/_definitionCanonical
 */
var _definitionCanonical = 'http://hl7.org/fhir/_definitionCanonical';
/**
 * fhir:v
 *
 * http://hl7.org/fhir/v
 */
var v = 'http://hl7.org/fhir/v';
/**
 * _classification
 *
 * (Modified) Citation.classification
 *
 * http://hl7.org/fhir/_classification
 */
var _classification = 'http://hl7.org/fhir/_classification';
/**
 * Claim
 *
 * A provider issued list of professional services and products which have been provided, or are to be provided, to a patient which is sent to an insurer for reimbursement.
 *
 * http://hl7.org/fhir/Claim
 */
var Claim = 'http://hl7.org/fhir/Claim';
/**
 * asNeeded
 *
 * PlanDefinition.asNeeded
 *
 * http://hl7.org/fhir/asNeeded
 */
var asNeeded = 'http://hl7.org/fhir/asNeeded';
/**
 * defaultManualCompletion
 *
 * TestScript.test.action.assert.defaultManualCompletion: The default manual completion outcome applied to this assertion.
 *
 * http://hl7.org/fhir/defaultManualCompletion
 */
var defaultManualCompletion = 'http://hl7.org/fhir/defaultManualCompletion';
/**
 * partDescription
 *
 * SubstanceSourceMaterial.partDescription: To do.
 *
 * http://hl7.org/fhir/partDescription
 */
var partDescription = 'http://hl7.org/fhir/partDescription';
/**
 * articleDate
 *
 * Citation.citedArtifact.publicationForm.articleDate: The date the article was added to the database, or the date the article was released.
 *
 * http://hl7.org/fhir/articleDate
 */
var articleDate = 'http://hl7.org/fhir/articleDate';
/**
 * narrative
 *
 * TestPlan.testCase.testRun.narrative: The narrative description of the tests.
 *
 * http://hl7.org/fhir/narrative
 */
var narrative = 'http://hl7.org/fhir/narrative';
/**
 * participant
 *
 * AllergyIntolerance.participant: Indicates who or what participated in the activities related to the allergy or intolerance and how they were involved.
 *
 * http://hl7.org/fhir/participant
 */
var participant = 'http://hl7.org/fhir/participant';
/**
 * incidence
 *
 * ClinicalUseDefinition.interaction.incidence: The incidence of the interaction, e.g. theoretical, observed.
 *
 * http://hl7.org/fhir/incidence
 */
var incidence = 'http://hl7.org/fhir/incidence';
/**
 * div
 *
 * Narrative.div: The actual narrative content, a stripped down version of XHTML.
 *
 * http://hl7.org/fhir/div
 */
var div = 'http://hl7.org/fhir/div';
/**
 * _versioning
 *
 * (Modified) CapabilityStatement.rest.resource.versioning
 *
 * http://hl7.org/fhir/_versioning
 */
var _versioning = 'http://hl7.org/fhir/_versioning';
/**
 * RelatedClaim
 *
 * ExplanationOfBenefit.RelatedClaim: Other claims which are related to this claim such as prior submissions or claims for related services or for the same event.
 *
 * http://hl7.org/fhir/RelatedClaim
 */
var RelatedClaim = 'http://hl7.org/fhir/RelatedClaim';
/**
 * _page
 *
 * (Modified) ImplementationGuide.manifest.page
 *
 * http://hl7.org/fhir/_page
 */
var _page = 'http://hl7.org/fhir/_page';
/**
 * appointment
 *
 * Encounter.appointment: The appointment that scheduled this encounter.
 *
 * http://hl7.org/fhir/appointment
 */
var appointment = 'http://hl7.org/fhir/appointment';
/**
 * AuditEventEntityDetailComponent
 *
 * AuditEventEntityComponent.AuditEventEntityDetailComponent: Tagged value pairs for conveying additional information about the entity.
 *
 * http://hl7.org/fhir/AuditEventEntityDetailComponent
 */
var AuditEventEntityDetailComponent = 'http://hl7.org/fhir/AuditEventEntityDetailComponent';
/**
 * productionIdentifierInUDI
 *
 * DeviceDefinition.productionIdentifierInUDI: Indicates the production identifier(s) that are expected to appear in the UDI carrier on the device label.
 *
 * http://hl7.org/fhir/productionIdentifierInUDI
 */
var productionIdentifierInUDI = 'http://hl7.org/fhir/productionIdentifierInUDI';
/**
 * _photo
 *
 * (Modified) RelatedPerson.photo
 *
 * http://hl7.org/fhir/_photo
 */
var _photo = 'http://hl7.org/fhir/_photo';
/**
 * formOf
 *
 * AdministrableProductDefinition.formOf: References a product from which one or more of the constituent parts of that product can be prepared and used as described by this administrable product.  If this administrable product describes the administration of a crushed tablet, the 'formOf' would be the product representing a distribution containing tablets and possibly also a cream.  This is distinct from the 'producedFrom' which refers to the specific components of the product that are used in this preparation, rather than the product as a whole.
 *
 * http://hl7.org/fhir/formOf
 */
var formOf = 'http://hl7.org/fhir/formOf';
/**
 * referrer
 *
 * ImagingStudy.referrer: The requesting/referring physician.
 *
 * http://hl7.org/fhir/referrer
 */
var referrer = 'http://hl7.org/fhir/referrer';
/**
 * _subdetailSequence
 *
 * (Modified) ClaimResponse.addItem.subdetailSequence
 *
 * http://hl7.org/fhir/_subdetailSequence
 */
var _subdetailSequence = 'http://hl7.org/fhir/_subdetailSequence';
/**
 * CareTeamParticipantComponent
 *
 * CareTeamParticipantComponent: Identifies all people and organizations who are expected to be involved in the care team.
 *
 * http://hl7.org/fhir/CareTeamParticipantComponent
 */
var CareTeamParticipantComponent = 'http://hl7.org/fhir/CareTeamParticipantComponent';
/**
 * SpecimenDefinition
 *
 * A kind of specimen with associated set of requirements.
 *
 * http://hl7.org/fhir/SpecimenDefinition
 */
var SpecimenDefinition = 'http://hl7.org/fhir/SpecimenDefinition';
/**
 * _affectsState
 *
 * (Modified) OperationDefinition.affectsState
 *
 * http://hl7.org/fhir/_affectsState
 */
var _affectsState = 'http://hl7.org/fhir/_affectsState';
/**
 * _inputPopulationId
 *
 * (Modified) Measure.group.population.inputPopulationId
 *
 * http://hl7.org/fhir/_inputPopulationId
 */
var _inputPopulationId = 'http://hl7.org/fhir/_inputPopulationId';
/**
 * outputProfile
 *
 * OperationDefinition.outputProfile: Additional validation information for the out parameters - a single profile that covers all the parameters. The profile is a constraint on the parameters resource.
 *
 * http://hl7.org/fhir/outputProfile
 */
var outputProfile = 'http://hl7.org/fhir/outputProfile';
/**
 * MessageDefinitionAllowedResponseComponent
 *
 * MessageDefinitionAllowedResponseComponent: Indicates what types of messages may be sent as an application-level response to this message.
 *
 * http://hl7.org/fhir/MessageDefinitionAllowedResponseComponent
 */
var MessageDefinitionAllowedResponseComponent = 'http://hl7.org/fhir/MessageDefinitionAllowedResponseComponent';
/**
 * numberOfInstances
 *
 * ImagingStudy.series.numberOfInstances: Number of SOP Instances in the Study. The value given may be larger than the number of instance elements this resource contains due to resource availability, security, or other factors. This element should be present if any instance elements are present.
 *
 * http://hl7.org/fhir/numberOfInstances
 */
var numberOfInstances = 'http://hl7.org/fhir/numberOfInstances';
/**
 * Term
 *
 * Contract.Term: One or more Contract Provisions, which may be related and conveyed as a group, and may contain nested groups.
 *
 * http://hl7.org/fhir/Term
 */
var Term = 'http://hl7.org/fhir/Term';
/**
 * supportingImmunization
 *
 * ImmunizationRecommendation.recommendation.supportingImmunization: Immunization event history and/or evaluation that supports the status and recommendation.
 *
 * http://hl7.org/fhir/supportingImmunization
 */
var supportingImmunization = 'http://hl7.org/fhir/supportingImmunization';
/**
 * previousAppointment
 *
 * Appointment.previousAppointment: The previous appointment in a series of related appointments.
 *
 * http://hl7.org/fhir/previousAppointment
 */
var previousAppointment = 'http://hl7.org/fhir/previousAppointment';
/**
 * seriesDoses
 *
 * ImmunizationRecommendation.recommendation.seriesDoses: The recommended number of doses to achieve immunity as determined by the evaluation and forecasting process.
 *
 * http://hl7.org/fhir/seriesDoses
 */
var seriesDoses = 'http://hl7.org/fhir/seriesDoses';
/**
 * propertyGroup
 *
 * ChargeItemDefinition.propertyGroup: Group of properties which are applicable under the same conditions. If no applicability rules are established for the group, then all properties always apply.
 *
 * http://hl7.org/fhir/propertyGroup
 */
var propertyGroup = 'http://hl7.org/fhir/propertyGroup';
/**
 * option
 *
 * PlanDefinition.actor.option: The characteristics of the candidates that could serve as the actor.
 *
 * http://hl7.org/fhir/option
 */
var option = 'http://hl7.org/fhir/option';
/**
 * component
 *
 * ArtifactAssessment.content.component.component: If the informationType is container, the components of the content.
 *
 * http://hl7.org/fhir/component
 */
var component = 'http://hl7.org/fhir/component';
/**
 * offset
 *
 * Timing.repeat.offset: The number of minutes from the event. If the event code does not indicate whether the minutes is before or after the event, then the offset is assumed to be after the event.
 *
 * http://hl7.org/fhir/offset
 */
var offset = 'http://hl7.org/fhir/offset';
/**
 * materialType
 *
 * SubstanceSourceMaterial.fractionDescription.materialType: The specific type of the material constituting the component. For Herbal preparations the particulars of the extracts (liquid/dry) is described in Specified Substance Group 1.
 *
 * http://hl7.org/fhir/materialType
 */
var materialType = 'http://hl7.org/fhir/materialType';
/**
 * marketingAuthorizationHolder
 *
 * Medication.marketingAuthorizationHolder: The company or other legal entity that has authorization, from the appropriate drug regulatory authority,  to market a medicine in one or more jurisdictions.  Typically abbreviated MAH.Note:  The MAH may manufacture the product and may also contract the manufacturing of the product to one or more companies (organizations).
 *
 * http://hl7.org/fhir/marketingAuthorizationHolder
 */
var marketingAuthorizationHolder = 'http://hl7.org/fhir/marketingAuthorizationHolder';
/**
 * requestedPerformer
 *
 * Task.requestedPerformer: The kind of participant or specific participant that should perform the task.
 *
 * http://hl7.org/fhir/requestedPerformer
 */
var requestedPerformer = 'http://hl7.org/fhir/requestedPerformer';
/**
 * developmentStage
 *
 * SubstanceSourceMaterial.developmentStage: Stage of life for animals, plants, insects and microorganisms. This information shall be provided only when the substance is significantly different in these stages (e.g. foetal bovine serum).
 *
 * http://hl7.org/fhir/developmentStage
 */
var developmentStage = 'http://hl7.org/fhir/developmentStage';
/**
 * _deliveryDevice
 *
 * (Modified) NutritionOrder.enteralFormula.deliveryDevice
 *
 * http://hl7.org/fhir/_deliveryDevice
 */
var _deliveryDevice = 'http://hl7.org/fhir/_deliveryDevice';
/**
 * _Timing
 *
 * (Modified) Timing
 *
 * http://hl7.org/fhir/_Timing
 */
var _Timing = 'http://hl7.org/fhir/_Timing';
/**
 * AdverseEventSuspectEntityCausalityComponent
 *
 * AdverseEventSuspectEntityComponent.AdverseEventSuspectEntityCausalityComponent: Information on the possible cause of the event.
 *
 * http://hl7.org/fhir/AdverseEventSuspectEntityCausalityComponent
 */
var AdverseEventSuspectEntityCausalityComponent = 'http://hl7.org/fhir/AdverseEventSuspectEntityCausalityComponent';
/**
 * add
 *
 * VisionPrescription.lensSpecification.add: Power adjustment for multifocal lenses measured in dioptres (0.25 units).
 *
 * http://hl7.org/fhir/add
 */
var add = 'http://hl7.org/fhir/add';
/**
 * ImmunizationPerformerComponent
 *
 * ImmunizationPerformerComponent: Indicates who performed the immunization event.
 *
 * http://hl7.org/fhir/ImmunizationPerformerComponent
 */
var ImmunizationPerformerComponent = 'http://hl7.org/fhir/ImmunizationPerformerComponent';
/**
 * _BodyStructure
 *
 * (Modified) BodyStructure
 *
 * http://hl7.org/fhir/_BodyStructure
 */
var _BodyStructure = 'http://hl7.org/fhir/_BodyStructure';
/**
 * _organismName
 *
 * (Modified) SubstanceSourceMaterial.organismName
 *
 * http://hl7.org/fhir/_organismName
 */
var _organismName = 'http://hl7.org/fhir/_organismName';
/**
 * _monthlyTemplate
 *
 * (Modified) Appointment.recurrenceTemplate.monthlyTemplate
 *
 * http://hl7.org/fhir/_monthlyTemplate
 */
var _monthlyTemplate = 'http://hl7.org/fhir/_monthlyTemplate';
/**
 * versionAlgorithm
 *
 * ObservationDefinition.versionAlgorithm
 *
 * http://hl7.org/fhir/versionAlgorithm
 */
var versionAlgorithm = 'http://hl7.org/fhir/versionAlgorithm';
/**
 * _deliverFor
 *
 * (Modified) SupplyRequest.deliverFor
 *
 * http://hl7.org/fhir/_deliverFor
 */
var _deliverFor = 'http://hl7.org/fhir/_deliverFor';
/**
 * ElementDefinitionSlicingComponent
 *
 * ElementDefinitionSlicingComponent: Indicates that the element is sliced into a set of alternative definitions (i.e. in a structure definition, there are multiple different constraints on a single element in the base resource). Slicing can be used in any resource that has cardinality ..* on the base resource, or any resource with a choice of types. The set of slices is any elements that come after this in the element sequence that have the same path, until a shorter path occurs (the shorter path terminates the set).
 *
 * http://hl7.org/fhir/ElementDefinitionSlicingComponent
 */
var ElementDefinitionSlicingComponent = 'http://hl7.org/fhir/ElementDefinitionSlicingComponent';
/**
 * _responseId
 *
 * (Modified) TestScript.teardown.action.operation.responseId
 *
 * http://hl7.org/fhir/_responseId
 */
var _responseId = 'http://hl7.org/fhir/_responseId';
/**
 * _tenderedAmount
 *
 * (Modified) PaymentReconciliation.tenderedAmount
 *
 * http://hl7.org/fhir/_tenderedAmount
 */
var _tenderedAmount = 'http://hl7.org/fhir/_tenderedAmount';
/**
 * upperLimit
 *
 * SampledData.upperLimit: The upper limit of detection of the measured points. This is needed if any of the data points have the value "U" (higher than detection limit).
 *
 * http://hl7.org/fhir/upperLimit
 */
var upperLimit = 'http://hl7.org/fhir/upperLimit';
/**
 * _verificationStatus
 *
 * (Modified) Condition.verificationStatus
 *
 * http://hl7.org/fhir/_verificationStatus
 */
var _verificationStatus = 'http://hl7.org/fhir/_verificationStatus';
/**
 * amountType
 *
 * SubstanceReferenceInformation.target.amountType: Todo.
 *
 * http://hl7.org/fhir/amountType
 */
var amountType = 'http://hl7.org/fhir/amountType';
/**
 * _patientPaid
 *
 * (Modified) ExplanationOfBenefit.addItem.detail.subDetail.patientPaid
 *
 * http://hl7.org/fhir/_patientPaid
 */
var _patientPaid = 'http://hl7.org/fhir/_patientPaid';
/**
 * RequestOrchestrationActionOutputComponent
 *
 * RequestOrchestrationActionComponentAction.RequestOrchestrationActionOutputComponent: Defines the outputs of the action, if any.
 *
 * http://hl7.org/fhir/RequestOrchestrationActionOutputComponent
 */
var RequestOrchestrationActionOutputComponent = 'http://hl7.org/fhir/RequestOrchestrationActionOutputComponent';
/**
 * _quantity
 *
 * (Modified) Contract.term.group.asset.valuedItem.quantity
 *
 * http://hl7.org/fhir/_quantity
 */
var _quantity = 'http://hl7.org/fhir/_quantity';
/**
 * InsurancePlanPlanSpecificCostBenefitCostComponent
 *
 * InsurancePlanPlanComponent.InsurancePlanPlanSpecificCostComponent.PlanBenefit.InsurancePlanPlanSpecificCostBenefitCostComponent: List of the costs associated with a specific benefit.
 *
 * http://hl7.org/fhir/InsurancePlanPlanSpecificCostBenefitCostComponent
 */
var InsurancePlanPlanSpecificCostBenefitCostComponent = 'http://hl7.org/fhir/InsurancePlanPlanSpecificCostBenefitCostComponent';
/**
 * _alternate
 *
 * (Modified) DeviceDefinition.material.alternate
 *
 * http://hl7.org/fhir/_alternate
 */
var _alternate = 'http://hl7.org/fhir/_alternate';
/**
 * _contributingFactor
 *
 * (Modified) AdverseEvent.contributingFactor
 *
 * http://hl7.org/fhir/_contributingFactor
 */
var _contributingFactor = 'http://hl7.org/fhir/_contributingFactor';
/**
 * _sourceIdentityCertificate
 *
 * (Modified) VerificationResult.attestation.sourceIdentityCertificate
 *
 * http://hl7.org/fhir/_sourceIdentityCertificate
 */
var _sourceIdentityCertificate = 'http://hl7.org/fhir/_sourceIdentityCertificate';
/**
 * eventNumber
 *
 * SubscriptionStatus.notificationEvent.eventNumber: Either the sequential number of this event in this subscription context or a relative event number for this notification.
 *
 * http://hl7.org/fhir/eventNumber
 */
var eventNumber = 'http://hl7.org/fhir/eventNumber';
/**
 * AdministrableProductDefinitionPropertyComponent
 *
 * AdministrableProductDefinitionPropertyComponent: Characteristics e.g. a product's onset of action.
 *
 * http://hl7.org/fhir/AdministrableProductDefinitionPropertyComponent
 */
var AdministrableProductDefinitionPropertyComponent = 'http://hl7.org/fhir/AdministrableProductDefinitionPropertyComponent';
/**
 * responseRequired
 *
 * MessageDefinition.responseRequired: Declare at a message definition level whether a response is required or only upon error or success, or never.
 *
 * http://hl7.org/fhir/responseRequired
 */
var responseRequired = 'http://hl7.org/fhir/responseRequired';
/**
 * _verifiedBy
 *
 * (Modified) Consent.verification.verifiedBy
 *
 * http://hl7.org/fhir/_verifiedBy
 */
var _verifiedBy = 'http://hl7.org/fhir/_verifiedBy';
/**
 * _maritalStatus
 *
 * (Modified) Person.maritalStatus
 *
 * http://hl7.org/fhir/_maritalStatus
 */
var _maritalStatus = 'http://hl7.org/fhir/_maritalStatus';
/**
 * _timeOfDay
 *
 * (Modified) Timing.repeat.timeOfDay
 *
 * http://hl7.org/fhir/_timeOfDay
 */
var _timeOfDay = 'http://hl7.org/fhir/_timeOfDay';
/**
 * contraindication
 *
 * DeviceDefinition.guideline.contraindication: A specific situation when a device should not be used because it may cause harm.
 *
 * http://hl7.org/fhir/contraindication
 */
var contraindication = 'http://hl7.org/fhir/contraindication';
/**
 * patientPreparation
 *
 * SpecimenDefinition.patientPreparation: Preparation of the patient for specimen collection.
 *
 * http://hl7.org/fhir/patientPreparation
 */
var patientPreparation = 'http://hl7.org/fhir/patientPreparation';
/**
 * _expression
 *
 * (Modified) Permission.rule.data.expression
 *
 * http://hl7.org/fhir/_expression
 */
var _expression = 'http://hl7.org/fhir/_expression';
/**
 * _min
 *
 * (Modified) ElementDefinition.base.min
 *
 * http://hl7.org/fhir/_min
 */
var _min = 'http://hl7.org/fhir/_min';
/**
 * _attester
 *
 * (Modified) DocumentReference.attester
 *
 * http://hl7.org/fhir/_attester
 */
var _attester = 'http://hl7.org/fhir/_attester';
/**
 * _progress
 *
 * (Modified) ResearchSubject.progress
 *
 * http://hl7.org/fhir/_progress
 */
var _progress = 'http://hl7.org/fhir/_progress';
/**
 * _collection
 *
 * (Modified) SpecimenDefinition.collection
 *
 * http://hl7.org/fhir/_collection
 */
var _collection = 'http://hl7.org/fhir/_collection';
/**
 * base64Binary
 *
 * A stream of bytes
 *
 * http://hl7.org/fhir/base64Binary
 */
var base64Binary = 'http://hl7.org/fhir/base64Binary';
/**
 * ExampleScenarioProcessStepComponent
 *
 * ExampleScenarioProcessComponent.ExampleScenarioProcessStepComponent.ExampleScenarioProcessStepAlternativeComponentStepProcess.ExampleScenarioProcessStepComponent: A significant action that occurs as part of the process.
 *
 * http://hl7.org/fhir/ExampleScenarioProcessStepComponent
 */
var ExampleScenarioProcessStepComponent = 'http://hl7.org/fhir/ExampleScenarioProcessStepComponent';
/**
 * _comprisedOf
 *
 * (Modified) MedicinalProductDefinition.comprisedOf
 *
 * http://hl7.org/fhir/_comprisedOf
 */
var _comprisedOf = 'http://hl7.org/fhir/_comprisedOf';
/**
 * _factor
 *
 * (Modified) ClaimResponse.addItem.detail.factor
 *
 * http://hl7.org/fhir/_factor
 */
var _factor = 'http://hl7.org/fhir/_factor';
/**
 * _endRelationship
 *
 * (Modified) RequestOrchestration.action.action.relatedAction.endRelationship
 *
 * http://hl7.org/fhir/_endRelationship
 */
var _endRelationship = 'http://hl7.org/fhir/_endRelationship';
/**
 * _startingMaterial
 *
 * (Modified) SubstancePolymer.monomerSet.startingMaterial
 *
 * http://hl7.org/fhir/_startingMaterial
 */
var _startingMaterial = 'http://hl7.org/fhir/_startingMaterial';
/**
 * expectedSupplyDuration
 *
 * MedicationRequest.dispenseRequest.expectedSupplyDuration: Identifies the period time over which the supplied product is expected to be used, or the length of time the dispense is expected to last.
 *
 * http://hl7.org/fhir/expectedSupplyDuration
 */
var expectedSupplyDuration = 'http://hl7.org/fhir/expectedSupplyDuration';
/**
 * totalPriceComponent
 *
 * Invoice.totalPriceComponent: The total amount for the Invoice may be calculated as the sum of the line items with surcharges/deductions that apply in certain conditions.  The priceComponent element can be used to offer transparency to the recipient of the Invoice of how the total price was calculated.
 *
 * http://hl7.org/fhir/totalPriceComponent
 */
var totalPriceComponent = 'http://hl7.org/fhir/totalPriceComponent';
/**
 * _signer
 *
 * (Modified) Contract.signer
 *
 * http://hl7.org/fhir/_signer
 */
var _signer = 'http://hl7.org/fhir/_signer';
/**
 * enableBehavior
 *
 * Questionnaire.item.item.enableBehavior: Controls how multiple enableWhen values are interpreted -  whether all or any must be true.
 *
 * http://hl7.org/fhir/enableBehavior
 */
var enableBehavior = 'http://hl7.org/fhir/enableBehavior';
/**
 * Contract
 *
 * Legally enforceable, formally recorded unilateral or bilateral directive i.e., a policy or agreement.
 *
 * http://hl7.org/fhir/Contract
 */
var Contract = 'http://hl7.org/fhir/Contract';
/**
 * _cTerminalModificationId
 *
 * (Modified) SubstanceProtein.subunit.cTerminalModificationId
 *
 * http://hl7.org/fhir/_cTerminalModificationId
 */
var _cTerminalModificationId = 'http://hl7.org/fhir/_cTerminalModificationId';
/**
 * ObservationReferenceRangeComponent
 *
 * ObservationReferenceRangeComponent: Guidance on how to interpret the value by comparison to a normal or recommended range.  Multiple reference ranges are interpreted as an "OR".   In other words, to represent two distinct target populations, two `referenceRange` elements would be used.
 *
 * http://hl7.org/fhir/ObservationReferenceRangeComponent
 */
var ObservationReferenceRangeComponent = 'http://hl7.org/fhir/ObservationReferenceRangeComponent';
/**
 * maxVolumeToDeliver
 *
 * NutritionOrder.enteralFormula.maxVolumeToDeliver: The maximum total quantity of formula that may be administered to a subject over the period of time, e.g. 1440 mL over 24 hours.
 *
 * http://hl7.org/fhir/maxVolumeToDeliver
 */
var maxVolumeToDeliver = 'http://hl7.org/fhir/maxVolumeToDeliver';
/**
 * CapabilityStatementRestResourceOperationComponent
 *
 * CapabilityStatementRestComponent.CapabilityStatementRestResourceComponent.CapabilityStatementRestResourceOperationComponent: Definition of an operation or a named query together with its parameters and their meaning and type. Consult the definition of the operation for details about how to invoke the operation, and the parameters.
 *
 * http://hl7.org/fhir/CapabilityStatementRestResourceOperationComponent
 */
var CapabilityStatementRestResourceOperationComponent = 'http://hl7.org/fhir/CapabilityStatementRestResourceOperationComponent';
/**
 * isDerived
 *
 * SpecimenDefinition.typeTested.isDerived: Primary of secondary specimen.
 *
 * http://hl7.org/fhir/isDerived
 */
var isDerived = 'http://hl7.org/fhir/isDerived';
/**
 * conditionalUpdate
 *
 * CapabilityStatement.rest.resource.conditionalUpdate: A flag that indicates that the server supports conditional update.
 *
 * http://hl7.org/fhir/conditionalUpdate
 */
var conditionalUpdate = 'http://hl7.org/fhir/conditionalUpdate';
/**
 * repeatUnitAmountType
 *
 * SubstancePolymer.repeat.repeatUnitAmountType: How the quantitative amount of Structural Repeat Units is captured (e.g. Exact, Numeric, Average).
 *
 * http://hl7.org/fhir/repeatUnitAmountType
 */
var repeatUnitAmountType = 'http://hl7.org/fhir/repeatUnitAmountType';
/**
 * subjects
 *
 * MeasureReport.group.stratifier.stratum.population.subjects: Optional Group identifying the individuals that make up the population.
 *
 * http://hl7.org/fhir/subjects
 */
var subjects = 'http://hl7.org/fhir/subjects';
/**
 * EvidenceVariableCharacteristicTimeFromEventComponent
 *
 * EvidenceVariableCharacteristicComponent.EvidenceVariableCharacteristicTimeFromEventComponent: Timing in which the characteristic is determined.
 *
 * http://hl7.org/fhir/EvidenceVariableCharacteristicTimeFromEventComponent
 */
var EvidenceVariableCharacteristicTimeFromEventComponent = 'http://hl7.org/fhir/EvidenceVariableCharacteristicTimeFromEventComponent';
/**
 * _expansion
 *
 * (Modified) ValueSet.expansion
 *
 * http://hl7.org/fhir/_expansion
 */
var _expansion = 'http://hl7.org/fhir/_expansion';
/**
 * _Ingredient
 *
 * (Modified) Ingredient
 *
 * http://hl7.org/fhir/_Ingredient
 */
var _Ingredient = 'http://hl7.org/fhir/_Ingredient';
/**
 * _phase
 *
 * (Modified) TestScript.scope.phase
 *
 * http://hl7.org/fhir/_phase
 */
var _phase = 'http://hl7.org/fhir/_phase';
/**
 * _benefitPeriod
 *
 * (Modified) ExplanationOfBenefit.benefitPeriod
 *
 * http://hl7.org/fhir/_benefitPeriod
 */
var _benefitPeriod = 'http://hl7.org/fhir/_benefitPeriod';
/**
 * Organization
 *
 * A formally or informally recognized grouping of people or organizations formed for the purpose of achieving some form of collective action.  Includes companies, institutions, corporations, departments, community groups, healthcare practice groups, payer/insurer, etc.
 *
 * http://hl7.org/fhir/Organization
 */
var Organization = 'http://hl7.org/fhir/Organization';
/**
 * _referenceStrength
 *
 * (Modified) Ingredient.substance.strength.referenceStrength
 *
 * http://hl7.org/fhir/_referenceStrength
 */
var _referenceStrength = 'http://hl7.org/fhir/_referenceStrength';
/**
 * StructureMapGroupComponent
 *
 * StructureMapGroupComponent: Organizes the mapping into managable chunks for human review/ease of maintenance.
 *
 * http://hl7.org/fhir/StructureMapGroupComponent
 */
var StructureMapGroupComponent = 'http://hl7.org/fhir/StructureMapGroupComponent';
/**
 * referencePolicy
 *
 * CapabilityStatement.rest.resource.referencePolicy: A set of flags that defines how references are supported.
 *
 * http://hl7.org/fhir/referencePolicy
 */
var referencePolicy = 'http://hl7.org/fhir/referencePolicy';
/**
 * previous
 *
 * SubscriptionTopic.resourceTrigger.queryCriteria.previous: The FHIR query based rules are applied to the previous resource state (e.g., state before an update).
 *
 * http://hl7.org/fhir/previous
 */
var previous = 'http://hl7.org/fhir/previous';
/**
 * _stage
 *
 * (Modified) ConditionDefinition.stage
 *
 * http://hl7.org/fhir/_stage
 */
var _stage = 'http://hl7.org/fhir/_stage';
/**
 * PlanDefinitionActionOutputComponent
 *
 * PlanDefinitionActionComponentAction.PlanDefinitionActionOutputComponent: Defines the outputs of the action, if any.
 *
 * http://hl7.org/fhir/PlanDefinitionActionOutputComponent
 */
var PlanDefinitionActionOutputComponent = 'http://hl7.org/fhir/PlanDefinitionActionOutputComponent';
/**
 * _publisherLocation
 *
 * (Modified) Citation.citedArtifact.publicationForm.publishedIn.publisherLocation
 *
 * http://hl7.org/fhir/_publisherLocation
 */
var _publisherLocation = 'http://hl7.org/fhir/_publisherLocation';
/**
 * MedicationKnowledgeIndicationGuidelineDosingGuidelineDosageComponent
 *
 * MedicationKnowledgeIndicationGuidelineComponent.MedicationKnowledgeIndicationGuidelineDosingGuidelineComponent.MedicationKnowledgeIndicationGuidelineDosingGuidelineDosageComponent: Dosage for the medication for the specific guidelines.
 *
 * http://hl7.org/fhir/MedicationKnowledgeIndicationGuidelineDosingGuidelineDosageComponent
 */
var MedicationKnowledgeIndicationGuidelineDosingGuidelineDosageComponent = 'http://hl7.org/fhir/MedicationKnowledgeIndicationGuidelineDosingGuidelineDosageComponent';
/**
 * containedItemQuantity
 *
 * PackagedProductDefinition.containedItemQuantity: A total of the complete count of contained items of a particular type/form, independent of sub-packaging or organization. This can be considered as the pack size. This attribute differs from containedItem.amount in that it can give a single aggregated count of all tablet types in a pack, even when these are different manufactured items. For example a pill pack of 21 tablets plus 7 sugar tablets, can be denoted here as '28 tablets'. This attribute is repeatable so that the different item types in one pack type can be counted (e.g. a count of vials and count of syringes). Each repeat must have different units, so that it is clear what the different sets of counted items are, and it is not intended to allow different counts of similar items (e.g. not '2 tubes and 3 tubes'). Repeats are not to be used to represent different pack sizes (e.g. 20 pack vs. 50 pack) - which would be different instances of this resource.
 *
 * http://hl7.org/fhir/containedItemQuantity
 */
var containedItemQuantity = 'http://hl7.org/fhir/containedItemQuantity';
/**
 * copyrightLabel
 *
 * GraphDefinition.copyrightLabel: A short string (<50 characters), suitable for inclusion in a page footer that identifies the copyright holder, effective period, and optionally whether rights are resctricted. (e.g. 'All rights reserved', 'Some rights reserved').
 *
 * http://hl7.org/fhir/copyrightLabel
 */
var copyrightLabel = 'http://hl7.org/fhir/copyrightLabel';
/**
 * BodyStructureIncludedStructureBodyLandmarkOrientationComponent
 *
 * BodyStructureIncludedStructureBodyLandmarkOrientationComponent: Body locations in relation to a specific body landmark (tatoo, scar, other body structure).
 *
 * http://hl7.org/fhir/BodyStructureIncludedStructureBodyLandmarkOrientationComponent
 */
var BodyStructureIncludedStructureBodyLandmarkOrientationComponent = 'http://hl7.org/fhir/BodyStructureIncludedStructureBodyLandmarkOrientationComponent';
/**
 * hasBodySite
 *
 * ConditionDefinition.hasBodySite: Whether bodySite is appropriate to collect for this condition.
 *
 * http://hl7.org/fhir/hasBodySite
 */
var hasBodySite = 'http://hl7.org/fhir/hasBodySite';
/**
 * _valuedItem
 *
 * (Modified) Contract.term.group.asset.valuedItem
 *
 * http://hl7.org/fhir/_valuedItem
 */
var _valuedItem = 'http://hl7.org/fhir/_valuedItem';
/**
 * Period
 *
 * A time period defined by a start and end date and optionally time.
 *
 * http://hl7.org/fhir/Period
 */
var Period = 'http://hl7.org/fhir/Period';
/**
 * questionnaire
 *
 * QuestionnaireResponse.questionnaire: The Questionnaire that defines and organizes the questions for which answers are being provided.
 *
 * http://hl7.org/fhir/questionnaire
 */
var questionnaire = 'http://hl7.org/fhir/questionnaire';
/**
 * specificCost
 *
 * InsurancePlan.plan.specificCost: Costs associated with the coverage provided by the product.
 *
 * http://hl7.org/fhir/specificCost
 */
var specificCost = 'http://hl7.org/fhir/specificCost';
/**
 * _collected
 *
 * (Modified) Specimen.collection.collected
 *
 * http://hl7.org/fhir/_collected
 */
var _collected = 'http://hl7.org/fhir/_collected';
/**
 * _notAvailableTime
 *
 * (Modified) Availability.notAvailableTime
 *
 * http://hl7.org/fhir/_notAvailableTime
 */
var _notAvailableTime = 'http://hl7.org/fhir/_notAvailableTime';
/**
 * AllergyIntoleranceParticipantComponent
 *
 * AllergyIntoleranceParticipantComponent: Indicates who or what participated in the activities related to the allergy or intolerance and how they were involved.
 *
 * http://hl7.org/fhir/AllergyIntoleranceParticipantComponent
 */
var AllergyIntoleranceParticipantComponent = 'http://hl7.org/fhir/AllergyIntoleranceParticipantComponent';
/**
 * headerField
 *
 * TestScript.test.action.assert.headerField: The HTTP header field name e.g. 'Location'.
 *
 * http://hl7.org/fhir/headerField
 */
var headerField = 'http://hl7.org/fhir/headerField';
/**
 * _contained
 *
 * (Modified) DomainResource.contained
 *
 * http://hl7.org/fhir/_contained
 */
var _contained = 'http://hl7.org/fhir/_contained';
/**
 * _assigner
 *
 * (Modified) Identifier.assigner
 *
 * http://hl7.org/fhir/_assigner
 */
var _assigner = 'http://hl7.org/fhir/_assigner';
/**
 * _ifNoneMatch
 *
 * (Modified) Bundle.entry.request.ifNoneMatch
 *
 * http://hl7.org/fhir/_ifNoneMatch
 */
var _ifNoneMatch = 'http://hl7.org/fhir/_ifNoneMatch';
/**
 * DeviceAssociationOperationComponent
 *
 * DeviceAssociationOperationComponent: The details about the device when it is in use to describe its operation.
 *
 * http://hl7.org/fhir/DeviceAssociationOperationComponent
 */
var DeviceAssociationOperationComponent = 'http://hl7.org/fhir/DeviceAssociationOperationComponent';
/**
 * _graph
 *
 * (Modified) MessageDefinition.graph
 *
 * http://hl7.org/fhir/_graph
 */
var _graph = 'http://hl7.org/fhir/_graph';
/**
 * changeType
 *
 * GenomicStudy.analysis.changeType: Type of the genomic changes studied in the analysis, e.g., DNA, RNA, or amino acid change.
 *
 * http://hl7.org/fhir/changeType
 */
var changeType = 'http://hl7.org/fhir/changeType';
/**
 * _orientation
 *
 * (Modified) SubstancePolymer.repeat.repeatUnit.orientation
 *
 * http://hl7.org/fhir/_orientation
 */
var _orientation = 'http://hl7.org/fhir/_orientation';
/**
 * parentSubstanceId
 *
 * SubstanceSourceMaterial.parentSubstanceId: The parent of the herbal drug Ginkgo biloba, Leaf is the substance ID of the substance (fresh) of Ginkgo biloba L. or Ginkgo biloba L. (Whole plant).
 *
 * http://hl7.org/fhir/parentSubstanceId
 */
var parentSubstanceId = 'http://hl7.org/fhir/parentSubstanceId';
/**
 * recorded
 *
 * MedicationAdministration.recorded: The date the occurrence of the  MedicationAdministration was first captured in the record - potentially significantly after the occurrence of the event.
 *
 * http://hl7.org/fhir/recorded
 */
var recorded = 'http://hl7.org/fhir/recorded';
/**
 * _contributionType
 *
 * (Modified) Citation.citedArtifact.contributorship.entry.contributionType
 *
 * http://hl7.org/fhir/_contributionType
 */
var _contributionType = 'http://hl7.org/fhir/_contributionType';
/**
 * filterParameter
 *
 * SubscriptionTopic.canFilterBy.filterParameter: Either the canonical URL to a search parameter (like "http://hl7.org/fhir/SearchParameter/encounter-patient") or topic-defined parameter (like "hub.event") which is a label for the filter.
 *
 * http://hl7.org/fhir/filterParameter
 */
var filterParameter = 'http://hl7.org/fhir/filterParameter';
/**
 * positiveInt
 *
 * An integer with a value that is positive (e.g. >0)
 *
 * http://hl7.org/fhir/positiveInt
 */
var positiveInt = 'http://hl7.org/fhir/positiveInt';
/**
 * docStatus
 *
 * DocumentReference.docStatus: The status of the underlying document.
 *
 * http://hl7.org/fhir/docStatus
 */
var docStatus = 'http://hl7.org/fhir/docStatus';
/**
 * CoverageBenefit
 *
 * InsurancePlanCoverageComponent.CoverageBenefit: Specific benefits under this type of coverage.
 *
 * http://hl7.org/fhir/CoverageBenefit
 */
var CoverageBenefit = 'http://hl7.org/fhir/CoverageBenefit';
/**
 * durationUnit
 *
 * Timing.repeat.durationUnit: The units of time for the duration, in UCUM units
 * Normal practice is to use the 'mo' code as a calendar month when calculating the next occurrence.
 *
 * http://hl7.org/fhir/durationUnit
 */
var durationUnit = 'http://hl7.org/fhir/durationUnit';
/**
 * contentType
 *
 * Attachment.contentType: Identifies the type of the data in the attachment and allows a method to be chosen to interpret or render the data. Includes mime type parameters such as charset where appropriate.
 *
 * http://hl7.org/fhir/contentType
 */
var contentType = 'http://hl7.org/fhir/contentType';
/**
 * _addItem
 *
 * (Modified) ExplanationOfBenefit.addItem
 *
 * http://hl7.org/fhir/_addItem
 */
var _addItem = 'http://hl7.org/fhir/_addItem';
/**
 * MedicationKnowledgeIndicationGuidelineDosingGuidelineComponent
 *
 * MedicationKnowledgeIndicationGuidelineComponent.MedicationKnowledgeIndicationGuidelineDosingGuidelineComponent: The guidelines for the dosage of the medication for the indication.
 *
 * http://hl7.org/fhir/MedicationKnowledgeIndicationGuidelineDosingGuidelineComponent
 */
var MedicationKnowledgeIndicationGuidelineDosingGuidelineComponent = 'http://hl7.org/fhir/MedicationKnowledgeIndicationGuidelineDosingGuidelineComponent';
/**
 * dateRange
 *
 * MarketingStatus.dateRange: The date when the Medicinal Product is placed on the market by the Marketing Authorization Holder (or where applicable, the manufacturer/distributor) in a country and/or jurisdiction shall be provided A complete date consisting of day, month and year shall be specified using the ISO 8601 date format NOTE “Placed on the market” refers to the release of the Medicinal Product into the distribution chain.
 *
 * http://hl7.org/fhir/dateRange
 */
var dateRange = 'http://hl7.org/fhir/dateRange';
/**
 * used
 *
 * Procedure.used: Identifies medications, devices and any other substance used as part of the procedure.
 *
 * http://hl7.org/fhir/used
 */
var used = 'http://hl7.org/fhir/used';
/**
 * _city
 *
 * (Modified) Address.city
 *
 * http://hl7.org/fhir/_city
 */
var _city = 'http://hl7.org/fhir/_city';
/**
 * reaction
 *
 * Immunization.reaction: Categorical data indicating that an adverse event is associated in time to an immunization.
 *
 * http://hl7.org/fhir/reaction
 */
var reaction = 'http://hl7.org/fhir/reaction';
/**
 * subset
 *
 * ImagingSelection.instance.subset: Selected subset of the SOP Instance. The content and format of the subset item is determined by the SOP Class of the selected instance.
 *        May be one of:
 *        - A list of frame numbers selected from a multiframe SOP Instance.
 *        - A list of Content Item Observation UID values selected from a DICOM SR or other structured document SOP Instance.
 *        - A list of segment numbers selected from a segmentation SOP Instance.
 *        - A list of Region of Interest (ROI) numbers selected from a radiotherapy structure set SOP Instance.
 *
 * http://hl7.org/fhir/subset
 */
var subset = 'http://hl7.org/fhir/subset';
/**
 * performerRole
 *
 * Contract.term.group.action.performerRole: The type of role or competency of an individual desired or required to perform or not perform the action.
 *
 * http://hl7.org/fhir/performerRole
 */
var performerRole = 'http://hl7.org/fhir/performerRole';
/**
 * retentionTime
 *
 * SpecimenDefinition.typeTested.retentionTime: The usual time that a specimen of this kind is retained after the ordered tests are completed, for the purpose of additional testing.
 *
 * http://hl7.org/fhir/retentionTime
 */
var retentionTime = 'http://hl7.org/fhir/retentionTime';
/**
 * _ClinicalImpression
 *
 * (Modified) ClinicalImpression
 *
 * http://hl7.org/fhir/_ClinicalImpression
 */
var _ClinicalImpression = 'http://hl7.org/fhir/_ClinicalImpression';
/**
 * _generalCost
 *
 * (Modified) InsurancePlan.plan.generalCost
 *
 * http://hl7.org/fhir/_generalCost
 */
var _generalCost = 'http://hl7.org/fhir/_generalCost';
/**
 * instanceReference
 *
 * ExampleScenario.process.step.alternative.step.operation.request.instanceReference: A reference to the key of an instance found within this one.
 *
 * http://hl7.org/fhir/instanceReference
 */
var instanceReference = 'http://hl7.org/fhir/instanceReference';
/**
 * _history
 *
 * (Modified) Transport.history
 *
 * http://hl7.org/fhir/_history
 */
var _history = 'http://hl7.org/fhir/_history';
/**
 * molecularFormulaByMoiety
 *
 * SubstanceDefinition.structure.molecularFormulaByMoiety: Specified per moiety according to the Hill system, i.e. first C, then H, then alphabetical, each moiety separated by a dot.
 *
 * http://hl7.org/fhir/molecularFormulaByMoiety
 */
var molecularFormulaByMoiety = 'http://hl7.org/fhir/molecularFormulaByMoiety';
/**
 * _orderer
 *
 * (Modified) NutritionOrder.orderer
 *
 * http://hl7.org/fhir/_orderer
 */
var _orderer = 'http://hl7.org/fhir/_orderer';
/**
 * _payee
 *
 * (Modified) PaymentReconciliation.allocation.payee
 *
 * http://hl7.org/fhir/_payee
 */
var _payee = 'http://hl7.org/fhir/_payee';
/**
 * _windowEnd
 *
 * (Modified) MolecularSequence.relative.startingSequence.windowEnd
 *
 * http://hl7.org/fhir/_windowEnd
 */
var _windowEnd = 'http://hl7.org/fhir/_windowEnd';
/**
 * _maxDosePerTreatmentPeriod
 *
 * (Modified) AdministrableProductDefinition.routeOfAdministration.maxDosePerTreatmentPeriod
 *
 * http://hl7.org/fhir/_maxDosePerTreatmentPeriod
 */
var _maxDosePerTreatmentPeriod = 'http://hl7.org/fhir/_maxDosePerTreatmentPeriod';
/**
 * sopClass
 *
 * ImagingStudy.series.instance.sopClass: DICOM instance  type.
 *
 * http://hl7.org/fhir/sopClass
 */
var sopClass = 'http://hl7.org/fhir/sopClass';
/**
 * PlanDefinitionActorOptionComponent
 *
 * PlanDefinitionActorComponent.PlanDefinitionActorOptionComponent: The characteristics of the candidates that could serve as the actor.
 *
 * http://hl7.org/fhir/PlanDefinitionActorOptionComponent
 */
var PlanDefinitionActorOptionComponent = 'http://hl7.org/fhir/PlanDefinitionActorOptionComponent';
/**
 * ExampleScenarioInstanceComponent
 *
 * ExampleScenarioInstanceComponent: A single data collection that is shared as part of the scenario.
 *
 * http://hl7.org/fhir/ExampleScenarioInstanceComponent
 */
var ExampleScenarioInstanceComponent = 'http://hl7.org/fhir/ExampleScenarioInstanceComponent';
/**
 * organismGeneral
 *
 * SubstanceSourceMaterial.organism.organismGeneral: 4.9.13.7.1 Kingdom (Conditional).
 *
 * http://hl7.org/fhir/organismGeneral
 */
var organismGeneral = 'http://hl7.org/fhir/organismGeneral';
/**
 * abatement
 *
 * Condition.abatement
 *
 * http://hl7.org/fhir/abatement
 */
var abatement = 'http://hl7.org/fhir/abatement';
/**
 * _relatedDevice
 *
 * (Modified) DeviceDefinition.link.relatedDevice
 *
 * http://hl7.org/fhir/_relatedDevice
 */
var _relatedDevice = 'http://hl7.org/fhir/_relatedDevice';
/**
 * daysSupply
 *
 * MedicationDispense.daysSupply: The amount of medication expressed as a timing amount.
 *
 * http://hl7.org/fhir/daysSupply
 */
var daysSupply = 'http://hl7.org/fhir/daysSupply';
/**
 * _legal
 *
 * (Modified) Contract.legal
 *
 * http://hl7.org/fhir/_legal
 */
var _legal = 'http://hl7.org/fhir/_legal';
/**
 * _EpisodeOfCare
 *
 * (Modified) EpisodeOfCare
 *
 * http://hl7.org/fhir/_EpisodeOfCare
 */
var _EpisodeOfCare = 'http://hl7.org/fhir/_EpisodeOfCare';
/**
 * _excludeFoodModifier
 *
 * (Modified) NutritionOrder.excludeFoodModifier
 *
 * http://hl7.org/fhir/_excludeFoodModifier
 */
var _excludeFoodModifier = 'http://hl7.org/fhir/_excludeFoodModifier';
/**
 * weekInterval
 *
 * Appointment.recurrenceTemplate.weeklyTemplate.weekInterval: The interval defines if the recurrence is every nth week. The default is every week, so it is expected that this value will be 2 or more.

e.g. For recurring every second week this interval would be 2, or every third week the interval would be 3.
 *
 * http://hl7.org/fhir/weekInterval
 */
var weekInterval = 'http://hl7.org/fhir/weekInterval';
/**
 * _measureScore
 *
 * (Modified) MeasureReport.group.stratifier.stratum.measureScore
 *
 * http://hl7.org/fhir/_measureScore
 */
var _measureScore = 'http://hl7.org/fhir/_measureScore';
/**
 * _const
 *
 * (Modified) StructureMap.const
 *
 * http://hl7.org/fhir/_const
 */
var _const = 'http://hl7.org/fhir/_const';
/**
 * _hybrid
 *
 * (Modified) SubstanceSourceMaterial.organism.hybrid
 *
 * http://hl7.org/fhir/_hybrid
 */
var _hybrid = 'http://hl7.org/fhir/_hybrid';
/**
 * PackagedProductDefinitionPackagingComponent
 *
 * PackagedProductDefinitionPackagingComponent: A packaging item, as a container for medically related items, possibly with other packaging items within, or a packaging component, such as bottle cap (which is not a device or a medication manufactured item).
 *
 * http://hl7.org/fhir/PackagedProductDefinitionPackagingComponent
 */
var PackagedProductDefinitionPackagingComponent = 'http://hl7.org/fhir/PackagedProductDefinitionPackagingComponent';
/**
 * _prefix
 *
 * (Modified) RequestOrchestration.action.action.prefix
 *
 * http://hl7.org/fhir/_prefix
 */
var _prefix = 'http://hl7.org/fhir/_prefix';
/**
 * _publicationDateText
 *
 * (Modified) Citation.citedArtifact.publicationForm.publicationDateText
 *
 * http://hl7.org/fhir/_publicationDateText
 */
var _publicationDateText = 'http://hl7.org/fhir/_publicationDateText';
/**
 * ConceptSet
 *
 * ValueSetComposeComponent.ConceptSet: Include one or more codes from a code system or other value set(s).
 *
 * http://hl7.org/fhir/ConceptSet
 */
var ConceptSet = 'http://hl7.org/fhir/ConceptSet';
/**
 * payeeType
 *
 * ClaimResponse.payeeType: Type of Party to be reimbursed: subscriber, provider, other.
 *
 * http://hl7.org/fhir/payeeType
 */
var payeeType = 'http://hl7.org/fhir/payeeType';
/**
 * _shelfLifeStorage
 *
 * (Modified) PackagedProductDefinition.packaging.packaging.shelfLifeStorage
 *
 * http://hl7.org/fhir/_shelfLifeStorage
 */
var _shelfLifeStorage = 'http://hl7.org/fhir/_shelfLifeStorage';
/**
 * balance
 *
 * Account.balance: The calculated account balances - these are calculated and processed by the finance system.

The balances with a `term` that is not current are usually generated/updated by an invoicing or similar process.
 *
 * http://hl7.org/fhir/balance
 */
var balance = 'http://hl7.org/fhir/balance';
/**
 * _type
 *
 * (Modified) ManufacturedItemDefinition.component.component.property.type
 *
 * http://hl7.org/fhir/_type
 */
var _type = 'http://hl7.org/fhir/_type';
/**
 * dataPeriod
 *
 * Consent.provision.provision.dataPeriod: Clinical or Operational Relevant period of time that bounds the data controlled by this provision.
 *
 * http://hl7.org/fhir/dataPeriod
 */
var dataPeriod = 'http://hl7.org/fhir/dataPeriod';
/**
 * _Immunization
 *
 * (Modified) Immunization
 *
 * http://hl7.org/fhir/_Immunization
 */
var _Immunization = 'http://hl7.org/fhir/_Immunization';
/**
 * resourceReference
 *
 * Citation.citedArtifact.relatesTo.resourceReference: The related artifact, if the artifact is not a canonical resource, or a resource reference to a canonical resource.
 *
 * http://hl7.org/fhir/resourceReference
 */
var resourceReference = 'http://hl7.org/fhir/resourceReference';
/**
 * _providedBy
 *
 * (Modified) HealthcareService.providedBy
 *
 * http://hl7.org/fhir/_providedBy
 */
var _providedBy = 'http://hl7.org/fhir/_providedBy';
/**
 * _fhirVersion
 *
 * (Modified) StructureDefinition.fhirVersion
 *
 * http://hl7.org/fhir/_fhirVersion
 */
var _fhirVersion = 'http://hl7.org/fhir/_fhirVersion';
/**
 * _HealthcareService
 *
 * (Modified) HealthcareService
 *
 * http://hl7.org/fhir/_HealthcareService
 */
var _HealthcareService = 'http://hl7.org/fhir/_HealthcareService';
/**
 * submitter
 *
 * PaymentReconciliation.allocation.submitter: The party which submitted the claim or financial transaction.
 *
 * http://hl7.org/fhir/submitter
 */
var submitter = 'http://hl7.org/fhir/submitter';
/**
 * description
 *
 * Availability.notAvailableTime.description: Reason presented to the user explaining why time not available.
 *
 * http://hl7.org/fhir/description
 */
var description = 'http://hl7.org/fhir/description';
/**
 * combinedPharmaceuticalDoseForm
 *
 * MedicinalProductDefinition.combinedPharmaceuticalDoseForm: The dose form for a single part product, or combined form of a multiple part product. This is one concept that describes all the components. It does not represent the form with components physically mixed, if that might be necessary, for which see (AdministrableProductDefinition.administrableDoseForm).
 *
 * http://hl7.org/fhir/combinedPharmaceuticalDoseForm
 */
var combinedPharmaceuticalDoseForm = 'http://hl7.org/fhir/combinedPharmaceuticalDoseForm';
/**
 * _targetScope
 *
 * (Modified) ConceptMap.targetScope
 *
 * http://hl7.org/fhir/_targetScope
 */
var _targetScope = 'http://hl7.org/fhir/_targetScope';
/**
 * Parameter
 *
 * Transport.Parameter: Additional information that may be needed in the execution of the transport.
 *
 * http://hl7.org/fhir/Parameter
 */
var Parameter = 'http://hl7.org/fhir/Parameter';
/**
 * BiologicallyDerivedProduct
 *
 * A biological material originating from a biological entity intended to be transplanted or infused into another (possibly the same) biological entity.
 *
 * http://hl7.org/fhir/BiologicallyDerivedProduct
 */
var BiologicallyDerivedProduct = 'http://hl7.org/fhir/BiologicallyDerivedProduct';
/**
 * _GenomicStudy
 *
 * (Modified) GenomicStudy
 *
 * http://hl7.org/fhir/_GenomicStudy
 */
var _GenomicStudy = 'http://hl7.org/fhir/_GenomicStudy';
/**
 * _NutritionProduct
 *
 * (Modified) NutritionProduct
 *
 * http://hl7.org/fhir/_NutritionProduct
 */
var _NutritionProduct = 'http://hl7.org/fhir/_NutritionProduct';
/**
 * _additionalContext
 *
 * (Modified) SubscriptionStatus.notificationEvent.additionalContext
 *
 * http://hl7.org/fhir/_additionalContext
 */
var _additionalContext = 'http://hl7.org/fhir/_additionalContext';
/**
 * version
 *
 * Measure.version: The identifier that is used to identify this version of the measure when it is referenced in a specification, model, design or instance. This is an arbitrary value managed by the measure author and is not expected to be globally unique. For example, it might be a timestamp (e.g. yyyymmdd) if a managed version is not available. There is also no expectation that versions can be placed in a lexicographical sequence. To provide a version consistent with the Decision Support Service specification, use the format Major.Minor.Revision (e.g. 1.0.0). For more information on versioning knowledge assets, refer to the Decision Support Service specification. Note that a version is required for non-experimental active artifacts.
 *
 * http://hl7.org/fhir/version
 */
var version = 'http://hl7.org/fhir/version';
/**
 * detected
 *
 * AdverseEvent.detected: Estimated or actual date the AdverseEvent began, in the opinion of the reporter.
 *
 * http://hl7.org/fhir/detected
 */
var detected = 'http://hl7.org/fhir/detected';
/**
 * _statistic
 *
 * (Modified) Evidence.statistic
 *
 * http://hl7.org/fhir/_statistic
 */
var _statistic = 'http://hl7.org/fhir/_statistic';
/**
 * _bodyStructure
 *
 * (Modified) ServiceRequest.bodyStructure
 *
 * http://hl7.org/fhir/_bodyStructure
 */
var _bodyStructure = 'http://hl7.org/fhir/_bodyStructure';
/**
 * _definitionExpression
 *
 * (Modified) EvidenceVariable.characteristic.definitionByCombination.characteristic.definitionExpression
 *
 * http://hl7.org/fhir/_definitionExpression
 */
var _definitionExpression = 'http://hl7.org/fhir/_definitionExpression';
/**
 * translations
 *
 * TerminologyCapabilities.validateCode.translations: Whether translations are validated.
 *
 * http://hl7.org/fhir/translations
 */
var translations = 'http://hl7.org/fhir/translations';
/**
 * _targetProfile
 *
 * (Modified) OperationDefinition.parameter.part.targetProfile
 *
 * http://hl7.org/fhir/_targetProfile
 */
var _targetProfile = 'http://hl7.org/fhir/_targetProfile';
/**
 * _notPerformedReason
 *
 * (Modified) MedicationDispense.notPerformedReason
 *
 * http://hl7.org/fhir/_notPerformedReason
 */
var _notPerformedReason = 'http://hl7.org/fhir/_notPerformedReason';
/**
 * ArtifactAssessmentContentComponent
 *
 * ArtifactAssessmentContentComponent: A component comment, classifier, or rating of the artifact.
 *
 * http://hl7.org/fhir/ArtifactAssessmentContentComponent
 */
var ArtifactAssessmentContentComponent = 'http://hl7.org/fhir/ArtifactAssessmentContentComponent';
/**
 * cost
 *
 * MedicationKnowledge.packaging.cost.cost
 *
 * http://hl7.org/fhir/cost
 */
var cost = 'http://hl7.org/fhir/cost';
/**
 * CanonicalResource
 *
 * Common Interface declaration for conformance and knowledge artifact resources.
 *
 * http://hl7.org/fhir/CanonicalResource
 */
var CanonicalResource = 'http://hl7.org/fhir/CanonicalResource';
/**
 * _authorizationSupporting
 *
 * (Modified) CoverageEligibilityResponse.insurance.item.authorizationSupporting
 *
 * http://hl7.org/fhir/_authorizationSupporting
 */
var _authorizationSupporting = 'http://hl7.org/fhir/_authorizationSupporting';
/**
 * team
 *
 * ConditionDefinition.team: Appropriate team for this condition.
 *
 * http://hl7.org/fhir/team
 */
var team = 'http://hl7.org/fhir/team';
/**
 * actual
 *
 * Citation.statusDate.actual: Whether the status date is actual (has occurred) or expected (estimated or anticipated).
 *
 * http://hl7.org/fhir/actual
 */
var actual = 'http://hl7.org/fhir/actual';
/**
 * landmarkDescription
 *
 * BodyStructure.excludedStructure.bodyLandmarkOrientation.landmarkDescription: A description of a landmark on the body used as a reference to locate something else.
 *
 * http://hl7.org/fhir/landmarkDescription
 */
var landmarkDescription = 'http://hl7.org/fhir/landmarkDescription';
/**
 * typeCanonical
 *
 * RequestOrchestration.action.action.participant.typeCanonical: The type of participant in the action.
 *
 * http://hl7.org/fhir/typeCanonical
 */
var typeCanonical = 'http://hl7.org/fhir/typeCanonical';
/**
 * ArtifactAssessmentContentComponentContent
 *
 * If the informationType is container, the components of the content.
 *
 * http://hl7.org/fhir/ArtifactAssessmentContentComponentContent
 */
var ArtifactAssessmentContentComponentContent = 'http://hl7.org/fhir/ArtifactAssessmentContentComponentContent';
/**
 * _organizationReference
 *
 * (Modified) DeviceDefinition.packaging.packaging.distributor.organizationReference
 *
 * http://hl7.org/fhir/_organizationReference
 */
var _organizationReference = 'http://hl7.org/fhir/_organizationReference';
/**
 * _minimumVolume
 *
 * (Modified) SpecimenDefinition.typeTested.container.minimumVolume
 *
 * http://hl7.org/fhir/_minimumVolume
 */
var _minimumVolume = 'http://hl7.org/fhir/_minimumVolume';
/**
 * precedence
 *
 * ExplanationOfBenefit.precedence: This indicates the relative order of a series of EOBs related to different coverages for the same suite of services.
 *
 * http://hl7.org/fhir/precedence
 */
var precedence = 'http://hl7.org/fhir/precedence';
/**
 * CitationSummaryComponent
 *
 * CitationSummaryComponent: A human-readable display of key concepts to represent the citation.
 *
 * http://hl7.org/fhir/CitationSummaryComponent
 */
var CitationSummaryComponent = 'http://hl7.org/fhir/CitationSummaryComponent';
/**
 * decision
 *
 * ExplanationOfBenefit.decision: The result of the claim, predetermination, or preauthorization adjudication.
 *
 * http://hl7.org/fhir/decision
 */
var decision = 'http://hl7.org/fhir/decision';
/**
 * role
 *
 * CareTeam.participant.role: Indicates specific responsibility of an individual within the care team, such as "Primary care physician", "Trained social worker counselor", "Caregiver", etc.
 *
 * http://hl7.org/fhir/role
 */
var role = 'http://hl7.org/fhir/role';
/**
 * maternalOrganismId
 *
 * SubstanceSourceMaterial.organism.hybrid.maternalOrganismId: The identifier of the maternal species constituting the hybrid organism shall be specified based on a controlled vocabulary. For plants, the parents aren’t always known, and it is unlikely that it will be known which is maternal and which is paternal.
 *
 * http://hl7.org/fhir/maternalOrganismId
 */
var maternalOrganismId = 'http://hl7.org/fhir/maternalOrganismId';
/**
 * _triggeredBy
 *
 * (Modified) Observation.triggeredBy
 *
 * http://hl7.org/fhir/_triggeredBy
 */
var _triggeredBy = 'http://hl7.org/fhir/_triggeredBy';
/**
 * MedicationKnowledgeStorageGuidelineComponent
 *
 * MedicationKnowledgeStorageGuidelineComponent: Information on how the medication should be stored, for example, refrigeration temperatures and length of stability at a given temperature.
 *
 * http://hl7.org/fhir/MedicationKnowledgeStorageGuidelineComponent
 */
var MedicationKnowledgeStorageGuidelineComponent = 'http://hl7.org/fhir/MedicationKnowledgeStorageGuidelineComponent';
/**
 * dischargeDisposition
 *
 * Encounter.admission.dischargeDisposition: Category or kind of location after discharge.
 *
 * http://hl7.org/fhir/dischargeDisposition
 */
var dischargeDisposition = 'http://hl7.org/fhir/dischargeDisposition';
/**
 * _output
 *
 * (Modified) Transport.output
 *
 * http://hl7.org/fhir/_output
 */
var _output = 'http://hl7.org/fhir/_output';
/**
 * QuestionnaireItemComponent
 *
 * QuestionnaireItemComponent: A particular question, question grouping or display text that is part of the questionnaire.
 *
 * http://hl7.org/fhir/QuestionnaireItemComponent
 */
var QuestionnaireItemComponent = 'http://hl7.org/fhir/QuestionnaireItemComponent';
/**
 * _compareToSourcePath
 *
 * (Modified) TestScript.test.action.assert.compareToSourcePath
 *
 * http://hl7.org/fhir/_compareToSourcePath
 */
var _compareToSourcePath = 'http://hl7.org/fhir/_compareToSourcePath';
/**
 * traceNumber
 *
 * ExplanationOfBenefit.item.detail.traceNumber: Trace number for tracking purposes. May be defined at the jurisdiction level or between trading partners.
 *
 * http://hl7.org/fhir/traceNumber
 */
var traceNumber = 'http://hl7.org/fhir/traceNumber';
/**
 * InsurancePlanPlanComponent
 *
 * InsurancePlanPlanComponent: Details about an insurance plan.
 *
 * http://hl7.org/fhir/InsurancePlanPlanComponent
 */
var InsurancePlanPlanComponent = 'http://hl7.org/fhir/InsurancePlanPlanComponent';
/**
 * object
 *
 * TestPlan.testCase.assertion.object: The focus or object of the assertion i.e. a resource.
 *
 * http://hl7.org/fhir/object
 */
var object = 'http://hl7.org/fhir/object';
/**
 * statusReason
 *
 * Transport.statusReason: An explanation as to why this transport is held, failed, was refused, etc.
 *
 * http://hl7.org/fhir/statusReason
 */
var statusReason = 'http://hl7.org/fhir/statusReason';
/**
 * recall
 *
 * DeviceDefinition.correctiveAction.recall: Whether the last corrective action known for this device was a recall.
 *
 * http://hl7.org/fhir/recall
 */
var recall = 'http://hl7.org/fhir/recall';
/**
 * _codeSystem
 *
 * (Modified) TerminologyCapabilities.codeSystem
 *
 * http://hl7.org/fhir/_codeSystem
 */
var _codeSystem = 'http://hl7.org/fhir/_codeSystem';
/**
 * _processing
 *
 * (Modified) Specimen.processing
 *
 * http://hl7.org/fhir/_processing
 */
var _processing = 'http://hl7.org/fhir/_processing';
/**
 * gateway
 *
 * Device.gateway: The linked device acting as a communication controller, data collector, translator, or concentrator for the current device (e.g., mobile phone application that relays a blood pressure device's data).
 *
 * http://hl7.org/fhir/gateway
 */
var gateway = 'http://hl7.org/fhir/gateway';
/**
 * _performerType
 *
 * (Modified) Transport.performerType
 *
 * http://hl7.org/fhir/_performerType
 */
var _performerType = 'http://hl7.org/fhir/_performerType';
/**
 * _subcomponent
 *
 * (Modified) Evidence.certainty.subcomponent
 *
 * http://hl7.org/fhir/_subcomponent
 */
var _subcomponent = 'http://hl7.org/fhir/_subcomponent';
/**
 * postalCode
 *
 * Address.postalCode: A postal code designating a region defined by the postal service.
 *
 * http://hl7.org/fhir/postalCode
 */
var postalCode = 'http://hl7.org/fhir/postalCode';
/**
 * AddedItemDetail
 *
 * ExplanationOfBenefit.AddedItem.AddedItemDetail: The second-tier service adjudications for payor added services.
 *
 * http://hl7.org/fhir/AddedItemDetail
 */
var AddedItemDetail = 'http://hl7.org/fhir/AddedItemDetail';
/**
 * instance
 *
 * ChargeItemDefinition.instance: The defined billing details in this resource pertain to the given product instance(s).
 *
 * http://hl7.org/fhir/instance
 */
var instance = 'http://hl7.org/fhir/instance';
/**
 * _disposition
 *
 * (Modified) PaymentReconciliation.disposition
 *
 * http://hl7.org/fhir/_disposition
 */
var _disposition = 'http://hl7.org/fhir/_disposition';
/**
 * _statusDate
 *
 * (Modified) MedicinalProductDefinition.statusDate
 *
 * http://hl7.org/fhir/_statusDate
 */
var _statusDate = 'http://hl7.org/fhir/_statusDate';
/**
 * _facilityType
 *
 * (Modified) DocumentReference.facilityType
 *
 * http://hl7.org/fhir/_facilityType
 */
var _facilityType = 'http://hl7.org/fhir/_facilityType';
/**
 * _stratum
 *
 * (Modified) MeasureReport.group.stratifier.stratum
 *
 * http://hl7.org/fhir/_stratum
 */
var _stratum = 'http://hl7.org/fhir/_stratum';
/**
 * Payee
 *
 * Claim.Payee: The party to be reimbursed for cost of the products and services according to the terms of the policy.
 *
 * http://hl7.org/fhir/Payee
 */
var Payee = 'http://hl7.org/fhir/Payee';
/**
 * _measurementType
 *
 * (Modified) SubstanceDefinition.moiety.measurementType
 *
 * http://hl7.org/fhir/_measurementType
 */
var _measurementType = 'http://hl7.org/fhir/_measurementType';
/**
 * RelatedArtifact
 *
 * Related artifacts such as additional documentation, justification, or bibliographic references.
 *
 * http://hl7.org/fhir/RelatedArtifact
 */
var RelatedArtifact = 'http://hl7.org/fhir/RelatedArtifact';
/**
 * RequestOrchestrationActionDynamicValueComponent
 *
 * RequestOrchestrationActionComponentAction.RequestOrchestrationActionDynamicValueComponent: Customizations that should be applied to the statically defined resource. For example, if the dosage of a medication must be computed based on the patient's weight, a customization would be used to specify an expression that calculated the weight, and the path on the resource that would contain the result.
 *
 * http://hl7.org/fhir/RequestOrchestrationActionDynamicValueComponent
 */
var RequestOrchestrationActionDynamicValueComponent = 'http://hl7.org/fhir/RequestOrchestrationActionDynamicValueComponent';
/**
 * identity
 *
 * StructureDefinition.mapping.identity: An Internal id that is used to identify this mapping set when specific mappings are made.
 *
 * http://hl7.org/fhir/identity
 */
var identity = 'http://hl7.org/fhir/identity';
/**
 * subType
 *
 * Claim.subType: A finer grained suite of claim type codes which may convey additional information such as Inpatient vs Outpatient and/or a specialty service.
 *
 * http://hl7.org/fhir/subType
 */
var subType = 'http://hl7.org/fhir/subType';
/**
 * ValueSetExpansionContainsComponent
 *
 * ValueSetExpansionComponent.ValueSetExpansionContainsComponent: The codes that are contained in the value set expansion.
 *
 * http://hl7.org/fhir/ValueSetExpansionContainsComponent
 */
var ValueSetExpansionContainsComponent = 'http://hl7.org/fhir/ValueSetExpansionContainsComponent';
/**
 * MedicationKnowledgePackagingComponent
 *
 * MedicationKnowledgePackagingComponent: Information that only applies to packages (not products).
 *
 * http://hl7.org/fhir/MedicationKnowledgePackagingComponent
 */
var MedicationKnowledgePackagingComponent = 'http://hl7.org/fhir/MedicationKnowledgePackagingComponent';
/**
 * _display
 *
 * (Modified) ValueSet.expansion.contains.display
 *
 * http://hl7.org/fhir/_display
 */
var _display = 'http://hl7.org/fhir/_display';
/**
 * ImplementationGuideGlobalComponent
 *
 * ImplementationGuideGlobalComponent: A set of profiles that all resources covered by this implementation guide must conform to.
 *
 * http://hl7.org/fhir/ImplementationGuideGlobalComponent
 */
var ImplementationGuideGlobalComponent = 'http://hl7.org/fhir/ImplementationGuideGlobalComponent';
/**
 * _SubstanceNucleicAcid
 *
 * (Modified) SubstanceNucleicAcid
 *
 * http://hl7.org/fhir/_SubstanceNucleicAcid
 */
var _SubstanceNucleicAcid = 'http://hl7.org/fhir/_SubstanceNucleicAcid';
/**
 * TestScriptSetupActionOperationRequestHeaderComponent
 *
 * TestScriptTestComponent.TestActionOperation.TestScriptSetupActionOperationRequestHeaderComponent: Header elements would be used to set HTTP headers.
 *
 * http://hl7.org/fhir/TestScriptSetupActionOperationRequestHeaderComponent
 */
var TestScriptSetupActionOperationRequestHeaderComponent = 'http://hl7.org/fhir/TestScriptSetupActionOperationRequestHeaderComponent';
/**
 * targetItem
 *
 * PaymentReconciliation.allocation.targetItem
 *
 * http://hl7.org/fhir/targetItem
 */
var targetItem = 'http://hl7.org/fhir/targetItem';
/**
 * _dosingGuideline
 *
 * (Modified) MedicationKnowledge.indicationGuideline.dosingGuideline
 *
 * http://hl7.org/fhir/_dosingGuideline
 */
var _dosingGuideline = 'http://hl7.org/fhir/_dosingGuideline';
/**
 * _totalGross
 *
 * (Modified) Invoice.totalGross
 *
 * http://hl7.org/fhir/_totalGross
 */
var _totalGross = 'http://hl7.org/fhir/_totalGross';
/**
 * Reference
 *
 * A reference from one resource to another.
 *
 * http://hl7.org/fhir/Reference
 */
var Reference = 'http://hl7.org/fhir/Reference';
/**
 * _precheckBehavior
 *
 * (Modified) RequestOrchestration.action.action.precheckBehavior
 *
 * http://hl7.org/fhir/_precheckBehavior
 */
var _precheckBehavior = 'http://hl7.org/fhir/_precheckBehavior';
/**
 * _enableBehavior
 *
 * (Modified) Questionnaire.item.item.enableBehavior
 *
 * http://hl7.org/fhir/_enableBehavior
 */
var _enableBehavior = 'http://hl7.org/fhir/_enableBehavior';
/**
 * slot
 *
 * Appointment.slot: The slots from the participants' schedules that will be filled by the appointment.
 *
 * http://hl7.org/fhir/slot
 */
var slot = 'http://hl7.org/fhir/slot';
/**
 * groupDefinition
 *
 * Measure.group.stratifier.component.groupDefinition: A Group resource that defines this population as a set of characteristics.
 *
 * http://hl7.org/fhir/groupDefinition
 */
var groupDefinition = 'http://hl7.org/fhir/groupDefinition';
/**
 * _verifiedWith
 *
 * (Modified) Consent.verification.verifiedWith
 *
 * http://hl7.org/fhir/_verifiedWith
 */
var _verifiedWith = 'http://hl7.org/fhir/_verifiedWith';
/**
 * ResourceInteraction
 *
 * CapabilityStatementRestComponent.CapabilityStatementRestResourceComponent.ResourceInteraction: Identifies a restful operation supported by the solution.
 *
 * http://hl7.org/fhir/ResourceInteraction
 */
var ResourceInteraction = 'http://hl7.org/fhir/ResourceInteraction';
/**
 * _numberOfSubunits
 *
 * (Modified) SubstanceProtein.numberOfSubunits
 *
 * http://hl7.org/fhir/_numberOfSubunits
 */
var _numberOfSubunits = 'http://hl7.org/fhir/_numberOfSubunits';
/**
 * numberOfSeries
 *
 * ImagingStudy.numberOfSeries: Number of Series in the Study. This value given may be larger than the number of series elements this Resource contains due to resource availability, security, or other factors. This element should be present if any series elements are present.
 *
 * http://hl7.org/fhir/numberOfSeries
 */
var numberOfSeries = 'http://hl7.org/fhir/numberOfSeries';
/**
 * preAuthRefPeriod
 *
 * ExplanationOfBenefit.preAuthRefPeriod: The timeframe during which the supplied preauthorization reference may be quoted on claims to obtain the adjudication as provided.
 *
 * http://hl7.org/fhir/preAuthRefPeriod
 */
var preAuthRefPeriod = 'http://hl7.org/fhir/preAuthRefPeriod';
/**
 * _excludingRecurrenceId
 *
 * (Modified) Appointment.recurrenceTemplate.excludingRecurrenceId
 *
 * http://hl7.org/fhir/_excludingRecurrenceId
 */
var _excludingRecurrenceId = 'http://hl7.org/fhir/_excludingRecurrenceId';
/**
 * _baseCitation
 *
 * (Modified) Citation.citedArtifact.part.baseCitation
 *
 * http://hl7.org/fhir/_baseCitation
 */
var _baseCitation = 'http://hl7.org/fhir/_baseCitation';
/**
 * ContractAsset
 *
 * Contract.Term.ContractAsset: Contract Term Asset List.
 *
 * http://hl7.org/fhir/ContractAsset
 */
var ContractAsset = 'http://hl7.org/fhir/ContractAsset';
/**
 * ClinicalImpressionFindingComponent
 *
 * ClinicalImpressionFindingComponent: Specific findings or diagnoses that were considered likely or relevant to ongoing treatment.
 *
 * http://hl7.org/fhir/ClinicalImpressionFindingComponent
 */
var ClinicalImpressionFindingComponent = 'http://hl7.org/fhir/ClinicalImpressionFindingComponent';
/**
 * stopTestOnFail
 *
 * TestScript.test.action.assert.stopTestOnFail: Whether or not the current test execution will stop on failure for this assert.
 *
 * http://hl7.org/fhir/stopTestOnFail
 */
var stopTestOnFail = 'http://hl7.org/fhir/stopTestOnFail';
/**
 * _selectionBehavior
 *
 * (Modified) RequestOrchestration.action.action.selectionBehavior
 *
 * http://hl7.org/fhir/_selectionBehavior
 */
var _selectionBehavior = 'http://hl7.org/fhir/_selectionBehavior';
/**
 * _imports
 *
 * (Modified) CapabilityStatement.imports
 *
 * http://hl7.org/fhir/_imports
 */
var _imports = 'http://hl7.org/fhir/_imports';
/**
 * contextLinkId
 *
 * Contract.term.group.action.contextLinkId: Id [identifier??] of the clause or question text related to the requester of this action in the referenced form or QuestionnaireResponse.
 *
 * http://hl7.org/fhir/contextLinkId
 */
var contextLinkId = 'http://hl7.org/fhir/contextLinkId';
/**
 * _eye
 *
 * (Modified) VisionPrescription.lensSpecification.eye
 *
 * http://hl7.org/fhir/_eye
 */
var _eye = 'http://hl7.org/fhir/_eye';
/**
 * affiliation
 *
 * Citation.citedArtifact.contributorship.entry.affiliation: Organization affiliated with the contributor.
 *
 * http://hl7.org/fhir/affiliation
 */
var affiliation = 'http://hl7.org/fhir/affiliation';
/**
 * defaultValue
 *
 * TestScript.variable.defaultValue: A default, hard-coded, or user-defined value for this variable.
 *
 * http://hl7.org/fhir/defaultValue
 */
var defaultValue = 'http://hl7.org/fhir/defaultValue';
/**
 * MolecularSequence
 *
 * Representation of a molecular sequence.
 *
 * http://hl7.org/fhir/MolecularSequence
 */
var MolecularSequence = 'http://hl7.org/fhir/MolecularSequence';
/**
 * overload
 *
 * OperationDefinition.overload: Defines an appropriate combination of parameters to use when invoking this operation, to help code generators when generating overloaded parameter sets for this operation.
 *
 * http://hl7.org/fhir/overload
 */
var overload = 'http://hl7.org/fhir/overload';
/**
 * _productName
 *
 * (Modified) NutritionOrder.enteralFormula.additive.productName
 *
 * http://hl7.org/fhir/_productName
 */
var _productName = 'http://hl7.org/fhir/_productName';
/**
 * _comment
 *
 * (Modified) OperationDefinition.overload.comment
 *
 * http://hl7.org/fhir/_comment
 */
var _comment = 'http://hl7.org/fhir/_comment';
/**
 * _profile
 *
 * (Modified) Meta.profile
 *
 * http://hl7.org/fhir/_profile
 */
var _profile = 'http://hl7.org/fhir/_profile';
/**
 * _deleted
 *
 * (Modified) List.entry.deleted
 *
 * http://hl7.org/fhir/_deleted
 */
var _deleted = 'http://hl7.org/fhir/_deleted';
/**
 * _workflow
 *
 * (Modified) ExampleScenario.process.step.alternative.step.workflow
 *
 * http://hl7.org/fhir/_workflow
 */
var _workflow = 'http://hl7.org/fhir/_workflow';
/**
 * _attestationSignature
 *
 * (Modified) VerificationResult.validator.attestationSignature
 *
 * http://hl7.org/fhir/_attestationSignature
 */
var _attestationSignature = 'http://hl7.org/fhir/_attestationSignature';
/**
 * permittedDataType
 *
 * ObservationDefinition.component.permittedDataType: The data types allowed for the value element of the instance of this component observations.
 *
 * http://hl7.org/fhir/permittedDataType
 */
var permittedDataType = 'http://hl7.org/fhir/permittedDataType';
/**
 * gene
 *
 * SubstanceReferenceInformation.gene: Todo.
 *
 * http://hl7.org/fhir/gene
 */
var gene = 'http://hl7.org/fhir/gene';
/**
 * _prediction
 *
 * (Modified) RiskAssessment.prediction
 *
 * http://hl7.org/fhir/_prediction
 */
var _prediction = 'http://hl7.org/fhir/_prediction';
/**
 * exposureRoute
 *
 * AllergyIntolerance.reaction.exposureRoute: Identification of the route by which the subject was exposed to the substance.
 *
 * http://hl7.org/fhir/exposureRoute
 */
var exposureRoute = 'http://hl7.org/fhir/exposureRoute';
/**
 * height
 *
 * Attachment.height: Height of the image in pixels (photo/video).
 *
 * http://hl7.org/fhir/height
 */
var height = 'http://hl7.org/fhir/height';
/**
 * _entryClassifier
 *
 * (Modified) EvidenceReport.section.section.entryClassifier
 *
 * http://hl7.org/fhir/_entryClassifier
 */
var _entryClassifier = 'http://hl7.org/fhir/_entryClassifier';
/**
 * test
 *
 * TestScript.test: A test in this script.
 *
 * http://hl7.org/fhir/test
 */
var test = 'http://hl7.org/fhir/test';
/**
 * _previousAppointment
 *
 * (Modified) Appointment.previousAppointment
 *
 * http://hl7.org/fhir/_previousAppointment
 */
var _previousAppointment = 'http://hl7.org/fhir/_previousAppointment';
/**
 * implementationGuide
 *
 * CapabilityStatement.implementationGuide: A list of implementation guides that the server does (or should) support in their entirety.
 *
 * http://hl7.org/fhir/implementationGuide
 */
var implementationGuide = 'http://hl7.org/fhir/implementationGuide';
/**
 * UsageContext
 *
 * Specifies clinical/business/etc. metadata that can be used to retrieve, index and/or categorize an artifact. This metadata can either be specific to the applicable population (e.g., age category, DRG) or the specific context of care (e.g., venue, care setting, provider of care).
 *
 * http://hl7.org/fhir/UsageContext
 */
var UsageContext = 'http://hl7.org/fhir/UsageContext';
/**
 * EventDefinition
 *
 * The EventDefinition resource provides a reusable description of when a particular event can occur.
 *
 * http://hl7.org/fhir/EventDefinition
 */
var EventDefinition = 'http://hl7.org/fhir/EventDefinition';
/**
 * relatedIdentifier
 *
 * EvidenceReport.relatedIdentifier: A formal identifier that is used to identify things closely related to this EvidenceReport.
 *
 * http://hl7.org/fhir/relatedIdentifier
 */
var relatedIdentifier = 'http://hl7.org/fhir/relatedIdentifier';
/**
 * ImplementationGuideDependsOnComponent
 *
 * ImplementationGuideDependsOnComponent: Another implementation guide that this implementation depends on. Typically, an implementation guide uses value sets, profiles etc.defined in other implementation guides.
 *
 * http://hl7.org/fhir/ImplementationGuideDependsOnComponent
 */
var ImplementationGuideDependsOnComponent = 'http://hl7.org/fhir/ImplementationGuideDependsOnComponent';
/**
 * _procedureSequence
 *
 * (Modified) ExplanationOfBenefit.item.procedureSequence
 *
 * http://hl7.org/fhir/_procedureSequence
 */
var _procedureSequence = 'http://hl7.org/fhir/_procedureSequence';
/**
 * _copyrightLabel
 *
 * (Modified) ConceptMap.copyrightLabel
 *
 * http://hl7.org/fhir/_copyrightLabel
 */
var _copyrightLabel = 'http://hl7.org/fhir/_copyrightLabel';
/**
 * _navigationLinks
 *
 * (Modified) TestScript.test.action.assert.navigationLinks
 *
 * http://hl7.org/fhir/_navigationLinks
 */
var _navigationLinks = 'http://hl7.org/fhir/_navigationLinks';
/**
 * _generatedBy
 *
 * (Modified) GenomicStudy.analysis.input.generatedBy
 *
 * http://hl7.org/fhir/_generatedBy
 */
var _generatedBy = 'http://hl7.org/fhir/_generatedBy';
/**
 * administeredProduct
 *
 * Immunization.administeredProduct: An indication of which product was administered to the patient. This is typically a more detailed representation of the concept conveyed by the vaccineCode data element. If a Medication resource is referenced, it may be to a stand-alone resource or a contained resource within the Immunization resource.
 *
 * http://hl7.org/fhir/administeredProduct
 */
var administeredProduct = 'http://hl7.org/fhir/administeredProduct';
/**
 * validateProfileId
 *
 * TestScript.test.action.assert.validateProfileId: The ID of the Profile to validate against.
 *
 * http://hl7.org/fhir/validateProfileId
 */
var validateProfileId = 'http://hl7.org/fhir/validateProfileId';
/**
 * MedicationKnowledgeIndicationGuidelineComponent
 *
 * MedicationKnowledgeIndicationGuidelineComponent: Guidelines or protocols that are applicable for the administration of the medication based on indication.
 *
 * http://hl7.org/fhir/MedicationKnowledgeIndicationGuidelineComponent
 */
var MedicationKnowledgeIndicationGuidelineComponent = 'http://hl7.org/fhir/MedicationKnowledgeIndicationGuidelineComponent';
/**
 * intraspecificDescription
 *
 * SubstanceSourceMaterial.organism.intraspecificDescription: The intraspecific description of an organism shall be specified based on a controlled vocabulary. For Influenza Vaccine, the intraspecific description shall contain the syntax of the antigen in line with the WHO convention.
 *
 * http://hl7.org/fhir/intraspecificDescription
 */
var intraspecificDescription = 'http://hl7.org/fhir/intraspecificDescription';
/**
 * _protocolApplied
 *
 * (Modified) Immunization.protocolApplied
 *
 * http://hl7.org/fhir/_protocolApplied
 */
var _protocolApplied = 'http://hl7.org/fhir/_protocolApplied';
/**
 * _VerificationResult
 *
 * (Modified) VerificationResult
 *
 * http://hl7.org/fhir/_VerificationResult
 */
var _VerificationResult = 'http://hl7.org/fhir/_VerificationResult';
/**
 * monthInterval
 *
 * Appointment.recurrenceTemplate.monthlyTemplate.monthInterval: Indicates that recurring appointments should occur every nth month.
 *
 * http://hl7.org/fhir/monthInterval
 */
var monthInterval = 'http://hl7.org/fhir/monthInterval';
/**
 * expiry
 *
 * Substance.expiry: When the substance is no longer valid to use. For some substances, a single arbitrary date is used for expiry.
 *
 * http://hl7.org/fhir/expiry
 */
var expiry = 'http://hl7.org/fhir/expiry';
/**
 * versioning
 *
 * CapabilityStatement.rest.resource.versioning: This field is set to no-version to specify that the system does not support (server) or use (client) versioning for this resource type. If this has some other value, the server must at least correctly track and populate the versionId meta-property on resources. If the value is 'versioned-update', then the server supports all the versioning features, including using e-tags for version integrity in the API.
 *
 * http://hl7.org/fhir/versioning
 */
var versioning = 'http://hl7.org/fhir/versioning';
/**
 * pushTypeAvailable
 *
 * VerificationResult.primarySource.pushTypeAvailable: Type of alerts/updates the primary source can send (specific requested changes; any changes; as defined by source).
 *
 * http://hl7.org/fhir/pushTypeAvailable
 */
var pushTypeAvailable = 'http://hl7.org/fhir/pushTypeAvailable';
/**
 * CitationCitedArtifactStatusDateComponent
 *
 * CitationCitedArtifactComponent.CitationCitedArtifactStatusDateComponent: An effective date or period, historical or future, actual or expected, for a status of the cited artifact.
 *
 * http://hl7.org/fhir/CitationCitedArtifactStatusDateComponent
 */
var CitationCitedArtifactStatusDateComponent = 'http://hl7.org/fhir/CitationCitedArtifactStatusDateComponent';
/**
 * _assertion
 *
 * (Modified) TestPlan.testCase.assertion
 *
 * http://hl7.org/fhir/_assertion
 */
var _assertion = 'http://hl7.org/fhir/_assertion';
/**
 * diagnosis
 *
 * ExplanationOfBenefit.diagnosis.diagnosis
 *
 * http://hl7.org/fhir/diagnosis
 */
var diagnosis = 'http://hl7.org/fhir/diagnosis';
/**
 * _ifNoneExist
 *
 * (Modified) Bundle.entry.request.ifNoneExist
 *
 * http://hl7.org/fhir/_ifNoneExist
 */
var _ifNoneExist = 'http://hl7.org/fhir/_ifNoneExist';
/**
 * _low
 *
 * (Modified) SubstancePolymer.repeat.repeatUnit.degreeOfPolymerisation.low
 *
 * http://hl7.org/fhir/_low
 */
var _low = 'http://hl7.org/fhir/_low';
/**
 * undesirableEffect
 *
 * ClinicalUseDefinition.undesirableEffect: Describe the possible undesirable effects (negative outcomes) from the use of the medicinal product as treatment.
 *
 * http://hl7.org/fhir/undesirableEffect
 */
var undesirableEffect = 'http://hl7.org/fhir/undesirableEffect';
/**
 * _base
 *
 * (Modified) VisionPrescription.lensSpecification.prism.base
 *
 * http://hl7.org/fhir/_base
 */
var _base = 'http://hl7.org/fhir/_base';
/**
 * queryCriteria
 *
 * SubscriptionTopic.resourceTrigger.queryCriteria: The FHIR query based rules that the server should use to determine when to trigger a notification for this subscription topic.
 *
 * http://hl7.org/fhir/queryCriteria
 */
var queryCriteria = 'http://hl7.org/fhir/queryCriteria';
/**
 * _availableEndTime
 *
 * (Modified) Availability.availableTime.availableEndTime
 *
 * http://hl7.org/fhir/_availableEndTime
 */
var _availableEndTime = 'http://hl7.org/fhir/_availableEndTime';
/**
 * number
 *
 * ExampleScenario.process.step.process.step.alternative.step.number: The sequential number of the step, e.g. 1.2.5.
 *
 * http://hl7.org/fhir/number
 */
var number = 'http://hl7.org/fhir/number';
/**
 * spatialReference
 *
 * BodyStructure.excludedStructure.spatialReference: XY or XYZ-coordinate orientation for structure.
 *
 * http://hl7.org/fhir/spatialReference
 */
var spatialReference = 'http://hl7.org/fhir/spatialReference';
/**
 * conditionality
 *
 * Requirements.statement.conditionality: This boolean flag is set to true of the text of the requirement is conditional on something e.g. it includes lanauage like 'if x then y'. This conditionality flag is introduced for purposes of filtering and colour highlighting etc.
 *
 * http://hl7.org/fhir/conditionality
 */
var conditionality = 'http://hl7.org/fhir/conditionality';
/**
 * _codeFilter
 *
 * (Modified) DataRequirement.codeFilter
 *
 * http://hl7.org/fhir/_codeFilter
 */
var _codeFilter = 'http://hl7.org/fhir/_codeFilter';
/**
 * SubstanceDefinitionCharacterizationComponent
 *
 * SubstanceDefinitionCharacterizationComponent: General specifications for this substance.
 *
 * http://hl7.org/fhir/SubstanceDefinitionCharacterizationComponent
 */
var SubstanceDefinitionCharacterizationComponent = 'http://hl7.org/fhir/SubstanceDefinitionCharacterizationComponent';
/**
 * offsets
 *
 * SampledData.offsets: A series of data points which are decimal values separated by a single space (character u20).  The units in which the offsets are expressed are found in intervalUnit.  The absolute point at which the measurements begin SHALL be conveyed outside the scope of this datatype, e.g. Observation.effectiveDateTime for a timing offset.
 *
 * http://hl7.org/fhir/offsets
 */
var offsets = 'http://hl7.org/fhir/offsets';
/**
 * _orderedBy
 *
 * (Modified) List.orderedBy
 *
 * http://hl7.org/fhir/_orderedBy
 */
var _orderedBy = 'http://hl7.org/fhir/_orderedBy';
/**
 * _authorizationUrl
 *
 * (Modified) CoverageEligibilityResponse.insurance.item.authorizationUrl
 *
 * http://hl7.org/fhir/_authorizationUrl
 */
var _authorizationUrl = 'http://hl7.org/fhir/_authorizationUrl';
/**
 * _carrierAIDC
 *
 * (Modified) Device.udiCarrier.carrierAIDC
 *
 * http://hl7.org/fhir/_carrierAIDC
 */
var _carrierAIDC = 'http://hl7.org/fhir/_carrierAIDC';
/**
 * _episodeOfCare
 *
 * (Modified) Encounter.episodeOfCare
 *
 * http://hl7.org/fhir/_episodeOfCare
 */
var _episodeOfCare = 'http://hl7.org/fhir/_episodeOfCare';
/**
 * disabledDisplay
 *
 * Questionnaire.item.item.disabledDisplay: Indicates if and how items that are disabled (because enableWhen evaluates to 'false') should be displayed.
 *
 * http://hl7.org/fhir/disabledDisplay
 */
var disabledDisplay = 'http://hl7.org/fhir/disabledDisplay';
/**
 * DocumentReference
 *
 * A reference to a document of any kind for any purpose. While the term “document” implies a more narrow focus, for this resource this “document” encompasses *any* serialized object with a mime-type, it includes formal patient-centric documents (CDA), clinical notes, scanned paper, non-patient specific documents like policy text, as well as a photo, video, or audio recording acquired or used in healthcare.  The DocumentReference resource provides metadata about the document so that the document can be discovered and managed.  The actual content may be inline base64 encoded data or provided by direct reference.
 *
 * http://hl7.org/fhir/DocumentReference
 */
var DocumentReference = 'http://hl7.org/fhir/DocumentReference';
/**
 * compositeScoring
 *
 * Measure.compositeScoring: If this is a composite measure, the scoring method used to combine the component measures to determine the composite score.
 *
 * http://hl7.org/fhir/compositeScoring
 */
var compositeScoring = 'http://hl7.org/fhir/compositeScoring';
/**
 * _yearInterval
 *
 * (Modified) Appointment.recurrenceTemplate.yearlyTemplate.yearInterval
 *
 * http://hl7.org/fhir/_yearInterval
 */
var _yearInterval = 'http://hl7.org/fhir/_yearInterval';
/**
 * RelatedPersonCommunicationComponent
 *
 * RelatedPersonCommunicationComponent: A language which may be used to communicate with the related person about the patient's health.
 *
 * http://hl7.org/fhir/RelatedPersonCommunicationComponent
 */
var RelatedPersonCommunicationComponent = 'http://hl7.org/fhir/RelatedPersonCommunicationComponent';
/**
 * _displayName
 *
 * (Modified) Device.displayName
 *
 * http://hl7.org/fhir/_displayName
 */
var _displayName = 'http://hl7.org/fhir/_displayName';
/**
 * _monday
 *
 * (Modified) Appointment.recurrenceTemplate.weeklyTemplate.monday
 *
 * http://hl7.org/fhir/_monday
 */
var _monday = 'http://hl7.org/fhir/_monday';
/**
 * messaging
 *
 * CapabilityStatement.messaging: A description of the messaging capabilities of the solution.
 *
 * http://hl7.org/fhir/messaging
 */
var messaging = 'http://hl7.org/fhir/messaging';
/**
 * geneElement
 *
 * SubstanceReferenceInformation.geneElement: Todo.
 *
 * http://hl7.org/fhir/geneElement
 */
var geneElement = 'http://hl7.org/fhir/geneElement';
/**
 * exclude
 *
 * EvidenceVariable.characteristic.exclude: When true, this characteristic is an exclusion criterion. In other words, not matching this characteristic definition is equivalent to meeting this criterion.
 *
 * http://hl7.org/fhir/exclude
 */
var exclude = 'http://hl7.org/fhir/exclude';
/**
 * _itemSequence
 *
 * (Modified) ExplanationOfBenefit.addItem.itemSequence
 *
 * http://hl7.org/fhir/_itemSequence
 */
var _itemSequence = 'http://hl7.org/fhir/_itemSequence';
/**
 * _artifactAssessment
 *
 * (Modified) Citation.citedArtifact.classification.artifactAssessment
 *
 * http://hl7.org/fhir/_artifactAssessment
 */
var _artifactAssessment = 'http://hl7.org/fhir/_artifactAssessment';
/**
 * dispenseRequest
 *
 * MedicationRequest.dispenseRequest: Indicates the specific details for the dispense or medication supply part of a medication request (also known as a Medication Prescription or Medication Order).  Note that this information is not always sent with the order.  There may be in some settings (e.g. hospitals) institutional or system support for completing the dispense details in the pharmacy department.
 *
 * http://hl7.org/fhir/dispenseRequest
 */
var dispenseRequest = 'http://hl7.org/fhir/dispenseRequest';
/**
 * intendedJurisdiction
 *
 * MedicationKnowledge.intendedJurisdiction: Lists the jurisdictions that this medication knowledge was written for.
 *
 * http://hl7.org/fhir/intendedJurisdiction
 */
var intendedJurisdiction = 'http://hl7.org/fhir/intendedJurisdiction';
/**
 * _restriction
 *
 * (Modified) Transport.restriction
 *
 * http://hl7.org/fhir/_restriction
 */
var _restriction = 'http://hl7.org/fhir/_restriction';
/**
 * ImmunizationEvaluation
 *
 * Describes a comparison of an immunization event against published recommendations to determine if the administration is "valid" in relation to those  recommendations.
 *
 * http://hl7.org/fhir/ImmunizationEvaluation
 */
var ImmunizationEvaluation = 'http://hl7.org/fhir/ImmunizationEvaluation';
/**
 * Observation
 *
 * Measurements and simple assertions made about a patient, device or other subject.
 *
 * http://hl7.org/fhir/Observation
 */
var Observation = 'http://hl7.org/fhir/Observation';
/**
 * _supplier
 *
 * (Modified) SupplyRequest.supplier
 *
 * http://hl7.org/fhir/_supplier
 */
var _supplier = 'http://hl7.org/fhir/_supplier';
/**
 * NutritionIntakePerformerComponent
 *
 * NutritionIntakePerformerComponent: Who performed the intake and how they were involved.
 *
 * http://hl7.org/fhir/NutritionIntakePerformerComponent
 */
var NutritionIntakePerformerComponent = 'http://hl7.org/fhir/NutritionIntakePerformerComponent';
/**
 * CapabilityStatementRestComponentSearchParam
 *
 * Search parameters that are supported for searching all resources for implementations to support and/or make use of - either references to ones defined in the specification, or additional ones defined for/by the implementation. This is only for searches executed against the system-level endpoint.
 *
 * http://hl7.org/fhir/CapabilityStatementRestComponentSearchParam
 */
var CapabilityStatementRestComponentSearchParam = 'http://hl7.org/fhir/CapabilityStatementRestComponentSearchParam';
/**
 * _SubstanceReferenceInformation
 *
 * (Modified) SubstanceReferenceInformation
 *
 * http://hl7.org/fhir/_SubstanceReferenceInformation
 */
var _SubstanceReferenceInformation = 'http://hl7.org/fhir/_SubstanceReferenceInformation';
/**
 * _CarePlan
 *
 * (Modified) CarePlan
 *
 * http://hl7.org/fhir/_CarePlan
 */
var _CarePlan = 'http://hl7.org/fhir/_CarePlan';
/**
 * AdverseEventPreventiveActionComponent
 *
 * AdverseEventPreventiveActionComponent: Preventive actions that contributed to avoiding the adverse event.
 *
 * http://hl7.org/fhir/AdverseEventPreventiveActionComponent
 */
var AdverseEventPreventiveActionComponent = 'http://hl7.org/fhir/AdverseEventPreventiveActionComponent';
/**
 * outsideFoodAllowed
 *
 * NutritionOrder.outsideFoodAllowed: This modifier is used to convey whether a food item is allowed to be brought in by the patient and/or family.  If set to true, indicates that the receiving system does not need to supply the food item.
 *
 * http://hl7.org/fhir/outsideFoodAllowed
 */
var outsideFoodAllowed = 'http://hl7.org/fhir/outsideFoodAllowed';
/**
 * _maxVolumeToDeliver
 *
 * (Modified) NutritionOrder.enteralFormula.maxVolumeToDeliver
 *
 * http://hl7.org/fhir/_maxVolumeToDeliver
 */
var _maxVolumeToDeliver = 'http://hl7.org/fhir/_maxVolumeToDeliver';
/**
 * InventoryItemAssociationComponent
 *
 * InventoryItemAssociationComponent: Association with other items or products.
 *
 * http://hl7.org/fhir/InventoryItemAssociationComponent
 */
var InventoryItemAssociationComponent = 'http://hl7.org/fhir/InventoryItemAssociationComponent';
/**
 * deliverFor
 *
 * SupplyRequest.deliverFor: The patient to whom the supply will be given or for whom they will be used.
 *
 * http://hl7.org/fhir/deliverFor
 */
var deliverFor = 'http://hl7.org/fhir/deliverFor';
/**
 * ElementDefinitionExampleComponent
 *
 * ElementDefinitionExampleComponent: A sample value for this element demonstrating the type of information that would typically be found in the element.
 *
 * http://hl7.org/fhir/ElementDefinitionExampleComponent
 */
var ElementDefinitionExampleComponent = 'http://hl7.org/fhir/ElementDefinitionExampleComponent';
/**
 * _totalPriceComponent
 *
 * (Modified) Invoice.totalPriceComponent
 *
 * http://hl7.org/fhir/_totalPriceComponent
 */
var _totalPriceComponent = 'http://hl7.org/fhir/_totalPriceComponent';
/**
 * _carrierHRF
 *
 * (Modified) Device.udiCarrier.carrierHRF
 *
 * http://hl7.org/fhir/_carrierHRF
 */
var _carrierHRF = 'http://hl7.org/fhir/_carrierHRF';
/**
 * _subProperty
 *
 * (Modified) ValueSet.expansion.contains.contains.property.subProperty
 *
 * http://hl7.org/fhir/_subProperty
 */
var _subProperty = 'http://hl7.org/fhir/_subProperty';
/**
 * allowed
 *
 * MedicationRequest.substitution.allowed
 *
 * http://hl7.org/fhir/allowed
 */
var allowed = 'http://hl7.org/fhir/allowed';
/**
 * _searchType
 *
 * (Modified) OperationDefinition.parameter.part.searchType
 *
 * http://hl7.org/fhir/_searchType
 */
var _searchType = 'http://hl7.org/fhir/_searchType';
/**
 * List
 *
 * A List is a curated collection of resources, for things such as problem lists, allergy lists, facility list, organization list, etc.
 *
 * http://hl7.org/fhir/List
 */
var List = 'http://hl7.org/fhir/List';
/**
 * responseId
 *
 * TestScript.teardown.action.operation.responseId: The fixture id (maybe new) to map to the response.
 *
 * http://hl7.org/fhir/responseId
 */
var responseId = 'http://hl7.org/fhir/responseId';
/**
 * _defaultManualCompletion
 *
 * (Modified) TestScript.test.action.assert.defaultManualCompletion
 *
 * http://hl7.org/fhir/_defaultManualCompletion
 */
var _defaultManualCompletion = 'http://hl7.org/fhir/_defaultManualCompletion';
/**
 * _subscriberId
 *
 * (Modified) Coverage.subscriberId
 *
 * http://hl7.org/fhir/_subscriberId
 */
var _subscriberId = 'http://hl7.org/fhir/_subscriberId';
/**
 * _groupingId
 *
 * (Modified) ImplementationGuide.definition.resource.groupingId
 *
 * http://hl7.org/fhir/_groupingId
 */
var _groupingId = 'http://hl7.org/fhir/_groupingId';
/**
 * _protocolPerformed
 *
 * (Modified) GenomicStudy.analysis.protocolPerformed
 *
 * http://hl7.org/fhir/_protocolPerformed
 */
var _protocolPerformed = 'http://hl7.org/fhir/_protocolPerformed';
/**
 * subPotentReason
 *
 * MedicationAdministration.subPotentReason: The reason or reasons why the full dose was not administered.
 *
 * http://hl7.org/fhir/subPotentReason
 */
var subPotentReason = 'http://hl7.org/fhir/subPotentReason';
/**
 * maxValue
 *
 * ElementDefinition.maxValue
 *
 * http://hl7.org/fhir/maxValue
 */
var maxValue = 'http://hl7.org/fhir/maxValue';
/**
 * _data
 *
 * (Modified) TriggerDefinition.data
 *
 * http://hl7.org/fhir/_data
 */
var _data = 'http://hl7.org/fhir/_data';
/**
 * _disulfideLinkage
 *
 * (Modified) SubstanceProtein.disulfideLinkage
 *
 * http://hl7.org/fhir/_disulfideLinkage
 */
var _disulfideLinkage = 'http://hl7.org/fhir/_disulfideLinkage';
/**
 * metadata
 *
 * TestScript.metadata: The required capability must exist and are assumed to function correctly on the FHIR server being tested.
 *
 * http://hl7.org/fhir/metadata
 */
var metadata = 'http://hl7.org/fhir/metadata';
/**
 * ConditionParticipantComponent
 *
 * ConditionParticipantComponent: Indicates who or what participated in the activities related to the condition and how they were involved.
 *
 * http://hl7.org/fhir/ConditionParticipantComponent
 */
var ConditionParticipantComponent = 'http://hl7.org/fhir/ConditionParticipantComponent';
/**
 * rationale
 *
 * RiskAssessment.prediction.rationale: Additional information explaining the basis for the prediction.
 *
 * http://hl7.org/fhir/rationale
 */
var rationale = 'http://hl7.org/fhir/rationale';
/**
 * tax
 *
 * ClaimResponse.addItem.detail.tax: The total of taxes applicable for this product or service.
 *
 * http://hl7.org/fhir/tax
 */
var tax = 'http://hl7.org/fhir/tax';
/**
 * _line
 *
 * (Modified) Address.line
 *
 * http://hl7.org/fhir/_line
 */
var _line = 'http://hl7.org/fhir/_line';
/**
 * index
 *
 * TestScript.destination.index: Abstract name given to a destination server in this test script.  The name is provided as a number starting at 1.
 *
 * http://hl7.org/fhir/index
 */
var index = 'http://hl7.org/fhir/index';
/**
 * _firstPage
 *
 * (Modified) Citation.citedArtifact.publicationForm.firstPage
 *
 * http://hl7.org/fhir/_firstPage
 */
var _firstPage = 'http://hl7.org/fhir/_firstPage';
/**
 * verifiedBy
 *
 * Consent.verification.verifiedBy: The person who conducted the verification/validation of the Grantor decision.
 *
 * http://hl7.org/fhir/verifiedBy
 */
var verifiedBy = 'http://hl7.org/fhir/verifiedBy';
/**
 * _requestProvider
 *
 * (Modified) EnrollmentResponse.requestProvider
 *
 * http://hl7.org/fhir/_requestProvider
 */
var _requestProvider = 'http://hl7.org/fhir/_requestProvider';
/**
 * Diagnosis
 *
 * ExplanationOfBenefit.Diagnosis: Information about diagnoses relevant to the claim items.
 *
 * http://hl7.org/fhir/Diagnosis
 */
var Diagnosis = 'http://hl7.org/fhir/Diagnosis';
/**
 * _hybridType
 *
 * (Modified) SubstanceSourceMaterial.organism.hybrid.hybridType
 *
 * http://hl7.org/fhir/_hybridType
 */
var _hybridType = 'http://hl7.org/fhir/_hybridType';
/**
 * _abnormalCodedValueSet
 *
 * (Modified) ObservationDefinition.component.qualifiedValue.abnormalCodedValueSet
 *
 * http://hl7.org/fhir/_abnormalCodedValueSet
 */
var _abnormalCodedValueSet = 'http://hl7.org/fhir/_abnormalCodedValueSet';
/**
 * Encounter
 *
 * An interaction between healthcare provider(s), and/or patient(s) for the purpose of providing healthcare service(s) or assessing the health status of patient(s).
 *
 * http://hl7.org/fhir/Encounter
 */
var Encounter = 'http://hl7.org/fhir/Encounter';
/**
 * expression
 *
 * RequestOrchestration.action.condition.expression: An expression that returns true or false, indicating whether or not the condition is satisfied.
 *
 * http://hl7.org/fhir/expression
 */
var expression = 'http://hl7.org/fhir/expression';
/**
 * _current
 *
 * (Modified) SubscriptionTopic.resourceTrigger.queryCriteria.current
 *
 * http://hl7.org/fhir/_current
 */
var _current = 'http://hl7.org/fhir/_current';
/**
 * BackboneType
 *
 * Base definition for the few data types that are allowed to carry modifier extensions.
 *
 * http://hl7.org/fhir/BackboneType
 */
var BackboneType = 'http://hl7.org/fhir/BackboneType';
/**
 * collection
 *
 * SpecimenDefinition.collection: The action to be performed for collecting the specimen.
 *
 * http://hl7.org/fhir/collection
 */
var collection = 'http://hl7.org/fhir/collection';
/**
 * _family
 *
 * (Modified) SubstanceSourceMaterial.organism.family
 *
 * http://hl7.org/fhir/_family
 */
var _family = 'http://hl7.org/fhir/_family';
/**
 * _validated
 *
 * (Modified) TestScript.metadata.capability.validated
 *
 * http://hl7.org/fhir/_validated
 */
var _validated = 'http://hl7.org/fhir/_validated';
/**
 * question
 *
 * Questionnaire.item.item.enableWhen.question: The linkId for the question whose answer (or lack of answer) governs whether this item is enabled.
 *
 * http://hl7.org/fhir/question
 */
var question = 'http://hl7.org/fhir/question';
/**
 * _noMap
 *
 * (Modified) ConceptMap.group.element.noMap
 *
 * http://hl7.org/fhir/_noMap
 */
var _noMap = 'http://hl7.org/fhir/_noMap';
/**
 * _comparisonGroup
 *
 * (Modified) ResearchStudy.comparisonGroup
 *
 * http://hl7.org/fhir/_comparisonGroup
 */
var _comparisonGroup = 'http://hl7.org/fhir/_comparisonGroup';
/**
 * EnrollmentRequest
 *
 * This resource provides the insurance enrollment details to the insurer regarding a specified coverage.
 *
 * http://hl7.org/fhir/EnrollmentRequest
 */
var EnrollmentRequest = 'http://hl7.org/fhir/EnrollmentRequest';
/**
 * _surfaceOrientation
 *
 * (Modified) BodyStructure.excludedStructure.bodyLandmarkOrientation.surfaceOrientation
 *
 * http://hl7.org/fhir/_surfaceOrientation
 */
var _surfaceOrientation = 'http://hl7.org/fhir/_surfaceOrientation';
/**
 * prescription
 *
 * ExplanationOfBenefit.prescription: Prescription is the document/authorization given to the claim author for them to provide products and services for which consideration (reimbursement) is sought. Could be a RX for medications, an 'order' for oxygen or wheelchair or physiotherapy treatments.
 *
 * http://hl7.org/fhir/prescription
 */
var prescription = 'http://hl7.org/fhir/prescription';
/**
 * _contributorship
 *
 * (Modified) Citation.citedArtifact.contributorship
 *
 * http://hl7.org/fhir/_contributorship
 */
var _contributorship = 'http://hl7.org/fhir/_contributorship';
/**
 * synthesisType
 *
 * Evidence.synthesisType: The method to combine studies.
 *
 * http://hl7.org/fhir/synthesisType
 */
var synthesisType = 'http://hl7.org/fhir/synthesisType';
/**
 * _anchor
 *
 * (Modified) ImplementationGuide.manifest.page.anchor
 *
 * http://hl7.org/fhir/_anchor
 */
var _anchor = 'http://hl7.org/fhir/_anchor';
/**
 * _suppress
 *
 * (Modified) ElementDefinition.constraint.suppress
 *
 * http://hl7.org/fhir/_suppress
 */
var _suppress = 'http://hl7.org/fhir/_suppress';
/**
 * _other
 *
 * (Modified) Patient.link.other
 *
 * http://hl7.org/fhir/_other
 */
var _other = 'http://hl7.org/fhir/_other';
/**
 * variable
 *
 * StructureMap.group.rule.target.variable: Named context for field, if desired, and a field is specified.
 *
 * http://hl7.org/fhir/variable
 */
var variable = 'http://hl7.org/fhir/variable';
/**
 * MolecularSequenceRelativeComponent
 *
 * MolecularSequenceRelativeComponent: A sequence defined relative to another sequence.
 *
 * http://hl7.org/fhir/MolecularSequenceRelativeComponent
 */
var MolecularSequenceRelativeComponent = 'http://hl7.org/fhir/MolecularSequenceRelativeComponent';
/**
 * Ingredient
 *
 * An ingredient of a manufactured item or pharmaceutical product.
 *
 * http://hl7.org/fhir/Ingredient
 */
var Ingredient = 'http://hl7.org/fhir/Ingredient';
/**
 * _occurrenceDateTime
 *
 * (Modified) GuidanceResponse.occurrenceDateTime
 *
 * http://hl7.org/fhir/_occurrenceDateTime
 */
var _occurrenceDateTime = 'http://hl7.org/fhir/_occurrenceDateTime';
/**
 * Annotation
 *
 * A  text note which also  contains information about who made the statement and when.
 *
 * http://hl7.org/fhir/Annotation
 */
var Annotation = 'http://hl7.org/fhir/Annotation';
/**
 * SubstanceReferenceInformationGeneComponent
 *
 * SubstanceReferenceInformationGeneComponent: Todo.
 *
 * http://hl7.org/fhir/SubstanceReferenceInformationGeneComponent
 */
var SubstanceReferenceInformationGeneComponent = 'http://hl7.org/fhir/SubstanceReferenceInformationGeneComponent';
/**
 * _valueQuantity
 *
 * (Modified) Evidence.statistic.modelCharacteristic.variable.valueQuantity
 *
 * http://hl7.org/fhir/_valueQuantity
 */
var _valueQuantity = 'http://hl7.org/fhir/_valueQuantity';
/**
 * DeviceDefinitionCorrectiveActionComponent
 *
 * DeviceDefinitionCorrectiveActionComponent: Tracking of latest field safety corrective action.
 *
 * http://hl7.org/fhir/DeviceDefinitionCorrectiveActionComponent
 */
var DeviceDefinitionCorrectiveActionComponent = 'http://hl7.org/fhir/DeviceDefinitionCorrectiveActionComponent';
/**
 * OperationDefinitionParameterComponent
 *
 * OperationDefinitionParameterComponent: The parameters for the operation/query.
 *
 * http://hl7.org/fhir/OperationDefinitionParameterComponent
 */
var OperationDefinitionParameterComponent = 'http://hl7.org/fhir/OperationDefinitionParameterComponent';
/**
 * EvidenceVariableCharacteristicDefinitionByCombinationComponent
 *
 * EvidenceVariableCharacteristicComponent.EvidenceVariableCharacteristicDefinitionByCombinationComponent: Defines the characteristic as a combination of two or more characteristics.
 *
 * http://hl7.org/fhir/EvidenceVariableCharacteristicDefinitionByCombinationComponent
 */
var EvidenceVariableCharacteristicDefinitionByCombinationComponent = 'http://hl7.org/fhir/EvidenceVariableCharacteristicDefinitionByCombinationComponent';
/**
 * SpecimenDefinitionTypeTestedHandlingComponent
 *
 * SpecimenDefinitionTypeTestedComponent.SpecimenDefinitionTypeTestedHandlingComponent: Set of instructions for preservation/transport of the specimen at a defined temperature interval, prior the testing process.
 *
 * http://hl7.org/fhir/SpecimenDefinitionTypeTestedHandlingComponent
 */
var SpecimenDefinitionTypeTestedHandlingComponent = 'http://hl7.org/fhir/SpecimenDefinitionTypeTestedHandlingComponent';
/**
 * _testRun
 *
 * (Modified) TestPlan.testCase.testRun
 *
 * http://hl7.org/fhir/_testRun
 */
var _testRun = 'http://hl7.org/fhir/_testRun';
/**
 * compareToSourceId
 *
 * TestScript.test.action.assert.compareToSourceId: Id of the source fixture used as the contents to be evaluated by either the "source/expression" or "sourceId/path" definition.
 *
 * http://hl7.org/fhir/compareToSourceId
 */
var compareToSourceId = 'http://hl7.org/fhir/compareToSourceId';
/**
 * _definitional
 *
 * (Modified) MedicationKnowledge.definitional
 *
 * http://hl7.org/fhir/_definitional
 */
var _definitional = 'http://hl7.org/fhir/_definitional';
/**
 * _testCase
 *
 * (Modified) TestPlan.testCase
 *
 * http://hl7.org/fhir/_testCase
 */
var _testCase = 'http://hl7.org/fhir/_testCase';
/**
 * _PaymentReconciliation
 *
 * (Modified) PaymentReconciliation
 *
 * http://hl7.org/fhir/_PaymentReconciliation
 */
var _PaymentReconciliation = 'http://hl7.org/fhir/_PaymentReconciliation';
/**
 * valuedItem
 *
 * Contract.term.group.asset.valuedItem: Contract Valued Item List.
 *
 * http://hl7.org/fhir/valuedItem
 */
var valuedItem = 'http://hl7.org/fhir/valuedItem';
/**
 * relatedItem
 *
 * InventoryItem.association.relatedItem: The related item or product.
 *
 * http://hl7.org/fhir/relatedItem
 */
var relatedItem = 'http://hl7.org/fhir/relatedItem';
/**
 * consumedItem
 *
 * NutritionIntake.consumedItem: What food or fluid product or item was consumed.
 *
 * http://hl7.org/fhir/consumedItem
 */
var consumedItem = 'http://hl7.org/fhir/consumedItem';
/**
 * search
 *
 * CompartmentDefinition.search: Whether the search syntax is supported,.
 *
 * http://hl7.org/fhir/search
 */
var search = 'http://hl7.org/fhir/search';
/**
 * duration
 *
 * EvidenceVariable.characteristic.definitionByCombination.characteristic.duration
 *
 * http://hl7.org/fhir/duration
 */
var duration = 'http://hl7.org/fhir/duration';
/**
 * status
 *
 * PackagedProductDefinition.status: The status within the lifecycle of this item. A high level status, this is not intended to duplicate details carried elsewhere such as legal status, or authorization or marketing status.
 *
 * http://hl7.org/fhir/status
 */
var status = 'http://hl7.org/fhir/status';
/**
 * _context
 *
 * (Modified) Contract.term.group.asset.context
 *
 * http://hl7.org/fhir/_context
 */
var _context = 'http://hl7.org/fhir/_context';
/**
 * _requirements
 *
 * (Modified) ElementDefinition.constraint.requirements
 *
 * http://hl7.org/fhir/_requirements
 */
var _requirements = 'http://hl7.org/fhir/_requirements';
/**
 * _subjectType
 *
 * (Modified) Questionnaire.subjectType
 *
 * http://hl7.org/fhir/_subjectType
 */
var _subjectType = 'http://hl7.org/fhir/_subjectType';
/**
 * _use
 *
 * (Modified) OperationDefinition.parameter.use
 *
 * http://hl7.org/fhir/_use
 */
var _use = 'http://hl7.org/fhir/_use';
/**
 * udi
 *
 * ExplanationOfBenefit.item.detail.udi: Unique Device Identifiers associated with this line item.
 *
 * http://hl7.org/fhir/udi
 */
var udi = 'http://hl7.org/fhir/udi';
/**
 * nameType
 *
 * InventoryItem.name.nameType: The type of name e.g. 'brand-name', 'functional-name', 'common-name'.
 *
 * http://hl7.org/fhir/nameType
 */
var nameType = 'http://hl7.org/fhir/nameType';
/**
 * _producedFrom
 *
 * (Modified) AdministrableProductDefinition.producedFrom
 *
 * http://hl7.org/fhir/_producedFrom
 */
var _producedFrom = 'http://hl7.org/fhir/_producedFrom';
/**
 * _interval
 *
 * (Modified) SampledData.interval
 *
 * http://hl7.org/fhir/_interval
 */
var _interval = 'http://hl7.org/fhir/_interval';
/**
 * summary
 *
 * Citation.summary: A human-readable display of key concepts to represent the citation.
 *
 * http://hl7.org/fhir/summary
 */
var summary = 'http://hl7.org/fhir/summary';
/**
 * MedicinalProductDefinitionCharacteristicComponent
 *
 * MedicinalProductDefinitionCharacteristicComponent: Allows the key product features to be recorded, such as "sugar free", "modified release", "parallel import".
 *
 * http://hl7.org/fhir/MedicinalProductDefinitionCharacteristicComponent
 */
var MedicinalProductDefinitionCharacteristicComponent = 'http://hl7.org/fhir/MedicinalProductDefinitionCharacteristicComponent';
/**
 * sex
 *
 * FamilyMemberHistory.sex: The birth sex of the family member.
 *
 * http://hl7.org/fhir/sex
 */
var sex = 'http://hl7.org/fhir/sex';
/**
 * AdministrableProductDefinition
 *
 * A medicinal product in the final form which is suitable for administering to a patient (after any mixing of multiple components, dissolution etc. has been performed).
 *
 * http://hl7.org/fhir/AdministrableProductDefinition
 */
var AdministrableProductDefinition = 'http://hl7.org/fhir/AdministrableProductDefinition';
/**
 * SecurityLabel
 *
 * Contract.Term.SecurityLabel: Security labels that protect the handling of information about the term and its elements, which may be specifically identified.
 *
 * http://hl7.org/fhir/SecurityLabel
 */
var SecurityLabel = 'http://hl7.org/fhir/SecurityLabel';
/**
 * SubstanceDefinitionRelationshipComponent
 *
 * SubstanceDefinitionRelationshipComponent: A link between this substance and another, with details of the relationship.
 *
 * http://hl7.org/fhir/SubstanceDefinitionRelationshipComponent
 */
var SubstanceDefinitionRelationshipComponent = 'http://hl7.org/fhir/SubstanceDefinitionRelationshipComponent';
/**
 * knownAllergen
 *
 * NutritionProduct.knownAllergen: Allergens that are known or suspected to be a part of this nutrition product.
 *
 * http://hl7.org/fhir/knownAllergen
 */
var knownAllergen = 'http://hl7.org/fhir/knownAllergen';
/**
 * knownDataCount
 *
 * Evidence.statistic.sampleSize.knownDataCount: Number of participants with known results for measured variables.
 *
 * http://hl7.org/fhir/knownDataCount
 */
var knownDataCount = 'http://hl7.org/fhir/knownDataCount';
/**
 * observer
 *
 * AuditEvent.source.observer: Identifier of the source where the event was detected.
 *
 * http://hl7.org/fhir/observer
 */
var observer = 'http://hl7.org/fhir/observer';
/**
 * _subtitle
 *
 * (Modified) PlanDefinition.subtitle
 *
 * http://hl7.org/fhir/_subtitle
 */
var _subtitle = 'http://hl7.org/fhir/_subtitle';
/**
 * accessionNumber
 *
 * Citation.citedArtifact.publicationForm.accessionNumber: Entry number or identifier for inclusion in a database.
 *
 * http://hl7.org/fhir/accessionNumber
 */
var accessionNumber = 'http://hl7.org/fhir/accessionNumber';
/**
 * _finding
 *
 * (Modified) ClinicalImpression.finding
 *
 * http://hl7.org/fhir/_finding
 */
var _finding = 'http://hl7.org/fhir/_finding';
/**
 * _style
 *
 * (Modified) Citation.citedArtifact.contributorship.summary.style
 *
 * http://hl7.org/fhir/_style
 */
var _style = 'http://hl7.org/fhir/_style';
/**
 * relation
 *
 * DeviceDefinition.link.relation: The type indicates the relationship of the related device to the device instance.
 *
 * http://hl7.org/fhir/relation
 */
var relation = 'http://hl7.org/fhir/relation';
/**
 * priority
 *
 * Transport.priority: Indicates how quickly the Transport should be addressed with respect to other requests.
 *
 * http://hl7.org/fhir/priority
 */
var priority = 'http://hl7.org/fhir/priority';
/**
 * _requestId
 *
 * (Modified) TestScript.teardown.action.operation.requestId
 *
 * http://hl7.org/fhir/_requestId
 */
var _requestId = 'http://hl7.org/fhir/_requestId';
/**
 * ElementDefinitionBindingComponent
 *
 * ElementDefinitionBindingComponent: Binds to a value set if this element is coded (code, Coding, CodeableConcept, Quantity), or the data types (string, uri).
 *
 * http://hl7.org/fhir/ElementDefinitionBindingComponent
 */
var ElementDefinitionBindingComponent = 'http://hl7.org/fhir/ElementDefinitionBindingComponent';
/**
 * sequenceAttachment
 *
 * SubstanceProtein.subunit.sequenceAttachment: The sequence information shall be provided enumerating the amino acids from N- to C-terminal end using standard single-letter amino acid codes. Uppercase shall be used for L-amino acids and lowercase for D-amino acids. Transcribed SubstanceProteins will always be described using the translated sequence; for synthetic peptide containing amino acids that are not represented with a single letter code an X should be used within the sequence. The modified amino acids will be distinguished by their position in the sequence.
 *
 * http://hl7.org/fhir/sequenceAttachment
 */
var sequenceAttachment = 'http://hl7.org/fhir/sequenceAttachment';
/**
 * AddedItemBodySite
 *
 * ExplanationOfBenefit.AddedItem.AddedItemBodySite: Physical location where the service is performed or applies.
 *
 * http://hl7.org/fhir/AddedItemBodySite
 */
var AddedItemBodySite = 'http://hl7.org/fhir/AddedItemBodySite';
/**
 * _group
 *
 * (Modified) StructureMap.group
 *
 * http://hl7.org/fhir/_group
 */
var _group = 'http://hl7.org/fhir/_group';
/**
 * publisher
 *
 * ConditionDefinition.publisher: The name of the organization or individual responsible for the release and ongoing maintenance of the condition definition.
 *
 * http://hl7.org/fhir/publisher
 */
var publisher = 'http://hl7.org/fhir/publisher';
/**
 * consent
 *
 * ResearchSubject.consent: A record of the patient's informed agreement to participate in the study.
 *
 * http://hl7.org/fhir/consent
 */
var consent = 'http://hl7.org/fhir/consent';
/**
 * site
 *
 * ExplanationOfBenefit.item.bodySite.site: Physical service site on the patient (limb, tooth, etc.).
 *
 * http://hl7.org/fhir/site
 */
var site = 'http://hl7.org/fhir/site';
/**
 * canFilterBy
 *
 * SubscriptionTopic.canFilterBy: List of properties by which Subscriptions on the SubscriptionTopic can be filtered. May be defined Search Parameters (e.g., Encounter.patient) or parameters defined within this SubscriptionTopic context (e.g., hub.event).
 *
 * http://hl7.org/fhir/canFilterBy
 */
var canFilterBy = 'http://hl7.org/fhir/canFilterBy';
/**
 * TerminologyCapabilitiesValidateCodeComponent
 *
 * TerminologyCapabilitiesValidateCodeComponent: Information about the [ValueSet/$validate-code](valueset-operation-validate-code.html) operation.
 *
 * http://hl7.org/fhir/TerminologyCapabilitiesValidateCodeComponent
 */
var TerminologyCapabilitiesValidateCodeComponent = 'http://hl7.org/fhir/TerminologyCapabilitiesValidateCodeComponent';
/**
 * _isSubPotent
 *
 * (Modified) MedicationAdministration.isSubPotent
 *
 * http://hl7.org/fhir/_isSubPotent
 */
var _isSubPotent = 'http://hl7.org/fhir/_isSubPotent';
/**
 * EncounterParticipantComponent
 *
 * EncounterParticipantComponent: The list of people responsible for providing the service.
 *
 * http://hl7.org/fhir/EncounterParticipantComponent
 */
var EncounterParticipantComponent = 'http://hl7.org/fhir/EncounterParticipantComponent';
/**
 * _cancellationReason
 *
 * (Modified) Appointment.cancellationReason
 *
 * http://hl7.org/fhir/_cancellationReason
 */
var _cancellationReason = 'http://hl7.org/fhir/_cancellationReason';
/**
 * _repetitions
 *
 * (Modified) Transport.restriction.repetitions
 *
 * http://hl7.org/fhir/_repetitions
 */
var _repetitions = 'http://hl7.org/fhir/_repetitions';
/**
 * TestPlanTestCaseTestRunScriptComponent
 *
 * TestPlanTestCaseComponent.TestPlanTestCaseTestRunComponent.TestPlanTestCaseTestRunScriptComponent: The test cases in a structured language e.g. gherkin, Postman, or FHIR TestScript.
 *
 * http://hl7.org/fhir/TestPlanTestCaseTestRunScriptComponent
 */
var TestPlanTestCaseTestRunScriptComponent = 'http://hl7.org/fhir/TestPlanTestCaseTestRunScriptComponent';
/**
 * distributor
 *
 * DeviceDefinition.packaging.packaging.distributor: An organization that distributes the packaged device.
 *
 * http://hl7.org/fhir/distributor
 */
var distributor = 'http://hl7.org/fhir/distributor';
/**
 * _stopTestOnFail
 *
 * (Modified) TestScript.test.action.assert.stopTestOnFail
 *
 * http://hl7.org/fhir/_stopTestOnFail
 */
var _stopTestOnFail = 'http://hl7.org/fhir/_stopTestOnFail';
/**
 * organizationReference
 *
 * DeviceDefinition.packaging.packaging.distributor.organizationReference: Distributor as an Organization resource.
 *
 * http://hl7.org/fhir/organizationReference
 */
var organizationReference = 'http://hl7.org/fhir/organizationReference';
/**
 * residueSite
 *
 * SubstanceNucleicAcid.subunit.sugar.residueSite: The residues that contain a given sugar will be captured. The order of given residues will be captured in the 5‘-3‘direction consistent with the base sequences listed above.
 *
 * http://hl7.org/fhir/residueSite
 */
var residueSite = 'http://hl7.org/fhir/residueSite';
/**
 * guidance
 *
 * Measure.guidance: Additional guidance for the measure including how it can be used in a clinical context, and the intent of the measure.
 *
 * http://hl7.org/fhir/guidance
 */
var guidance = 'http://hl7.org/fhir/guidance';
/**
 * _originatingAppointment
 *
 * (Modified) Appointment.originatingAppointment
 *
 * http://hl7.org/fhir/_originatingAppointment
 */
var _originatingAppointment = 'http://hl7.org/fhir/_originatingAppointment';
/**
 * intended
 *
 * Evidence.variableDefinition.intended: Definition of the intended variable related to the Evidence.
 *
 * http://hl7.org/fhir/intended
 */
var intended = 'http://hl7.org/fhir/intended';
/**
 * _measurementFrequency
 *
 * (Modified) DeviceMetric.measurementFrequency
 *
 * http://hl7.org/fhir/_measurementFrequency
 */
var _measurementFrequency = 'http://hl7.org/fhir/_measurementFrequency';
/**
 * _variableRole
 *
 * (Modified) Evidence.variableDefinition.variableRole
 *
 * http://hl7.org/fhir/_variableRole
 */
var _variableRole = 'http://hl7.org/fhir/_variableRole';
/**
 * assurance
 *
 * Person.link.assurance: Level of assurance that this link is associated with the target resource.
 *
 * http://hl7.org/fhir/assurance
 */
var assurance = 'http://hl7.org/fhir/assurance';
/**
 * literal
 *
 * MolecularSequence.literal: Sequence that was observed.
 *
 * http://hl7.org/fhir/literal
 */
var literal = 'http://hl7.org/fhir/literal';
/**
 * _suppliedItem
 *
 * (Modified) SupplyDelivery.suppliedItem
 *
 * http://hl7.org/fhir/_suppliedItem
 */
var _suppliedItem = 'http://hl7.org/fhir/_suppliedItem';
/**
 * ProcedurePerformerComponent
 *
 * ProcedurePerformerComponent: Indicates who or what performed the procedure and how they were involved.
 *
 * http://hl7.org/fhir/ProcedurePerformerComponent
 */
var ProcedurePerformerComponent = 'http://hl7.org/fhir/ProcedurePerformerComponent';
/**
 * baseUnit
 *
 * InventoryItem.baseUnit: The base unit of measure - the unit in which the product is used or counted.
 *
 * http://hl7.org/fhir/baseUnit
 */
var baseUnit = 'http://hl7.org/fhir/baseUnit';
/**
 * _translation
 *
 * (Modified) TerminologyCapabilities.closure.translation
 *
 * http://hl7.org/fhir/_translation
 */
var _translation = 'http://hl7.org/fhir/_translation';
/**
 * StructureDefinitionSnapshotComponent
 *
 * StructureDefinitionSnapshotComponent: A snapshot view is expressed in a standalone form that can be used and interpreted without considering the base StructureDefinition.
 *
 * http://hl7.org/fhir/StructureDefinitionSnapshotComponent
 */
var StructureDefinitionSnapshotComponent = 'http://hl7.org/fhir/StructureDefinitionSnapshotComponent';
/**
 * _name
 *
 * (Modified) InventoryItem.name.name
 *
 * http://hl7.org/fhir/_name
 */
var _name = 'http://hl7.org/fhir/_name';
/**
 * MedicationRequestDispenseRequestInitialFillComponent
 *
 * MedicationRequestDispenseRequestComponent.MedicationRequestDispenseRequestInitialFillComponent: Indicates the quantity or duration for the first dispense of the medication.
 *
 * http://hl7.org/fhir/MedicationRequestDispenseRequestInitialFillComponent
 */
var MedicationRequestDispenseRequestInitialFillComponent = 'http://hl7.org/fhir/MedicationRequestDispenseRequestInitialFillComponent';
/**
 * _incidence
 *
 * (Modified) ClinicalUseDefinition.interaction.incidence
 *
 * http://hl7.org/fhir/_incidence
 */
var _incidence = 'http://hl7.org/fhir/_incidence';
/**
 * _during
 *
 * (Modified) Availability.notAvailableTime.during
 *
 * http://hl7.org/fhir/_during
 */
var _during = 'http://hl7.org/fhir/_during';
/**
 * _snapshot
 *
 * (Modified) StructureDefinition.snapshot
 *
 * http://hl7.org/fhir/_snapshot
 */
var _snapshot = 'http://hl7.org/fhir/_snapshot';
/**
 * SubstancePolymerRepeatRepeatUnitComponent
 *
 * SubstancePolymerRepeatComponent.SubstancePolymerRepeatRepeatUnitComponent: An SRU - Structural Repeat Unit.
 *
 * http://hl7.org/fhir/SubstancePolymerRepeatRepeatUnitComponent
 */
var SubstancePolymerRepeatRepeatUnitComponent = 'http://hl7.org/fhir/SubstancePolymerRepeatRepeatUnitComponent';
/**
 * _format
 *
 * (Modified) SubstancePolymer.repeat.repeatUnit.structuralRepresentation.format
 *
 * http://hl7.org/fhir/_format
 */
var _format = 'http://hl7.org/fhir/_format';
/**
 * PlanBenefit
 *
 * InsurancePlanPlanComponent.InsurancePlanPlanSpecificCostComponent.PlanBenefit: List of the specific benefits under this category of benefit.
 *
 * http://hl7.org/fhir/PlanBenefit
 */
var PlanBenefit = 'http://hl7.org/fhir/PlanBenefit';
/**
 * _foodPreferenceModifier
 *
 * (Modified) NutritionOrder.foodPreferenceModifier
 *
 * http://hl7.org/fhir/_foodPreferenceModifier
 */
var _foodPreferenceModifier = 'http://hl7.org/fhir/_foodPreferenceModifier';
/**
 * function
 *
 * ChargeItem.performer.function: Describes the type of performance or participation(e.g. primary surgeon, anesthesiologiest, etc.).
 * Note that `function` is a reserved Javascript keyword, and is therefore suffixed by `__workaround`.
 * For a list of reserved keywords, see https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Lexical_grammar#Keywords.
 *
 * http://hl7.org/fhir/function
 */
var function__workaround = 'http://hl7.org/fhir/function';
/**
 * environmentType
 *
 * Endpoint.environmentType: The type of environment(s) exposed at this endpoint (dev, prod, test, etc.).
 *
 * http://hl7.org/fhir/environmentType
 */
var environmentType = 'http://hl7.org/fhir/environmentType';
/**
 * SubscriptionTopicCanFilterByComponent
 *
 * SubscriptionTopicCanFilterByComponent: List of properties by which Subscriptions on the SubscriptionTopic can be filtered. May be defined Search Parameters (e.g., Encounter.patient) or parameters defined within this SubscriptionTopic context (e.g., hub.event).
 *
 * http://hl7.org/fhir/SubscriptionTopicCanFilterByComponent
 */
var SubscriptionTopicCanFilterByComponent = 'http://hl7.org/fhir/SubscriptionTopicCanFilterByComponent';
/**
 * occurrenceCount
 *
 * Appointment.recurrenceTemplate.occurrenceCount: How many appointments are planned in the recurrence.
 *
 * http://hl7.org/fhir/occurrenceCount
 */
var occurrenceCount = 'http://hl7.org/fhir/occurrenceCount';
/**
 * careTeamSequence
 *
 * ExplanationOfBenefit.item.careTeamSequence: Care team members related to this service or product.
 *
 * http://hl7.org/fhir/careTeamSequence
 */
var careTeamSequence = 'http://hl7.org/fhir/careTeamSequence';
/**
 * _notConsumedReason
 *
 * (Modified) NutritionIntake.consumedItem.notConsumedReason
 *
 * http://hl7.org/fhir/_notConsumedReason
 */
var _notConsumedReason = 'http://hl7.org/fhir/_notConsumedReason';
/**
 * _restoreDate
 *
 * (Modified) MarketingStatus.restoreDate
 *
 * http://hl7.org/fhir/_restoreDate
 */
var _restoreDate = 'http://hl7.org/fhir/_restoreDate';
/**
 * providedBy
 *
 * HealthcareService.providedBy: The organization that provides this healthcare service.
 *
 * http://hl7.org/fhir/providedBy
 */
var providedBy = 'http://hl7.org/fhir/providedBy';
/**
 * meta
 *
 * Resource.meta: The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.
 *
 * http://hl7.org/fhir/meta
 */
var meta = 'http://hl7.org/fhir/meta';
/**
 * _subDetailSequence
 *
 * (Modified) ExplanationOfBenefit.addItem.subDetailSequence
 *
 * http://hl7.org/fhir/_subDetailSequence
 */
var _subDetailSequence = 'http://hl7.org/fhir/_subDetailSequence';
/**
 * required
 *
 * Questionnaire.item.required: An indication, if true, that the item must be present in a "completed" QuestionnaireResponse.  If false, the item may be skipped when answering the questionnaire.
 *
 * http://hl7.org/fhir/required
 */
var required = 'http://hl7.org/fhir/required';
/**
 * _dateWritten
 *
 * (Modified) VisionPrescription.dateWritten
 *
 * http://hl7.org/fhir/_dateWritten
 */
var _dateWritten = 'http://hl7.org/fhir/_dateWritten';
/**
 * _deviceIdentifier
 *
 * (Modified) DeviceDefinition.packaging.packaging.udiDeviceIdentifier.deviceIdentifier
 *
 * http://hl7.org/fhir/_deviceIdentifier
 */
var _deviceIdentifier = 'http://hl7.org/fhir/_deviceIdentifier';
/**
 * referral
 *
 * ExplanationOfBenefit.referral: The referral information received by the claim author, it is not to be used when the author generates a referral for a patient. A copy of that referral may be provided as supporting information. Some insurers require proof of referral to pay for services or to pay specialist rates for services.
 *
 * http://hl7.org/fhir/referral
 */
var referral = 'http://hl7.org/fhir/referral';
/**
 * _conditionality
 *
 * (Modified) Requirements.statement.conditionality
 *
 * http://hl7.org/fhir/_conditionality
 */
var _conditionality = 'http://hl7.org/fhir/_conditionality';
/**
 * AuditEventSourceComponent
 *
 * AuditEventSourceComponent: The actor that is reporting the event.
 *
 * http://hl7.org/fhir/AuditEventSourceComponent
 */
var AuditEventSourceComponent = 'http://hl7.org/fhir/AuditEventSourceComponent';
/**
 * _component
 *
 * (Modified) DeviceDefinition.version.component
 *
 * http://hl7.org/fhir/_component
 */
var _component = 'http://hl7.org/fhir/_component';
/**
 * link
 *
 * TestScript.test.action.assert.requirement.link
 *
 * http://hl7.org/fhir/link
 */
var link = 'http://hl7.org/fhir/link';
/**
 * _hasStage
 *
 * (Modified) ConditionDefinition.hasStage
 *
 * http://hl7.org/fhir/_hasStage
 */
var _hasStage = 'http://hl7.org/fhir/_hasStage';
/**
 * _contentReference
 *
 * (Modified) ElementDefinition.contentReference
 *
 * http://hl7.org/fhir/_contentReference
 */
var _contentReference = 'http://hl7.org/fhir/_contentReference';
/**
 * program
 *
 * Immunization.programEligibility.program: Indicates which program the patient had their eligility evaluated for.
 *
 * http://hl7.org/fhir/program
 */
var program = 'http://hl7.org/fhir/program';
/**
 * OtherElement
 *
 * ConceptMapGroupComponent.SourceElement.TargetElement.OtherElement: A set of additional dependencies for this mapping to hold. This mapping is only applicable if the specified data attribute can be resolved, and it has the specified value.
 *
 * http://hl7.org/fhir/OtherElement
 */
var OtherElement = 'http://hl7.org/fhir/OtherElement';
/**
 * scoringUnit
 *
 * Measure.group.scoringUnit: Defines the expected units of measure for the measure score. This element SHOULD be specified as a UCUM unit.
 *
 * http://hl7.org/fhir/scoringUnit
 */
var scoringUnit = 'http://hl7.org/fhir/scoringUnit';
/**
 * _maxCount
 *
 * (Modified) Subscription.maxCount
 *
 * http://hl7.org/fhir/_maxCount
 */
var _maxCount = 'http://hl7.org/fhir/_maxCount';
/**
 * ExplanationOfBenefitEventComponent
 *
 * ExplanationOfBenefitEventComponent: Information code for an event with a corresponding date or period.
 *
 * http://hl7.org/fhir/ExplanationOfBenefitEventComponent
 */
var ExplanationOfBenefitEventComponent = 'http://hl7.org/fhir/ExplanationOfBenefitEventComponent';
/**
 * _ArtifactAssessment
 *
 * (Modified) ArtifactAssessment
 *
 * http://hl7.org/fhir/_ArtifactAssessment
 */
var _ArtifactAssessment = 'http://hl7.org/fhir/_ArtifactAssessment';
/**
 * scope
 *
 * Contract.term.group.asset.scope: Differentiates the kind of the asset .
 *
 * http://hl7.org/fhir/scope
 */
var scope = 'http://hl7.org/fhir/scope';
/**
 * inventoryListing
 *
 * InventoryReport.inventoryListing: An inventory listing section (grouped by any of the attributes).
 *
 * http://hl7.org/fhir/inventoryListing
 */
var inventoryListing = 'http://hl7.org/fhir/inventoryListing';
/**
 * concentration
 *
 * Ingredient.substance.strength.concentration
 *
 * http://hl7.org/fhir/concentration
 */
var concentration = 'http://hl7.org/fhir/concentration';
/**
 * _device
 *
 * (Modified) Specimen.collection.device
 *
 * http://hl7.org/fhir/_device
 */
var _device = 'http://hl7.org/fhir/_device';
/**
 * hierarchyMeaning
 *
 * CodeSystem.hierarchyMeaning: The meaning of the hierarchy of concepts as represented in this resource.
 *
 * http://hl7.org/fhir/hierarchyMeaning
 */
var hierarchyMeaning = 'http://hl7.org/fhir/hierarchyMeaning';
/**
 * CapabilityStatementRestComponentOperation
 *
 * Definition of an operation or a named query together with its parameters and their meaning and type.
 *
 * http://hl7.org/fhir/CapabilityStatementRestComponentOperation
 */
var CapabilityStatementRestComponentOperation = 'http://hl7.org/fhir/CapabilityStatementRestComponentOperation';
/**
 * otherMap
 *
 * ConceptMap.group.unmapped.otherMap: The canonical reference to an additional ConceptMap resource instance to use for mapping if this ConceptMap resource contains no matching mapping for the source concept.
 *
 * http://hl7.org/fhir/otherMap
 */
var otherMap = 'http://hl7.org/fhir/otherMap';
/**
 * answerConstraint
 *
 * Questionnaire.item.item.answerConstraint: For items that have a defined set of allowed answers (via answerOption or answerValueSet), indicates whether values *other* than those specified can be selected.
 *
 * http://hl7.org/fhir/answerConstraint
 */
var answerConstraint = 'http://hl7.org/fhir/answerConstraint';
/**
 * normalCodedValueSet
 *
 * ObservationDefinition.component.qualifiedValue.normalCodedValueSet: The set of normal coded results for qualitative observations  that match the criteria of this set of qualified values.
 *
 * http://hl7.org/fhir/normalCodedValueSet
 */
var normalCodedValueSet = 'http://hl7.org/fhir/normalCodedValueSet';
/**
 * global
 *
 * ImplementationGuide.global: A set of profiles that all resources covered by this implementation guide must conform to.
 *
 * http://hl7.org/fhir/global
 */
var global = 'http://hl7.org/fhir/global';
/**
 * excludingRecurrenceId
 *
 * Appointment.recurrenceTemplate.excludingRecurrenceId: Any dates, such as holidays, that should be excluded from the recurrence.
 *
 * http://hl7.org/fhir/excludingRecurrenceId
 */
var excludingRecurrenceId = 'http://hl7.org/fhir/excludingRecurrenceId';
/**
 * _SubstanceSourceMaterial
 *
 * (Modified) SubstanceSourceMaterial
 *
 * http://hl7.org/fhir/_SubstanceSourceMaterial
 */
var _SubstanceSourceMaterial = 'http://hl7.org/fhir/_SubstanceSourceMaterial';
/**
 * validity
 *
 * Permission.validity: The period in which the permission is active.
 *
 * http://hl7.org/fhir/validity
 */
var validity = 'http://hl7.org/fhir/validity';
/**
 * subjectReport
 *
 * MeasureReport.group.stratifier.stratum.population.subjectReport: A reference to an individual level MeasureReport resource for a member of the population.
 *
 * http://hl7.org/fhir/subjectReport
 */
var subjectReport = 'http://hl7.org/fhir/subjectReport';
/**
 * _any
 *
 * (Modified) ElementDefinition.binding.additional.any
 *
 * http://hl7.org/fhir/_any
 */
var _any = 'http://hl7.org/fhir/_any';
/**
 * _nextScheduled
 *
 * (Modified) VerificationResult.nextScheduled
 *
 * http://hl7.org/fhir/_nextScheduled
 */
var _nextScheduled = 'http://hl7.org/fhir/_nextScheduled';
/**
 * administration
 *
 * NutritionOrder.enteralFormula.administration: Formula administration instructions as structured data.  This repeating structure allows for changing the administration rate or volume over time for both bolus and continuous feeding.  An example of this would be an instruction to increase the rate of continuous feeding every 2 hours.
 *
 * http://hl7.org/fhir/administration
 */
var administration = 'http://hl7.org/fhir/administration';
/**
 * sort
 *
 * DataRequirement.sort: Specifies the order of the results to be returned.
 *
 * http://hl7.org/fhir/sort
 */
var sort = 'http://hl7.org/fhir/sort';
/**
 * ManufacturedItemDefinitionComponentComponentProperty
 *
 * General characteristics of this component.
 *
 * http://hl7.org/fhir/ManufacturedItemDefinitionComponentComponentProperty
 */
var ManufacturedItemDefinitionComponentComponentProperty = 'http://hl7.org/fhir/ManufacturedItemDefinitionComponentComponentProperty';
/**
 * _sent
 *
 * (Modified) Communication.sent
 *
 * http://hl7.org/fhir/_sent
 */
var _sent = 'http://hl7.org/fhir/_sent';
/**
 * _directnessMatch
 *
 * (Modified) Evidence.variableDefinition.directnessMatch
 *
 * http://hl7.org/fhir/_directnessMatch
 */
var _directnessMatch = 'http://hl7.org/fhir/_directnessMatch';
/**
 * _targetFormat
 *
 * (Modified) Signature.targetFormat
 *
 * http://hl7.org/fhir/_targetFormat
 */
var _targetFormat = 'http://hl7.org/fhir/_targetFormat';
/**
 * _used
 *
 * (Modified) Procedure.used
 *
 * http://hl7.org/fhir/_used
 */
var _used = 'http://hl7.org/fhir/_used';
/**
 * _occurence
 *
 * (Modified) MedicationAdministration.occurence
 *
 * http://hl7.org/fhir/_occurence
 */
var _occurence = 'http://hl7.org/fhir/_occurence';
/**
 * _partOf
 *
 * (Modified) Procedure.partOf
 *
 * http://hl7.org/fhir/_partOf
 */
var _partOf = 'http://hl7.org/fhir/_partOf';
/**
 * relativeRisk
 *
 * RiskAssessment.prediction.relativeRisk: Indicates the risk for this particular subject (with their specific characteristics) divided by the risk of the population in general.  (Numbers greater than 1 = higher risk than the population, numbers less than 1 = lower risk.).
 *
 * http://hl7.org/fhir/relativeRisk
 */
var relativeRisk = 'http://hl7.org/fhir/relativeRisk';
/**
 * supportedMessage
 *
 * CapabilityStatement.messaging.supportedMessage: References to message definitions for messages this system can send or receive.
 *
 * http://hl7.org/fhir/supportedMessage
 */
var supportedMessage = 'http://hl7.org/fhir/supportedMessage';
/**
 * _dateOfDiagnosis
 *
 * (Modified) Account.diagnosis.dateOfDiagnosis
 *
 * http://hl7.org/fhir/_dateOfDiagnosis
 */
var _dateOfDiagnosis = 'http://hl7.org/fhir/_dateOfDiagnosis';
/**
 * _seriesNumber
 *
 * (Modified) ImagingSelection.seriesNumber
 *
 * http://hl7.org/fhir/_seriesNumber
 */
var _seriesNumber = 'http://hl7.org/fhir/_seriesNumber';
/**
 * DataRequirementSortComponent
 *
 * DataRequirementSortComponent: Specifies the order of the results to be returned.
 *
 * http://hl7.org/fhir/DataRequirementSortComponent
 */
var DataRequirementSortComponent = 'http://hl7.org/fhir/DataRequirementSortComponent';
/**
 * ChargeItemDefinitionPropertyGroupComponentApplicability
 *
 * Expressions that describe applicability criteria for the priceComponent.
 *
 * http://hl7.org/fhir/ChargeItemDefinitionPropertyGroupComponentApplicability
 */
var ChargeItemDefinitionPropertyGroupComponentApplicability = 'http://hl7.org/fhir/ChargeItemDefinitionPropertyGroupComponentApplicability';
/**
 * codeSystem
 *
 * TerminologyCapabilities.codeSystem: Identifies a code system that is supported by the server. If there is a no code system URL, then this declares the general assumptions a client can make about support for any CodeSystem resource.
 *
 * http://hl7.org/fhir/codeSystem
 */
var codeSystem = 'http://hl7.org/fhir/codeSystem';
/**
 * processing
 *
 * Specimen.processing: Details concerning processing and processing steps for the specimen.
 *
 * http://hl7.org/fhir/processing
 */
var processing = 'http://hl7.org/fhir/processing';
/**
 * _ResearchSubject
 *
 * (Modified) ResearchSubject
 *
 * http://hl7.org/fhir/_ResearchSubject
 */
var _ResearchSubject = 'http://hl7.org/fhir/_ResearchSubject';
/**
 * _heartbeatPeriod
 *
 * (Modified) Subscription.heartbeatPeriod
 *
 * http://hl7.org/fhir/_heartbeatPeriod
 */
var _heartbeatPeriod = 'http://hl7.org/fhir/_heartbeatPeriod';
/**
 * ValueSetExpansionPropertyComponent
 *
 * ValueSetExpansionComponent.ValueSetExpansionPropertyComponent: A property defines an additional slot through which additional information can be provided about a concept.
 *
 * http://hl7.org/fhir/ValueSetExpansionPropertyComponent
 */
var ValueSetExpansionPropertyComponent = 'http://hl7.org/fhir/ValueSetExpansionPropertyComponent';
/**
 * orderDetail
 *
 * ServiceRequest.orderDetail: Additional details and instructions about the how the services are to be delivered.   For example, and order for a urinary catheter may have an order detail for an external or indwelling catheter, or an order for a bandage may require additional instructions specifying how the bandage should be applied.
 *
 * http://hl7.org/fhir/orderDetail
 */
var orderDetail = 'http://hl7.org/fhir/orderDetail';
/**
 * Group
 *
 * Represents a defined collection of entities that may be discussed or acted upon collectively but which are not expected to act collectively, and are not formally or legally recognized; i.e. a collection of entities that isn't an Organization.
 *
 * http://hl7.org/fhir/Group
 */
var Group = 'http://hl7.org/fhir/Group';
/**
 * statusDate
 *
 * VerificationResult.statusDate: When the validation status was updated.
 *
 * http://hl7.org/fhir/statusDate
 */
var statusDate = 'http://hl7.org/fhir/statusDate';
/**
 * uri
 *
 * ConceptMap.property.uri: Reference to the formal meaning of the property.
 *
 * http://hl7.org/fhir/uri
 */
var uri = 'http://hl7.org/fhir/uri';
/**
 * max
 *
 * StructureMap.group.rule.source.max: Specified maximum cardinality for the element - a number or a "*". This is optional; if present, it acts an implicit check on the input content (* just serves as documentation; it's the default value).
 *
 * http://hl7.org/fhir/max
 */
var max = 'http://hl7.org/fhir/max';
/**
 * _conformance
 *
 * (Modified) TestScript.scope.conformance
 *
 * http://hl7.org/fhir/_conformance
 */
var _conformance = 'http://hl7.org/fhir/_conformance';
/**
 * _unitPriceComponent
 *
 * (Modified) ChargeItem.unitPriceComponent
 *
 * http://hl7.org/fhir/_unitPriceComponent
 */
var _unitPriceComponent = 'http://hl7.org/fhir/_unitPriceComponent';
/**
 * _availabilityStatus
 *
 * (Modified) Device.availabilityStatus
 *
 * http://hl7.org/fhir/_availabilityStatus
 */
var _availabilityStatus = 'http://hl7.org/fhir/_availabilityStatus';
/**
 * _exitCriteria
 *
 * (Modified) TestPlan.exitCriteria
 *
 * http://hl7.org/fhir/_exitCriteria
 */
var _exitCriteria = 'http://hl7.org/fhir/_exitCriteria';
/**
 * Schedule
 *
 * A container for slots of time that may be available for booking appointments.
 *
 * http://hl7.org/fhir/Schedule
 */
var Schedule = 'http://hl7.org/fhir/Schedule';
/**
 * BiologicallyDerivedProductCollectionComponent
 *
 * BiologicallyDerivedProductCollectionComponent: How this product was collected.
 *
 * http://hl7.org/fhir/BiologicallyDerivedProductCollectionComponent
 */
var BiologicallyDerivedProductCollectionComponent = 'http://hl7.org/fhir/BiologicallyDerivedProductCollectionComponent';
/**
 * DomainResource
 *
 * A resource that includes narrative, extensions, and contained resources.
 *
 * http://hl7.org/fhir/DomainResource
 */
var DomainResource = 'http://hl7.org/fhir/DomainResource';
/**
 * _AdverseEvent
 *
 * (Modified) AdverseEvent
 *
 * http://hl7.org/fhir/_AdverseEvent
 */
var _AdverseEvent = 'http://hl7.org/fhir/_AdverseEvent';
/**
 * focalDevice
 *
 * Procedure.focalDevice: A device that is implanted, removed or otherwise manipulated (calibration, battery replacement, fitting a prosthesis, attaching a wound-vac, etc.) as a focal portion of the Procedure.
 *
 * http://hl7.org/fhir/focalDevice
 */
var focalDevice = 'http://hl7.org/fhir/focalDevice';
/**
 * _authorType
 *
 * (Modified) SubstanceSourceMaterial.organism.author.authorType
 *
 * http://hl7.org/fhir/_authorType
 */
var _authorType = 'http://hl7.org/fhir/_authorType';
/**
 * mode
 *
 * EvidenceReport.section.section.mode: How the entry list was prepared - whether it is a working list that is suitable for being maintained on an ongoing basis, or if it represents a snapshot of a list of items from another source, or whether it is a prepared list where items may be marked as added, modified or deleted.
 *
 * http://hl7.org/fhir/mode
 */
var mode = 'http://hl7.org/fhir/mode';
/**
 * observation
 *
 * Observation.triggeredBy.observation: Reference to the triggering observation.
 *
 * http://hl7.org/fhir/observation
 */
var observation = 'http://hl7.org/fhir/observation';
/**
 * _issuer
 *
 * (Modified) Device.udiCarrier.issuer
 *
 * http://hl7.org/fhir/_issuer
 */
var _issuer = 'http://hl7.org/fhir/_issuer';
/**
 * ClaimEventComponent
 *
 * ClaimEventComponent: Information code for an event with a corresponding date or period.
 *
 * http://hl7.org/fhir/ClaimEventComponent
 */
var ClaimEventComponent = 'http://hl7.org/fhir/ClaimEventComponent';
/**
 * FamilyMemberHistoryParticipantComponent
 *
 * FamilyMemberHistoryParticipantComponent: Indicates who or what participated in the activities related to the family member history and how they were involved.
 *
 * http://hl7.org/fhir/FamilyMemberHistoryParticipantComponent
 */
var FamilyMemberHistoryParticipantComponent = 'http://hl7.org/fhir/FamilyMemberHistoryParticipantComponent';
/**
 * _validationStatus
 *
 * (Modified) VerificationResult.primarySource.validationStatus
 *
 * http://hl7.org/fhir/_validationStatus
 */
var _validationStatus = 'http://hl7.org/fhir/_validationStatus';
/**
 * string
 *
 * A sequence of Unicode characters
 *
 * http://hl7.org/fhir/string
 */
var string = 'http://hl7.org/fhir/string';
/**
 * productCode
 *
 * BiologicallyDerivedProduct.productCode: A codified value that systematically supports characterization and classification of medical products of human origin inclusive of processing conditions such as additives, volumes and handling conditions.
 *
 * http://hl7.org/fhir/productCode
 */
var productCode = 'http://hl7.org/fhir/productCode';
/**
 * receiver
 *
 * ExampleScenario.process.step.process.step.operation.receiver: The system on which the action is invoked/receives the data.
 *
 * http://hl7.org/fhir/receiver
 */
var receiver = 'http://hl7.org/fhir/receiver';
/**
 * CitationCitedArtifactTitleComponent
 *
 * CitationCitedArtifactComponent.CitationCitedArtifactTitleComponent: The title details of the article or artifact.
 *
 * http://hl7.org/fhir/CitationCitedArtifactTitleComponent
 */
var CitationCitedArtifactTitleComponent = 'http://hl7.org/fhir/CitationCitedArtifactTitleComponent';
/**
 * totalGross
 *
 * Invoice.totalGross: Invoice total, tax included.
 *
 * http://hl7.org/fhir/totalGross
 */
var totalGross = 'http://hl7.org/fhir/totalGross';
/**
 * _outputProfile
 *
 * (Modified) OperationDefinition.outputProfile
 *
 * http://hl7.org/fhir/_outputProfile
 */
var _outputProfile = 'http://hl7.org/fhir/_outputProfile';
/**
 * conditionalDelete
 *
 * CapabilityStatement.rest.resource.conditionalDelete: A code that indicates how the server supports conditional delete.
 *
 * http://hl7.org/fhir/conditionalDelete
 */
var conditionalDelete = 'http://hl7.org/fhir/conditionalDelete';
/**
 * baseDefinition
 *
 * StructureDefinition.baseDefinition: An absolute URI that is the base structure from which this type is derived, either by specialization or constraint.
 *
 * http://hl7.org/fhir/baseDefinition
 */
var baseDefinition = 'http://hl7.org/fhir/baseDefinition';
/**
 * NutritionProductInstanceComponent
 *
 * NutritionProductInstanceComponent: Conveys instance-level information about this product item. One or several physical, countable instances or occurrences of the product.
 *
 * http://hl7.org/fhir/NutritionProductInstanceComponent
 */
var NutritionProductInstanceComponent = 'http://hl7.org/fhir/NutritionProductInstanceComponent';
/**
 * ClinicalUseDefinitionIndicationComponent
 *
 * ClinicalUseDefinitionIndicationComponent: Specifics for when this is an indication.
 *
 * http://hl7.org/fhir/ClinicalUseDefinitionIndicationComponent
 */
var ClinicalUseDefinitionIndicationComponent = 'http://hl7.org/fhir/ClinicalUseDefinitionIndicationComponent';
/**
 * relevantHistory
 *
 * Task.relevantHistory: Links to Provenance records for past versions of this Task that identify key state transitions or updates that are likely to be relevant to a user looking at the current version of the task.
 *
 * http://hl7.org/fhir/relevantHistory
 */
var relevantHistory = 'http://hl7.org/fhir/relevantHistory';
/**
 * referenceInformation
 *
 * SubstanceDefinition.referenceInformation: General information detailing this substance.
 *
 * http://hl7.org/fhir/referenceInformation
 */
var referenceInformation = 'http://hl7.org/fhir/referenceInformation';
/**
 * valueSet
 *
 * OperationDefinition.parameter.part.binding.valueSet: Points to the value set or external definition (e.g. implicit value set) that identifies the set of codes to be used.
 *
 * http://hl7.org/fhir/valueSet
 */
var valueSet = 'http://hl7.org/fhir/valueSet';
/**
 * library
 *
 * PlanDefinition.library: A reference to a Library resource containing any formal logic used by the plan definition.
 *
 * http://hl7.org/fhir/library
 */
var library = 'http://hl7.org/fhir/library';
/**
 * InventoryReportInventoryListingItemComponent
 *
 * InventoryReportInventoryListingComponent.InventoryReportInventoryListingItemComponent: The item or items in this listing.
 *
 * http://hl7.org/fhir/InventoryReportInventoryListingItemComponent
 */
var InventoryReportInventoryListingItemComponent = 'http://hl7.org/fhir/InventoryReportInventoryListingItemComponent';
/**
 * performedActivity
 *
 * CarePlan.activity.performedActivity: Identifies the activity that was performed. For example, an activity could be patient education, exercise, or a medication administration. The reference to an "event" resource, such as Procedure or Encounter or Observation, represents the activity that was performed. The requested activity can be conveyed using the CarePlan.activity.plannedActivityReference (a reference to a “request” resource).
 *
 * http://hl7.org/fhir/performedActivity
 */
var performedActivity = 'http://hl7.org/fhir/performedActivity';
/**
 * Coverage
 *
 * Financial instrument which may be used to reimburse or pay for health care products and services. Includes both insurance and self-payment.
 *
 * http://hl7.org/fhir/Coverage
 */
var Coverage = 'http://hl7.org/fhir/Coverage';
/**
 * probability
 *
 * RiskAssessment.prediction.probability
 *
 * http://hl7.org/fhir/probability
 */
var probability = 'http://hl7.org/fhir/probability';
/**
 * TerminologyCapabilitiesSoftwareComponent
 *
 * TerminologyCapabilitiesSoftwareComponent: Software that is covered by this terminology capability statement.  It is used when the statement describes the capabilities of a particular software version, independent of an installation.
 *
 * http://hl7.org/fhir/TerminologyCapabilitiesSoftwareComponent
 */
var TerminologyCapabilitiesSoftwareComponent = 'http://hl7.org/fhir/TerminologyCapabilitiesSoftwareComponent';
/**
 * _activity
 *
 * (Modified) Provenance.activity
 *
 * http://hl7.org/fhir/_activity
 */
var _activity = 'http://hl7.org/fhir/_activity';
/**
 * prediction
 *
 * RiskAssessment.prediction: Describes the expected outcome for the subject.
 *
 * http://hl7.org/fhir/prediction
 */
var prediction = 'http://hl7.org/fhir/prediction';
/**
 * _mimeType
 *
 * (Modified) Endpoint.payload.mimeType
 *
 * http://hl7.org/fhir/_mimeType
 */
var _mimeType = 'http://hl7.org/fhir/_mimeType';
/**
 * exception
 *
 * Coverage.costToBeneficiary.exception: A suite of codes indicating exceptions or reductions to patient costs and their effective periods.
 *
 * http://hl7.org/fhir/exception
 */
var exception = 'http://hl7.org/fhir/exception';
/**
 * ImplementationGuideDefinitionTemplateComponent
 *
 * ImplementationGuideDefinitionComponent.ImplementationGuideDefinitionTemplateComponent: A template for building resources.
 *
 * http://hl7.org/fhir/ImplementationGuideDefinitionTemplateComponent
 */
var ImplementationGuideDefinitionTemplateComponent = 'http://hl7.org/fhir/ImplementationGuideDefinitionTemplateComponent';
/**
 * _edit
 *
 * (Modified) MolecularSequence.relative.edit
 *
 * http://hl7.org/fhir/_edit
 */
var _edit = 'http://hl7.org/fhir/_edit';
/**
 * _usage
 *
 * (Modified) NamingSystem.usage
 *
 * http://hl7.org/fhir/_usage
 */
var _usage = 'http://hl7.org/fhir/_usage';
/**
 * proposedNewTime
 *
 * AppointmentResponse.proposedNewTime: Indicates that the response is proposing a different time that was initially requested.  The new proposed time will be indicated in the start and end properties.
 *
 * http://hl7.org/fhir/proposedNewTime
 */
var proposedNewTime = 'http://hl7.org/fhir/proposedNewTime';
/**
 * security
 *
 * Permission.rule.data.security: The data in scope are those with the given codes present in that data .meta.security element.
 *
 * http://hl7.org/fhir/security
 */
var security = 'http://hl7.org/fhir/security';
/**
 * _parameter
 *
 * (Modified) ValueSet.expansion.parameter
 *
 * http://hl7.org/fhir/_parameter
 */
var _parameter = 'http://hl7.org/fhir/_parameter';
/**
 * InventoryItemDescriptionComponent
 *
 * InventoryItemDescriptionComponent: The descriptive characteristics of the inventory item.
 *
 * http://hl7.org/fhir/InventoryItemDescriptionComponent
 */
var InventoryItemDescriptionComponent = 'http://hl7.org/fhir/InventoryItemDescriptionComponent';
/**
 * ConditionDefinitionPreconditionComponent
 *
 * ConditionDefinitionPreconditionComponent: An observation that suggests that this condition applies.
 *
 * http://hl7.org/fhir/ConditionDefinitionPreconditionComponent
 */
var ConditionDefinitionPreconditionComponent = 'http://hl7.org/fhir/ConditionDefinitionPreconditionComponent';
/**
 * LocationPositionComponent
 *
 * LocationPositionComponent: The absolute geographic location of the Location, expressed using the WGS84 datum (This is the same co-ordinate system used in KML).
 *
 * http://hl7.org/fhir/LocationPositionComponent
 */
var LocationPositionComponent = 'http://hl7.org/fhir/LocationPositionComponent';
/**
 * sequenceRange
 *
 * MolecularSequence.relative.sequenceRange: Indicates the nucleotide range in the composed sequence when multiple 'relative' elements are used together.
 *
 * http://hl7.org/fhir/sequenceRange
 */
var sequenceRange = 'http://hl7.org/fhir/sequenceRange';
/**
 * policyBasis
 *
 * Consent.policyBasis: A Reference or URL used to uniquely identify the policy the organization will enforce for this Consent. This Reference or URL should be specific to the version of the policy and should be dereferencable to a computable policy of some form.
 *
 * http://hl7.org/fhir/policyBasis
 */
var policyBasis = 'http://hl7.org/fhir/policyBasis';
/**
 * _inputParameters
 *
 * (Modified) MeasureReport.inputParameters
 *
 * http://hl7.org/fhir/_inputParameters
 */
var _inputParameters = 'http://hl7.org/fhir/_inputParameters';
/**
 * _dateRange
 *
 * (Modified) MarketingStatus.dateRange
 *
 * http://hl7.org/fhir/_dateRange
 */
var _dateRange = 'http://hl7.org/fhir/_dateRange';
/**
 * _cost
 *
 * (Modified) MedicationKnowledge.packaging.cost
 *
 * http://hl7.org/fhir/_cost
 */
var _cost = 'http://hl7.org/fhir/_cost';
/**
 * Timing
 *
 * Specifies an event that may occur multiple times. Timing schedules are used to record when things are planned, expected or requested to occur. The most common usage is in dosage instructions for medications. They are also used when planning care of various kinds, and may be used for reporting the schedule to which past regular activities were carried out.
 *
 * http://hl7.org/fhir/Timing
 */
var Timing = 'http://hl7.org/fhir/Timing';
/**
 * _team
 *
 * (Modified) ConditionDefinition.team
 *
 * http://hl7.org/fhir/_team
 */
var _team = 'http://hl7.org/fhir/_team';
/**
 * _paternalOrganismId
 *
 * (Modified) SubstanceSourceMaterial.organism.hybrid.paternalOrganismId
 *
 * http://hl7.org/fhir/_paternalOrganismId
 */
var _paternalOrganismId = 'http://hl7.org/fhir/_paternalOrganismId';
/**
 * _statusChanged
 *
 * (Modified) MedicationRequest.statusChanged
 *
 * http://hl7.org/fhir/_statusChanged
 */
var _statusChanged = 'http://hl7.org/fhir/_statusChanged';
/**
 * ActivityDefinitionDynamicValueComponent
 *
 * ActivityDefinitionDynamicValueComponent: Dynamic values that will be evaluated to produce values for elements of the resulting resource. For example, if the dosage of a medication must be computed based on the patient's weight, a dynamic value would be used to specify an expression that calculated the weight, and the path on the request resource that would contain the result.
 *
 * http://hl7.org/fhir/ActivityDefinitionDynamicValueComponent
 */
var ActivityDefinitionDynamicValueComponent = 'http://hl7.org/fhir/ActivityDefinitionDynamicValueComponent';
/**
 * processor
 *
 * PaymentReconciliation.processor: The name of the card processor, etf processor, bank for checks.
 *
 * http://hl7.org/fhir/processor
 */
var processor = 'http://hl7.org/fhir/processor';
/**
 * _constraint
 *
 * (Modified) SearchParameter.constraint
 *
 * http://hl7.org/fhir/_constraint
 */
var _constraint = 'http://hl7.org/fhir/_constraint';
/**
 * _sampleSize
 *
 * (Modified) Evidence.statistic.sampleSize
 *
 * http://hl7.org/fhir/_sampleSize
 */
var _sampleSize = 'http://hl7.org/fhir/_sampleSize';
/**
 * ClinicalUseDefinitionContraindicationComponent
 *
 * ClinicalUseDefinitionContraindicationComponent: Specifics for when this is a contraindication.
 *
 * http://hl7.org/fhir/ClinicalUseDefinitionContraindicationComponent
 */
var ClinicalUseDefinitionContraindicationComponent = 'http://hl7.org/fhir/ClinicalUseDefinitionContraindicationComponent';
/**
 * _comorbidity
 *
 * (Modified) ClinicalUseDefinition.indication.comorbidity
 *
 * http://hl7.org/fhir/_comorbidity
 */
var _comorbidity = 'http://hl7.org/fhir/_comorbidity';
/**
 * _knownDataCount
 *
 * (Modified) Evidence.statistic.sampleSize.knownDataCount
 *
 * http://hl7.org/fhir/_knownDataCount
 */
var _knownDataCount = 'http://hl7.org/fhir/_knownDataCount';
/**
 * template
 *
 * ImplementationGuide.definition.template: A template for building resources.
 *
 * http://hl7.org/fhir/template
 */
var template = 'http://hl7.org/fhir/template';
/**
 * codeFilter
 *
 * DataRequirement.codeFilter: Code filters specify additional constraints on the data, specifying the value set of interest for a particular element of the data. Each code filter defines an additional constraint on the data, i.e. code filters are AND'ed, not OR'ed.
 *
 * http://hl7.org/fhir/codeFilter
 */
var codeFilter = 'http://hl7.org/fhir/codeFilter';
/**
 * dateAccessed
 *
 * Citation.citedArtifact.dateAccessed: When the cited artifact was accessed.
 *
 * http://hl7.org/fhir/dateAccessed
 */
var dateAccessed = 'http://hl7.org/fhir/dateAccessed';
/**
 * _organization
 *
 * (Modified) MedicinalProductDefinition.operation.organization
 *
 * http://hl7.org/fhir/_organization
 */
var _organization = 'http://hl7.org/fhir/_organization';
/**
 * _ifModifiedSince
 *
 * (Modified) Bundle.entry.request.ifModifiedSince
 *
 * http://hl7.org/fhir/_ifModifiedSince
 */
var _ifModifiedSince = 'http://hl7.org/fhir/_ifModifiedSince';
/**
 * _lastRevisionDate
 *
 * (Modified) Citation.citedArtifact.publicationForm.lastRevisionDate
 *
 * http://hl7.org/fhir/_lastRevisionDate
 */
var _lastRevisionDate = 'http://hl7.org/fhir/_lastRevisionDate';
/**
 * _strength
 *
 * (Modified) OperationDefinition.parameter.part.binding.strength
 *
 * http://hl7.org/fhir/_strength
 */
var _strength = 'http://hl7.org/fhir/_strength';
/**
 * numerator
 *
 * Ratio.numerator: The value of the numerator.
 *
 * http://hl7.org/fhir/numerator
 */
var numerator = 'http://hl7.org/fhir/numerator';
/**
 * _altitude
 *
 * (Modified) Location.position.altitude
 *
 * http://hl7.org/fhir/_altitude
 */
var _altitude = 'http://hl7.org/fhir/_altitude';
/**
 * _countingDateTime
 *
 * (Modified) InventoryReport.inventoryListing.countingDateTime
 *
 * http://hl7.org/fhir/_countingDateTime
 */
var _countingDateTime = 'http://hl7.org/fhir/_countingDateTime';
/**
 * MedicationDispense
 *
 * Indicates that a medication product is to be or has been dispensed for a named person/patient.  This includes a description of the medication product (supply) provided and the instructions for administering the medication.  The medication dispense is the result of a pharmacy system responding to a medication order.
 *
 * http://hl7.org/fhir/MedicationDispense
 */
var MedicationDispense = 'http://hl7.org/fhir/MedicationDispense';
/**
 * _maxDuration
 *
 * (Modified) SpecimenDefinition.typeTested.handling.maxDuration
 *
 * http://hl7.org/fhir/_maxDuration
 */
var _maxDuration = 'http://hl7.org/fhir/_maxDuration';
/**
 * requirement
 *
 * RequestOrchestration.action.input.requirement: Defines the data that is to be provided as input to the action.
 *
 * http://hl7.org/fhir/requirement
 */
var requirement = 'http://hl7.org/fhir/requirement';
/**
 * SubstanceProteinSubunitComponent
 *
 * SubstanceProteinSubunitComponent: This subclause refers to the description of each subunit constituting the SubstanceProtein. A subunit is a linear sequence of amino acids linked through peptide bonds. The Subunit information shall be provided when the finished SubstanceProtein is a complex of multiple sequences; subunits are not used to delineate domains within a single sequence. Subunits are listed in order of decreasing length; sequences of the same length will be ordered by decreasing molecular weight; subunits that have identical sequences will be repeated multiple times.
 *
 * http://hl7.org/fhir/SubstanceProteinSubunitComponent
 */
var SubstanceProteinSubunitComponent = 'http://hl7.org/fhir/SubstanceProteinSubunitComponent';
/**
 * _abatement
 *
 * (Modified) Condition.abatement
 *
 * http://hl7.org/fhir/_abatement
 */
var _abatement = 'http://hl7.org/fhir/_abatement';
/**
 * reportingPeriod
 *
 * InventoryReport.reportingPeriod: The period the report refers to.
 *
 * http://hl7.org/fhir/reportingPeriod
 */
var reportingPeriod = 'http://hl7.org/fhir/reportingPeriod';
/**
 * dosage
 *
 * MedicationKnowledge.indicationGuideline.dosingGuideline.dosage: Dosage for the medication for the specific guidelines.
 *
 * http://hl7.org/fhir/dosage
 */
var dosage = 'http://hl7.org/fhir/dosage';
/**
 * _supplement
 *
 * (Modified) NutritionOrder.supplement
 *
 * http://hl7.org/fhir/_supplement
 */
var _supplement = 'http://hl7.org/fhir/_supplement';
/**
 * _treatmentIntent
 *
 * (Modified) MedicationKnowledge.indicationGuideline.dosingGuideline.treatmentIntent
 *
 * http://hl7.org/fhir/_treatmentIntent
 */
var _treatmentIntent = 'http://hl7.org/fhir/_treatmentIntent';
/**
 * performingOrganization
 *
 * ChargeItem.performingOrganization: The organization performing the service.
 *
 * http://hl7.org/fhir/performingOrganization
 */
var performingOrganization = 'http://hl7.org/fhir/performingOrganization';
/**
 * _what
 *
 * (Modified) Provenance.entity.what
 *
 * http://hl7.org/fhir/_what
 */
var _what = 'http://hl7.org/fhir/_what';
/**
 * intervalUnit
 *
 * SampledData.intervalUnit: The measurement unit in which the sample interval is expressed.
 *
 * http://hl7.org/fhir/intervalUnit
 */
var intervalUnit = 'http://hl7.org/fhir/intervalUnit';
/**
 * preAuthPeriod
 *
 * ClaimResponse.item.detail.subDetail.reviewOutcome.preAuthPeriod: The time frame during which this authorization is effective.
 *
 * http://hl7.org/fhir/preAuthPeriod
 */
var preAuthPeriod = 'http://hl7.org/fhir/preAuthPeriod';
/**
 * fhirPathCriteria
 *
 * SubscriptionTopic.resourceTrigger.fhirPathCriteria: The FHIRPath based rules that the server should use to determine when to trigger a notification for this topic.
 *
 * http://hl7.org/fhir/fhirPathCriteria
 */
var fhirPathCriteria = 'http://hl7.org/fhir/fhirPathCriteria';
/**
 * administeredBy
 *
 * InsurancePlan.administeredBy: An organization which administer other services such as underwriting, customer service and/or claims processing on behalf of the health insurance product owner.
 *
 * http://hl7.org/fhir/administeredBy
 */
var administeredBy = 'http://hl7.org/fhir/administeredBy';
/**
 * factor
 *
 * ClaimResponse.addItem.factor: A real number that represents a multiplier used in determining the overall value of services delivered and/or goods received. The concept of a Factor allows for a discount or surcharge multiplier to be applied to a monetary amount.
 *
 * http://hl7.org/fhir/factor
 */
var factor = 'http://hl7.org/fhir/factor';
/**
 * ContactPoint
 *
 * Details for all kinds of technology mediated contact points for a person or organization, including telephone, email, etc.
 *
 * http://hl7.org/fhir/ContactPoint
 */
var ContactPoint = 'http://hl7.org/fhir/ContactPoint';
/**
 * appointmentType
 *
 * Slot.appointmentType: The style of appointment or patient that may be booked in the slot (not service type).
 *
 * http://hl7.org/fhir/appointmentType
 */
var appointmentType = 'http://hl7.org/fhir/appointmentType';
/**
 * _collector
 *
 * (Modified) Specimen.collection.collector
 *
 * http://hl7.org/fhir/_collector
 */
var _collector = 'http://hl7.org/fhir/_collector';
/**
 * answerValueSet
 *
 * Questionnaire.item.item.answerValueSet: A reference to a value set containing a list of values representing permitted answers for a question.
 *
 * http://hl7.org/fhir/answerValueSet
 */
var answerValueSet = 'http://hl7.org/fhir/answerValueSet';
/**
 * _achievementStatus
 *
 * (Modified) Goal.achievementStatus
 *
 * http://hl7.org/fhir/_achievementStatus
 */
var _achievementStatus = 'http://hl7.org/fhir/_achievementStatus';
/**
 * carrierHRF
 *
 * Device.udiCarrier.carrierHRF: The full UDI carrier as the human readable form (HRF) representation of the barcode string as printed on the packaging of the device.
 *
 * http://hl7.org/fhir/carrierHRF
 */
var carrierHRF = 'http://hl7.org/fhir/carrierHRF';
/**
 * _evaluatedResource
 *
 * (Modified) MeasureReport.evaluatedResource
 *
 * http://hl7.org/fhir/_evaluatedResource
 */
var _evaluatedResource = 'http://hl7.org/fhir/_evaluatedResource';
/**
 * signer
 *
 * Contract.signer: Parties with legal standing in the Contract, including the principal parties, the grantor(s) and grantee(s), which are any person or organization bound by the contract, and any ancillary parties, which facilitate the execution of the contract such as a notary or witness.
 *
 * http://hl7.org/fhir/signer
 */
var signer = 'http://hl7.org/fhir/signer';
/**
 * _usageReason
 *
 * (Modified) DeviceUsage.usageReason
 *
 * http://hl7.org/fhir/_usageReason
 */
var _usageReason = 'http://hl7.org/fhir/_usageReason';
/**
 * variableDefinition
 *
 * Evidence.statistic.modelCharacteristic.variable.variableDefinition: Description of the variable.
 *
 * http://hl7.org/fhir/variableDefinition
 */
var variableDefinition = 'http://hl7.org/fhir/variableDefinition';
/**
 * manifestation
 *
 * Immunization.reaction.manifestation: Details of the reaction.
 *
 * http://hl7.org/fhir/manifestation
 */
var manifestation = 'http://hl7.org/fhir/manifestation';
/**
 * searchType
 *
 * OperationDefinition.parameter.part.searchType: How the parameter is understood if/when it used as search parameter. This is only used if the parameter is a string.
 *
 * http://hl7.org/fhir/searchType
 */
var searchType = 'http://hl7.org/fhir/searchType';
/**
 * PaymentReconciliation
 *
 * This resource provides the details including amount of a payment and allocates the payment items being paid.
 *
 * http://hl7.org/fhir/PaymentReconciliation
 */
var PaymentReconciliation = 'http://hl7.org/fhir/PaymentReconciliation';
/**
 * _modelNumber
 *
 * (Modified) DeviceDefinition.modelNumber
 *
 * http://hl7.org/fhir/_modelNumber
 */
var _modelNumber = 'http://hl7.org/fhir/_modelNumber';
/**
 * groupingId
 *
 * ImplementationGuide.definition.resource.groupingId: Reference to the id of the grouping this resource appears in.
 *
 * http://hl7.org/fhir/groupingId
 */
var groupingId = 'http://hl7.org/fhir/groupingId';
/**
 * _VisionPrescription
 *
 * (Modified) VisionPrescription
 *
 * http://hl7.org/fhir/_VisionPrescription
 */
var _VisionPrescription = 'http://hl7.org/fhir/_VisionPrescription';
/**
 * performerLinkId
 *
 * Contract.term.group.action.performerLinkId: Id [identifier??] of the clause or question text related to the reason type or reference of this  action in the referenced form or QuestionnaireResponse.
 *
 * http://hl7.org/fhir/performerLinkId
 */
var performerLinkId = 'http://hl7.org/fhir/performerLinkId';
/**
 * procedure
 *
 * ExplanationOfBenefit.procedure: Procedures performed on the patient relevant to the billing items with the claim.
 *
 * http://hl7.org/fhir/procedure
 */
var procedure = 'http://hl7.org/fhir/procedure';
/**
 * implicitRules
 *
 * Resource.implicitRules: A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.
 *
 * http://hl7.org/fhir/implicitRules
 */
var implicitRules = 'http://hl7.org/fhir/implicitRules';
/**
 * query
 *
 * AuditEvent.entity.query: The query parameters for a query-type entities.
 *
 * http://hl7.org/fhir/query
 */
var query = 'http://hl7.org/fhir/query';
/**
 * Items
 *
 * CoverageEligibilityResponse.Insurance.Items: Benefits and optionally current balances, and authorization details by category or service.
 *
 * http://hl7.org/fhir/Items
 */
var Items = 'http://hl7.org/fhir/Items';
/**
 * _slot
 *
 * (Modified) Appointment.slot
 *
 * http://hl7.org/fhir/_slot
 */
var _slot = 'http://hl7.org/fhir/_slot';
/**
 * _conditionalCreate
 *
 * (Modified) CapabilityStatement.rest.resource.conditionalCreate
 *
 * http://hl7.org/fhir/_conditionalCreate
 */
var _conditionalCreate = 'http://hl7.org/fhir/_conditionalCreate';
/**
 * PatientCommunicationComponent
 *
 * PatientCommunicationComponent: A language which may be used to communicate with the patient about his or her health.
 *
 * http://hl7.org/fhir/PatientCommunicationComponent
 */
var PatientCommunicationComponent = 'http://hl7.org/fhir/PatientCommunicationComponent';
/**
 * ConditionDefinitionMedicationComponent
 *
 * ConditionDefinitionMedicationComponent: Medications particularly relevant for this condition.
 *
 * http://hl7.org/fhir/ConditionDefinitionMedicationComponent
 */
var ConditionDefinitionMedicationComponent = 'http://hl7.org/fhir/ConditionDefinitionMedicationComponent';
/**
 * documentation
 *
 * ActorDefinition.documentation: Documentation about the functionality of the actor.
 *
 * http://hl7.org/fhir/documentation
 */
var documentation = 'http://hl7.org/fhir/documentation';
/**
 * maxDosePerTreatmentPeriod
 *
 * AdministrableProductDefinition.routeOfAdministration.maxDosePerTreatmentPeriod: The maximum dose per treatment period that can be administered.
 *
 * http://hl7.org/fhir/maxDosePerTreatmentPeriod
 */
var maxDosePerTreatmentPeriod = 'http://hl7.org/fhir/maxDosePerTreatmentPeriod';
/**
 * example
 *
 * ElementDefinition.example: A sample value for this element demonstrating the type of information that would typically be found in the element.
 *
 * http://hl7.org/fhir/example
 */
var example = 'http://hl7.org/fhir/example';
/**
 * _sessionKey
 *
 * (Modified) VirtualServiceDetail.sessionKey
 *
 * http://hl7.org/fhir/_sessionKey
 */
var _sessionKey = 'http://hl7.org/fhir/_sessionKey';
/**
 * lastPage
 *
 * Citation.citedArtifact.publicationForm.lastPage: Used for isolated representation of last page.
 *
 * http://hl7.org/fhir/lastPage
 */
var lastPage = 'http://hl7.org/fhir/lastPage';
/**
 * hybridType
 *
 * SubstanceSourceMaterial.organism.hybrid.hybridType: The hybrid type of an organism shall be specified.
 *
 * http://hl7.org/fhir/hybridType
 */
var hybridType = 'http://hl7.org/fhir/hybridType';
/**
 * field
 *
 * TestScript.teardown.action.operation.requestHeader.field: The HTTP header field e.g. "Accept".
 *
 * http://hl7.org/fhir/field
 */
var field = 'http://hl7.org/fhir/field';
/**
 * maxDosePerPeriod
 *
 * Dosage.maxDosePerPeriod: Upper limit on medication per unit of time.
 *
 * http://hl7.org/fhir/maxDosePerPeriod
 */
var maxDosePerPeriod = 'http://hl7.org/fhir/maxDosePerPeriod';
/**
 * _excludedStructure
 *
 * (Modified) BodyStructure.excludedStructure
 *
 * http://hl7.org/fhir/_excludedStructure
 */
var _excludedStructure = 'http://hl7.org/fhir/_excludedStructure';
/**
 * _script
 *
 * (Modified) TestPlan.testCase.testRun.script
 *
 * http://hl7.org/fhir/_script
 */
var _script = 'http://hl7.org/fhir/_script';
/**
 * acceptLanguage
 *
 * CapabilityStatement.acceptLanguage: A list of the languages supported by this implementation that are usefully supported in the ```Accept-Language``` header.
 *
 * http://hl7.org/fhir/acceptLanguage
 */
var acceptLanguage = 'http://hl7.org/fhir/acceptLanguage';
/**
 * practiceSetting
 *
 * DocumentReference.practiceSetting: This property may convey specifics about the practice setting where the content was created, often reflecting the clinical specialty.
 *
 * http://hl7.org/fhir/practiceSetting
 */
var practiceSetting = 'http://hl7.org/fhir/practiceSetting';
/**
 * brand
 *
 * VisionPrescription.lensSpecification.brand: Brand recommendations or restrictions.
 *
 * http://hl7.org/fhir/brand
 */
var brand = 'http://hl7.org/fhir/brand';
/**
 * _attributeEstimate
 *
 * (Modified) Evidence.statistic.modelCharacteristic.attributeEstimate
 *
 * http://hl7.org/fhir/_attributeEstimate
 */
var _attributeEstimate = 'http://hl7.org/fhir/_attributeEstimate';
/**
 * _end
 *
 * (Modified) Subscription.end
 *
 * http://hl7.org/fhir/_end
 */
var _end = 'http://hl7.org/fhir/_end';
/**
 * diagnosisSequence
 *
 * ExplanationOfBenefit.item.diagnosisSequence: Diagnoses applicable for this service or product.
 *
 * http://hl7.org/fhir/diagnosisSequence
 */
var diagnosisSequence = 'http://hl7.org/fhir/diagnosisSequence';
/**
 * _specification
 *
 * (Modified) DeviceDefinition.conformsTo.specification
 *
 * http://hl7.org/fhir/_specification
 */
var _specification = 'http://hl7.org/fhir/_specification';
/**
 * _test
 *
 * (Modified) TestScript.test
 *
 * http://hl7.org/fhir/_test
 */
var _test = 'http://hl7.org/fhir/_test';
/**
 * _durationMax
 *
 * (Modified) Timing.repeat.durationMax
 *
 * http://hl7.org/fhir/_durationMax
 */
var _durationMax = 'http://hl7.org/fhir/_durationMax';
/**
 * impurity
 *
 * MedicinalProductDefinition.impurity: Any component of the drug product which is not the chemical entity defined as the drug substance, or an excipient in the drug product. This includes process-related impurities and contaminants, product-related impurities including degradation products.
 *
 * http://hl7.org/fhir/impurity
 */
var impurity = 'http://hl7.org/fhir/impurity';
/**
 * _Practitioner
 *
 * (Modified) Practitioner
 *
 * http://hl7.org/fhir/_Practitioner
 */
var _Practitioner = 'http://hl7.org/fhir/_Practitioner';
/**
 * SubstanceIngredientComponent
 *
 * SubstanceIngredientComponent: A substance can be composed of other substances.
 *
 * http://hl7.org/fhir/SubstanceIngredientComponent
 */
var SubstanceIngredientComponent = 'http://hl7.org/fhir/SubstanceIngredientComponent';
/**
 * control
 *
 * Contract.term.group.securityLabel.control: Security label privacy tag that specifies the manner in which term and/or term elements are to be protected.
 *
 * http://hl7.org/fhir/control
 */
var control = 'http://hl7.org/fhir/control';
/**
 * _enterer
 *
 * (Modified) PaymentReconciliation.enterer
 *
 * http://hl7.org/fhir/_enterer
 */
var _enterer = 'http://hl7.org/fhir/_enterer';
/**
 * TransportOutputComponent
 *
 * TransportOutputComponent: Outputs produced by the Transport.
 *
 * http://hl7.org/fhir/TransportOutputComponent
 */
var TransportOutputComponent = 'http://hl7.org/fhir/TransportOutputComponent';
/**
 * _retentionTime
 *
 * (Modified) SpecimenDefinition.typeTested.retentionTime
 *
 * http://hl7.org/fhir/_retentionTime
 */
var _retentionTime = 'http://hl7.org/fhir/_retentionTime';
/**
 * _encodeRequestUrl
 *
 * (Modified) TestScript.teardown.action.operation.encodeRequestUrl
 *
 * http://hl7.org/fhir/_encodeRequestUrl
 */
var _encodeRequestUrl = 'http://hl7.org/fhir/_encodeRequestUrl';
/**
 * countMax
 *
 * Timing.repeat.countMax: If present, indicates that the count is a range - so to perform the action between [count] and [countMax] times.
 *
 * http://hl7.org/fhir/countMax
 */
var countMax = 'http://hl7.org/fhir/countMax';
/**
 * _netContent
 *
 * (Modified) InventoryItem.netContent
 *
 * http://hl7.org/fhir/_netContent
 */
var _netContent = 'http://hl7.org/fhir/_netContent';
/**
 * AccountBalanceComponent
 *
 * AccountBalanceComponent: The calculated account balances - these are calculated and processed by the finance system.

The balances with a `term` that is not current are usually generated/updated by an invoicing or similar process.
 *
 * http://hl7.org/fhir/AccountBalanceComponent
 */
var AccountBalanceComponent = 'http://hl7.org/fhir/AccountBalanceComponent';
/**
 * _sequenceAttachment
 *
 * (Modified) SubstanceProtein.subunit.sequenceAttachment
 *
 * http://hl7.org/fhir/_sequenceAttachment
 */
var _sequenceAttachment = 'http://hl7.org/fhir/_sequenceAttachment';
/**
 * requestedLocation
 *
 * Transport.requestedLocation: The desired or final location for the transport.
 *
 * http://hl7.org/fhir/requestedLocation
 */
var requestedLocation = 'http://hl7.org/fhir/requestedLocation';
/**
 * DeviceDefinitionRegulatoryIdentifierComponent
 *
 * DeviceDefinitionRegulatoryIdentifierComponent: Identifier associated with the regulatory documentation (certificates, technical documentation, post-market surveillance documentation and reports) of a set of device models sharing the same intended purpose, risk class and essential design and manufacturing characteristics. One example is the Basic UDI-DI in Europe.
 *
 * http://hl7.org/fhir/DeviceDefinitionRegulatoryIdentifierComponent
 */
var DeviceDefinitionRegulatoryIdentifierComponent = 'http://hl7.org/fhir/DeviceDefinitionRegulatoryIdentifierComponent';
/**
 * _target
 *
 * (Modified) ConceptMap.group.element.target
 *
 * http://hl7.org/fhir/_target
 */
var _target = 'http://hl7.org/fhir/_target';
/**
 * _implicated
 *
 * (Modified) DetectedIssue.implicated
 *
 * http://hl7.org/fhir/_implicated
 */
var _implicated = 'http://hl7.org/fhir/_implicated';
/**
 * _administration
 *
 * (Modified) NutritionOrder.enteralFormula.administration
 *
 * http://hl7.org/fhir/_administration
 */
var _administration = 'http://hl7.org/fhir/_administration';
/**
 * _flag
 *
 * (Modified) List.entry.flag
 *
 * http://hl7.org/fhir/_flag
 */
var _flag = 'http://hl7.org/fhir/_flag';
/**
 * _party
 *
 * (Modified) Coverage.paymentBy.party
 *
 * http://hl7.org/fhir/_party
 */
var _party = 'http://hl7.org/fhir/_party';
/**
 * _version
 *
 * (Modified) ValueSet.expansion.contains.version
 *
 * http://hl7.org/fhir/_version
 */
var _version = 'http://hl7.org/fhir/_version';
/**
 * provision
 *
 * Consent.provision.provision.provision: Provisions which provide exceptions to the base provision or subprovisions.
 *
 * http://hl7.org/fhir/provision
 */
var provision = 'http://hl7.org/fhir/provision';
/**
 * patientPaid
 *
 * Claim.item.patientPaid: The amount paid by the patient, in total at the claim claim level or specifically for the item and detail level, to the provider for goods and services.
 *
 * http://hl7.org/fhir/patientPaid
 */
var patientPaid = 'http://hl7.org/fhir/patientPaid';
/**
 * referenceNumber
 *
 * PaymentReconciliation.referenceNumber: The check number, eft reference, car processor reference.
 *
 * http://hl7.org/fhir/referenceNumber
 */
var referenceNumber = 'http://hl7.org/fhir/referenceNumber';
/**
 * manifest
 *
 * ImplementationGuide.manifest: Information about an assembled implementation guide, created by the publication tooling.
 *
 * http://hl7.org/fhir/manifest
 */
var manifest = 'http://hl7.org/fhir/manifest';
/**
 * Account
 *
 * A financial tool for tracking value accrued for a particular purpose.  In the healthcare field, used to track charges for a patient, cost centers, etc.
 *
 * http://hl7.org/fhir/Account
 */
var Account = 'http://hl7.org/fhir/Account';
/**
 * _goal
 *
 * (Modified) RequestOrchestration.action.action.goal
 *
 * http://hl7.org/fhir/_goal
 */
var _goal = 'http://hl7.org/fhir/_goal';
/**
 * _basis
 *
 * (Modified) RiskAssessment.basis
 *
 * http://hl7.org/fhir/_basis
 */
var _basis = 'http://hl7.org/fhir/_basis';
/**
 * MessageSource
 *
 * MessageHeader.MessageSource: The source application from which this message originated.
 *
 * http://hl7.org/fhir/MessageSource
 */
var MessageSource = 'http://hl7.org/fhir/MessageSource';
/**
 * _formCode
 *
 * (Modified) PaymentReconciliation.formCode
 *
 * http://hl7.org/fhir/_formCode
 */
var _formCode = 'http://hl7.org/fhir/_formCode';
/**
 * _disclaimer
 *
 * (Modified) Measure.disclaimer
 *
 * http://hl7.org/fhir/_disclaimer
 */
var _disclaimer = 'http://hl7.org/fhir/_disclaimer';
/**
 * _definitionByCombination
 *
 * (Modified) EvidenceVariable.characteristic.definitionByCombination.characteristic.definitionByCombination
 *
 * http://hl7.org/fhir/_definitionByCombination
 */
var _definitionByCombination = 'http://hl7.org/fhir/_definitionByCombination';
/**
 * step
 *
 * ExampleScenario.process.step.process.step.alternative.step.alternative.step: Indicates the operation, sub-process or scenario that happens if the alternative option is selected.
 *
 * http://hl7.org/fhir/step
 */
var step = 'http://hl7.org/fhir/step';
/**
 * fractionDescription
 *
 * SubstanceSourceMaterial.fractionDescription: Many complex materials are fractions of parts of plants, animals, or minerals. Fraction elements are often necessary to define both Substances and Specified Group 1 Substances. For substances derived from Plants, fraction information will be captured at the Substance information level ( . Oils, Juices and Exudates). Additional information for Extracts, such as extraction solvent composition, will be captured at the Specified Substance Group 1 information level. For plasma-derived products fraction information will be captured at the Substance and the Specified Substance Group 1 levels.
 *
 * http://hl7.org/fhir/fractionDescription
 */
var fractionDescription = 'http://hl7.org/fhir/fractionDescription';
/**
 * valueCategory
 *
 * Evidence.statistic.modelCharacteristic.variable.valueCategory: Description for grouping of ordinal or polychotomous variables.
 *
 * http://hl7.org/fhir/valueCategory
 */
var valueCategory = 'http://hl7.org/fhir/valueCategory';
/**
 * requestMethod
 *
 * TestScript.test.action.assert.requestMethod: The request method or HTTP operation code to compare against that used by the client system under test.
 *
 * http://hl7.org/fhir/requestMethod
 */
var requestMethod = 'http://hl7.org/fhir/requestMethod';
/**
 * BodySite
 *
 * Claim.Item.BodySite: Physical location where the service is performed or applies.
 *
 * http://hl7.org/fhir/BodySite
 */
var BodySite = 'http://hl7.org/fhir/BodySite';
/**
 * etag
 *
 * Bundle.entry.response.etag: The Etag for the resource, if the operation for the entry produced a versioned resource (see [Resource Metadata and Versioning](http.html#versioning) and [Managing Resource Contention](http.html#concurrency)).
 *
 * http://hl7.org/fhir/etag
 */
var etag = 'http://hl7.org/fhir/etag';
/**
 * specimenQuantity
 *
 * Specimen.container.specimenQuantity: The quantity of specimen in the container; may be volume, dimensions, or other appropriate measurements, depending on the specimen type.
 *
 * http://hl7.org/fhir/specimenQuantity
 */
var specimenQuantity = 'http://hl7.org/fhir/specimenQuantity';
/**
 * comprisedOf
 *
 * MedicinalProductDefinition.comprisedOf: Types of medicinal manufactured items and/or devices that this product consists of, such as tablets, capsule, or syringes. Used as a direct link when the item's packaging is not being recorded (see also PackagedProductDefinition.package.containedItem.item).
 *
 * http://hl7.org/fhir/comprisedOf
 */
var comprisedOf = 'http://hl7.org/fhir/comprisedOf';
/**
 * _pediatricUseIndicator
 *
 * (Modified) MedicinalProductDefinition.pediatricUseIndicator
 *
 * http://hl7.org/fhir/_pediatricUseIndicator
 */
var _pediatricUseIndicator = 'http://hl7.org/fhir/_pediatricUseIndicator';
/**
 * _destination
 *
 * (Modified) TestScript.metadata.capability.destination
 *
 * http://hl7.org/fhir/_destination
 */
var _destination = 'http://hl7.org/fhir/_destination';
/**
 * _evaluationMessage
 *
 * (Modified) GuidanceResponse.evaluationMessage
 *
 * http://hl7.org/fhir/_evaluationMessage
 */
var _evaluationMessage = 'http://hl7.org/fhir/_evaluationMessage';
/**
 * ResearchStudyComparisonGroupComponent
 *
 * ResearchStudyComparisonGroupComponent: Describes an expected event or sequence of events for one of the subjects of a study. E.g. for a living subject: exposure to drug A, wash-out, exposure to drug B, wash-out, follow-up. E.g. for a stability study: {store sample from lot A at 25 degrees for 1 month}, {store sample from lot A at 40 degrees for 1 month}.
 *
 * http://hl7.org/fhir/ResearchStudyComparisonGroupComponent
 */
var ResearchStudyComparisonGroupComponent = 'http://hl7.org/fhir/ResearchStudyComparisonGroupComponent';
/**
 * _DomainResource
 *
 * http://hl7.org/fhir/_DomainResource
 */
var _DomainResource = 'http://hl7.org/fhir/_DomainResource';
/**
 * CitationCitedArtifactWebLocationComponent
 *
 * CitationCitedArtifactComponent.CitationCitedArtifactWebLocationComponent: Used for any URL for the article or artifact cited.
 *
 * http://hl7.org/fhir/CitationCitedArtifactWebLocationComponent
 */
var CitationCitedArtifactWebLocationComponent = 'http://hl7.org/fhir/CitationCitedArtifactWebLocationComponent';
/**
 * beneficiary
 *
 * Coverage.beneficiary: The party who benefits from the insurance coverage; the patient when products and/or services are provided.
 *
 * http://hl7.org/fhir/beneficiary
 */
var beneficiary = 'http://hl7.org/fhir/beneficiary';
/**
 * prefix
 *
 * Questionnaire.item.item.prefix: A short label for a particular group, question or set of display text within the questionnaire used for reference by the individual completing the questionnaire.
 *
 * http://hl7.org/fhir/prefix
 */
var prefix = 'http://hl7.org/fhir/prefix';
/**
 * effectiveTime
 *
 * Contract.term.group.asset.valuedItem.effectiveTime: Indicates the time during which this Contract ValuedItem information is effective.
 *
 * http://hl7.org/fhir/effectiveTime
 */
var effectiveTime = 'http://hl7.org/fhir/effectiveTime';
/**
 * RegulatedAuthorizationCaseComponent
 *
 * RegulatedAuthorizationCaseComponent: The case or regulatory procedure for granting or amending a regulated authorization. An authorization is granted in response to submissions/applications by those seeking authorization. A case is the administrative process that deals with the application(s) that relate to this and assesses them. Note: This area is subject to ongoing review and the workgroup is seeking implementer feedback on its use (see link at bottom of page).
 *
 * http://hl7.org/fhir/RegulatedAuthorizationCaseComponent
 */
var RegulatedAuthorizationCaseComponent = 'http://hl7.org/fhir/RegulatedAuthorizationCaseComponent';
/**
 * AccountProcedureComponent
 *
 * AccountProcedureComponent: When using an account for billing a specific Encounter the set of procedures that are relevant for billing are stored here on the account where they are able to be sequenced appropriately prior to processing to produce claim(s).
 *
 * http://hl7.org/fhir/AccountProcedureComponent
 */
var AccountProcedureComponent = 'http://hl7.org/fhir/AccountProcedureComponent';
/**
 * doseStatusReason
 *
 * ImmunizationEvaluation.doseStatusReason: Provides an explanation as to why the vaccine administration event is valid or not relative to the published recommendations.
 *
 * http://hl7.org/fhir/doseStatusReason
 */
var doseStatusReason = 'http://hl7.org/fhir/doseStatusReason';
/**
 * ResearchStudyAssociatedPartyComponent
 *
 * ResearchStudyAssociatedPartyComponent: Sponsors, collaborators, and other parties.
 *
 * http://hl7.org/fhir/ResearchStudyAssociatedPartyComponent
 */
var ResearchStudyAssociatedPartyComponent = 'http://hl7.org/fhir/ResearchStudyAssociatedPartyComponent';
/**
 * reason
 *
 * Procedure.reason: The coded reason or reference why the procedure was performed. This may be a coded entity of some type, be present as text, or be a reference to one of several resources that justify the procedure.
 *
 * http://hl7.org/fhir/reason
 */
var reason = 'http://hl7.org/fhir/reason';
/**
 * _precondition
 *
 * (Modified) ConditionDefinition.precondition
 *
 * http://hl7.org/fhir/_precondition
 */
var _precondition = 'http://hl7.org/fhir/_precondition';
/**
 * criteria
 *
 * Measure.supplementalData.criteria: The criteria for the supplemental data. This is typically the name of a valid expression defined within a referenced library, but it may also be a path to a specific data element. The criteria defines the data to be returned for this element.
 *
 * http://hl7.org/fhir/criteria
 */
var criteria = 'http://hl7.org/fhir/criteria';
/**
 * MedicationAdministrationDosageComponent
 *
 * MedicationAdministrationDosageComponent: Describes the medication dosage information details e.g. dose, rate, site, route, etc.
 *
 * http://hl7.org/fhir/MedicationAdministrationDosageComponent
 */
var MedicationAdministrationDosageComponent = 'http://hl7.org/fhir/MedicationAdministrationDosageComponent';
/**
 * latitude
 *
 * Location.position.latitude: Latitude. The value domain and the interpretation are the same as for the text of the latitude element in KML (see notes on Location main page).
 *
 * http://hl7.org/fhir/latitude
 */
var latitude = 'http://hl7.org/fhir/latitude';
/**
 * IngredientSubstanceStrengthReferenceStrengthComponent
 *
 * IngredientSubstanceComponent.IngredientSubstanceStrengthComponent.IngredientSubstanceStrengthReferenceStrengthComponent: Strength expressed in terms of a reference substance. For when the ingredient strength is additionally expressed as equivalent to the strength of some other closely related substance (e.g. salt vs. base). Reference strength represents the strength (quantitative composition) of the active moiety of the active substance. There are situations when the active substance and active moiety are different, therefore both a strength and a reference strength are needed.
 *
 * http://hl7.org/fhir/IngredientSubstanceStrengthReferenceStrengthComponent
 */
var IngredientSubstanceStrengthReferenceStrengthComponent = 'http://hl7.org/fhir/IngredientSubstanceStrengthReferenceStrengthComponent';
/**
 * _thursday
 *
 * (Modified) Appointment.recurrenceTemplate.weeklyTemplate.thursday
 *
 * http://hl7.org/fhir/_thursday
 */
var _thursday = 'http://hl7.org/fhir/_thursday';
/**
 * securityContext
 *
 * Binary.securityContext: This element identifies another resource that can be used as a proxy of the security sensitivity to use when deciding and enforcing access control rules for the Binary resource. Given that the Binary resource contains very few elements that can be used to determine the sensitivity of the data and relationships to individuals, the referenced resource stands in as a proxy equivalent for this purpose. This referenced resource may be related to the Binary (e.g. DocumentReference), or may be some non-related Resource purely as a security proxy. E.g. to identify that the binary resource relates to a patient, and access should only be granted to applications that have access to the patient.
 *
 * http://hl7.org/fhir/securityContext
 */
var securityContext = 'http://hl7.org/fhir/securityContext';
/**
 * _baseDefinition
 *
 * (Modified) StructureDefinition.baseDefinition
 *
 * http://hl7.org/fhir/_baseDefinition
 */
var _baseDefinition = 'http://hl7.org/fhir/_baseDefinition';
/**
 * _publicationStatus
 *
 * (Modified) Contract.contentDefinition.publicationStatus
 *
 * http://hl7.org/fhir/_publicationStatus
 */
var _publicationStatus = 'http://hl7.org/fhir/_publicationStatus';
/**
 * relatedArtifact
 *
 * Measure.relatedArtifact: Related artifacts such as additional documentation, justification, or bibliographic references.
 *
 * http://hl7.org/fhir/relatedArtifact
 */
var relatedArtifact = 'http://hl7.org/fhir/relatedArtifact';
/**
 * safety
 *
 * DeviceDefinition.safety: Safety characteristics of the device.
 *
 * http://hl7.org/fhir/safety
 */
var safety = 'http://hl7.org/fhir/safety';
/**
 * stereochemistry
 *
 * SubstanceDefinition.structure.stereochemistry: Stereochemistry type.
 *
 * http://hl7.org/fhir/stereochemistry
 */
var stereochemistry = 'http://hl7.org/fhir/stereochemistry';
/**
 * _timeout
 *
 * (Modified) Subscription.timeout
 *
 * http://hl7.org/fhir/_timeout
 */
var _timeout = 'http://hl7.org/fhir/_timeout';
/**
 * primarySource
 *
 * VerificationResult.primarySource: Information about the primary source(s) involved in validation.
 *
 * http://hl7.org/fhir/primarySource
 */
var primarySource = 'http://hl7.org/fhir/primarySource';
/**
 * NutritionOrderOralDietNutrientComponent
 *
 * NutritionOrderOralDietComponent.NutritionOrderOralDietNutrientComponent: Class that defines the quantity and type of nutrient modifications (for example carbohydrate, fiber or sodium) required for the oral diet.
 *
 * http://hl7.org/fhir/NutritionOrderOralDietNutrientComponent
 */
var NutritionOrderOralDietNutrientComponent = 'http://hl7.org/fhir/NutritionOrderOralDietNutrientComponent';
/**
 * responseCode
 *
 * TestScript.test.action.assert.responseCode: The value of the HTTP response code to be tested.
 *
 * http://hl7.org/fhir/responseCode
 */
var responseCode = 'http://hl7.org/fhir/responseCode';
/**
 * eventHistory
 *
 * DeviceDispense.eventHistory: A summary of the events of interest that have occurred, such as when the dispense was verified.
 *
 * http://hl7.org/fhir/eventHistory
 */
var eventHistory = 'http://hl7.org/fhir/eventHistory';
/**
 * _doseForm
 *
 * (Modified) MedicationKnowledge.definitional.doseForm
 *
 * http://hl7.org/fhir/_doseForm
 */
var _doseForm = 'http://hl7.org/fhir/_doseForm';
/**
 * _allowedResponse
 *
 * (Modified) MessageDefinition.allowedResponse
 *
 * http://hl7.org/fhir/_allowedResponse
 */
var _allowedResponse = 'http://hl7.org/fhir/_allowedResponse';
/**
 * _storageGuideline
 *
 * (Modified) MedicationKnowledge.storageGuideline
 *
 * http://hl7.org/fhir/_storageGuideline
 */
var _storageGuideline = 'http://hl7.org/fhir/_storageGuideline';
/**
 * timezone
 *
 * Appointment.recurrenceTemplate.timezone: The timezone of the recurring appointment occurrences.
 *
 * http://hl7.org/fhir/timezone
 */
var timezone = 'http://hl7.org/fhir/timezone';
/**
 * copolymerConnectivity
 *
 * SubstancePolymer.copolymerConnectivity: Descrtibes the copolymer sequence type (polymer connectivity).
 *
 * http://hl7.org/fhir/copolymerConnectivity
 */
var copolymerConnectivity = 'http://hl7.org/fhir/copolymerConnectivity';
/**
 * GenomicStudyAnalysisOutputComponent
 *
 * GenomicStudyAnalysisComponent.GenomicStudyAnalysisOutputComponent: Outputs for the analysis event.
 *
 * http://hl7.org/fhir/GenomicStudyAnalysisOutputComponent
 */
var GenomicStudyAnalysisOutputComponent = 'http://hl7.org/fhir/GenomicStudyAnalysisOutputComponent';
/**
 * _molecularWeight
 *
 * (Modified) SubstanceDefinition.structure.molecularWeight
 *
 * http://hl7.org/fhir/_molecularWeight
 */
var _molecularWeight = 'http://hl7.org/fhir/_molecularWeight';
/**
 * ObservationDefinition
 *
 * Set of definitional characteristics for a kind of observation or measurement produced or consumed by an orderable health care service.
 *
 * http://hl7.org/fhir/ObservationDefinition
 */
var ObservationDefinition = 'http://hl7.org/fhir/ObservationDefinition';
/**
 * ifNoneMatch
 *
 * Bundle.entry.request.ifNoneMatch: If the ETag values match, return a 304 Not Modified status. See the API documentation for ["Conditional Read"](http.html#cread).
 *
 * http://hl7.org/fhir/ifNoneMatch
 */
var ifNoneMatch = 'http://hl7.org/fhir/ifNoneMatch';
/**
 * _notConsumed
 *
 * (Modified) NutritionIntake.consumedItem.notConsumed
 *
 * http://hl7.org/fhir/_notConsumed
 */
var _notConsumed = 'http://hl7.org/fhir/_notConsumed';
/**
 * grade
 *
 * SubstanceDefinition.grade: The quality standard, established benchmark, to which substance complies (e.g. USP/NF, Ph. Eur, JP, BP, Company Standard).
 *
 * http://hl7.org/fhir/grade
 */
var grade = 'http://hl7.org/fhir/grade';
/**
 * OralDietSchedule
 *
 * NutritionOrderOralDietComponent.OralDietSchedule: Schedule information for an oral diet.
 *
 * http://hl7.org/fhir/OralDietSchedule
 */
var OralDietSchedule = 'http://hl7.org/fhir/OralDietSchedule';
/**
 * _diagnosis
 *
 * (Modified) Encounter.diagnosis
 *
 * http://hl7.org/fhir/_diagnosis
 */
var _diagnosis = 'http://hl7.org/fhir/_diagnosis';
/**
 * _channelType
 *
 * (Modified) Subscription.channelType
 *
 * http://hl7.org/fhir/_channelType
 */
var _channelType = 'http://hl7.org/fhir/_channelType';
/**
 * _encounter
 *
 * (Modified) ServiceRequest.encounter
 *
 * http://hl7.org/fhir/_encounter
 */
var _encounter = 'http://hl7.org/fhir/_encounter';
/**
 * SubstancePolymerMonomerSetStartingMaterialComponent
 *
 * SubstancePolymerMonomerSetComponent.SubstancePolymerMonomerSetStartingMaterialComponent: The starting materials - monomer(s) used in the synthesis of the polymer.
 *
 * http://hl7.org/fhir/SubstancePolymerMonomerSetStartingMaterialComponent
 */
var SubstancePolymerMonomerSetStartingMaterialComponent = 'http://hl7.org/fhir/SubstancePolymerMonomerSetStartingMaterialComponent';
/**
 * statisticType
 *
 * Evidence.statistic.statisticType: Type of statistic, e.g., relative risk.
 *
 * http://hl7.org/fhir/statisticType
 */
var statisticType = 'http://hl7.org/fhir/statisticType';
/**
 * _webLocation
 *
 * (Modified) Citation.citedArtifact.webLocation
 *
 * http://hl7.org/fhir/_webLocation
 */
var _webLocation = 'http://hl7.org/fhir/_webLocation';
/**
 * SubstanceSourceMaterialOrganismOrganismGeneralComponent
 *
 * SubstanceSourceMaterialOrganismComponent.SubstanceSourceMaterialOrganismOrganismGeneralComponent: 4.9.13.7.1 Kingdom (Conditional).
 *
 * http://hl7.org/fhir/SubstanceSourceMaterialOrganismOrganismGeneralComponent
 */
var SubstanceSourceMaterialOrganismOrganismGeneralComponent = 'http://hl7.org/fhir/SubstanceSourceMaterialOrganismOrganismGeneralComponent';
/**
 * textConcentration
 *
 * Ingredient.substance.strength.textConcentration: A textual represention of either the whole of the concentration strength or a part of it - with the rest being in Strength.concentration as a ratio.
 *
 * http://hl7.org/fhir/textConcentration
 */
var textConcentration = 'http://hl7.org/fhir/textConcentration';
/**
 * _multipleAnd
 *
 * (Modified) SearchParameter.multipleAnd
 *
 * http://hl7.org/fhir/_multipleAnd
 */
var _multipleAnd = 'http://hl7.org/fhir/_multipleAnd';
/**
 * _freeToShare
 *
 * (Modified) ArtifactAssessment.content.component.freeToShare
 *
 * http://hl7.org/fhir/_freeToShare
 */
var _freeToShare = 'http://hl7.org/fhir/_freeToShare';
/**
 * _contributionInstance
 *
 * (Modified) Citation.citedArtifact.contributorship.entry.contributionInstance
 *
 * http://hl7.org/fhir/_contributionInstance
 */
var _contributionInstance = 'http://hl7.org/fhir/_contributionInstance';
/**
 * MedicationStatementAdherenceComponent
 *
 * MedicationStatementAdherenceComponent: Indicates whether the medication is or is not being consumed or administered.
 *
 * http://hl7.org/fhir/MedicationStatementAdherenceComponent
 */
var MedicationStatementAdherenceComponent = 'http://hl7.org/fhir/MedicationStatementAdherenceComponent';
/**
 * _onAdmission
 *
 * (Modified) ExplanationOfBenefit.diagnosis.onAdmission
 *
 * http://hl7.org/fhir/_onAdmission
 */
var _onAdmission = 'http://hl7.org/fhir/_onAdmission';
/**
 * output
 *
 * GenomicStudy.analysis.output: Outputs for the analysis event.
 *
 * http://hl7.org/fhir/output
 */
var output = 'http://hl7.org/fhir/output';
/**
 * _indication
 *
 * (Modified) RegulatedAuthorization.indication
 *
 * http://hl7.org/fhir/_indication
 */
var _indication = 'http://hl7.org/fhir/_indication';
/**
 * DeviceDefinitionChargeItemComponent
 *
 * DeviceDefinitionChargeItemComponent: Billing code or reference associated with the device.
 *
 * http://hl7.org/fhir/DeviceDefinitionChargeItemComponent
 */
var DeviceDefinitionChargeItemComponent = 'http://hl7.org/fhir/DeviceDefinitionChargeItemComponent';
/**
 * location
 *
 * InventoryItem.instance.location: The location that the item is associated with.
 *
 * http://hl7.org/fhir/location
 */
var location = 'http://hl7.org/fhir/location';
/**
 * generalCost
 *
 * InsurancePlan.plan.generalCost: Overall costs associated with the plan.
 *
 * http://hl7.org/fhir/generalCost
 */
var generalCost = 'http://hl7.org/fhir/generalCost';
/**
 * _plannedActivityReference
 *
 * (Modified) CarePlan.activity.plannedActivityReference
 *
 * http://hl7.org/fhir/_plannedActivityReference
 */
var _plannedActivityReference = 'http://hl7.org/fhir/_plannedActivityReference';
/**
 * rules
 *
 * ElementDefinition.slicing.rules: Whether additional slices are allowed or not. When the slices are ordered, profile authors can also say that additional slices are only allowed at the end.
 *
 * http://hl7.org/fhir/rules
 */
var rules = 'http://hl7.org/fhir/rules';
/**
 * reported
 *
 * Procedure.reported
 *
 * http://hl7.org/fhir/reported
 */
var reported = 'http://hl7.org/fhir/reported';
/**
 * maxDosePerDay
 *
 * AdministrableProductDefinition.routeOfAdministration.maxDosePerDay: The maximum dose per day (maximum dose quantity to be administered in any one 24-h period) that can be administered.
 *
 * http://hl7.org/fhir/maxDosePerDay
 */
var maxDosePerDay = 'http://hl7.org/fhir/maxDosePerDay';
/**
 * NutritionOrderOralDietTextureComponent
 *
 * NutritionOrderOralDietComponent.NutritionOrderOralDietTextureComponent: Class that describes any texture modifications required for the patient to safely consume various types of solid foods.
 *
 * http://hl7.org/fhir/NutritionOrderOralDietTextureComponent
 */
var NutritionOrderOralDietTextureComponent = 'http://hl7.org/fhir/NutritionOrderOralDietTextureComponent';
/**
 * _definitionByTypeAndValue
 *
 * (Modified) EvidenceVariable.characteristic.definitionByCombination.characteristic.definitionByTypeAndValue
 *
 * http://hl7.org/fhir/_definitionByTypeAndValue
 */
var _definitionByTypeAndValue = 'http://hl7.org/fhir/_definitionByTypeAndValue';
/**
 * GroupMemberComponent
 *
 * GroupMemberComponent: Identifies the resource instances that are members of the group.
 *
 * http://hl7.org/fhir/GroupMemberComponent
 */
var GroupMemberComponent = 'http://hl7.org/fhir/GroupMemberComponent';
/**
 * _verificationType
 *
 * (Modified) Consent.verification.verificationType
 *
 * http://hl7.org/fhir/_verificationType
 */
var _verificationType = 'http://hl7.org/fhir/_verificationType';
/**
 * _supportingInformation
 *
 * (Modified) MedicationAdministration.supportingInformation
 *
 * http://hl7.org/fhir/_supportingInformation
 */
var _supportingInformation = 'http://hl7.org/fhir/_supportingInformation';
/**
 * kingdom
 *
 * SubstanceSourceMaterial.organism.organismGeneral.kingdom: The kingdom of an organism shall be specified.
 *
 * http://hl7.org/fhir/kingdom
 */
var kingdom = 'http://hl7.org/fhir/kingdom';
/**
 * sourceMaterialClass
 *
 * SubstanceSourceMaterial.sourceMaterialClass: General high level classification of the source material specific to the origin of the material.
 *
 * http://hl7.org/fhir/sourceMaterialClass
 */
var sourceMaterialClass = 'http://hl7.org/fhir/sourceMaterialClass';
/**
 * _polymer
 *
 * (Modified) SubstanceDefinition.polymer
 *
 * http://hl7.org/fhir/_polymer
 */
var _polymer = 'http://hl7.org/fhir/_polymer';
/**
 * insurance
 *
 * Transport.insurance: Insurance plans, coverage extensions, pre-authorizations and/or pre-determinations that may be relevant to the Transport.
 *
 * http://hl7.org/fhir/insurance
 */
var insurance = 'http://hl7.org/fhir/insurance';
/**
 * _handling
 *
 * (Modified) SpecimenDefinition.typeTested.handling
 *
 * http://hl7.org/fhir/_handling
 */
var _handling = 'http://hl7.org/fhir/_handling';
/**
 * supportingInfo
 *
 * AdverseEvent.supportingInfo: Supporting information relevant to the event.
 *
 * http://hl7.org/fhir/supportingInfo
 */
var supportingInfo = 'http://hl7.org/fhir/supportingInfo';
/**
 * lifecycleStatus
 *
 * Goal.lifecycleStatus: The state of the goal throughout its lifecycle.
 *
 * http://hl7.org/fhir/lifecycleStatus
 */
var lifecycleStatus = 'http://hl7.org/fhir/lifecycleStatus';
/**
 * _symptomConditionEffect
 *
 * (Modified) ClinicalUseDefinition.undesirableEffect.symptomConditionEffect
 *
 * http://hl7.org/fhir/_symptomConditionEffect
 */
var _symptomConditionEffect = 'http://hl7.org/fhir/_symptomConditionEffect';
/**
 * _fraction
 *
 * (Modified) SubstanceSourceMaterial.fractionDescription.fraction
 *
 * http://hl7.org/fhir/_fraction
 */
var _fraction = 'http://hl7.org/fhir/_fraction';
/**
 * language
 *
 * RelatedPerson.communication.language: The ISO-639-1 alpha 2 code in lower case for the language, optionally followed by a hyphen and the ISO-3166-1 alpha 2 code for the region in upper case; e.g. "en" for English, or "en-US" for American English versus "en-AU" for Australian English.
 *
 * http://hl7.org/fhir/language
 */
var language = 'http://hl7.org/fhir/language';
/**
 * combining
 *
 * Permission.combining: Defines a procedure for arriving at an access decision given the set of rules.
 *
 * http://hl7.org/fhir/combining
 */
var combining = 'http://hl7.org/fhir/combining';
/**
 * country
 *
 * Address.country: Country - a nation as commonly understood or generally accepted.
 *
 * http://hl7.org/fhir/country
 */
var country = 'http://hl7.org/fhir/country';
/**
 * isExample
 *
 * ImplementationGuide.manifest.resource.isExample: If true, indicates the resource is an example instance.
 *
 * http://hl7.org/fhir/isExample
 */
var isExample = 'http://hl7.org/fhir/isExample';
/**
 * _readHistory
 *
 * (Modified) CapabilityStatement.rest.resource.readHistory
 *
 * http://hl7.org/fhir/_readHistory
 */
var _readHistory = 'http://hl7.org/fhir/_readHistory';
/**
 * BundleLinkComponent
 *
 * BundleLinkComponent: A series of links that provide context to this bundle.
 *
 * http://hl7.org/fhir/BundleLinkComponent
 */
var BundleLinkComponent = 'http://hl7.org/fhir/BundleLinkComponent';
/**
 * currentLocation
 *
 * Transport.currentLocation: The current location for the entity to be transported.
 *
 * http://hl7.org/fhir/currentLocation
 */
var currentLocation = 'http://hl7.org/fhir/currentLocation';
/**
 * official
 *
 * SubstanceDefinition.name.official: Details of the official nature of this name.
 *
 * http://hl7.org/fhir/official
 */
var official = 'http://hl7.org/fhir/official';
/**
 * _EncounterHistory
 *
 * (Modified) EncounterHistory
 *
 * http://hl7.org/fhir/_EncounterHistory
 */
var _EncounterHistory = 'http://hl7.org/fhir/_EncounterHistory';
/**
 * EvidenceVariableCategoryComponent
 *
 * EvidenceVariableCategoryComponent: A grouping for ordinal or polychotomous variables.
 *
 * http://hl7.org/fhir/EvidenceVariableCategoryComponent
 */
var EvidenceVariableCategoryComponent = 'http://hl7.org/fhir/EvidenceVariableCategoryComponent';
/**
 * _administeredBy
 *
 * (Modified) InsurancePlan.administeredBy
 *
 * http://hl7.org/fhir/_administeredBy
 */
var _administeredBy = 'http://hl7.org/fhir/_administeredBy';
/**
 * _ProductShelfLife
 *
 * (Modified) ProductShelfLife
 *
 * http://hl7.org/fhir/_ProductShelfLife
 */
var _ProductShelfLife = 'http://hl7.org/fhir/_ProductShelfLife';
/**
 * SubstanceDefinitionMolecularWeightComponent
 *
 * SubstanceDefinitionMolecularWeightComponent: The average mass of a molecule of a compound compared to 1/12 the mass of carbon 12 and calculated as the sum of the atomic weights of the constituent atoms.
 *
 * http://hl7.org/fhir/SubstanceDefinitionMolecularWeightComponent
 */
var SubstanceDefinitionMolecularWeightComponent = 'http://hl7.org/fhir/SubstanceDefinitionMolecularWeightComponent';
/**
 * affectsState
 *
 * OperationDefinition.affectsState: Whether the operation affects state. Side effects such as producing audit trail entries do not count as 'affecting  state'.
 *
 * http://hl7.org/fhir/affectsState
 */
var affectsState = 'http://hl7.org/fhir/affectsState';
/**
 * notificationShape
 *
 * SubscriptionTopic.notificationShape: List of properties to describe the shape (e.g., resources) included in notifications from this Subscription Topic.
 *
 * http://hl7.org/fhir/notificationShape
 */
var notificationShape = 'http://hl7.org/fhir/notificationShape';
/**
 * descriptionSummary
 *
 * ResearchStudy.descriptionSummary: A brief text for explaining the study.
 *
 * http://hl7.org/fhir/descriptionSummary
 */
var descriptionSummary = 'http://hl7.org/fhir/descriptionSummary';
/**
 * _answerValueSet
 *
 * (Modified) Questionnaire.item.item.answerValueSet
 *
 * http://hl7.org/fhir/_answerValueSet
 */
var _answerValueSet = 'http://hl7.org/fhir/_answerValueSet';
/**
 * PractitionerRole
 *
 * A specific set of Roles/Locations/specialties/services that a practitioner may perform, or has performed at an organization during a period of time.
 *
 * http://hl7.org/fhir/PractitionerRole
 */
var PractitionerRole = 'http://hl7.org/fhir/PractitionerRole';
/**
 * _rationale
 *
 * (Modified) RiskAssessment.prediction.rationale
 *
 * http://hl7.org/fhir/_rationale
 */
var _rationale = 'http://hl7.org/fhir/_rationale';
/**
 * _ChargeItem
 *
 * (Modified) ChargeItem
 *
 * http://hl7.org/fhir/_ChargeItem
 */
var _ChargeItem = 'http://hl7.org/fhir/_ChargeItem';
/**
 * _offer
 *
 * (Modified) Contract.term.group.offer
 *
 * http://hl7.org/fhir/_offer
 */
var _offer = 'http://hl7.org/fhir/_offer';
/**
 * OperationDefinitionParameterReferencedFromComponent
 *
 * OperationDefinitionParameterComponent.OperationDefinitionParameterReferencedFromComponent: Identifies other resource parameters within the operation invocation that are expected to resolve to this resource.
 *
 * http://hl7.org/fhir/OperationDefinitionParameterReferencedFromComponent
 */
var OperationDefinitionParameterReferencedFromComponent = 'http://hl7.org/fhir/OperationDefinitionParameterReferencedFromComponent';
/**
 * singleUse
 *
 * SpecimenDefinition.typeTested.singleUse: Specimen can be used by only one test or panel if the value is "true".
 *
 * http://hl7.org/fhir/singleUse
 */
var singleUse = 'http://hl7.org/fhir/singleUse';
/**
 * _exclude
 *
 * (Modified) ValueSet.compose.exclude
 *
 * http://hl7.org/fhir/_exclude
 */
var _exclude = 'http://hl7.org/fhir/_exclude';
/**
 * fhirVersion
 *
 * ImplementationGuide.fhirVersion: The version(s) of the FHIR specification that this ImplementationGuide targets - e.g. describes how to use. The value of this element is the formal version of the specification, without the revision number, e.g. [publication].[major].[minor], which is 4.6.0. for this version.
 *
 * http://hl7.org/fhir/fhirVersion
 */
var fhirVersion = 'http://hl7.org/fhir/fhirVersion';
/**
 * _nucleicAcid
 *
 * (Modified) SubstanceDefinition.nucleicAcid
 *
 * http://hl7.org/fhir/_nucleicAcid
 */
var _nucleicAcid = 'http://hl7.org/fhir/_nucleicAcid';
/**
 * CodeableConcept
 *
 * A concept that may be defined by a formal reference to a terminology or ontology or may be provided by text.
 *
 * http://hl7.org/fhir/CodeableConcept
 */
var CodeableConcept = 'http://hl7.org/fhir/CodeableConcept';
/**
 * _Claim
 *
 * (Modified) Claim
 *
 * http://hl7.org/fhir/_Claim
 */
var _Claim = 'http://hl7.org/fhir/_Claim';
/**
 * _site
 *
 * (Modified) ExplanationOfBenefit.item.bodySite.site
 *
 * http://hl7.org/fhir/_site
 */
var _site = 'http://hl7.org/fhir/_site';
/**
 * targetScope
 *
 * ConceptMap.targetScope
 *
 * http://hl7.org/fhir/targetScope
 */
var targetScope = 'http://hl7.org/fhir/targetScope';
/**
 * _monthInterval
 *
 * (Modified) Appointment.recurrenceTemplate.monthlyTemplate.monthInterval
 *
 * http://hl7.org/fhir/_monthInterval
 */
var _monthInterval = 'http://hl7.org/fhir/_monthInterval';
/**
 * _monitoringProgram
 *
 * (Modified) MedicationKnowledge.monitoringProgram
 *
 * http://hl7.org/fhir/_monitoringProgram
 */
var _monitoringProgram = 'http://hl7.org/fhir/_monitoringProgram';
/**
 * mustHaveValue
 *
 * ElementDefinition.mustHaveValue: Specifies for a primitive data type that the value of the data type cannot be replaced by an extension.
 *
 * http://hl7.org/fhir/mustHaveValue
 */
var mustHaveValue = 'http://hl7.org/fhir/mustHaveValue';
/**
 * _interpreter
 *
 * (Modified) GenomicStudy.interpreter
 *
 * http://hl7.org/fhir/_interpreter
 */
var _interpreter = 'http://hl7.org/fhir/_interpreter';
/**
 * SubscriptionStatus
 *
 * The SubscriptionStatus resource describes the state of a Subscription during notifications. It is not persisted.
 *
 * http://hl7.org/fhir/SubscriptionStatus
 */
var SubscriptionStatus = 'http://hl7.org/fhir/SubscriptionStatus';
/**
 * _productOrServiceEnd
 *
 * (Modified) ClaimResponse.addItem.detail.productOrServiceEnd
 *
 * http://hl7.org/fhir/_productOrServiceEnd
 */
var _productOrServiceEnd = 'http://hl7.org/fhir/_productOrServiceEnd';
/**
 * doseQuantity
 *
 * Immunization.doseQuantity: The quantity of vaccine product that was administered.
 *
 * http://hl7.org/fhir/doseQuantity
 */
var doseQuantity = 'http://hl7.org/fhir/doseQuantity';
/**
 * _prism
 *
 * (Modified) VisionPrescription.lensSpecification.prism
 *
 * http://hl7.org/fhir/_prism
 */
var _prism = 'http://hl7.org/fhir/_prism';
/**
 * highNumerator
 *
 * RatioRange.highNumerator: The value of the high limit numerator.
 *
 * http://hl7.org/fhir/highNumerator
 */
var highNumerator = 'http://hl7.org/fhir/highNumerator';
/**
 * contentDefinition
 *
 * Contract.contentDefinition: Precusory content developed with a focus and intent of supporting the formation a Contract instance, which may be associated with and transformable into a Contract.
 *
 * http://hl7.org/fhir/contentDefinition
 */
var contentDefinition = 'http://hl7.org/fhir/contentDefinition';
/**
 * due
 *
 * PlanDefinition.goal.target.due: Indicates the timeframe after the start of the goal in which the goal should be met.
 *
 * http://hl7.org/fhir/due
 */
var due = 'http://hl7.org/fhir/due';
/**
 * structureProfile
 *
 * ExampleScenario.instance.structureProfile
 *
 * http://hl7.org/fhir/structureProfile
 */
var structureProfile = 'http://hl7.org/fhir/structureProfile';
/**
 * _acceptLanguage
 *
 * (Modified) CapabilityStatement.acceptLanguage
 *
 * http://hl7.org/fhir/_acceptLanguage
 */
var _acceptLanguage = 'http://hl7.org/fhir/_acceptLanguage';
/**
 * _RegulatedAuthorization
 *
 * (Modified) RegulatedAuthorization
 *
 * http://hl7.org/fhir/_RegulatedAuthorization
 */
var _RegulatedAuthorization = 'http://hl7.org/fhir/_RegulatedAuthorization';
/**
 * authorType
 *
 * SubstanceSourceMaterial.organism.author.authorType: The type of author of an organism species shall be specified. The parenthetical author of an organism species refers to the first author who published the plant/animal name (of any rank). The primary author of an organism species refers to the first author(s), who validly published the plant/animal name.
 *
 * http://hl7.org/fhir/authorType
 */
var authorType = 'http://hl7.org/fhir/authorType';
/**
 * paymentIssuer
 *
 * PaymentReconciliation.paymentIssuer: The party who generated the payment.
 *
 * http://hl7.org/fhir/paymentIssuer
 */
var paymentIssuer = 'http://hl7.org/fhir/paymentIssuer';
/**
 * clinicalTrial
 *
 * MedicinalProductDefinition.clinicalTrial: Clinical trials or studies that this product is involved in.
 *
 * http://hl7.org/fhir/clinicalTrial
 */
var clinicalTrial = 'http://hl7.org/fhir/clinicalTrial';
/**
 * _parentSubstanceName
 *
 * (Modified) SubstanceSourceMaterial.parentSubstanceName
 *
 * http://hl7.org/fhir/_parentSubstanceName
 */
var _parentSubstanceName = 'http://hl7.org/fhir/_parentSubstanceName';
/**
 * _high
 *
 * (Modified) SubstancePolymer.repeat.repeatUnit.degreeOfPolymerisation.high
 *
 * http://hl7.org/fhir/_high
 */
var _high = 'http://hl7.org/fhir/_high';
/**
 * actorId
 *
 * PlanDefinition.action.action.participant.actorId: A reference to the id element of the actor who will participate in this action.
 *
 * http://hl7.org/fhir/actorId
 */
var actorId = 'http://hl7.org/fhir/actorId';
/**
 * _document
 *
 * (Modified) SubstanceDefinition.structure.representation.document
 *
 * http://hl7.org/fhir/_document
 */
var _document = 'http://hl7.org/fhir/_document';
/**
 * _marketPeriod
 *
 * (Modified) DeviceDefinition.packaging.packaging.udiDeviceIdentifier.marketDistribution.marketPeriod
 *
 * http://hl7.org/fhir/_marketPeriod
 */
var _marketPeriod = 'http://hl7.org/fhir/_marketPeriod';
/**
 * _denominator
 *
 * (Modified) RatioRange.denominator
 *
 * http://hl7.org/fhir/_denominator
 */
var _denominator = 'http://hl7.org/fhir/_denominator';
/**
 * accessionIdentifier
 *
 * Specimen.accessionIdentifier: The identifier assigned by the lab when accessioning specimen(s). This is not necessarily the same as the specimen identifier, depending on local lab procedures.
 *
 * http://hl7.org/fhir/accessionIdentifier
 */
var accessionIdentifier = 'http://hl7.org/fhir/accessionIdentifier';
/**
 * VerificationResultPrimarySourceComponent
 *
 * VerificationResultPrimarySourceComponent: Information about the primary source(s) involved in validation.
 *
 * http://hl7.org/fhir/VerificationResultPrimarySourceComponent
 */
var VerificationResultPrimarySourceComponent = 'http://hl7.org/fhir/VerificationResultPrimarySourceComponent';
/**
 * authored
 *
 * QuestionnaireResponse.authored: The date and/or time that this questionnaire response was last modified by the user - e.g. changing answers or revising status.
 *
 * http://hl7.org/fhir/authored
 */
var authored = 'http://hl7.org/fhir/authored';
/**
 * serialNumber
 *
 * Device.serialNumber: The serial number assigned by the organization when the device was manufactured.
 *
 * http://hl7.org/fhir/serialNumber
 */
var serialNumber = 'http://hl7.org/fhir/serialNumber';
/**
 * Consent
 *
 * A record of a healthcare consumer’s  choices  or choices made on their behalf by a third party, which permits or denies identified recipient(s) or recipient role(s) to perform one or more actions within a given policy context, for specific purposes and periods of time.
 *
 * http://hl7.org/fhir/Consent
 */
var Consent = 'http://hl7.org/fhir/Consent';
/**
 * _resourceType
 *
 * (Modified) Subscription.filterBy.resourceType
 *
 * http://hl7.org/fhir/_resourceType
 */
var _resourceType = 'http://hl7.org/fhir/_resourceType';
/**
 * outcomeMeasure
 *
 * ResearchStudy.outcomeMeasure: An "outcome measure", "endpoint", "effect measure" or "measure of effect" is a specific measurement or observation used to quantify the effect of experimental variables on the participants in a study, or for observational studies, to describe patterns of diseases or traits or associations with exposures, risk factors or treatment.
 *
 * http://hl7.org/fhir/outcomeMeasure
 */
var outcomeMeasure = 'http://hl7.org/fhir/outcomeMeasure';
/**
 * purpose
 *
 * Requirements.purpose: Explanation of why this Requirements is needed and why it has been designed as it has.
 *
 * http://hl7.org/fhir/purpose
 */
var purpose = 'http://hl7.org/fhir/purpose';
/**
 * DiagnosticReportSupportingInfoComponent
 *
 * DiagnosticReportSupportingInfoComponent: This backbone element contains supporting information that was used in the creation of the report not included in the results already included in the report.
 *
 * http://hl7.org/fhir/DiagnosticReportSupportingInfoComponent
 */
var DiagnosticReportSupportingInfoComponent = 'http://hl7.org/fhir/DiagnosticReportSupportingInfoComponent';
/**
 * Citation
 *
 * The Citation Resource enables reference to any knowledge artifact for purposes of identification and attribution. The Citation Resource supports existing reference structures and developing publication practices such as versioning, expressing complex contributorship roles, and referencing computable resources.
 *
 * http://hl7.org/fhir/Citation
 */
var Citation = 'http://hl7.org/fhir/Citation';
/**
 * _serviced
 *
 * (Modified) Invoice.lineItem.serviced
 *
 * http://hl7.org/fhir/_serviced
 */
var _serviced = 'http://hl7.org/fhir/_serviced';
/**
 * performer
 *
 * Procedure.performer: Indicates who or what performed the procedure and how they were involved.
 *
 * http://hl7.org/fhir/performer
 */
var performer = 'http://hl7.org/fhir/performer';
/**
 * _stratifier
 *
 * (Modified) MeasureReport.group.stratifier
 *
 * http://hl7.org/fhir/_stratifier
 */
var _stratifier = 'http://hl7.org/fhir/_stratifier';
/**
 * InvoiceParticipantComponent
 *
 * InvoiceParticipantComponent: Indicates who or what performed or participated in the charged service.
 *
 * http://hl7.org/fhir/InvoiceParticipantComponent
 */
var InvoiceParticipantComponent = 'http://hl7.org/fhir/InvoiceParticipantComponent';
/**
 * requiredBehavior
 *
 * PlanDefinition.action.requiredBehavior: Defines the required behavior for the action.
 *
 * http://hl7.org/fhir/requiredBehavior
 */
var requiredBehavior = 'http://hl7.org/fhir/requiredBehavior';
/**
 * _oralDiet
 *
 * (Modified) NutritionOrder.oralDiet
 *
 * http://hl7.org/fhir/_oralDiet
 */
var _oralDiet = 'http://hl7.org/fhir/_oralDiet';
/**
 * monday
 *
 * Appointment.recurrenceTemplate.weeklyTemplate.monday: Indicates that recurring appointments should occur on Mondays.
 *
 * http://hl7.org/fhir/monday
 */
var monday = 'http://hl7.org/fhir/monday';
/**
 * MedicationRequestDispenseRequestComponent
 *
 * MedicationRequestDispenseRequestComponent: Indicates the specific details for the dispense or medication supply part of a medication request (also known as a Medication Prescription or Medication Order).  Note that this information is not always sent with the order.  There may be in some settings (e.g. hospitals) institutional or system support for completing the dispense details in the pharmacy department.
 *
 * http://hl7.org/fhir/MedicationRequestDispenseRequestComponent
 */
var MedicationRequestDispenseRequestComponent = 'http://hl7.org/fhir/MedicationRequestDispenseRequestComponent';
/**
 * _subJurisdiction
 *
 * (Modified) DeviceDefinition.packaging.packaging.udiDeviceIdentifier.marketDistribution.subJurisdiction
 *
 * http://hl7.org/fhir/_subJurisdiction
 */
var _subJurisdiction = 'http://hl7.org/fhir/_subJurisdiction';
/**
 * _interactant
 *
 * (Modified) ClinicalUseDefinition.interaction.interactant
 *
 * http://hl7.org/fhir/_interactant
 */
var _interactant = 'http://hl7.org/fhir/_interactant';
/**
 * _admitSource
 *
 * (Modified) Encounter.admission.admitSource
 *
 * http://hl7.org/fhir/_admitSource
 */
var _admitSource = 'http://hl7.org/fhir/_admitSource';
/**
 * TargetElement
 *
 * ConceptMapGroupComponent.SourceElement.TargetElement: A concept from the target value set that this concept maps to.
 *
 * http://hl7.org/fhir/TargetElement
 */
var TargetElement = 'http://hl7.org/fhir/TargetElement';
/**
 * _given
 *
 * (Modified) HumanName.given
 *
 * http://hl7.org/fhir/_given
 */
var _given = 'http://hl7.org/fhir/_given';
/**
 * _recorder
 *
 * (Modified) Procedure.recorder
 *
 * http://hl7.org/fhir/_recorder
 */
var _recorder = 'http://hl7.org/fhir/_recorder';
/**
 * hasPart
 *
 * DeviceDefinition.hasPart: A device that is part (for example a component) of the present device.
 *
 * http://hl7.org/fhir/hasPart
 */
var hasPart = 'http://hl7.org/fhir/hasPart';
/**
 * _cancellationDate
 *
 * (Modified) Appointment.cancellationDate
 *
 * http://hl7.org/fhir/_cancellationDate
 */
var _cancellationDate = 'http://hl7.org/fhir/_cancellationDate';
/**
 * supplements
 *
 * CodeSystem.supplements: The canonical URL of the code system that this code system supplement is adding designations and properties to.
 *
 * http://hl7.org/fhir/supplements
 */
var supplements = 'http://hl7.org/fhir/supplements';
/**
 * constraint
 *
 * SearchParameter.constraint: FHIRPath expression that defines/sets a complex constraint for when this SearchParameter is applicable.
 *
 * http://hl7.org/fhir/constraint
 */
var constraint = 'http://hl7.org/fhir/constraint';
/**
 * total
 *
 * ValueSet.expansion.total: The total number of concepts in the expansion. If the number of concept nodes in this resource is less than the stated number, then the server can return more using the offset parameter.
 *
 * http://hl7.org/fhir/total
 */
var total = 'http://hl7.org/fhir/total';
/**
 * outcome
 *
 * Goal.outcome: Identifies the change (or lack of change) at the point when the status of the goal is assessed.
 *
 * http://hl7.org/fhir/outcome
 */
var outcome = 'http://hl7.org/fhir/outcome';
/**
 * sampleSize
 *
 * Evidence.statistic.sampleSize: Number of samples in the statistic.
 *
 * http://hl7.org/fhir/sampleSize
 */
var sampleSize = 'http://hl7.org/fhir/sampleSize';
/**
 * ContributorshipSummary
 *
 * CitationCitedArtifactComponent.CitationCitedArtifactContributorshipComponent.ContributorshipSummary: Used to record a display of the author/contributor list without separate data element for each list member.
 *
 * http://hl7.org/fhir/ContributorshipSummary
 */
var ContributorshipSummary = 'http://hl7.org/fhir/ContributorshipSummary';
/**
 * PrimitiveType
 *
 * The base type for all re-useable types defined that have a simple property.
 *
 * http://hl7.org/fhir/PrimitiveType
 */
var PrimitiveType = 'http://hl7.org/fhir/PrimitiveType';
/**
 * caloricDensity
 *
 * NutritionOrder.enteralFormula.caloricDensity: The amount of energy (calories) that the formula should provide per specified volume, typically per mL or fluid oz.  For example, an infant may require a formula that provides 24 calories per fluid ounce or an adult may require an enteral formula that provides 1.5 calorie/mL.
 *
 * http://hl7.org/fhir/caloricDensity
 */
var caloricDensity = 'http://hl7.org/fhir/caloricDensity';
/**
 * MedicationKnowledgeStorageGuidelineEnvironmentalSettingComponent
 *
 * MedicationKnowledgeStorageGuidelineComponent.MedicationKnowledgeStorageGuidelineEnvironmentalSettingComponent: Describes a setting/value on the environment for the adequate storage of the medication and other substances.  Environment settings may involve temperature, humidity, or exposure to light.
 *
 * http://hl7.org/fhir/MedicationKnowledgeStorageGuidelineEnvironmentalSettingComponent
 */
var MedicationKnowledgeStorageGuidelineEnvironmentalSettingComponent = 'http://hl7.org/fhir/MedicationKnowledgeStorageGuidelineEnvironmentalSettingComponent';
/**
 * _clinicalUseIssue
 *
 * (Modified) MedicationKnowledge.clinicalUseIssue
 *
 * http://hl7.org/fhir/_clinicalUseIssue
 */
var _clinicalUseIssue = 'http://hl7.org/fhir/_clinicalUseIssue';
/**
 * LinkageItemComponent
 *
 * LinkageItemComponent: Identifies which record considered as the reference to the same real-world occurrence as well as how the items should be evaluated within the collection of linked items.
 *
 * http://hl7.org/fhir/LinkageItemComponent
 */
var LinkageItemComponent = 'http://hl7.org/fhir/LinkageItemComponent';
/**
 * AdministrableProductDefinitionRouteOfAdministrationComponent
 *
 * AdministrableProductDefinitionRouteOfAdministrationComponent: The path by which the product is taken into or makes contact with the body. In some regions this is referred to as the licenced or approved route. RouteOfAdministration cannot be used when the 'formOf' product already uses MedicinalProductDefinition.route (and vice versa).
 *
 * http://hl7.org/fhir/AdministrableProductDefinitionRouteOfAdministrationComponent
 */
var AdministrableProductDefinitionRouteOfAdministrationComponent = 'http://hl7.org/fhir/AdministrableProductDefinitionRouteOfAdministrationComponent';
/**
 * _conditionalUpdate
 *
 * (Modified) CapabilityStatement.rest.resource.conditionalUpdate
 *
 * http://hl7.org/fhir/_conditionalUpdate
 */
var _conditionalUpdate = 'http://hl7.org/fhir/_conditionalUpdate';
/**
 * _publisher
 *
 * (Modified) ImplementationGuide.publisher
 *
 * http://hl7.org/fhir/_publisher
 */
var _publisher = 'http://hl7.org/fhir/_publisher';
/**
 * MolecularSequenceRelativeStartingSequenceComponent
 *
 * MolecularSequenceRelativeComponent.MolecularSequenceRelativeStartingSequenceComponent: A sequence that is used as a starting sequence to describe variants that are present in a sequence analyzed.
 *
 * http://hl7.org/fhir/MolecularSequenceRelativeStartingSequenceComponent
 */
var MolecularSequenceRelativeStartingSequenceComponent = 'http://hl7.org/fhir/MolecularSequenceRelativeStartingSequenceComponent';
/**
 * _validator
 *
 * (Modified) VerificationResult.validator
 *
 * http://hl7.org/fhir/_validator
 */
var _validator = 'http://hl7.org/fhir/_validator';
/**
 * _inactive
 *
 * (Modified) ValueSet.expansion.contains.contains.inactive
 *
 * http://hl7.org/fhir/_inactive
 */
var _inactive = 'http://hl7.org/fhir/_inactive';
/**
 * AppointmentResponse
 *
 * A reply to an appointment request for a patient and/or practitioner(s), such as a confirmation or rejection.
 *
 * http://hl7.org/fhir/AppointmentResponse
 */
var AppointmentResponse = 'http://hl7.org/fhir/AppointmentResponse';
/**
 * _molecularFormula
 *
 * (Modified) SubstanceDefinition.structure.molecularFormula
 *
 * http://hl7.org/fhir/_molecularFormula
 */
var _molecularFormula = 'http://hl7.org/fhir/_molecularFormula';
/**
 * payload
 *
 * Endpoint.payload: The set of payloads that are provided/available at this endpoint.
 *
 * http://hl7.org/fhir/payload
 */
var payload = 'http://hl7.org/fhir/payload';
/**
 * subSite
 *
 * ExplanationOfBenefit.addItem.bodySite.subSite: A region or surface of the bodySite, e.g. limb region or tooth surface(s).
 *
 * http://hl7.org/fhir/subSite
 */
var subSite = 'http://hl7.org/fhir/subSite';
/**
 * _sort
 *
 * (Modified) DataRequirement.sort
 *
 * http://hl7.org/fhir/_sort
 */
var _sort = 'http://hl7.org/fhir/_sort';
/**
 * TestScriptOriginComponent
 *
 * TestScriptOriginComponent: An abstract server used in operations within this test script in the origin element.
 *
 * http://hl7.org/fhir/TestScriptOriginComponent
 */
var TestScriptOriginComponent = 'http://hl7.org/fhir/TestScriptOriginComponent';
/**
 * _allergyIntolerance
 *
 * (Modified) NutritionOrder.allergyIntolerance
 *
 * http://hl7.org/fhir/_allergyIntolerance
 */
var _allergyIntolerance = 'http://hl7.org/fhir/_allergyIntolerance';
/**
 * _identityCertificate
 *
 * (Modified) VerificationResult.validator.identityCertificate
 *
 * http://hl7.org/fhir/_identityCertificate
 */
var _identityCertificate = 'http://hl7.org/fhir/_identityCertificate';
/**
 * _additional
 *
 * (Modified) ElementDefinition.binding.additional
 *
 * http://hl7.org/fhir/_additional
 */
var _additional = 'http://hl7.org/fhir/_additional';
/**
 * _assurance
 *
 * (Modified) Person.link.assurance
 *
 * http://hl7.org/fhir/_assurance
 */
var _assurance = 'http://hl7.org/fhir/_assurance';
/**
 * _careManager
 *
 * (Modified) EpisodeOfCare.careManager
 *
 * http://hl7.org/fhir/_careManager
 */
var _careManager = 'http://hl7.org/fhir/_careManager';
/**
 * ImageRegion2D
 *
 * ImagingSelectionInstanceComponent.ImageRegion2D: Each imaging selection instance or frame list might includes an image region, specified by a region type and a set of 2D coordinates.
 *        If the parent imagingSelection.instance contains a subset element of type frame, the image region applies to all frames in the subset list.
 *
 * http://hl7.org/fhir/ImageRegion2D
 */
var ImageRegion2D = 'http://hl7.org/fhir/ImageRegion2D';
/**
 * forecastReason
 *
 * ImmunizationRecommendation.recommendation.forecastReason: The reason for the assigned forecast status.
 *
 * http://hl7.org/fhir/forecastReason
 */
var forecastReason = 'http://hl7.org/fhir/forecastReason';
/**
 * supplement
 *
 * NutritionOrder.supplement: Oral nutritional products given in order to add further nutritional value to the patient's diet.
 *
 * http://hl7.org/fhir/supplement
 */
var supplement = 'http://hl7.org/fhir/supplement';
/**
 * _nutrient
 *
 * (Modified) NutritionProduct.nutrient
 *
 * http://hl7.org/fhir/_nutrient
 */
var _nutrient = 'http://hl7.org/fhir/_nutrient';
/**
 * _sugar
 *
 * (Modified) SubstanceNucleicAcid.subunit.sugar
 *
 * http://hl7.org/fhir/_sugar
 */
var _sugar = 'http://hl7.org/fhir/_sugar';
/**
 * entryReference
 *
 * EvidenceReport.section.section.entryReference: A reference to the actual resource from which the narrative in the section is derived.
 *
 * http://hl7.org/fhir/entryReference
 */
var entryReference = 'http://hl7.org/fhir/entryReference';
/**
 * _citedMedium
 *
 * (Modified) Citation.citedArtifact.publicationForm.citedMedium
 *
 * http://hl7.org/fhir/_citedMedium
 */
var _citedMedium = 'http://hl7.org/fhir/_citedMedium';
/**
 * MeasureSupplementalDataComponent
 *
 * MeasureSupplementalDataComponent: The supplemental data criteria for the measure report, specified as either the name of a valid CQL expression within a referenced library, or a valid FHIR Resource Path.
 *
 * http://hl7.org/fhir/MeasureSupplementalDataComponent
 */
var MeasureSupplementalDataComponent = 'http://hl7.org/fhir/MeasureSupplementalDataComponent';
/**
 * input
 *
 * StructureMap.group.input: A name assigned to an instance of data. The instance must be provided when the mapping is invoked.
 *
 * http://hl7.org/fhir/input
 */
var input = 'http://hl7.org/fhir/input';
/**
 * ManufacturedItemDefinition
 *
 * The definition and characteristics of a medicinal manufactured item, such as a tablet or capsule, as contained in a packaged medicinal product.
 *
 * http://hl7.org/fhir/ManufacturedItemDefinition
 */
var ManufacturedItemDefinition = 'http://hl7.org/fhir/ManufacturedItemDefinition';
/**
 * Prism
 *
 * VisionPrescriptionLensSpecificationComponent.Prism: Allows for adjustment on two axis.
 *
 * http://hl7.org/fhir/Prism
 */
var Prism = 'http://hl7.org/fhir/Prism';
/**
 * GroupCharacteristicComponent
 *
 * GroupCharacteristicComponent: Identifies traits whose presence r absence is shared by members of the group.
 *
 * http://hl7.org/fhir/GroupCharacteristicComponent
 */
var GroupCharacteristicComponent = 'http://hl7.org/fhir/GroupCharacteristicComponent';
/**
 * _qualifier
 *
 * (Modified) BodyStructure.excludedStructure.qualifier
 *
 * http://hl7.org/fhir/_qualifier
 */
var _qualifier = 'http://hl7.org/fhir/_qualifier';
/**
 * GraphDefinition
 *
 * A formal computable definition of a graph of resources - that is, a coherent set of resources that form a graph by following references. The Graph Definition resource defines a set and makes rules about the set.
 *
 * http://hl7.org/fhir/GraphDefinition
 */
var GraphDefinition = 'http://hl7.org/fhir/GraphDefinition';
/**
 * _BiologicallyDerivedProduct
 *
 * (Modified) BiologicallyDerivedProduct
 *
 * http://hl7.org/fhir/_BiologicallyDerivedProduct
 */
var _BiologicallyDerivedProduct = 'http://hl7.org/fhir/_BiologicallyDerivedProduct';
/**
 * _Procedure
 *
 * (Modified) Procedure
 *
 * http://hl7.org/fhir/_Procedure
 */
var _Procedure = 'http://hl7.org/fhir/_Procedure';
/**
 * _receivedTime
 *
 * (Modified) Specimen.receivedTime
 *
 * http://hl7.org/fhir/_receivedTime
 */
var _receivedTime = 'http://hl7.org/fhir/_receivedTime';
/**
 * quantity
 *
 * ArtifactAssessment.content.component.quantity: A quantitative rating of the artifact.
 *
 * http://hl7.org/fhir/quantity
 */
var quantity = 'http://hl7.org/fhir/quantity';
/**
 * _linkId
 *
 * (Modified) Contract.term.offer.linkId
 *
 * http://hl7.org/fhir/_linkId
 */
var _linkId = 'http://hl7.org/fhir/_linkId';
/**
 * ManufacturedItemDefinitionComponentComponentComponentComponent
 *
 * A component that this component contains or is made from.
 *
 * http://hl7.org/fhir/ManufacturedItemDefinitionComponentComponentComponentComponent
 */
var ManufacturedItemDefinitionComponentComponentComponentComponent = 'http://hl7.org/fhir/ManufacturedItemDefinitionComponentComponentComponentComponent';
/**
 * _prescriber
 *
 * (Modified) VisionPrescription.prescriber
 *
 * http://hl7.org/fhir/_prescriber
 */
var _prescriber = 'http://hl7.org/fhir/_prescriber';
/**
 * EvidenceReportSubjectCharacteristicComponent
 *
 * EvidenceReportSubjectComponent.EvidenceReportSubjectCharacteristicComponent: Characteristic.
 *
 * http://hl7.org/fhir/EvidenceReportSubjectCharacteristicComponent
 */
var EvidenceReportSubjectCharacteristicComponent = 'http://hl7.org/fhir/EvidenceReportSubjectCharacteristicComponent';
/**
 * hasSeverity
 *
 * ConditionDefinition.hasSeverity: Whether Severity is appropriate to collect for this condition.
 *
 * http://hl7.org/fhir/hasSeverity
 */
var hasSeverity = 'http://hl7.org/fhir/hasSeverity';
/**
 * _estimate
 *
 * (Modified) Account.balance.estimate
 *
 * http://hl7.org/fhir/_estimate
 */
var _estimate = 'http://hl7.org/fhir/_estimate';
/**
 * certainty
 *
 * Evidence.certainty: Assessment of certainty, confidence in the estimates, or quality of the evidence.
 *
 * http://hl7.org/fhir/certainty
 */
var certainty = 'http://hl7.org/fhir/certainty';
/**
 * _billingStatus
 *
 * (Modified) Account.billingStatus
 *
 * http://hl7.org/fhir/_billingStatus
 */
var _billingStatus = 'http://hl7.org/fhir/_billingStatus';
/**
 * ContactDetail
 *
 * Specifies contact information for a person or organization.
 *
 * http://hl7.org/fhir/ContactDetail
 */
var ContactDetail = 'http://hl7.org/fhir/ContactDetail';
/**
 * sessionKey
 *
 * VirtualServiceDetail.sessionKey: Session Key required by the virtual service.
 *
 * http://hl7.org/fhir/sessionKey
 */
var sessionKey = 'http://hl7.org/fhir/sessionKey';
/**
 * calibration
 *
 * DeviceMetric.calibration: Describes the calibrations that have been performed or that are required to be performed.
 *
 * http://hl7.org/fhir/calibration
 */
var calibration = 'http://hl7.org/fhir/calibration';
/**
 * _literal
 *
 * (Modified) MolecularSequence.literal
 *
 * http://hl7.org/fhir/_literal
 */
var _literal = 'http://hl7.org/fhir/_literal';
/**
 * ConditionDefinitionQuestionnaireComponent
 *
 * ConditionDefinitionQuestionnaireComponent: Questionnaire for this condition.
 *
 * http://hl7.org/fhir/ConditionDefinitionQuestionnaireComponent
 */
var ConditionDefinitionQuestionnaireComponent = 'http://hl7.org/fhir/ConditionDefinitionQuestionnaireComponent';
/**
 * _dateTime
 *
 * (Modified) NutritionOrder.dateTime
 *
 * http://hl7.org/fhir/_dateTime
 */
var _dateTime = 'http://hl7.org/fhir/_dateTime';
/**
 * CoverageEligibilityRequest
 *
 * The CoverageEligibilityRequest provides patient and insurance coverage information to an insurer for them to respond, in the form of an CoverageEligibilityResponse, with information regarding whether the stated coverage is valid and in-force and optionally to provide the insurance details of the policy.
 *
 * http://hl7.org/fhir/CoverageEligibilityRequest
 */
var CoverageEligibilityRequest = 'http://hl7.org/fhir/CoverageEligibilityRequest';
/**
 * _repeatUnitAmountType
 *
 * (Modified) SubstancePolymer.repeat.repeatUnitAmountType
 *
 * http://hl7.org/fhir/_repeatUnitAmountType
 */
var _repeatUnitAmountType = 'http://hl7.org/fhir/_repeatUnitAmountType';
/**
 * pediatricUseIndicator
 *
 * MedicinalProductDefinition.pediatricUseIndicator: If authorised for use in children, or infants, neonates etc.
 *
 * http://hl7.org/fhir/pediatricUseIndicator
 */
var pediatricUseIndicator = 'http://hl7.org/fhir/pediatricUseIndicator';
/**
 * SampledData
 *
 * A series of measurements taken by a device, with upper and lower limits. There may be more than one dimension in the data.
 *
 * http://hl7.org/fhir/SampledData
 */
var SampledData = 'http://hl7.org/fhir/SampledData';
/**
 * attester
 *
 * DocumentReference.attester: A participant who has authenticated the accuracy of the document.
 *
 * http://hl7.org/fhir/attester
 */
var attester = 'http://hl7.org/fhir/attester';
/**
 * originatingAppointment
 *
 * Appointment.originatingAppointment: The originating appointment in a recurring set of related appointments.
 *
 * http://hl7.org/fhir/originatingAppointment
 */
var originatingAppointment = 'http://hl7.org/fhir/originatingAppointment';
/**
 * progress
 *
 * ResearchSubject.progress: The current state (status) of the subject and resons for status change where appropriate.
 *
 * http://hl7.org/fhir/progress
 */
var progress = 'http://hl7.org/fhir/progress';
/**
 * _frequencyMax
 *
 * (Modified) Timing.repeat.frequencyMax
 *
 * http://hl7.org/fhir/_frequencyMax
 */
var _frequencyMax = 'http://hl7.org/fhir/_frequencyMax';
/**
 * measureScore
 *
 * MeasureReport.group.stratifier.stratum.measureScore
 *
 * http://hl7.org/fhir/measureScore
 */
var measureScore = 'http://hl7.org/fhir/measureScore';
/**
 * InsurancePlanCoverageComponent
 *
 * InsurancePlanCoverageComponent: Details about the coverage offered by the insurance product.
 *
 * http://hl7.org/fhir/InsurancePlanCoverageComponent
 */
var InsurancePlanCoverageComponent = 'http://hl7.org/fhir/InsurancePlanCoverageComponent';
/**
 * Evidence
 *
 * The Evidence Resource provides a machine-interpretable expression of an evidence concept including the evidence variables (e.g., population, exposures/interventions, comparators, outcomes, measured variables, confounding variables), the statistics, and the certainty of this evidence.
 *
 * http://hl7.org/fhir/Evidence
 */
var Evidence = 'http://hl7.org/fhir/Evidence';
/**
 * _operationalStatus
 *
 * (Modified) Location.operationalStatus
 *
 * http://hl7.org/fhir/_operationalStatus
 */
var _operationalStatus = 'http://hl7.org/fhir/_operationalStatus';
/**
 * ImagingSelectionPerformerComponent
 *
 * ImagingSelectionPerformerComponent: Selector of the instances – human or machine.
 *
 * http://hl7.org/fhir/ImagingSelectionPerformerComponent
 */
var ImagingSelectionPerformerComponent = 'http://hl7.org/fhir/ImagingSelectionPerformerComponent';
/**
 * restriction
 *
 * Transport.restriction: If the Transport.focus is a request resource and the transport is seeking fulfillment (i.e. is asking for the request to be actioned), this element identifies any limitations on what parts of the referenced request should be actioned.
 *
 * http://hl7.org/fhir/restriction
 */
var restriction = 'http://hl7.org/fhir/restriction';
/**
 * _issues
 *
 * (Modified) Bundle.issues
 *
 * http://hl7.org/fhir/_issues
 */
var _issues = 'http://hl7.org/fhir/_issues';
/**
 * dose
 *
 * MedicationAdministration.dosage.dose: The amount of the medication given at one administration event.   Use this value when the administration is essentially an instantaneous event such as a swallowing a tablet or giving an injection.
 *
 * http://hl7.org/fhir/dose
 */
var dose = 'http://hl7.org/fhir/dose';
/**
 * _updateCreate
 *
 * (Modified) CapabilityStatement.rest.resource.updateCreate
 *
 * http://hl7.org/fhir/_updateCreate
 */
var _updateCreate = 'http://hl7.org/fhir/_updateCreate';
/**
 * _supportingInfo
 *
 * (Modified) Procedure.supportingInfo
 *
 * http://hl7.org/fhir/_supportingInfo
 */
var _supportingInfo = 'http://hl7.org/fhir/_supportingInfo';
/**
 * warningOnly
 *
 * TestScript.test.action.assert.warningOnly: Whether or not the test execution will produce a warning only on error for this assert.
 *
 * http://hl7.org/fhir/warningOnly
 */
var warningOnly = 'http://hl7.org/fhir/warningOnly';
/**
 * _coverage
 *
 * (Modified) Account.coverage.coverage
 *
 * http://hl7.org/fhir/_coverage
 */
var _coverage = 'http://hl7.org/fhir/_coverage';
/**
 * informationSequence
 *
 * ExplanationOfBenefit.item.informationSequence: Exceptions, special conditions and supporting information applicable for this service or product.
 *
 * http://hl7.org/fhir/informationSequence
 */
var informationSequence = 'http://hl7.org/fhir/informationSequence';
/**
 * netContent
 *
 * InventoryItem.netContent: Net content or amount present in the item.
 *
 * http://hl7.org/fhir/netContent
 */
var netContent = 'http://hl7.org/fhir/netContent';
/**
 * representation
 *
 * SubstanceDefinition.structure.representation: A depiction of the structure of the substance.
 *
 * http://hl7.org/fhir/representation
 */
var representation = 'http://hl7.org/fhir/representation';
/**
 * _typeMode
 *
 * (Modified) StructureMap.group.typeMode
 *
 * http://hl7.org/fhir/_typeMode
 */
var _typeMode = 'http://hl7.org/fhir/_typeMode';
/**
 * subProperty
 *
 * ValueSet.expansion.contains.contains.property.subProperty: A subproperty value for this concept.
 *
 * http://hl7.org/fhir/subProperty
 */
var subProperty = 'http://hl7.org/fhir/subProperty';
/**
 * _subscription
 *
 * (Modified) SubscriptionStatus.subscription
 *
 * http://hl7.org/fhir/_subscription
 */
var _subscription = 'http://hl7.org/fhir/_subscription';
/**
 * Library
 *
 * The Library resource is a general-purpose container for knowledge asset definitions. It can be used to describe and expose existing knowledge assets such as logic libraries and information model descriptions, as well as to describe a collection of knowledge assets.
 *
 * http://hl7.org/fhir/Library
 */
var Library = 'http://hl7.org/fhir/Library';
/**
 * DeviceMetricCalibrationComponent
 *
 * DeviceMetricCalibrationComponent: Describes the calibrations that have been performed or that are required to be performed.
 *
 * http://hl7.org/fhir/DeviceMetricCalibrationComponent
 */
var DeviceMetricCalibrationComponent = 'http://hl7.org/fhir/DeviceMetricCalibrationComponent';
/**
 * implicated
 *
 * DetectedIssue.implicated: Indicates the resource representing the current activity or proposed activity that is potentially problematic.
 *
 * http://hl7.org/fhir/implicated
 */
var implicated = 'http://hl7.org/fhir/implicated';
/**
 * _actualGroup
 *
 * (Modified) ResearchStudy.recruitment.actualGroup
 *
 * http://hl7.org/fhir/_actualGroup
 */
var _actualGroup = 'http://hl7.org/fhir/_actualGroup';
/**
 * _SubstanceProtein
 *
 * (Modified) SubstanceProtein
 *
 * http://hl7.org/fhir/_SubstanceProtein
 */
var _SubstanceProtein = 'http://hl7.org/fhir/_SubstanceProtein';
/**
 * _capabilities
 *
 * (Modified) TestScript.metadata.capability.capabilities
 *
 * http://hl7.org/fhir/_capabilities
 */
var _capabilities = 'http://hl7.org/fhir/_capabilities';
/**
 * _associatedParty
 *
 * (Modified) ResearchStudy.associatedParty
 *
 * http://hl7.org/fhir/_associatedParty
 */
var _associatedParty = 'http://hl7.org/fhir/_associatedParty';
/**
 * _supplementalData
 *
 * (Modified) MeasureReport.supplementalData
 *
 * http://hl7.org/fhir/_supplementalData
 */
var _supplementalData = 'http://hl7.org/fhir/_supplementalData';
/**
 * _program
 *
 * (Modified) Immunization.programEligibility.program
 *
 * http://hl7.org/fhir/_program
 */
var _program = 'http://hl7.org/fhir/_program';
/**
 * offeredIn
 *
 * HealthcareService.offeredIn: When the HealthcareService is representing a specific, schedulable service, the availableIn property can refer to a generic service.
 *
 * http://hl7.org/fhir/offeredIn
 */
var offeredIn = 'http://hl7.org/fhir/offeredIn';
/**
 * TerminologyCapabilitiesCodeSystemComponent
 *
 * TerminologyCapabilitiesCodeSystemComponent: Identifies a code system that is supported by the server. If there is a no code system URL, then this declares the general assumptions a client can make about support for any CodeSystem resource.
 *
 * http://hl7.org/fhir/TerminologyCapabilitiesCodeSystemComponent
 */
var TerminologyCapabilitiesCodeSystemComponent = 'http://hl7.org/fhir/TerminologyCapabilitiesCodeSystemComponent';
/**
 * multipleBirth
 *
 * Patient.multipleBirth
 *
 * http://hl7.org/fhir/multipleBirth
 */
var multipleBirth = 'http://hl7.org/fhir/multipleBirth';
/**
 * _replacedSequence
 *
 * (Modified) MolecularSequence.relative.edit.replacedSequence
 *
 * http://hl7.org/fhir/_replacedSequence
 */
var _replacedSequence = 'http://hl7.org/fhir/_replacedSequence';
/**
 * disclaimer
 *
 * Measure.disclaimer: Notices and disclaimers regarding the use of the measure or related to intellectual property (such as code systems) referenced by the measure.
 *
 * http://hl7.org/fhir/disclaimer
 */
var disclaimer = 'http://hl7.org/fhir/disclaimer';
/**
 * InsurancePlan
 *
 * Details of a Health Insurance product/plan provided by an organization.
 *
 * http://hl7.org/fhir/InsurancePlan
 */
var InsurancePlan = 'http://hl7.org/fhir/InsurancePlan';
/**
 * _installDate
 *
 * (Modified) Device.version.installDate
 *
 * http://hl7.org/fhir/_installDate
 */
var _installDate = 'http://hl7.org/fhir/_installDate';
/**
 * _extends
 *
 * (Modified) StructureMap.group.extends
 *
 * http://hl7.org/fhir/_extends
 */
var _extends = 'http://hl7.org/fhir/_extends';
/**
 * fundsReserve
 *
 * ExplanationOfBenefit.fundsReserve: A code, used only on a response to a preauthorization, to indicate whether the benefits payable have been reserved and for whom.
 *
 * http://hl7.org/fhir/fundsReserve
 */
var fundsReserve = 'http://hl7.org/fhir/fundsReserve';
/**
 * assigner
 *
 * Identifier.assigner: Organization that issued/manages the identifier.
 *
 * http://hl7.org/fhir/assigner
 */
var assigner = 'http://hl7.org/fhir/assigner';
/**
 * SpecimenProcessingComponent
 *
 * SpecimenProcessingComponent: Details concerning processing and processing steps for the specimen.
 *
 * http://hl7.org/fhir/SpecimenProcessingComponent
 */
var SpecimenProcessingComponent = 'http://hl7.org/fhir/SpecimenProcessingComponent';
/**
 * occurred
 *
 * Provenance.occurred
 *
 * http://hl7.org/fhir/occurred
 */
var occurred = 'http://hl7.org/fhir/occurred';
/**
 * _lockedDate
 *
 * (Modified) ValueSet.compose.lockedDate
 *
 * http://hl7.org/fhir/_lockedDate
 */
var _lockedDate = 'http://hl7.org/fhir/_lockedDate';
/**
 * GenomicStudyAnalysisPerformerComponent
 *
 * GenomicStudyAnalysisComponent.GenomicStudyAnalysisPerformerComponent: Performer for the analysis event.
 *
 * http://hl7.org/fhir/GenomicStudyAnalysisPerformerComponent
 */
var GenomicStudyAnalysisPerformerComponent = 'http://hl7.org/fhir/GenomicStudyAnalysisPerformerComponent';
/**
 * _lowNumerator
 *
 * (Modified) RatioRange.lowNumerator
 *
 * http://hl7.org/fhir/_lowNumerator
 */
var _lowNumerator = 'http://hl7.org/fhir/_lowNumerator';
/**
 * _classifier
 *
 * (Modified) ResearchStudy.classifier
 *
 * http://hl7.org/fhir/_classifier
 */
var _classifier = 'http://hl7.org/fhir/_classifier';
/**
 * resultsInterpreter
 *
 * DiagnosticReport.resultsInterpreter: The practitioner or organization that is responsible for the report's conclusions and interpretations.
 *
 * http://hl7.org/fhir/resultsInterpreter
 */
var resultsInterpreter = 'http://hl7.org/fhir/resultsInterpreter';
/**
 * _limit
 *
 * (Modified) Permission.rule.limit
 *
 * http://hl7.org/fhir/_limit
 */
var _limit = 'http://hl7.org/fhir/_limit';
/**
 * _serviceProvider
 *
 * (Modified) Encounter.serviceProvider
 *
 * http://hl7.org/fhir/_serviceProvider
 */
var _serviceProvider = 'http://hl7.org/fhir/_serviceProvider';
/**
 * patientInstruction
 *
 * ServiceRequest.patientInstruction: Instructions in terms that are understood by the patient or consumer.
 *
 * http://hl7.org/fhir/patientInstruction
 */
var patientInstruction = 'http://hl7.org/fhir/patientInstruction';
/**
 * binding
 *
 * OperationDefinition.parameter.part.binding: Binds to a value set if this parameter is coded (code, Coding, CodeableConcept).
 *
 * http://hl7.org/fhir/binding
 */
var binding = 'http://hl7.org/fhir/binding';
/**
 * recurrenceType
 *
 * Appointment.recurrenceTemplate.recurrenceType: How often the appointment series should recur.
 *
 * http://hl7.org/fhir/recurrenceType
 */
var recurrenceType = 'http://hl7.org/fhir/recurrenceType';
/**
 * during
 *
 * Availability.notAvailableTime.during: Service not available during this period.
 *
 * http://hl7.org/fhir/during
 */
var during = 'http://hl7.org/fhir/during';
/**
 * capability
 *
 * TestScript.metadata.capability: Capabilities that must exist and are assumed to function correctly on the FHIR server being tested.
 *
 * http://hl7.org/fhir/capability
 */
var capability = 'http://hl7.org/fhir/capability';
/**
 * Substance
 *
 * A homogeneous material with a definite composition.
 *
 * http://hl7.org/fhir/Substance
 */
var Substance = 'http://hl7.org/fhir/Substance';
/**
 * suspectEntity
 *
 * AdverseEvent.suspectEntity: Describes the entity that is suspected to have caused the adverse event.
 *
 * http://hl7.org/fhir/suspectEntity
 */
var suspectEntity = 'http://hl7.org/fhir/suspectEntity';
/**
 * QuestionnaireItemInitialComponent
 *
 * QuestionnaireItemComponentItem.QuestionnaireItemInitialComponent: One or more values that should be pre-populated in the answer when initially rendering the questionnaire for user input.
 *
 * http://hl7.org/fhir/QuestionnaireItemInitialComponent
 */
var QuestionnaireItemInitialComponent = 'http://hl7.org/fhir/QuestionnaireItemInitialComponent';
/**
 * occurrenceDate
 *
 * AppointmentResponse.occurrenceDate: The original date within a recurring request. This could be used in place of the recurrenceId to be more direct (or where the template is provided through the simple list of dates in `Appointment.occurrenceDate`).
 *
 * http://hl7.org/fhir/occurrenceDate
 */
var occurrenceDate = 'http://hl7.org/fhir/occurrenceDate';
/**
 * monthlyTemplate
 *
 * Appointment.recurrenceTemplate.monthlyTemplate: Information about monthly recurring appointments.
 *
 * http://hl7.org/fhir/monthlyTemplate
 */
var monthlyTemplate = 'http://hl7.org/fhir/monthlyTemplate';
/**
 * supportingInformation
 *
 * DeviceDispense.supportingInformation: Additional information that supports the device being dispensed.
 *
 * http://hl7.org/fhir/supportingInformation
 */
var supportingInformation = 'http://hl7.org/fhir/supportingInformation';
/**
 * authorizationRequired
 *
 * CoverageEligibilityResponse.insurance.item.authorizationRequired: A boolean flag indicating whether a preauthorization is required prior to actual service delivery.
 *
 * http://hl7.org/fhir/authorizationRequired
 */
var authorizationRequired = 'http://hl7.org/fhir/authorizationRequired';
/**
 * _versionReference
 *
 * (Modified) ExampleScenario.process.step.process.step.operation.request.versionReference
 *
 * http://hl7.org/fhir/_versionReference
 */
var _versionReference = 'http://hl7.org/fhir/_versionReference';
/**
 * ImmunizationRecommendationRecommendationComponent
 *
 * ImmunizationRecommendationRecommendationComponent: Vaccine administration recommendations.
 *
 * http://hl7.org/fhir/ImmunizationRecommendationRecommendationComponent
 */
var ImmunizationRecommendationRecommendationComponent = 'http://hl7.org/fhir/ImmunizationRecommendationRecommendationComponent';
/**
 * _measurementPoint
 *
 * (Modified) Ingredient.substance.strength.referenceStrength.measurementPoint
 *
 * http://hl7.org/fhir/_measurementPoint
 */
var _measurementPoint = 'http://hl7.org/fhir/_measurementPoint';
/**
 * batch
 *
 * Medication.batch: Information that only applies to packages (not products).
 *
 * http://hl7.org/fhir/batch
 */
var batch = 'http://hl7.org/fhir/batch';
/**
 * _include
 *
 * (Modified) ValueSet.compose.include
 *
 * http://hl7.org/fhir/_include
 */
var _include = 'http://hl7.org/fhir/_include';
/**
 * ValueSetComposeIncludeFilterComponent
 *
 * ValueSetComposeComponentInclude.ValueSetComposeIncludeFilterComponent: Select concepts by specifying a matching criterion based on the properties (including relationships) defined by the system, or on filters defined by the system. If multiple filters are specified within the include, they SHALL all be true.
 *
 * http://hl7.org/fhir/ValueSetComposeIncludeFilterComponent
 */
var ValueSetComposeIncludeFilterComponent = 'http://hl7.org/fhir/ValueSetComposeIncludeFilterComponent';
/**
 * subcomponent
 *
 * Evidence.certainty.subcomponent: A domain or subdomain of certainty.
 *
 * http://hl7.org/fhir/subcomponent
 */
var subcomponent = 'http://hl7.org/fhir/subcomponent';
/**
 * _DetectedIssue
 *
 * (Modified) DetectedIssue
 *
 * http://hl7.org/fhir/_DetectedIssue
 */
var _DetectedIssue = 'http://hl7.org/fhir/_DetectedIssue';
/**
 * _GuidanceResponse
 *
 * (Modified) GuidanceResponse
 *
 * http://hl7.org/fhir/_GuidanceResponse
 */
var _GuidanceResponse = 'http://hl7.org/fhir/_GuidanceResponse';
/**
 * _participantType
 *
 * (Modified) AppointmentResponse.participantType
 *
 * http://hl7.org/fhir/_participantType
 */
var _participantType = 'http://hl7.org/fhir/_participantType';
/**
 * _division
 *
 * (Modified) BiologicallyDerivedProduct.division
 *
 * http://hl7.org/fhir/_division
 */
var _division = 'http://hl7.org/fhir/_division';
/**
 * _section
 *
 * (Modified) EvidenceReport.section.section
 *
 * http://hl7.org/fhir/_section
 */
var _section = 'http://hl7.org/fhir/_section';
/**
 * _MedicationAdministration
 *
 * (Modified) MedicationAdministration
 *
 * http://hl7.org/fhir/_MedicationAdministration
 */
var _MedicationAdministration = 'http://hl7.org/fhir/_MedicationAdministration';
/**
 * _outcomeMeasure
 *
 * (Modified) ResearchStudy.outcomeMeasure
 *
 * http://hl7.org/fhir/_outcomeMeasure
 */
var _outcomeMeasure = 'http://hl7.org/fhir/_outcomeMeasure';
/**
 * PackagingDistributor
 *
 * DeviceDefinitionPackagingComponentPackaging.PackagingDistributor: An organization that distributes the packaged device.
 *
 * http://hl7.org/fhir/PackagingDistributor
 */
var PackagingDistributor = 'http://hl7.org/fhir/PackagingDistributor';
/**
 * _serviceType
 *
 * (Modified) Slot.serviceType
 *
 * http://hl7.org/fhir/_serviceType
 */
var _serviceType = 'http://hl7.org/fhir/_serviceType';
/**
 * _subjectReport
 *
 * (Modified) MeasureReport.group.stratifier.stratum.population.subjectReport
 *
 * http://hl7.org/fhir/_subjectReport
 */
var _subjectReport = 'http://hl7.org/fhir/_subjectReport';
/**
 * _initialFill
 *
 * (Modified) MedicationRequest.dispenseRequest.initialFill
 *
 * http://hl7.org/fhir/_initialFill
 */
var _initialFill = 'http://hl7.org/fhir/_initialFill';
/**
 * _administrableDoseForm
 *
 * (Modified) AdministrableProductDefinition.administrableDoseForm
 *
 * http://hl7.org/fhir/_administrableDoseForm
 */
var _administrableDoseForm = 'http://hl7.org/fhir/_administrableDoseForm';
/**
 * areaOfHybridisation
 *
 * SubstanceNucleicAcid.areaOfHybridisation: The area of hybridisation shall be described if applicable for double stranded RNA or DNA. The number associated with the subunit followed by the number associated to the residue shall be specified in increasing order. The underscore “” shall be used as separator as follows: “Subunitnumber Residue”.
 *
 * http://hl7.org/fhir/areaOfHybridisation
 */
var areaOfHybridisation = 'http://hl7.org/fhir/areaOfHybridisation';
/**
 * subjectType
 *
 * Questionnaire.subjectType: The types of subjects that can be the subject of responses created for the questionnaire.
 *
 * http://hl7.org/fhir/subjectType
 */
var subjectType = 'http://hl7.org/fhir/subjectType';
/**
 * device
 *
 * Specimen.container.device: The device resource for the the container holding the specimen. If the container is in a holder then the referenced device will point to a parent device.
 *
 * http://hl7.org/fhir/device
 */
var device = 'http://hl7.org/fhir/device';
/**
 * AddedItem
 *
 * ExplanationOfBenefit.AddedItem: The first-tier service adjudications for payor added product or service lines.
 *
 * http://hl7.org/fhir/AddedItem
 */
var AddedItem = 'http://hl7.org/fhir/AddedItem';
/**
 * _region
 *
 * (Modified) ResearchStudy.region
 *
 * http://hl7.org/fhir/_region
 */
var _region = 'http://hl7.org/fhir/_region';
/**
 * MedicationKnowledgeRegulatorySubstitutionComponent
 *
 * MedicationKnowledgeRegulatoryComponent.MedicationKnowledgeRegulatorySubstitutionComponent: Specifies if changes are allowed when dispensing a medication from a regulatory perspective.
 *
 * http://hl7.org/fhir/MedicationKnowledgeRegulatorySubstitutionComponent
 */
var MedicationKnowledgeRegulatorySubstitutionComponent = 'http://hl7.org/fhir/MedicationKnowledgeRegulatorySubstitutionComponent';
/**
 * MeasureReportGroupComponent
 *
 * MeasureReportGroupComponent: The results of the calculation, one for each population group in the measure.
 *
 * http://hl7.org/fhir/MeasureReportGroupComponent
 */
var MeasureReportGroupComponent = 'http://hl7.org/fhir/MeasureReportGroupComponent';
/**
 * _accident
 *
 * (Modified) ExplanationOfBenefit.accident
 *
 * http://hl7.org/fhir/_accident
 */
var _accident = 'http://hl7.org/fhir/_accident';
/**
 * endRelationship
 *
 * RequestOrchestration.action.relatedAction.endRelationship: The relationship of the end of this action to the related action.
 *
 * http://hl7.org/fhir/endRelationship
 */
var endRelationship = 'http://hl7.org/fhir/endRelationship';
/**
 * structure
 *
 * SubstanceDefinition.structure: Structural information.
 *
 * http://hl7.org/fhir/structure
 */
var structure = 'http://hl7.org/fhir/structure';
/**
 * _library
 *
 * (Modified) PlanDefinition.library
 *
 * http://hl7.org/fhir/_library
 */
var _library = 'http://hl7.org/fhir/_library';
/**
 * _descriptionSummary
 *
 * (Modified) ResearchStudy.descriptionSummary
 *
 * http://hl7.org/fhir/_descriptionSummary
 */
var _descriptionSummary = 'http://hl7.org/fhir/_descriptionSummary';
/**
 * baseCitation
 *
 * Citation.citedArtifact.part.baseCitation: The citation for the full article or artifact.
 *
 * http://hl7.org/fhir/baseCitation
 */
var baseCitation = 'http://hl7.org/fhir/baseCitation';
/**
 * definitionId
 *
 * EvidenceVariable.characteristic.definitionByCombination.characteristic.definitionId: Defines the characteristic using id.
 *
 * http://hl7.org/fhir/definitionId
 */
var definitionId = 'http://hl7.org/fhir/definitionId';
/**
 * _coordinateSystem
 *
 * (Modified) MolecularSequence.relative.coordinateSystem
 *
 * http://hl7.org/fhir/_coordinateSystem
 */
var _coordinateSystem = 'http://hl7.org/fhir/_coordinateSystem';
/**
 * characteristicType
 *
 * InventoryItem.characteristic.characteristicType: The type of characteristic that is being defined.
 *
 * http://hl7.org/fhir/characteristicType
 */
var characteristicType = 'http://hl7.org/fhir/characteristicType';
/**
 * _entry
 *
 * (Modified) List.entry
 *
 * http://hl7.org/fhir/_entry
 */
var _entry = 'http://hl7.org/fhir/_entry';
/**
 * imageRegion2D
 *
 * ImagingSelection.instance.imageRegion2D: Each imaging selection instance or frame list might includes an image region, specified by a region type and a set of 2D coordinates.
 *        If the parent imagingSelection.instance contains a subset element of type frame, the image region applies to all frames in the subset list.
 *
 * http://hl7.org/fhir/imageRegion2D
 */
var imageRegion2D = 'http://hl7.org/fhir/imageRegion2D';
/**
 * _DeviceDefinition
 *
 * (Modified) DeviceDefinition
 *
 * http://hl7.org/fhir/_DeviceDefinition
 */
var _DeviceDefinition = 'http://hl7.org/fhir/_DeviceDefinition';
/**
 * conclusionCode
 *
 * DiagnosticReport.conclusionCode: One or more codes that represent the summary conclusion (interpretation/impression) of the diagnostic report.
 *
 * http://hl7.org/fhir/conclusionCode
 */
var conclusionCode = 'http://hl7.org/fhir/conclusionCode';
/**
 * BiologicallyDerivedProductDispensePerformerComponent
 *
 * BiologicallyDerivedProductDispensePerformerComponent: Indicates who or what performed an action.
 *
 * http://hl7.org/fhir/BiologicallyDerivedProductDispensePerformerComponent
 */
var BiologicallyDerivedProductDispensePerformerComponent = 'http://hl7.org/fhir/BiologicallyDerivedProductDispensePerformerComponent';
/**
 * _caloricDensity
 *
 * (Modified) NutritionOrder.enteralFormula.caloricDensity
 *
 * http://hl7.org/fhir/_caloricDensity
 */
var _caloricDensity = 'http://hl7.org/fhir/_caloricDensity';
/**
 * ManufacturedItemDefinitionComponentComponent
 *
 * ManufacturedItemDefinitionComponentComponent: Physical parts of the manufactured item, that it is intrisically made from. This is distinct from the ingredients that are part of its chemical makeup.
 *
 * http://hl7.org/fhir/ManufacturedItemDefinitionComponentComponent
 */
var ManufacturedItemDefinitionComponentComponent = 'http://hl7.org/fhir/ManufacturedItemDefinitionComponentComponent';
/**
 * _focal
 *
 * (Modified) ExplanationOfBenefit.insurance.focal
 *
 * http://hl7.org/fhir/_focal
 */
var _focal = 'http://hl7.org/fhir/_focal';
/**
 * indication
 *
 * MedicinalProductDefinition.indication: Description of indication(s) for this product, used when structured indications are not required. In cases where structured indications are required, they are captured using the ClinicalUseDefinition resource. An indication is a medical situation for which using the product is appropriate.
 *
 * http://hl7.org/fhir/indication
 */
var indication = 'http://hl7.org/fhir/indication';
/**
 * _AllergyIntolerance
 *
 * (Modified) AllergyIntolerance
 *
 * http://hl7.org/fhir/_AllergyIntolerance
 */
var _AllergyIntolerance = 'http://hl7.org/fhir/_AllergyIntolerance';
/**
 * _publishedIn
 *
 * (Modified) Citation.citedArtifact.publicationForm.publishedIn
 *
 * http://hl7.org/fhir/_publishedIn
 */
var _publishedIn = 'http://hl7.org/fhir/_publishedIn';
/**
 * partOf
 *
 * BiologicallyDerivedProductDispense.partOf: A larger event of which this particular event is a component.
 *
 * http://hl7.org/fhir/partOf
 */
var partOf = 'http://hl7.org/fhir/partOf';
/**
 * _initialSelected
 *
 * (Modified) Questionnaire.item.item.answerOption.initialSelected
 *
 * http://hl7.org/fhir/_initialSelected
 */
var _initialSelected = 'http://hl7.org/fhir/_initialSelected';
/**
 * _key
 *
 * (Modified) Requirements.statement.key
 *
 * http://hl7.org/fhir/_key
 */
var _key = 'http://hl7.org/fhir/_key';
/**
 * backCurve
 *
 * VisionPrescription.lensSpecification.backCurve: Back curvature measured in millimetres.
 *
 * http://hl7.org/fhir/backCurve
 */
var backCurve = 'http://hl7.org/fhir/backCurve';
/**
 * _path
 *
 * (Modified) RequestOrchestration.action.dynamicValue.path
 *
 * http://hl7.org/fhir/_path
 */
var _path = 'http://hl7.org/fhir/_path';
/**
 * definitionUri
 *
 * ChargeItem.definitionUri: References the (external) source of pricing information, rules of application for the code this ChargeItem uses.
 *
 * http://hl7.org/fhir/definitionUri
 */
var definitionUri = 'http://hl7.org/fhir/definitionUri';
/**
 * ExplanationOfBenefitItemReviewOutcomeComponent
 *
 * ExplanationOfBenefit.Item.ExplanationOfBenefitItemReviewOutcomeComponent: The high-level results of the adjudication if adjudication has been performed.
 *
 * http://hl7.org/fhir/ExplanationOfBenefitItemReviewOutcomeComponent
 */
var ExplanationOfBenefitItemReviewOutcomeComponent = 'http://hl7.org/fhir/ExplanationOfBenefitItemReviewOutcomeComponent';
/**
 * DetectedIssueMitigationComponent
 *
 * DetectedIssueMitigationComponent: Indicates an action that has been taken or is committed to reduce or eliminate the likelihood of the risk identified by the detected issue from manifesting.  Can also reflect an observation of known mitigating factors that may reduce/eliminate the need for any action.
 *
 * http://hl7.org/fhir/DetectedIssueMitigationComponent
 */
var DetectedIssueMitigationComponent = 'http://hl7.org/fhir/DetectedIssueMitigationComponent';
/**
 * _lastOccurrenceDate
 *
 * (Modified) Appointment.recurrenceTemplate.lastOccurrenceDate
 *
 * http://hl7.org/fhir/_lastOccurrenceDate
 */
var _lastOccurrenceDate = 'http://hl7.org/fhir/_lastOccurrenceDate';
/**
 * _enableWhen
 *
 * (Modified) Questionnaire.item.item.enableWhen
 *
 * http://hl7.org/fhir/_enableWhen
 */
var _enableWhen = 'http://hl7.org/fhir/_enableWhen';
/**
 * time
 *
 * DocumentReference.attester.time: When the document was attested by the party.
 *
 * http://hl7.org/fhir/time
 */
var time = 'http://hl7.org/fhir/time';
/**
 * MedicinalProductDefinitionNameUsageComponent
 *
 * MedicinalProductDefinitionNameComponent.MedicinalProductDefinitionNameUsageComponent: Country and jurisdiction where the name applies, and associated language.
 *
 * http://hl7.org/fhir/MedicinalProductDefinitionNameUsageComponent
 */
var MedicinalProductDefinitionNameUsageComponent = 'http://hl7.org/fhir/MedicinalProductDefinitionNameUsageComponent';
/**
 * ChargeItemDefinitionApplicabilityComponent
 *
 * ChargeItemDefinitionApplicabilityComponent: Expressions that describe applicability criteria for the billing code.
 *
 * http://hl7.org/fhir/ChargeItemDefinitionApplicabilityComponent
 */
var ChargeItemDefinitionApplicabilityComponent = 'http://hl7.org/fhir/ChargeItemDefinitionApplicabilityComponent';
/**
 * InventoryItemCharacteristicComponent
 *
 * InventoryItemCharacteristicComponent: The descriptive or identifying characteristics of the item.
 *
 * http://hl7.org/fhir/InventoryItemCharacteristicComponent
 */
var InventoryItemCharacteristicComponent = 'http://hl7.org/fhir/InventoryItemCharacteristicComponent';
/**
 * _dischargeDisposition
 *
 * (Modified) Encounter.admission.dischargeDisposition
 *
 * http://hl7.org/fhir/_dischargeDisposition
 */
var _dischargeDisposition = 'http://hl7.org/fhir/_dischargeDisposition';
/**
 * isModifierReason
 *
 * ElementDefinition.isModifierReason: Explains how that element affects the interpretation of the resource or element that contains it.
 *
 * http://hl7.org/fhir/isModifierReason
 */
var isModifierReason = 'http://hl7.org/fhir/isModifierReason';
/**
 * StructureDefinitionContextComponent
 *
 * StructureDefinitionContextComponent: Identifies the types of resource or data type elements to which the extension can be applied. For more guidance on using the 'context' element, see the [defining extensions page](defining-extensions.html#context).
 *
 * http://hl7.org/fhir/StructureDefinitionContextComponent
 */
var StructureDefinitionContextComponent = 'http://hl7.org/fhir/StructureDefinitionContextComponent';
/**
 * _forecastReason
 *
 * (Modified) ImmunizationRecommendation.recommendation.forecastReason
 *
 * http://hl7.org/fhir/_forecastReason
 */
var _forecastReason = 'http://hl7.org/fhir/_forecastReason';
/**
 * SubstanceDefinitionMoietyComponent
 *
 * SubstanceDefinitionMoietyComponent: Moiety, for structural modifications.
 *
 * http://hl7.org/fhir/SubstanceDefinitionMoietyComponent
 */
var SubstanceDefinitionMoietyComponent = 'http://hl7.org/fhir/SubstanceDefinitionMoietyComponent';
/**
 * _step
 *
 * (Modified) ExampleScenario.process.step.alternative.step
 *
 * http://hl7.org/fhir/_step
 */
var _step = 'http://hl7.org/fhir/_step';
/**
 * rest
 *
 * CapabilityStatement.rest: A definition of the restful capabilities of the solution, if any.
 *
 * http://hl7.org/fhir/rest
 */
var rest = 'http://hl7.org/fhir/rest';
/**
 * issuer
 *
 * DeviceDefinition.packaging.packaging.udiDeviceIdentifier.issuer: The organization that assigns the identifier algorithm.
 *
 * http://hl7.org/fhir/issuer
 */
var issuer = 'http://hl7.org/fhir/issuer';
/**
 * _nutritionProduct
 *
 * (Modified) NutritionIntake.consumedItem.nutritionProduct
 *
 * http://hl7.org/fhir/_nutritionProduct
 */
var _nutritionProduct = 'http://hl7.org/fhir/_nutritionProduct';
/**
 * SubstancePolymer
 *
 * Properties of a substance specific to it being a polymer.
 *
 * http://hl7.org/fhir/SubstancePolymer
 */
var SubstancePolymer = 'http://hl7.org/fhir/SubstancePolymer';
/**
 * ValueSetComposeComponent
 *
 * ValueSetComposeComponent: A set of criteria that define the contents of the value set by including or excluding codes selected from the specified code system(s) that the value set draws from. This is also known as the Content Logical Definition (CLD).
 *
 * http://hl7.org/fhir/ValueSetComposeComponent
 */
var ValueSetComposeComponent = 'http://hl7.org/fhir/ValueSetComposeComponent';
/**
 * _doseNumber
 *
 * (Modified) ImmunizationRecommendation.recommendation.doseNumber
 *
 * http://hl7.org/fhir/_doseNumber
 */
var _doseNumber = 'http://hl7.org/fhir/_doseNumber';
/**
 * SubstanceDefinitionNameComponent
 *
 * SubstanceDefinitionNameComponent: Names applicable to this substance.
 *
 * http://hl7.org/fhir/SubstanceDefinitionNameComponent
 */
var SubstanceDefinitionNameComponent = 'http://hl7.org/fhir/SubstanceDefinitionNameComponent';
/**
 * derivedFromUri
 *
 * SpecimenDefinition.derivedFromUri: The URL pointing to an externally-defined type of specimen, guideline or other definition that is adhered to in whole or in part by this definition.
 *
 * http://hl7.org/fhir/derivedFromUri
 */
var derivedFromUri = 'http://hl7.org/fhir/derivedFromUri';
/**
 * _startParam
 *
 * (Modified) CompartmentDefinition.resource.startParam
 *
 * http://hl7.org/fhir/_startParam
 */
var _startParam = 'http://hl7.org/fhir/_startParam';
/**
 * _attribute
 *
 * (Modified) ConceptMap.group.element.target.product.attribute
 *
 * http://hl7.org/fhir/_attribute
 */
var _attribute = 'http://hl7.org/fhir/_attribute';
/**
 * _extraDetails
 *
 * (Modified) HealthcareService.extraDetails
 *
 * http://hl7.org/fhir/_extraDetails
 */
var _extraDetails = 'http://hl7.org/fhir/_extraDetails';
/**
 * _accessionIdentifier
 *
 * (Modified) Specimen.accessionIdentifier
 *
 * http://hl7.org/fhir/_accessionIdentifier
 */
var _accessionIdentifier = 'http://hl7.org/fhir/_accessionIdentifier';
/**
 * _entryReference
 *
 * (Modified) EvidenceReport.section.section.entryReference
 *
 * http://hl7.org/fhir/_entryReference
 */
var _entryReference = 'http://hl7.org/fhir/_entryReference';
/**
 * Parameters
 *
 * This resource is used to pass information into and back from an operation (whether invoked directly from REST or within a messaging environment).  It is not persisted or allowed to be referenced by other resources except as described in the definition of the Parameters resource.
 *
 * http://hl7.org/fhir/Parameters
 */
var Parameters = 'http://hl7.org/fhir/Parameters';
/**
 * ChargeItem
 *
 * The resource ChargeItem describes the provision of healthcare provider products for a certain patient, therefore referring not only to the product, but containing in addition details of the provision, like date, time, amounts and participating organizations and persons. Main Usage of the ChargeItem is to enable the billing process and internal cost allocation.
 *
 * http://hl7.org/fhir/ChargeItem
 */
var ChargeItem = 'http://hl7.org/fhir/ChargeItem';
/**
 * _uid
 *
 * (Modified) ImagingStudy.series.instance.uid
 *
 * http://hl7.org/fhir/_uid
 */
var _uid = 'http://hl7.org/fhir/_uid';
/**
 * chain
 *
 * SearchParameter.chain: Contains the names of any search parameters which may be chained to the containing search parameter. Chained parameters may be added to search parameters of type reference and specify that resources will only be returned if they contain a reference to a resource which matches the chained parameter value. Values for this field should be drawn from SearchParameter.code for a parameter on the target resource type.
 *
 * http://hl7.org/fhir/chain
 */
var chain = 'http://hl7.org/fhir/chain';
/**
 * _bodySite
 *
 * (Modified) Claim.item.bodySite
 *
 * http://hl7.org/fhir/_bodySite
 */
var _bodySite = 'http://hl7.org/fhir/_bodySite';
/**
 * qualification
 *
 * Practitioner.qualification: The official qualifications, certifications, accreditations, training, licenses (and other types of educations/skills/capabilities) that authorize or otherwise pertain to the provision of care by the practitioner.

For example, a medical license issued by a medical board of licensure authorizing the practitioner to practice medicine within a certain locality.
 *
 * http://hl7.org/fhir/qualification
 */
var qualification = 'http://hl7.org/fhir/qualification';
/**
 * yearInterval
 *
 * Appointment.recurrenceTemplate.yearlyTemplate.yearInterval: Appointment recurs every nth year.
 *
 * http://hl7.org/fhir/yearInterval
 */
var yearInterval = 'http://hl7.org/fhir/yearInterval';
/**
 * _developmentStage
 *
 * (Modified) SubstanceSourceMaterial.developmentStage
 *
 * http://hl7.org/fhir/_developmentStage
 */
var _developmentStage = 'http://hl7.org/fhir/_developmentStage';
/**
 * riskAdjustment
 *
 * Measure.riskAdjustment: A description of the risk adjustment factors that may impact the resulting score for the measure and how they may be accounted for when computing and reporting measure results.
 *
 * http://hl7.org/fhir/riskAdjustment
 */
var riskAdjustment = 'http://hl7.org/fhir/riskAdjustment';
/**
 * _estimatedAge
 *
 * (Modified) FamilyMemberHistory.estimatedAge
 *
 * http://hl7.org/fhir/_estimatedAge
 */
var _estimatedAge = 'http://hl7.org/fhir/_estimatedAge';
/**
 * RequirementsStatementComponent
 *
 * RequirementsStatementComponent: The actual statement of requirement, in markdown format.
 *
 * http://hl7.org/fhir/RequirementsStatementComponent
 */
var RequirementsStatementComponent = 'http://hl7.org/fhir/RequirementsStatementComponent';
/**
 * _intendedRoute
 *
 * (Modified) MedicationKnowledge.definitional.intendedRoute
 *
 * http://hl7.org/fhir/_intendedRoute
 */
var _intendedRoute = 'http://hl7.org/fhir/_intendedRoute';
/**
 * score
 *
 * TestReport.score: The final score (percentage of tests passed) resulting from the execution of the TestScript.
 *
 * http://hl7.org/fhir/score
 */
var score = 'http://hl7.org/fhir/score';
/**
 * DeviceRequestParameterComponent
 *
 * DeviceRequestParameterComponent: Specific parameters for the ordered item.  For example, the prism value for lenses.
 *
 * http://hl7.org/fhir/DeviceRequestParameterComponent
 */
var DeviceRequestParameterComponent = 'http://hl7.org/fhir/DeviceRequestParameterComponent';
/**
 * _diseaseSymptomProcedure
 *
 * (Modified) ClinicalUseDefinition.indication.diseaseSymptomProcedure
 *
 * http://hl7.org/fhir/_diseaseSymptomProcedure
 */
var _diseaseSymptomProcedure = 'http://hl7.org/fhir/_diseaseSymptomProcedure';
/**
 * _validationProcess
 *
 * (Modified) VerificationResult.validationProcess
 *
 * http://hl7.org/fhir/_validationProcess
 */
var _validationProcess = 'http://hl7.org/fhir/_validationProcess';
/**
 * ExampleScenarioProcessComponent
 *
 * ExampleScenarioProcessComponent: A group of operations that represents a significant step within a scenario.
 *
 * http://hl7.org/fhir/ExampleScenarioProcessComponent
 */
var ExampleScenarioProcessComponent = 'http://hl7.org/fhir/ExampleScenarioProcessComponent';
/**
 * _timestamp
 *
 * (Modified) ValueSet.expansion.timestamp
 *
 * http://hl7.org/fhir/_timestamp
 */
var _timestamp = 'http://hl7.org/fhir/_timestamp';
/**
 * supportedProfile
 *
 * CapabilityStatement.rest.resource.supportedProfile: A list of profiles representing different use cases the system hosts/produces. A supported profile is a statement about the functionality of the data and services provided by the server (or the client) for supported use cases. For example, a system can define and declare multiple Observation profiles for laboratory observations, vital sign observations, etc. By declaring supported profiles, systems provide a way to determine whether individual resources are conformant. See further discussion in [Using Profiles](profiling.html#profile-uses).
 *
 * http://hl7.org/fhir/supportedProfile
 */
var supportedProfile = 'http://hl7.org/fhir/supportedProfile';
/**
 * TestReportSetupActionAssertComponent
 *
 * TestReportSetupComponent.SetupAction.TestReportSetupActionAssertComponent: The results of the assertion performed on the previous operations.
 *
 * http://hl7.org/fhir/TestReportSetupActionAssertComponent
 */
var TestReportSetupActionAssertComponent = 'http://hl7.org/fhir/TestReportSetupActionAssertComponent';
/**
 * _label
 *
 * (Modified) Citation.citedArtifact.relatesTo.label
 *
 * http://hl7.org/fhir/_label
 */
var _label = 'http://hl7.org/fhir/_label';
/**
 * _preparationInstruction
 *
 * (Modified) MedicationKnowledge.preparationInstruction
 *
 * http://hl7.org/fhir/_preparationInstruction
 */
var _preparationInstruction = 'http://hl7.org/fhir/_preparationInstruction';
/**
 * InventoryItemResponsibleOrganizationComponent
 *
 * InventoryItemResponsibleOrganizationComponent: Organization(s) responsible for the product.
 *
 * http://hl7.org/fhir/InventoryItemResponsibleOrganizationComponent
 */
var InventoryItemResponsibleOrganizationComponent = 'http://hl7.org/fhir/InventoryItemResponsibleOrganizationComponent';
/**
 * informationType
 *
 * ArtifactAssessment.content.component.informationType: The type of information this component of the content represents.
 *
 * http://hl7.org/fhir/informationType
 */
var informationType = 'http://hl7.org/fhir/informationType';
/**
 * BodyStructureIncludedStructure
 *
 * The anatomical location(s) or region(s) not occupied or represented by the specimen, lesion, or body structure.
 *
 * http://hl7.org/fhir/BodyStructureIncludedStructure
 */
var BodyStructureIncludedStructure = 'http://hl7.org/fhir/BodyStructureIncludedStructure';
/**
 * _requesterLinkId
 *
 * (Modified) Contract.term.group.action.requesterLinkId
 *
 * http://hl7.org/fhir/_requesterLinkId
 */
var _requesterLinkId = 'http://hl7.org/fhir/_requesterLinkId';
/**
 * PlanDefinition
 *
 * This resource allows for the definition of various types of plans as a sharable, consumable, and executable artifact. The resource is general enough to support the description of a broad range of clinical and non-clinical artifacts such as clinical decision support rules, order sets, protocols, and drug quality specifications.
 *
 * http://hl7.org/fhir/PlanDefinition
 */
var PlanDefinition = 'http://hl7.org/fhir/PlanDefinition';
/**
 * postConditions
 *
 * ExampleScenario.process.step.alternative.step.process.postConditions: Description of the final state of the actors, environment and data after the process has been successfully completed.
 *
 * http://hl7.org/fhir/postConditions
 */
var postConditions = 'http://hl7.org/fhir/postConditions';
/**
 * EvidenceVariableDefinitionComponent
 *
 * EvidenceVariableDefinitionComponent: Evidence variable such as population, exposure, or outcome.
 *
 * http://hl7.org/fhir/EvidenceVariableDefinitionComponent
 */
var EvidenceVariableDefinitionComponent = 'http://hl7.org/fhir/EvidenceVariableDefinitionComponent';
/**
 * _meaningWhenMissing
 *
 * (Modified) ElementDefinition.meaningWhenMissing
 *
 * http://hl7.org/fhir/_meaningWhenMissing
 */
var _meaningWhenMissing = 'http://hl7.org/fhir/_meaningWhenMissing';
/**
 * DeviceDispense
 *
 * Indicates that a device is to be or has been dispensed for a named person/patient.  This includes a description of the product (supply) provided and the instructions for using the device.
 *
 * http://hl7.org/fhir/DeviceDispense
 */
var DeviceDispense = 'http://hl7.org/fhir/DeviceDispense';
/**
 * _modelCharacteristic
 *
 * (Modified) Evidence.statistic.modelCharacteristic
 *
 * http://hl7.org/fhir/_modelCharacteristic
 */
var _modelCharacteristic = 'http://hl7.org/fhir/_modelCharacteristic';
/**
 * SetupAction
 *
 * TestScriptSetupComponent.SetupAction: Action would contain either an operation or an assertion.
 *
 * http://hl7.org/fhir/SetupAction
 */
var SetupAction = 'http://hl7.org/fhir/SetupAction';
/**
 * _studyDesign
 *
 * (Modified) ResearchStudy.studyDesign
 *
 * http://hl7.org/fhir/_studyDesign
 */
var _studyDesign = 'http://hl7.org/fhir/_studyDesign';
/**
 * _analysis
 *
 * (Modified) GenomicStudy.analysis
 *
 * http://hl7.org/fhir/_analysis
 */
var _analysis = 'http://hl7.org/fhir/_analysis';
/**
 * insurancePlan
 *
 * Coverage.insurancePlan: The insurance plan details, benefits and costs, which constitute this insurance coverage.
 *
 * http://hl7.org/fhir/insurancePlan
 */
var insurancePlan = 'http://hl7.org/fhir/insurancePlan';
/**
 * communicationRequest
 *
 * ClaimResponse.communicationRequest: Request for additional supporting or authorizing information.
 *
 * http://hl7.org/fhir/communicationRequest
 */
var communicationRequest = 'http://hl7.org/fhir/communicationRequest';
/**
 * specialty
 *
 * Appointment.specialty: The specialty of a practitioner that would be required to perform the service requested in this appointment.
 *
 * http://hl7.org/fhir/specialty
 */
var specialty = 'http://hl7.org/fhir/specialty';
/**
 * _artifact
 *
 * (Modified) TestScript.scope.artifact
 *
 * http://hl7.org/fhir/_artifact
 */
var _artifact = 'http://hl7.org/fhir/_artifact';
/**
 * chargeItemCode
 *
 * DeviceDefinition.chargeItem.chargeItemCode: The code or reference for the charge item.
 *
 * http://hl7.org/fhir/chargeItemCode
 */
var chargeItemCode = 'http://hl7.org/fhir/chargeItemCode';
/**
 * actuality
 *
 * AdverseEvent.actuality: Whether the event actually happened or was a near miss. Note that this is independent of whether anyone was affected or harmed or how severely.
 *
 * http://hl7.org/fhir/actuality
 */
var actuality = 'http://hl7.org/fhir/actuality';
/**
 * _maxParticipants
 *
 * (Modified) VirtualServiceDetail.maxParticipants
 *
 * http://hl7.org/fhir/_maxParticipants
 */
var _maxParticipants = 'http://hl7.org/fhir/_maxParticipants';
/**
 * _Basic
 *
 * (Modified) Basic
 *
 * http://hl7.org/fhir/_Basic
 */
var _Basic = 'http://hl7.org/fhir/_Basic';
/**
 * _example
 *
 * (Modified) ElementDefinition.example
 *
 * http://hl7.org/fhir/_example
 */
var _example = 'http://hl7.org/fhir/_example';
/**
 * _representation
 *
 * (Modified) SubstancePolymer.repeat.repeatUnit.structuralRepresentation.representation
 *
 * http://hl7.org/fhir/_representation
 */
var _representation = 'http://hl7.org/fhir/_representation';
/**
 * telecom
 *
 * ContactDetail.telecom: The contact details for the individual (if a name was provided) or the organization.
 *
 * http://hl7.org/fhir/telecom
 */
var telecom = 'http://hl7.org/fhir/telecom';
/**
 * EvidenceCertaintyComponentCertaintyCertainty
 *
 * A domain or subdomain of certainty.
 *
 * http://hl7.org/fhir/EvidenceCertaintyComponentCertaintyCertainty
 */
var EvidenceCertaintyComponentCertaintyCertainty = 'http://hl7.org/fhir/EvidenceCertaintyComponentCertaintyCertainty';
/**
 * _lastPerformed
 *
 * (Modified) VerificationResult.lastPerformed
 *
 * http://hl7.org/fhir/_lastPerformed
 */
var _lastPerformed = 'http://hl7.org/fhir/_lastPerformed';
/**
 * _legalState
 *
 * (Modified) Contract.legalState
 *
 * http://hl7.org/fhir/_legalState
 */
var _legalState = 'http://hl7.org/fhir/_legalState';
/**
 * _preAuthPeriod
 *
 * (Modified) ExplanationOfBenefit.item.detail.reviewOutcome.preAuthPeriod
 *
 * http://hl7.org/fhir/_preAuthPeriod
 */
var _preAuthPeriod = 'http://hl7.org/fhir/_preAuthPeriod';
/**
 * GraphDefinitionLinkComponent
 *
 * GraphDefinitionLinkComponent: Links this graph makes rules about.
 *
 * http://hl7.org/fhir/GraphDefinitionLinkComponent
 */
var GraphDefinitionLinkComponent = 'http://hl7.org/fhir/GraphDefinitionLinkComponent';
/**
 * workflow
 *
 * ExampleScenario.process.step.alternative.step.process.step.workflow: Indicates that the step is defined by a seaparate scenario instance.
 *
 * http://hl7.org/fhir/workflow
 */
var workflow = 'http://hl7.org/fhir/workflow';
/**
 * _incomplete
 *
 * (Modified) TerminologyCapabilities.expansion.incomplete
 *
 * http://hl7.org/fhir/_incomplete
 */
var _incomplete = 'http://hl7.org/fhir/_incomplete';
/**
 * _sphere
 *
 * (Modified) VisionPrescription.lensSpecification.sphere
 *
 * http://hl7.org/fhir/_sphere
 */
var _sphere = 'http://hl7.org/fhir/_sphere';
/**
 * _substanceDefinition
 *
 * (Modified) SubstanceDefinition.relationship.substanceDefinition
 *
 * http://hl7.org/fhir/_substanceDefinition
 */
var _substanceDefinition = 'http://hl7.org/fhir/_substanceDefinition';
/**
 * informationSource
 *
 * Immunization.informationSource: Typically the source of the data when the report of the immunization event is not based on information from the person who administered the vaccine.
 *
 * http://hl7.org/fhir/informationSource
 */
var informationSource = 'http://hl7.org/fhir/informationSource';
/**
 * _periodUnit
 *
 * (Modified) Timing.repeat.periodUnit
 *
 * http://hl7.org/fhir/_periodUnit
 */
var _periodUnit = 'http://hl7.org/fhir/_periodUnit';
/**
 * paymentIdentifier
 *
 * PaymentReconciliation.paymentIdentifier: Issuer's unique identifier for the payment instrument.
 *
 * http://hl7.org/fhir/paymentIdentifier
 */
var paymentIdentifier = 'http://hl7.org/fhir/paymentIdentifier';
/**
 * stratifier
 *
 * MeasureReport.group.stratifier: When a measure includes multiple stratifiers, there will be a stratifier group for each stratifier defined by the measure.
 *
 * http://hl7.org/fhir/stratifier
 */
var stratifier = 'http://hl7.org/fhir/stratifier';
/**
 * pause
 *
 * ExampleScenario.process.step.process.step.alternative.step.pause: If true, indicates that, following this step, there is a pause in the flow and the subsequent step will occur at some later time (triggered by some event).
 *
 * http://hl7.org/fhir/pause
 */
var pause = 'http://hl7.org/fhir/pause';
/**
 * _isActive
 *
 * (Modified) Medication.ingredient.isActive
 *
 * http://hl7.org/fhir/_isActive
 */
var _isActive = 'http://hl7.org/fhir/_isActive';
/**
 * _synonym
 *
 * (Modified) SubstanceDefinition.name.translation.synonym
 *
 * http://hl7.org/fhir/_synonym
 */
var _synonym = 'http://hl7.org/fhir/_synonym';
/**
 * _manifestation
 *
 * (Modified) Immunization.reaction.manifestation
 *
 * http://hl7.org/fhir/_manifestation
 */
var _manifestation = 'http://hl7.org/fhir/_manifestation';
/**
 * _control
 *
 * (Modified) Contract.term.group.securityLabel.control
 *
 * http://hl7.org/fhir/_control
 */
var _control = 'http://hl7.org/fhir/_control';
/**
 * RegulatedAuthorizationCaseComponentCase
 *
 * A regulatory submission from an organization to a regulator, as part of an assessing case. Multiple applications may occur over time, with more or different information to support or modify the submission or the authorization. The applications can be considered as steps within the longer running case or procedure for this authorization process.
 *
 * http://hl7.org/fhir/RegulatedAuthorizationCaseComponentCase
 */
var RegulatedAuthorizationCaseComponentCase = 'http://hl7.org/fhir/RegulatedAuthorizationCaseComponentCase';
/**
 * dosageInstruction
 *
 * MedicationRequest.dosageInstruction: Specific instructions for how the medication is to be used by the patient.
 *
 * http://hl7.org/fhir/dosageInstruction
 */
var dosageInstruction = 'http://hl7.org/fhir/dosageInstruction';
/**
 * _implicitRules
 *
 * (Modified) Resource.implicitRules
 *
 * http://hl7.org/fhir/_implicitRules
 */
var _implicitRules = 'http://hl7.org/fhir/_implicitRules';
/**
 * AvailabilityAvailableTimeComponent
 *
 * AvailabilityAvailableTimeComponent: Times the {item} is available.
 *
 * http://hl7.org/fhir/AvailabilityAvailableTimeComponent
 */
var AvailabilityAvailableTimeComponent = 'http://hl7.org/fhir/AvailabilityAvailableTimeComponent';
/**
 * SpecimenCollectionComponent
 *
 * SpecimenCollectionComponent: Details concerning the specimen collection.
 *
 * http://hl7.org/fhir/SpecimenCollectionComponent
 */
var SpecimenCollectionComponent = 'http://hl7.org/fhir/SpecimenCollectionComponent';
/**
 * regulatoryAuthority
 *
 * MedicationKnowledge.regulatory.regulatoryAuthority: The authority that is specifying the regulations.
 *
 * http://hl7.org/fhir/regulatoryAuthority
 */
var regulatoryAuthority = 'http://hl7.org/fhir/regulatoryAuthority';
/**
 * _EnrollmentRequest
 *
 * (Modified) EnrollmentRequest
 *
 * http://hl7.org/fhir/_EnrollmentRequest
 */
var _EnrollmentRequest = 'http://hl7.org/fhir/_EnrollmentRequest';
/**
 * hash
 *
 * Attachment.hash: The calculated hash of the data using SHA-1. Represented using base64.
 *
 * http://hl7.org/fhir/hash
 */
var hash = 'http://hl7.org/fhir/hash';
/**
 * marketDistribution
 *
 * DeviceDefinition.packaging.packaging.udiDeviceIdentifier.marketDistribution: Indicates where and when the device is available on the market.
 *
 * http://hl7.org/fhir/marketDistribution
 */
var marketDistribution = 'http://hl7.org/fhir/marketDistribution';
/**
 * countType
 *
 * InventoryReport.countType: Whether the report is about the current inventory count (snapshot) or a differential change in inventory (change).
 *
 * http://hl7.org/fhir/countType
 */
var countType = 'http://hl7.org/fhir/countType';
/**
 * _documentation
 *
 * (Modified) ParameterDefinition.documentation
 *
 * http://hl7.org/fhir/_documentation
 */
var _documentation = 'http://hl7.org/fhir/_documentation';
/**
 * association
 *
 * InventoryItem.association: Association with other items or products.
 *
 * http://hl7.org/fhir/association
 */
var association = 'http://hl7.org/fhir/association';
/**
 * _intendedJurisdiction
 *
 * (Modified) MedicationKnowledge.intendedJurisdiction
 *
 * http://hl7.org/fhir/_intendedJurisdiction
 */
var _intendedJurisdiction = 'http://hl7.org/fhir/_intendedJurisdiction';
/**
 * _recurrenceType
 *
 * (Modified) Appointment.recurrenceTemplate.recurrenceType
 *
 * http://hl7.org/fhir/_recurrenceType
 */
var _recurrenceType = 'http://hl7.org/fhir/_recurrenceType';
/**
 * when
 *
 * RiskAssessment.prediction.when
 *
 * http://hl7.org/fhir/when
 */
var when = 'http://hl7.org/fhir/when';
/**
 * form
 *
 * ClaimResponse.form: The actual form, by reference or inclusion, for printing the content or an EOB.
 *
 * http://hl7.org/fhir/form
 */
var form = 'http://hl7.org/fhir/form';
/**
 * _complete
 *
 * (Modified) Citation.citedArtifact.contributorship.complete
 *
 * http://hl7.org/fhir/_complete
 */
var _complete = 'http://hl7.org/fhir/_complete';
/**
 * _shortDoco
 *
 * (Modified) ElementDefinition.binding.additional.shortDoco
 *
 * http://hl7.org/fhir/_shortDoco
 */
var _shortDoco = 'http://hl7.org/fhir/_shortDoco';
/**
 * differential
 *
 * StructureDefinition.differential: A differential view is expressed relative to the base StructureDefinition - a statement of differences that it applies.
 *
 * http://hl7.org/fhir/differential
 */
var differential = 'http://hl7.org/fhir/differential';
/**
 * _occurrenceDate
 *
 * (Modified) AppointmentResponse.occurrenceDate
 *
 * http://hl7.org/fhir/_occurrenceDate
 */
var _occurrenceDate = 'http://hl7.org/fhir/_occurrenceDate';
/**
 * additional
 *
 * ElementDefinition.binding.additional: Additional bindings that help applications implementing this element. Additional bindings do not replace the main binding but provide more information and/or context.
 *
 * http://hl7.org/fhir/additional
 */
var additional = 'http://hl7.org/fhir/additional';
/**
 * canonical
 *
 * A URI that is a reference to a canonical URL on a FHIR resource
 *
 * http://hl7.org/fhir/canonical
 */
var canonical = 'http://hl7.org/fhir/canonical';
/**
 * _actualComparisonGroup
 *
 * (Modified) ResearchSubject.actualComparisonGroup
 *
 * http://hl7.org/fhir/_actualComparisonGroup
 */
var _actualComparisonGroup = 'http://hl7.org/fhir/_actualComparisonGroup';
/**
 * _requestor
 *
 * (Modified) PaymentReconciliation.requestor
 *
 * http://hl7.org/fhir/_requestor
 */
var _requestor = 'http://hl7.org/fhir/_requestor';
/**
 * CommunicationPayloadComponent
 *
 * CommunicationPayloadComponent: Text, attachment(s), or resource(s) that was communicated to the recipient.
 *
 * http://hl7.org/fhir/CommunicationPayloadComponent
 */
var CommunicationPayloadComponent = 'http://hl7.org/fhir/CommunicationPayloadComponent';
/**
 * AccountDiagnosisComponent
 *
 * AccountDiagnosisComponent: When using an account for billing a specific Encounter the set of diagnoses that are relevant for billing are stored here on the account where they are able to be sequenced appropriately prior to processing to produce claim(s).
 *
 * http://hl7.org/fhir/AccountDiagnosisComponent
 */
var AccountDiagnosisComponent = 'http://hl7.org/fhir/AccountDiagnosisComponent';
/**
 * _doseStatus
 *
 * (Modified) ImmunizationEvaluation.doseStatus
 *
 * http://hl7.org/fhir/_doseStatus
 */
var _doseStatus = 'http://hl7.org/fhir/_doseStatus';
/**
 * TestScriptTestComponent
 *
 * TestScriptTestComponent: A test in this script.
 *
 * http://hl7.org/fhir/TestScriptTestComponent
 */
var TestScriptTestComponent = 'http://hl7.org/fhir/TestScriptTestComponent';
/**
 * TaskOutputComponent
 *
 * TaskOutputComponent: Outputs produced by the Task.
 *
 * http://hl7.org/fhir/TaskOutputComponent
 */
var TaskOutputComponent = 'http://hl7.org/fhir/TaskOutputComponent';
/**
 * MeasureReport
 *
 * The MeasureReport resource contains the results of the calculation of a measure; and optionally a reference to the resources involved in that calculation.
 *
 * http://hl7.org/fhir/MeasureReport
 */
var MeasureReport = 'http://hl7.org/fhir/MeasureReport';
/**
 * producedFrom
 *
 * AdministrableProductDefinition.producedFrom: Indicates the specific manufactured items that are part of the 'formOf' product that are used in the preparation of this specific administrable form.  In some cases, an administrable form might use all of the items from the overall product (or there might only be one item), while in other cases, an administrable form might use only a subset of the items available in the overall product.  For example, an administrable form might involve combining a liquid and a powder available as part of an overall product, but not involve applying the also supplied cream.
 *
 * http://hl7.org/fhir/producedFrom
 */
var producedFrom = 'http://hl7.org/fhir/producedFrom';
/**
 * tuesday
 *
 * Appointment.recurrenceTemplate.weeklyTemplate.tuesday: Indicates that recurring appointments should occur on Tuesdays.
 *
 * http://hl7.org/fhir/tuesday
 */
var tuesday = 'http://hl7.org/fhir/tuesday';
/**
 * _sourceReference
 *
 * (Modified) Consent.sourceReference
 *
 * http://hl7.org/fhir/_sourceReference
 */
var _sourceReference = 'http://hl7.org/fhir/_sourceReference';
/**
 * crossReference
 *
 * MedicinalProductDefinition.crossReference: Reference to another product, e.g. for linking authorised to investigational product, or a virtual product.
 *
 * http://hl7.org/fhir/crossReference
 */
var crossReference = 'http://hl7.org/fhir/crossReference';
/**
 * _Composition
 *
 * (Modified) Composition
 *
 * http://hl7.org/fhir/_Composition
 */
var _Composition = 'http://hl7.org/fhir/_Composition';
/**
 * subdetailSequence
 *
 * ClaimResponse.addItem.subdetailSequence: The sequence number of the sub-details within the details within the claim item which this line is intended to replace.
 *
 * http://hl7.org/fhir/subdetailSequence
 */
var subdetailSequence = 'http://hl7.org/fhir/subdetailSequence';
/**
 * _definitionReference
 *
 * (Modified) EvidenceVariable.characteristic.definitionByCombination.characteristic.definitionReference
 *
 * http://hl7.org/fhir/_definitionReference
 */
var _definitionReference = 'http://hl7.org/fhir/_definitionReference';
/**
 * supplier
 *
 * SubstanceDefinition.supplier: An entity that is the source for the substance. It may be different from the manufacturer. Supplier is synonymous to a distributor.
 *
 * http://hl7.org/fhir/supplier
 */
var supplier = 'http://hl7.org/fhir/supplier';
/**
 * inputPopulationId
 *
 * Measure.group.population.inputPopulationId: The id of a population element in this measure that provides the input for this population criteria. In most cases, the scoring structure of the measure implies specific relationships (e.g. the Numerator uses the Denominator as the source in a proportion scoring). In some cases, however, multiple possible choices exist and must be resolved explicitly. For example in a ratio measure with multiple initial populations, the denominator must specify which population should be used as the starting point.
 *
 * http://hl7.org/fhir/inputPopulationId
 */
var inputPopulationId = 'http://hl7.org/fhir/inputPopulationId';
/**
 * CarePlan
 *
 * Describes the intention of how one or more practitioners intend to deliver care for a particular patient, group or community for a period of time, possibly limited to care for a specific condition or set of conditions.
 *
 * http://hl7.org/fhir/CarePlan
 */
var CarePlan = 'http://hl7.org/fhir/CarePlan';
/**
 * clinicalStatus
 *
 * Condition.clinicalStatus: The clinical status of the condition.
 *
 * http://hl7.org/fhir/clinicalStatus
 */
var clinicalStatus = 'http://hl7.org/fhir/clinicalStatus';
/**
 * measurementType
 *
 * SubstanceDefinition.moiety.measurementType: The measurement type of the quantitative value. In capturing the actual relative amounts of substances or molecular fragments it may be necessary to indicate whether the amount refers to, for example, a mole ratio or weight ratio.
 *
 * http://hl7.org/fhir/measurementType
 */
var measurementType = 'http://hl7.org/fhir/measurementType';
/**
 * ImplementationGuideDefinitionGroupingComponent
 *
 * ImplementationGuideDefinitionComponent.ImplementationGuideDefinitionGroupingComponent: A logical group of resources. Logical groups can be used when building pages.
 *
 * http://hl7.org/fhir/ImplementationGuideDefinitionGroupingComponent
 */
var ImplementationGuideDefinitionGroupingComponent = 'http://hl7.org/fhir/ImplementationGuideDefinitionGroupingComponent';
/**
 * _fundingSource
 *
 * (Modified) Immunization.fundingSource
 *
 * http://hl7.org/fhir/_fundingSource
 */
var _fundingSource = 'http://hl7.org/fhir/_fundingSource';
/**
 * _immunizationEvent
 *
 * (Modified) ImmunizationEvaluation.immunizationEvent
 *
 * http://hl7.org/fhir/_immunizationEvent
 */
var _immunizationEvent = 'http://hl7.org/fhir/_immunizationEvent';
/**
 * ClaimResponseEventComponent
 *
 * ClaimResponseEventComponent: Information code for an event with a corresponding date or period.
 *
 * http://hl7.org/fhir/ClaimResponseEventComponent
 */
var ClaimResponseEventComponent = 'http://hl7.org/fhir/ClaimResponseEventComponent';
/**
 * statement
 *
 * Requirements.statement: The actual statement of requirement, in markdown format.
 *
 * http://hl7.org/fhir/statement
 */
var statement = 'http://hl7.org/fhir/statement';
/**
 * ImageRegion3D
 *
 * ImagingSelectionInstanceComponent.ImageRegion3D: Each imaging selection might includes a 3D image region, specified by a region type and a set of 3D coordinates.
 *
 * http://hl7.org/fhir/ImageRegion3D
 */
var ImageRegion3D = 'http://hl7.org/fhir/ImageRegion3D';
/**
 * _item
 *
 * (Modified) Linkage.item
 *
 * http://hl7.org/fhir/_item
 */
var _item = 'http://hl7.org/fhir/_item';
/**
 * _repeatUnit
 *
 * (Modified) SubstancePolymer.repeat.repeatUnit
 *
 * http://hl7.org/fhir/_repeatUnit
 */
var _repeatUnit = 'http://hl7.org/fhir/_repeatUnit';
/**
 * startingMaterial
 *
 * SubstancePolymer.monomerSet.startingMaterial: The starting materials - monomer(s) used in the synthesis of the polymer.
 *
 * http://hl7.org/fhir/startingMaterial
 */
var startingMaterial = 'http://hl7.org/fhir/startingMaterial';
/**
 * _temperatureQualifier
 *
 * (Modified) SpecimenDefinition.typeTested.handling.temperatureQualifier
 *
 * http://hl7.org/fhir/_temperatureQualifier
 */
var _temperatureQualifier = 'http://hl7.org/fhir/_temperatureQualifier';
/**
 * dosingGuideline
 *
 * MedicationKnowledge.indicationGuideline.dosingGuideline: The guidelines for the dosage of the medication for the indication.
 *
 * http://hl7.org/fhir/dosingGuideline
 */
var dosingGuideline = 'http://hl7.org/fhir/dosingGuideline';
/**
 * _serviceCategory
 *
 * (Modified) Slot.serviceCategory
 *
 * http://hl7.org/fhir/_serviceCategory
 */
var _serviceCategory = 'http://hl7.org/fhir/_serviceCategory';
/**
 * _rate
 *
 * (Modified) NutritionOrder.enteralFormula.administration.rate
 *
 * http://hl7.org/fhir/_rate
 */
var _rate = 'http://hl7.org/fhir/_rate';
/**
 * _filterDefinition
 *
 * (Modified) SubscriptionTopic.canFilterBy.filterDefinition
 *
 * http://hl7.org/fhir/_filterDefinition
 */
var _filterDefinition = 'http://hl7.org/fhir/_filterDefinition';
/**
 * prescriber
 *
 * VisionPrescription.prescriber: The healthcare professional responsible for authorizing the prescription.
 *
 * http://hl7.org/fhir/prescriber
 */
var prescriber = 'http://hl7.org/fhir/prescriber';
/**
 * oid
 *
 * An OID represented as a URI
 *
 * http://hl7.org/fhir/oid
 */
var oid = 'http://hl7.org/fhir/oid';
/**
 * _attachment
 *
 * (Modified) SubstancePolymer.repeat.repeatUnit.structuralRepresentation.attachment
 *
 * http://hl7.org/fhir/_attachment
 */
var _attachment = 'http://hl7.org/fhir/_attachment';
/**
 * _sourceAttachment
 *
 * (Modified) Consent.sourceAttachment
 *
 * http://hl7.org/fhir/_sourceAttachment
 */
var _sourceAttachment = 'http://hl7.org/fhir/_sourceAttachment';
/**
 * _materialType
 *
 * (Modified) SubstanceSourceMaterial.fractionDescription.materialType
 *
 * http://hl7.org/fhir/_materialType
 */
var _materialType = 'http://hl7.org/fhir/_materialType';
/**
 * target
 *
 * VerificationResult.target: A resource that was validated.
 *
 * http://hl7.org/fhir/target
 */
var target = 'http://hl7.org/fhir/target';
/**
 * _valueCategory
 *
 * (Modified) Evidence.statistic.modelCharacteristic.variable.valueCategory
 *
 * http://hl7.org/fhir/_valueCategory
 */
var _valueCategory = 'http://hl7.org/fhir/_valueCategory';
/**
 * _requestMethod
 *
 * (Modified) TestScript.test.action.assert.requestMethod
 *
 * http://hl7.org/fhir/_requestMethod
 */
var _requestMethod = 'http://hl7.org/fhir/_requestMethod';
/**
 * linkage
 *
 * SubstanceNucleicAcid.subunit.linkage: The linkages between sugar residues will also be captured.
 *
 * http://hl7.org/fhir/linkage
 */
var linkage = 'http://hl7.org/fhir/linkage';
/**
 * DeviceUdiCarrierComponent
 *
 * DeviceUdiCarrierComponent: Unique device identifier (UDI) assigned to device label or package.  Note that the Device may include multiple udiCarriers as it either may include just the udiCarrier for the jurisdiction it is sold, or for multiple jurisdictions it could have been sold.
 *
 * http://hl7.org/fhir/DeviceUdiCarrierComponent
 */
var DeviceUdiCarrierComponent = 'http://hl7.org/fhir/DeviceUdiCarrierComponent';
/**
 * TerminologyCapabilitiesClosureComponent
 *
 * TerminologyCapabilitiesClosureComponent: Whether the $closure operation is supported.
 *
 * http://hl7.org/fhir/TerminologyCapabilitiesClosureComponent
 */
var TerminologyCapabilitiesClosureComponent = 'http://hl7.org/fhir/TerminologyCapabilitiesClosureComponent';
/**
 * _conclusionCode
 *
 * (Modified) DiagnosticReport.conclusionCode
 *
 * http://hl7.org/fhir/_conclusionCode
 */
var _conclusionCode = 'http://hl7.org/fhir/_conclusionCode';
/**
 * _div
 *
 * (Modified) Narrative.div
 *
 * http://hl7.org/fhir/_div
 */
var _div = 'http://hl7.org/fhir/_div';
/**
 * processingMode
 *
 * SearchParameter.processingMode: How the search parameter relates to the set of elements returned by evaluating the expression query.
 *
 * http://hl7.org/fhir/processingMode
 */
var processingMode = 'http://hl7.org/fhir/processingMode';
/**
 * _rule
 *
 * (Modified) StructureMap.group.rule.rule
 *
 * http://hl7.org/fhir/_rule
 */
var _rule = 'http://hl7.org/fhir/_rule';
/**
 * StructureMap
 *
 * A Map of relationships between 2 structures that can be used to transform data.
 *
 * http://hl7.org/fhir/StructureMap
 */
var StructureMap = 'http://hl7.org/fhir/StructureMap';
/**
 * _molecularFormulaByMoiety
 *
 * (Modified) SubstanceDefinition.structure.molecularFormulaByMoiety
 *
 * http://hl7.org/fhir/_molecularFormulaByMoiety
 */
var _molecularFormulaByMoiety = 'http://hl7.org/fhir/_molecularFormulaByMoiety';
/**
 * firstDose
 *
 * AdministrableProductDefinition.routeOfAdministration.firstDose: The first dose (dose quantity) administered can be specified for the product, using a numerical value and its unit of measurement.
 *
 * http://hl7.org/fhir/firstDose
 */
var firstDose = 'http://hl7.org/fhir/firstDose';
/**
 * BundleEntryResponseComponent
 *
 * BundleEntryComponent.BundleEntryResponseComponent: Indicates the results of processing the corresponding 'request' entry in the batch or transaction being responded to or what the results of an operation where when returning history.
 *
 * http://hl7.org/fhir/BundleEntryResponseComponent
 */
var BundleEntryResponseComponent = 'http://hl7.org/fhir/BundleEntryResponseComponent';
/**
 * structureVersion
 *
 * ExampleScenario.instance.structureVersion: Conveys the version of the data structure instantiated.  I.e. what release of FHIR, X12, OpenEHR, etc. is instance compliant with.
 *
 * http://hl7.org/fhir/structureVersion
 */
var structureVersion = 'http://hl7.org/fhir/structureVersion';
/**
 * alias
 *
 * InsurancePlan.alias: A list of alternate names that the product is known as, or was known as in the past.
 *
 * http://hl7.org/fhir/alias
 */
var alias = 'http://hl7.org/fhir/alias';
/**
 * _programCode
 *
 * (Modified) ExplanationOfBenefit.item.detail.subDetail.programCode
 *
 * http://hl7.org/fhir/_programCode
 */
var _programCode = 'http://hl7.org/fhir/_programCode';
/**
 * _resultForDelete
 *
 * (Modified) SubscriptionTopic.resourceTrigger.queryCriteria.resultForDelete
 *
 * http://hl7.org/fhir/_resultForDelete
 */
var _resultForDelete = 'http://hl7.org/fhir/_resultForDelete';
/**
 * grantee
 *
 * Consent.grantee: The entity responsible for complying with the Consent Directive, including any obligations or limitations on authorizations and enforcement of prohibitions.
 *
 * http://hl7.org/fhir/grantee
 */
var grantee = 'http://hl7.org/fhir/grantee';
/**
 * _effectiveTime
 *
 * (Modified) Contract.term.group.asset.valuedItem.effectiveTime
 *
 * http://hl7.org/fhir/_effectiveTime
 */
var _effectiveTime = 'http://hl7.org/fhir/_effectiveTime';
/**
 * definitionCodeableConcept
 *
 * EvidenceVariable.characteristic.definitionByCombination.characteristic.definitionCodeableConcept: Defines the characteristic using CodeableConcept.
 *
 * http://hl7.org/fhir/definitionCodeableConcept
 */
var definitionCodeableConcept = 'http://hl7.org/fhir/definitionCodeableConcept';
/**
 * Property
 *
 * ConceptMap.Property: A property defines a slot through which additional information can be provided about a map from source -> target.
 *
 * http://hl7.org/fhir/Property
 */
var Property = 'http://hl7.org/fhir/Property';
/**
 * entryClassifier
 *
 * EvidenceReport.section.section.entryClassifier: Specifies any type of classification of the evidence report.
 *
 * http://hl7.org/fhir/entryClassifier
 */
var entryClassifier = 'http://hl7.org/fhir/entryClassifier';
/**
 * _combining
 *
 * (Modified) Permission.combining
 *
 * http://hl7.org/fhir/_combining
 */
var _combining = 'http://hl7.org/fhir/_combining';
/**
 * paternalOrganismName
 *
 * SubstanceSourceMaterial.organism.hybrid.paternalOrganismName: The name of the paternal species constituting the hybrid organism shall be specified.
 *
 * http://hl7.org/fhir/paternalOrganismName
 */
var paternalOrganismName = 'http://hl7.org/fhir/paternalOrganismName';
/**
 * _asset
 *
 * (Modified) Contract.term.group.asset
 *
 * http://hl7.org/fhir/_asset
 */
var _asset = 'http://hl7.org/fhir/_asset';
/**
 * PaymentReconciliationAllocationComponent
 *
 * PaymentReconciliationAllocationComponent: Distribution of the payment amount for a previously acknowledged payable.
 *
 * http://hl7.org/fhir/PaymentReconciliationAllocationComponent
 */
var PaymentReconciliationAllocationComponent = 'http://hl7.org/fhir/PaymentReconciliationAllocationComponent';
/**
 * _part
 *
 * (Modified) OperationDefinition.parameter.part
 *
 * http://hl7.org/fhir/_part
 */
var _part = 'http://hl7.org/fhir/_part';
/**
 * actor
 *
 * Schedule.actor: Slots that reference this schedule resource provide the availability details to these referenced resource(s).
 *
 * http://hl7.org/fhir/actor
 */
var actor = 'http://hl7.org/fhir/actor';
/**
 * _isExample
 *
 * (Modified) ImplementationGuide.manifest.resource.isExample
 *
 * http://hl7.org/fhir/_isExample
 */
var _isExample = 'http://hl7.org/fhir/_isExample';
/**
 * navigationLinks
 *
 * TestScript.test.action.assert.navigationLinks: Whether or not the test execution performs validation on the bundle navigation links.
 *
 * http://hl7.org/fhir/navigationLinks
 */
var navigationLinks = 'http://hl7.org/fhir/navigationLinks';
/**
 * availability
 *
 * PractitionerRole.availability: A collection of times the practitioner is available or performing this role at the location and/or healthcareservice.
 *
 * http://hl7.org/fhir/availability
 */
var availability = 'http://hl7.org/fhir/availability';
/**
 * _specimen
 *
 * (Modified) ServiceRequest.specimen
 *
 * http://hl7.org/fhir/_specimen
 */
var _specimen = 'http://hl7.org/fhir/_specimen';
/**
 * term
 *
 * Contract.term: One or more Contract Provisions, which may be related and conveyed as a group, and may contain nested groups.
 *
 * http://hl7.org/fhir/term
 */
var term = 'http://hl7.org/fhir/term';
/**
 * notAvailableTime
 *
 * Availability.notAvailableTime: Not available during this time due to provided reason.
 *
 * http://hl7.org/fhir/notAvailableTime
 */
var notAvailableTime = 'http://hl7.org/fhir/notAvailableTime';
/**
 * specimenRequirement
 *
 * ActivityDefinition.specimenRequirement: Defines specimen requirements for the action to be performed, such as required specimens for a lab test.
 *
 * http://hl7.org/fhir/specimenRequirement
 */
var specimenRequirement = 'http://hl7.org/fhir/specimenRequirement';
/**
 * answer
 *
 * Contract.term.offer.answer: Response to offer text.
 *
 * http://hl7.org/fhir/answer
 */
var answer = 'http://hl7.org/fhir/answer';
/**
 * _citation
 *
 * (Modified) Citation.citedArtifact.relatesTo.citation
 *
 * http://hl7.org/fhir/_citation
 */
var _citation = 'http://hl7.org/fhir/_citation';
/**
 * patient
 *
 * CoverageEligibilityRequest.patient: The party who is the beneficiary of the supplied coverage and for whom eligibility is sought.
 *
 * http://hl7.org/fhir/patient
 */
var patient = 'http://hl7.org/fhir/patient';
/**
 * suppress
 *
 * ElementDefinition.constraint.suppress: If true, indicates that the warning or best practice guideline should be suppressed.
 *
 * http://hl7.org/fhir/suppress
 */
var suppress = 'http://hl7.org/fhir/suppress';
/**
 * additionalUse
 *
 * CodeSystem.concept.concept.designation.additionalUse: Additional codes that detail how this designation would be used, if there is more than one use.
 *
 * http://hl7.org/fhir/additionalUse
 */
var additionalUse = 'http://hl7.org/fhir/additionalUse';
/**
 * _maxDosePerLifetime
 *
 * (Modified) Dosage.maxDosePerLifetime
 *
 * http://hl7.org/fhir/_maxDosePerLifetime
 */
var _maxDosePerLifetime = 'http://hl7.org/fhir/_maxDosePerLifetime';
/**
 * Distance
 *
 * A length - a value with a unit that is a physical distance.
 *
 * http://hl7.org/fhir/Distance
 */
var Distance = 'http://hl7.org/fhir/Distance';
/**
 * _primarySource
 *
 * (Modified) VerificationResult.primarySource
 *
 * http://hl7.org/fhir/_primarySource
 */
var _primarySource = 'http://hl7.org/fhir/_primarySource';
/**
 * _opticalActivity
 *
 * (Modified) SubstanceDefinition.structure.opticalActivity
 *
 * http://hl7.org/fhir/_opticalActivity
 */
var _opticalActivity = 'http://hl7.org/fhir/_opticalActivity';
/**
 * _multipleOr
 *
 * (Modified) SearchParameter.multipleOr
 *
 * http://hl7.org/fhir/_multipleOr
 */
var _multipleOr = 'http://hl7.org/fhir/_multipleOr';
/**
 * _specialMeasures
 *
 * (Modified) MedicinalProductDefinition.specialMeasures
 *
 * http://hl7.org/fhir/_specialMeasures
 */
var _specialMeasures = 'http://hl7.org/fhir/_specialMeasures';
/**
 * usageReason
 *
 * DeviceUsage.usageReason: The reason for asserting the usage status - for example forgot, lost, stolen, broken.
 *
 * http://hl7.org/fhir/usageReason
 */
var usageReason = 'http://hl7.org/fhir/usageReason';
/**
 * GoalTargetComponent
 *
 * GoalTargetComponent: Indicates what should be done by when.
 *
 * http://hl7.org/fhir/GoalTargetComponent
 */
var GoalTargetComponent = 'http://hl7.org/fhir/GoalTargetComponent';
/**
 * measure
 *
 * MeasureReport.measure: A reference to the Measure that was calculated to produce this report.
 *
 * http://hl7.org/fhir/measure
 */
var measure = 'http://hl7.org/fhir/measure';
/**
 * contributionType
 *
 * Citation.citedArtifact.contributorship.entry.contributionType: This element identifies the specific nature of an individual’s contribution with respect to the cited work.
 *
 * http://hl7.org/fhir/contributionType
 */
var contributionType = 'http://hl7.org/fhir/contributionType';
/**
 * modelNumber
 *
 * DeviceDefinition.modelNumber: The model number for the device for example as defined by the manufacturer or labeler, or other agency.
 *
 * http://hl7.org/fhir/modelNumber
 */
var modelNumber = 'http://hl7.org/fhir/modelNumber';
/**
 * _derivedFromUri
 *
 * (Modified) SpecimenDefinition.derivedFromUri
 *
 * http://hl7.org/fhir/_derivedFromUri
 */
var _derivedFromUri = 'http://hl7.org/fhir/_derivedFromUri';
/**
 * _method
 *
 * (Modified) MedicationAdministration.dosage.method
 *
 * http://hl7.org/fhir/_method
 */
var _method = 'http://hl7.org/fhir/_method';
/**
 * effectiveDate
 *
 * MedicinalProductDefinition.operation.effectiveDate: Date range of applicability.
 *
 * http://hl7.org/fhir/effectiveDate
 */
var effectiveDate = 'http://hl7.org/fhir/effectiveDate';
/**
 * _servicePeriod
 *
 * (Modified) Account.servicePeriod
 *
 * http://hl7.org/fhir/_servicePeriod
 */
var _servicePeriod = 'http://hl7.org/fhir/_servicePeriod';
/**
 * asNeededFor
 *
 * DeviceRequest.asNeededFor: The reason for using the device.
 *
 * http://hl7.org/fhir/asNeededFor
 */
var asNeededFor = 'http://hl7.org/fhir/asNeededFor';
/**
 * ExplanationOfBenefit
 *
 * This resource provides: the claim details; adjudication details from the processing of a Claim; and optionally account balance information, for informing the subscriber of the benefits provided.
 *
 * http://hl7.org/fhir/ExplanationOfBenefit
 */
var ExplanationOfBenefit = 'http://hl7.org/fhir/ExplanationOfBenefit';
/**
 * _add
 *
 * (Modified) VisionPrescription.lensSpecification.add
 *
 * http://hl7.org/fhir/_add
 */
var _add = 'http://hl7.org/fhir/_add';
/**
 * _cancelledReason
 *
 * (Modified) Invoice.cancelledReason
 *
 * http://hl7.org/fhir/_cancelledReason
 */
var _cancelledReason = 'http://hl7.org/fhir/_cancelledReason';
/**
 * orderMeaning
 *
 * ElementDefinition.orderMeaning: If present, indicates that the order of the repeating element has meaning and describes what that meaning is.  If absent, it means that the order of the element has no meaning.
 *
 * http://hl7.org/fhir/orderMeaning
 */
var orderMeaning = 'http://hl7.org/fhir/orderMeaning';
/**
 * testCase
 *
 * TestPlan.testCase: The individual test cases that are part of this plan, when they they are made explicit.
 *
 * http://hl7.org/fhir/testCase
 */
var testCase = 'http://hl7.org/fhir/testCase';
/**
 * net
 *
 * ExplanationOfBenefit.addItem.detail.net: The total amount claimed for the group (if a grouper) or the addItem.detail. Net = unit price * quantity * factor.
 *
 * http://hl7.org/fhir/net
 */
var net = 'http://hl7.org/fhir/net';
/**
 * VerificationResultAttestationComponent
 *
 * VerificationResultAttestationComponent: Information about the entity attesting to information.
 *
 * http://hl7.org/fhir/VerificationResultAttestationComponent
 */
var VerificationResultAttestationComponent = 'http://hl7.org/fhir/VerificationResultAttestationComponent';
/**
 * _class
 *
 * (Modified) SubstanceSourceMaterial.organism.organismGeneral.class
 *
 * http://hl7.org/fhir/_class
 */
var _class = 'http://hl7.org/fhir/_class';
/**
 * claim
 *
 * ExplanationOfBenefit.related.claim: Reference to a related claim.
 *
 * http://hl7.org/fhir/claim
 */
var claim = 'http://hl7.org/fhir/claim';
/**
 * Flag
 *
 * Prospective warnings of potential issues when providing care to the patient.
 *
 * http://hl7.org/fhir/Flag
 */
var Flag = 'http://hl7.org/fhir/Flag';
/**
 * _riskAdjustment
 *
 * (Modified) Measure.riskAdjustment
 *
 * http://hl7.org/fhir/_riskAdjustment
 */
var _riskAdjustment = 'http://hl7.org/fhir/_riskAdjustment';
/**
 * _compareToSourceExpression
 *
 * (Modified) TestScript.test.action.assert.compareToSourceExpression
 *
 * http://hl7.org/fhir/_compareToSourceExpression
 */
var _compareToSourceExpression = 'http://hl7.org/fhir/_compareToSourceExpression';
/**
 * _notificationEvent
 *
 * (Modified) SubscriptionStatus.notificationEvent
 *
 * http://hl7.org/fhir/_notificationEvent
 */
var _notificationEvent = 'http://hl7.org/fhir/_notificationEvent';
/**
 * guideline
 *
 * DeviceDefinition.guideline: Information aimed at providing directions for the usage of this model of device.
 *
 * http://hl7.org/fhir/guideline
 */
var guideline = 'http://hl7.org/fhir/guideline';
/**
 * amount
 *
 * ExplanationOfBenefit.total.amount: Monetary total amount associated with the category.
 *
 * http://hl7.org/fhir/amount
 */
var amount = 'http://hl7.org/fhir/amount';
/**
 * _dateFilter
 *
 * (Modified) DataRequirement.dateFilter
 *
 * http://hl7.org/fhir/_dateFilter
 */
var _dateFilter = 'http://hl7.org/fhir/_dateFilter';
/**
 * _statisticType
 *
 * (Modified) Evidence.statistic.statisticType
 *
 * http://hl7.org/fhir/_statisticType
 */
var _statisticType = 'http://hl7.org/fhir/_statisticType';
/**
 * genus
 *
 * SubstanceSourceMaterial.organism.genus: The genus of an organism shall be specified; refers to the Latin epithet of the genus element of the plant/animal scientific name; it is present in names for genera, species and infraspecies.
 *
 * http://hl7.org/fhir/genus
 */
var genus = 'http://hl7.org/fhir/genus';
/**
 * _MessageHeader
 *
 * (Modified) MessageHeader
 *
 * http://hl7.org/fhir/_MessageHeader
 */
var _MessageHeader = 'http://hl7.org/fhir/_MessageHeader';
/**
 * _administrationTreatment
 *
 * (Modified) MedicationKnowledge.indicationGuideline.dosingGuideline.administrationTreatment
 *
 * http://hl7.org/fhir/_administrationTreatment
 */
var _administrationTreatment = 'http://hl7.org/fhir/_administrationTreatment';
/**
 * _country
 *
 * (Modified) MedicinalProductDefinition.name.usage.country
 *
 * http://hl7.org/fhir/_country
 */
var _country = 'http://hl7.org/fhir/_country';
/**
 * insurer
 *
 * Claim.insurer: The Insurer who is target of the request.
 *
 * http://hl7.org/fhir/insurer
 */
var insurer = 'http://hl7.org/fhir/insurer';
/**
 * DeviceDefinitionLinkComponent
 *
 * DeviceDefinitionLinkComponent: An associated device, attached to, used with, communicating with or linking a previous or new device model to the focal device.
 *
 * http://hl7.org/fhir/DeviceDefinitionLinkComponent
 */
var DeviceDefinitionLinkComponent = 'http://hl7.org/fhir/DeviceDefinitionLinkComponent';
/**
 * container
 *
 * SpecimenDefinition.typeTested.container: The specimen's container.
 *
 * http://hl7.org/fhir/container
 */
var container = 'http://hl7.org/fhir/container';
/**
 * _params
 *
 * (Modified) TestScript.teardown.action.operation.params
 *
 * http://hl7.org/fhir/_params
 */
var _params = 'http://hl7.org/fhir/_params';
/**
 * Goal
 *
 * Describes the intended objective(s) for a patient, group or organization care, for example, weight loss, restoring an activity of daily living, obtaining herd immunity via immunization, meeting a process improvement objective, etc.
 *
 * http://hl7.org/fhir/Goal
 */
var Goal = 'http://hl7.org/fhir/Goal';
/**
 * lockedDate
 *
 * ValueSet.compose.lockedDate: The Locked Date is  the effective date that is used to determine the version of all referenced Code Systems and Value Set Definitions included in the compose that are not already tied to a specific version.
 *
 * http://hl7.org/fhir/lockedDate
 */
var lockedDate = 'http://hl7.org/fhir/lockedDate';
/**
 * symptomConditionEffect
 *
 * ClinicalUseDefinition.undesirableEffect.symptomConditionEffect: The situation in which the undesirable effect may manifest.
 *
 * http://hl7.org/fhir/symptomConditionEffect
 */
var symptomConditionEffect = 'http://hl7.org/fhir/symptomConditionEffect';
/**
 * referenceStrength
 *
 * Ingredient.substance.strength.referenceStrength: Strength expressed in terms of a reference substance. For when the ingredient strength is additionally expressed as equivalent to the strength of some other closely related substance (e.g. salt vs. base). Reference strength represents the strength (quantitative composition) of the active moiety of the active substance. There are situations when the active substance and active moiety are different, therefore both a strength and a reference strength are needed.
 *
 * http://hl7.org/fhir/referenceStrength
 */
var referenceStrength = 'http://hl7.org/fhir/referenceStrength';
/**
 * interval
 *
 * SampledData.interval: Amount of intervalUnits between samples, e.g. milliseconds for time-based sampling.
 *
 * http://hl7.org/fhir/interval
 */
var interval = 'http://hl7.org/fhir/interval';
/**
 * _compartment
 *
 * (Modified) GraphDefinition.link.compartment
 *
 * http://hl7.org/fhir/_compartment
 */
var _compartment = 'http://hl7.org/fhir/_compartment';
/**
 * classifier
 *
 * Citation.classification.classifier: The specific classification value.
 *
 * http://hl7.org/fhir/classifier
 */
var classifier = 'http://hl7.org/fhir/classifier';
/**
 * PackagedProductDefinitionPackagingPropertyComponent
 *
 * PackagedProductDefinitionPackagingComponent.PackagedProductDefinitionPackagingPropertyComponent: General characteristics of this item.
 *
 * http://hl7.org/fhir/PackagedProductDefinitionPackagingPropertyComponent
 */
var PackagedProductDefinitionPackagingPropertyComponent = 'http://hl7.org/fhir/PackagedProductDefinitionPackagingPropertyComponent';
/**
 * setup
 *
 * TestScript.setup: A series of required setup operations before tests are executed.
 *
 * http://hl7.org/fhir/setup
 */
var setup = 'http://hl7.org/fhir/setup';
/**
 * _areaOfHybridisation
 *
 * (Modified) SubstanceNucleicAcid.areaOfHybridisation
 *
 * http://hl7.org/fhir/_areaOfHybridisation
 */
var _areaOfHybridisation = 'http://hl7.org/fhir/_areaOfHybridisation';
/**
 * maxLength
 *
 * Questionnaire.item.item.maxLength: The maximum number of characters that are permitted in the answer to be considered a "valid" QuestionnaireResponse.
 *
 * http://hl7.org/fhir/maxLength
 */
var maxLength = 'http://hl7.org/fhir/maxLength';
/**
 * publisherLocation
 *
 * Citation.citedArtifact.publicationForm.publishedIn.publisherLocation: Geographic location of the publisher.
 *
 * http://hl7.org/fhir/publisherLocation
 */
var publisherLocation = 'http://hl7.org/fhir/publisherLocation';
/**
 * RelatedPerson
 *
 * Information about a person that is involved in a patient's health or the care for a patient, but who is not the target of healthcare, nor has a formal responsibility in the care process.
 *
 * http://hl7.org/fhir/RelatedPerson
 */
var RelatedPerson = 'http://hl7.org/fhir/RelatedPerson';
/**
 * _storageTempRequirements
 *
 * (Modified) BiologicallyDerivedProduct.storageTempRequirements
 *
 * http://hl7.org/fhir/_storageTempRequirements
 */
var _storageTempRequirements = 'http://hl7.org/fhir/_storageTempRequirements';
/**
 * _Organization
 *
 * (Modified) Organization
 *
 * http://hl7.org/fhir/_Organization
 */
var _Organization = 'http://hl7.org/fhir/_Organization';
/**
 * _postConditions
 *
 * (Modified) ExampleScenario.process.step.alternative.step.process.postConditions
 *
 * http://hl7.org/fhir/_postConditions
 */
var _postConditions = 'http://hl7.org/fhir/_postConditions';
/**
 * _DeviceDispense
 *
 * (Modified) DeviceDispense
 *
 * http://hl7.org/fhir/_DeviceDispense
 */
var _DeviceDispense = 'http://hl7.org/fhir/_DeviceDispense';
/**
 * state
 *
 * ResearchStudy.progressStatus.state: Label for status or state (e.g. recruitment status).
 *
 * http://hl7.org/fhir/state
 */
var state = 'http://hl7.org/fhir/state';
/**
 * SubstanceDefinitionSourceMaterialComponent
 *
 * SubstanceDefinitionSourceMaterialComponent: Material or taxonomic/anatomical source for the substance.
 *
 * http://hl7.org/fhir/SubstanceDefinitionSourceMaterialComponent
 */
var SubstanceDefinitionSourceMaterialComponent = 'http://hl7.org/fhir/SubstanceDefinitionSourceMaterialComponent';
/**
 * _aggregate
 *
 * (Modified) Account.balance.aggregate
 *
 * http://hl7.org/fhir/_aggregate
 */
var _aggregate = 'http://hl7.org/fhir/_aggregate';
/**
 * fluidConsistencyType
 *
 * NutritionOrder.oralDiet.fluidConsistencyType: The required consistency (e.g. honey-thick, nectar-thick, thin, thickened.) of liquids or fluids served to the patient.
 *
 * http://hl7.org/fhir/fluidConsistencyType
 */
var fluidConsistencyType = 'http://hl7.org/fhir/fluidConsistencyType';
/**
 * MoneyQuantity
 *
 * There SHALL be a code if there is a value and it SHALL be an expression of currency.  If system is present, it SHALL be ISO 4217 (system = "urn:iso:std:iso:4217" - currency).
 *
 * http://hl7.org/fhir/MoneyQuantity
 */
var MoneyQuantity = 'http://hl7.org/fhir/MoneyQuantity';
/**
 * _specificCost
 *
 * (Modified) InsurancePlan.plan.specificCost
 *
 * http://hl7.org/fhir/_specificCost
 */
var _specificCost = 'http://hl7.org/fhir/_specificCost';
/**
 * _organismId
 *
 * (Modified) SubstanceSourceMaterial.organismId
 *
 * http://hl7.org/fhir/_organismId
 */
var _organismId = 'http://hl7.org/fhir/_organismId';
/**
 * StructureMapGroupInputComponent
 *
 * StructureMapGroupComponent.StructureMapGroupInputComponent: A name assigned to an instance of data. The instance must be provided when the mapping is invoked.
 *
 * http://hl7.org/fhir/StructureMapGroupInputComponent
 */
var StructureMapGroupInputComponent = 'http://hl7.org/fhir/StructureMapGroupInputComponent';
/**
 * _check
 *
 * (Modified) StructureMap.group.rule.rule.source.check
 *
 * http://hl7.org/fhir/_check
 */
var _check = 'http://hl7.org/fhir/_check';
/**
 * _chargeItemCode
 *
 * (Modified) DeviceDefinition.chargeItem.chargeItemCode
 *
 * http://hl7.org/fhir/_chargeItemCode
 */
var _chargeItemCode = 'http://hl7.org/fhir/_chargeItemCode';
/**
 * ownedBy
 *
 * InsurancePlan.ownedBy: The entity that is providing  the health insurance product and underwriting the risk.  This is typically an insurance carriers, other third-party payers, or health plan sponsors comonly referred to as 'payers'.
 *
 * http://hl7.org/fhir/ownedBy
 */
var ownedBy = 'http://hl7.org/fhir/ownedBy';
/**
 * _participantStatus
 *
 * (Modified) AppointmentResponse.participantStatus
 *
 * http://hl7.org/fhir/_participantStatus
 */
var _participantStatus = 'http://hl7.org/fhir/_participantStatus';
/**
 * _baseFormulaType
 *
 * (Modified) NutritionOrder.enteralFormula.baseFormulaType
 *
 * http://hl7.org/fhir/_baseFormulaType
 */
var _baseFormulaType = 'http://hl7.org/fhir/_baseFormulaType';
/**
 * shelfLifeStorage
 *
 * PackagedProductDefinition.packaging.packaging.shelfLifeStorage: Shelf Life and storage information.
 *
 * http://hl7.org/fhir/shelfLifeStorage
 */
var shelfLifeStorage = 'http://hl7.org/fhir/shelfLifeStorage';
/**
 * authorizingPrescription
 *
 * MedicationDispense.authorizingPrescription: Indicates the medication order that is being dispensed against.
 *
 * http://hl7.org/fhir/authorizingPrescription
 */
var authorizingPrescription = 'http://hl7.org/fhir/authorizingPrescription';
/**
 * protein
 *
 * SubstanceDefinition.protein: Data items specific to proteins.
 *
 * http://hl7.org/fhir/protein
 */
var protein = 'http://hl7.org/fhir/protein';
/**
 * connectivity
 *
 * SubstanceNucleicAcid.subunit.linkage.connectivity: The entity that links the sugar residues together should also be captured for nearly all naturally occurring nucleic acid the linkage is a phosphate group. For many synthetic oligonucleotides phosphorothioate linkages are often seen. Linkage connectivity is assumed to be 3’-5’. If the linkage is either 3’-3’ or 5’-5’ this should be specified.
 *
 * http://hl7.org/fhir/connectivity
 */
var connectivity = 'http://hl7.org/fhir/connectivity';
/**
 * information
 *
 * CoverageEligibilityRequest.supportingInfo.information: Additional data or information such as resources, documents, images etc. including references to the data or the actual inclusion of the data.
 *
 * http://hl7.org/fhir/information
 */
var information = 'http://hl7.org/fhir/information';
/**
 * DeviceDefinitionVersionComponent
 *
 * DeviceDefinitionVersionComponent: The version of the device or software.
 *
 * http://hl7.org/fhir/DeviceDefinitionVersionComponent
 */
var DeviceDefinitionVersionComponent = 'http://hl7.org/fhir/DeviceDefinitionVersionComponent';
/**
 * AdverseEvent
 *
 * An event (i.e. any change to current patient status) that may be related to unintended effects on a patient or research participant. The unintended effects may require additional monitoring, treatment, hospitalization, or may result in death. The AdverseEvent resource also extends to potential or avoided events that could have had such effects. There are two major domains where the AdverseEvent resource is expected to be used. One is in clinical care reported adverse events and the other is in reporting adverse events in clinical  research trial management.  Adverse events can be reported by healthcare providers, patients, caregivers or by medical products manufacturers.  Given the differences between these two concepts, we recommend consulting the domain specific implementation guides when implementing the AdverseEvent Resource. The implementation guides include specific extensions, value sets and constraints.
 *
 * http://hl7.org/fhir/AdverseEvent
 */
var AdverseEvent = 'http://hl7.org/fhir/AdverseEvent';
/**
 * _originRelationshipType
 *
 * (Modified) BiologicallyDerivedProductDispense.originRelationshipType
 *
 * http://hl7.org/fhir/_originRelationshipType
 */
var _originRelationshipType = 'http://hl7.org/fhir/_originRelationshipType';
/**
 * definitionExpression
 *
 * EvidenceVariable.characteristic.definitionByCombination.characteristic.definitionExpression: Defines the characteristic using Expression.
 *
 * http://hl7.org/fhir/definitionExpression
 */
var definitionExpression = 'http://hl7.org/fhir/definitionExpression';
/**
 * ServiceRequestOrderDetailParameterComponent
 *
 * ServiceRequestOrderDetailComponent.ServiceRequestOrderDetailParameterComponent: The parameter details for the service being requested.
 *
 * http://hl7.org/fhir/ServiceRequestOrderDetailParameterComponent
 */
var ServiceRequestOrderDetailParameterComponent = 'http://hl7.org/fhir/ServiceRequestOrderDetailParameterComponent';
/**
 * TestPlan
 *
 * A plan for executing testing on an artifact or specifications
 *
 * http://hl7.org/fhir/TestPlan
 */
var TestPlan = 'http://hl7.org/fhir/TestPlan';
/**
 * requestProvider
 *
 * EnrollmentResponse.requestProvider: The practitioner who is responsible for the services rendered to the patient.
 *
 * http://hl7.org/fhir/requestProvider
 */
var requestProvider = 'http://hl7.org/fhir/requestProvider';
/**
 * _formatted
 *
 * (Modified) MolecularSequence.formatted
 *
 * http://hl7.org/fhir/_formatted
 */
var _formatted = 'http://hl7.org/fhir/_formatted';
/**
 * NutritionProduct
 *
 * A food or supplement that is consumed by patients.
 *
 * http://hl7.org/fhir/NutritionProduct
 */
var NutritionProduct = 'http://hl7.org/fhir/NutritionProduct';
/**
 * ActorDefinition
 *
 * The ActorDefinition resource is used to describe an actor - a human or an application that plays a role in data exchange, and that may have obligations associated with the role the actor plays.
 *
 * http://hl7.org/fhir/ActorDefinition
 */
var ActorDefinition = 'http://hl7.org/fhir/ActorDefinition';
/**
 * RegulatedAuthorization
 *
 * Regulatory approval, clearance or licencing related to a regulated product, treatment, facility or activity that is cited in a guidance, regulation, rule or legislative act. An example is Market Authorization relating to a Medicinal Product.
 *
 * http://hl7.org/fhir/RegulatedAuthorization
 */
var RegulatedAuthorization = 'http://hl7.org/fhir/RegulatedAuthorization';
/**
 * _facility
 *
 * (Modified) ExplanationOfBenefit.facility
 *
 * http://hl7.org/fhir/_facility
 */
var _facility = 'http://hl7.org/fhir/_facility';
/**
 * sourceDocument
 *
 * SubstanceDefinition.structure.sourceDocument: The source of information about the structure.
 *
 * http://hl7.org/fhir/sourceDocument
 */
var sourceDocument = 'http://hl7.org/fhir/sourceDocument';
/**
 * _morphology
 *
 * (Modified) BodyStructure.morphology
 *
 * http://hl7.org/fhir/_morphology
 */
var _morphology = 'http://hl7.org/fhir/_morphology';
/**
 * _kind
 *
 * (Modified) Coverage.kind
 *
 * http://hl7.org/fhir/_kind
 */
var _kind = 'http://hl7.org/fhir/_kind';
/**
 * color
 *
 * VisionPrescription.lensSpecification.color: Special color or pattern.
 *
 * http://hl7.org/fhir/color
 */
var color = 'http://hl7.org/fhir/color';
/**
 * _bounds
 *
 * (Modified) Timing.repeat.bounds
 *
 * http://hl7.org/fhir/_bounds
 */
var _bounds = 'http://hl7.org/fhir/_bounds';
/**
 * snapshot
 *
 * StructureDefinition.snapshot: A snapshot view is expressed in a standalone form that can be used and interpreted without considering the base StructureDefinition.
 *
 * http://hl7.org/fhir/snapshot
 */
var snapshot = 'http://hl7.org/fhir/snapshot';
/**
 * SpecimenContainerComponent
 *
 * SpecimenContainerComponent: The container holding the specimen.  The recursive nature of containers; i.e. blood in tube in tray in rack is not addressed here.
 *
 * http://hl7.org/fhir/SpecimenContainerComponent
 */
var SpecimenContainerComponent = 'http://hl7.org/fhir/SpecimenContainerComponent';
/**
 * unsignedInt
 *
 * An integer with a value that is not negative (e.g. >= 0)
 *
 * http://hl7.org/fhir/unsignedInt
 */
var unsignedInt = 'http://hl7.org/fhir/unsignedInt';
/**
 * MedicationKnowledgeMedicineClassificationComponent
 *
 * MedicationKnowledgeMedicineClassificationComponent: Categorization of the medication within a formulary or classification system.
 *
 * http://hl7.org/fhir/MedicationKnowledgeMedicineClassificationComponent
 */
var MedicationKnowledgeMedicineClassificationComponent = 'http://hl7.org/fhir/MedicationKnowledgeMedicineClassificationComponent';
/**
 * ImmunizationProgramEligibilityComponent
 *
 * ImmunizationProgramEligibilityComponent: Indicates a patient's eligibility for a funding program.
 *
 * http://hl7.org/fhir/ImmunizationProgramEligibilityComponent
 */
var ImmunizationProgramEligibilityComponent = 'http://hl7.org/fhir/ImmunizationProgramEligibilityComponent';
/**
 * _dose
 *
 * (Modified) MedicationAdministration.dosage.dose
 *
 * http://hl7.org/fhir/_dose
 */
var _dose = 'http://hl7.org/fhir/_dose';
/**
 * useBy
 *
 * NutritionProduct.instance.useBy: The time after which the product is no longer expected to be in proper condition, or its use is not advised or not allowed.
 *
 * http://hl7.org/fhir/useBy
 */
var useBy = 'http://hl7.org/fhir/useBy';
/**
 * _start
 *
 * (Modified) Period.start
 *
 * http://hl7.org/fhir/_start
 */
var _start = 'http://hl7.org/fhir/_start';
/**
 * _import
 *
 * (Modified) StructureMap.import
 *
 * http://hl7.org/fhir/_import
 */
var _import = 'http://hl7.org/fhir/_import';
/**
 * TaskPerformerComponent
 *
 * TaskPerformerComponent: The entity who performed the requested task.
 *
 * http://hl7.org/fhir/TaskPerformerComponent
 */
var TaskPerformerComponent = 'http://hl7.org/fhir/TaskPerformerComponent';
/**
 * grantor
 *
 * Consent.grantor: The entity responsible for granting the rights listed in a Consent Directive.
 *
 * http://hl7.org/fhir/grantor
 */
var grantor = 'http://hl7.org/fhir/grantor';
/**
 * _purpose
 *
 * (Modified) CanonicalResource.purpose
 *
 * http://hl7.org/fhir/_purpose
 */
var _purpose = 'http://hl7.org/fhir/_purpose';
/**
 * benefit
 *
 * InsurancePlan.plan.specificCost.benefit: List of the specific benefits under this category of benefit.
 *
 * http://hl7.org/fhir/benefit
 */
var benefit = 'http://hl7.org/fhir/benefit';
/**
 * contributorship
 *
 * Citation.citedArtifact.contributorship: This element is used to list authors and other contributors, their contact information, specific contributions, and summary statements.
 *
 * http://hl7.org/fhir/contributorship
 */
var contributorship = 'http://hl7.org/fhir/contributorship';
/**
 * PlanDefinitionActionDynamicValueComponent
 *
 * PlanDefinitionActionComponent.PlanDefinitionActionDynamicValueComponent: Customizations that should be applied to the statically defined resource. For example, if the dosage of a medication must be computed based on the patient's weight, a customization would be used to specify an expression that calculated the weight, and the path on the resource that would contain the result.
 *
 * http://hl7.org/fhir/PlanDefinitionActionDynamicValueComponent
 */
var PlanDefinitionActionDynamicValueComponent = 'http://hl7.org/fhir/PlanDefinitionActionDynamicValueComponent';
/**
 * ImagingStudySeriesComponent
 *
 * ImagingStudySeriesComponent: Each study has one or more series of images or other content.
 *
 * http://hl7.org/fhir/ImagingStudySeriesComponent
 */
var ImagingStudySeriesComponent = 'http://hl7.org/fhir/ImagingStudySeriesComponent';
/**
 * programStatus
 *
 * Immunization.programEligibility.programStatus: Indicates the patient's eligility status for for a specific payment program.
 *
 * http://hl7.org/fhir/programStatus
 */
var programStatus = 'http://hl7.org/fhir/programStatus';
/**
 * _evidence
 *
 * (Modified) Permission.justification.evidence
 *
 * http://hl7.org/fhir/_evidence
 */
var _evidence = 'http://hl7.org/fhir/_evidence';
/**
 * ClinicalUseDefinitionInteractionInteractantComponent
 *
 * ClinicalUseDefinitionInteractionComponent.ClinicalUseDefinitionInteractionInteractantComponent: The specific medication, product, food, substance etc. or laboratory test that interacts.
 *
 * http://hl7.org/fhir/ClinicalUseDefinitionInteractionInteractantComponent
 */
var ClinicalUseDefinitionInteractionInteractantComponent = 'http://hl7.org/fhir/ClinicalUseDefinitionInteractionInteractantComponent';
/**
 * _highNumerator
 *
 * (Modified) RatioRange.highNumerator
 *
 * http://hl7.org/fhir/_highNumerator
 */
var _highNumerator = 'http://hl7.org/fhir/_highNumerator';
/**
 * ChargeItemDefinitionPropertyGroupComponent
 *
 * ChargeItemDefinitionPropertyGroupComponent: Group of properties which are applicable under the same conditions. If no applicability rules are established for the group, then all properties always apply.
 *
 * http://hl7.org/fhir/ChargeItemDefinitionPropertyGroupComponent
 */
var ChargeItemDefinitionPropertyGroupComponent = 'http://hl7.org/fhir/ChargeItemDefinitionPropertyGroupComponent';
/**
 * boolean
 *
 * Value of "true" or "false"
 *
 * http://hl7.org/fhir/boolean
 */
var boolean = 'http://hl7.org/fhir/boolean';
/**
 * PackagedProductDefinitionProperty
 *
 * Allows the key features to be recorded, such as "hospital pack", "nurse prescribable", "calendar pack".
 *
 * http://hl7.org/fhir/PackagedProductDefinitionProperty
 */
var PackagedProductDefinitionProperty = 'http://hl7.org/fhir/PackagedProductDefinitionProperty';
/**
 * _Group
 *
 * (Modified) Group
 *
 * http://hl7.org/fhir/_Group
 */
var _Group = 'http://hl7.org/fhir/_Group';
/**
 * _media
 *
 * (Modified) DiagnosticReport.media
 *
 * http://hl7.org/fhir/_media
 */
var _media = 'http://hl7.org/fhir/_media';
/**
 * hasStage
 *
 * ConditionDefinition.hasStage: Whether stage is appropriate to collect for this condition.
 *
 * http://hl7.org/fhir/hasStage
 */
var hasStage = 'http://hl7.org/fhir/hasStage';
/**
 * TestReportSetupActionAssertRequirementComponent
 *
 * TestReportTestComponent.TestActionAssert.TestReportSetupActionAssertRequirementComponent: Links or references providing traceability to the testing requirements for this assert.
 *
 * http://hl7.org/fhir/TestReportSetupActionAssertRequirementComponent
 */
var TestReportSetupActionAssertRequirementComponent = 'http://hl7.org/fhir/TestReportSetupActionAssertRequirementComponent';
/**
 * _onBehalfOf
 *
 * (Modified) VerificationResult.attestation.onBehalfOf
 *
 * http://hl7.org/fhir/_onBehalfOf
 */
var _onBehalfOf = 'http://hl7.org/fhir/_onBehalfOf';
/**
 * SubstanceReferenceInformationGeneElementComponent
 *
 * SubstanceReferenceInformationGeneElementComponent: Todo.
 *
 * http://hl7.org/fhir/SubstanceReferenceInformationGeneElementComponent
 */
var SubstanceReferenceInformationGeneElementComponent = 'http://hl7.org/fhir/SubstanceReferenceInformationGeneElementComponent';
/**
 * maxCount
 *
 * Subscription.maxCount: If present, the maximum number of events that will be included in a notification bundle. Note that this is not a strict limit on the number of entries in a bundle, as dependent resources can be included.
 *
 * http://hl7.org/fhir/maxCount
 */
var maxCount = 'http://hl7.org/fhir/maxCount';
/**
 * enableWhen
 *
 * Questionnaire.item.item.enableWhen: A constraint indicating that this item should only be enabled (displayed/allow answers to be captured) when the specified condition is true.
 *
 * http://hl7.org/fhir/enableWhen
 */
var enableWhen = 'http://hl7.org/fhir/enableWhen';
/**
 * regulator
 *
 * RegulatedAuthorization.regulator: The regulatory authority or authorizing body granting the authorization. For example, European Medicines Agency (EMA), Food and Drug Administration (FDA), Health Canada (HC), etc.
 *
 * http://hl7.org/fhir/regulator
 */
var regulator = 'http://hl7.org/fhir/regulator';
/**
 * _medicineClassification
 *
 * (Modified) MedicationKnowledge.medicineClassification
 *
 * http://hl7.org/fhir/_medicineClassification
 */
var _medicineClassification = 'http://hl7.org/fhir/_medicineClassification';
/**
 * imageRegion3D
 *
 * ImagingSelection.instance.imageRegion3D: Each imaging selection might includes a 3D image region, specified by a region type and a set of 3D coordinates.
 *
 * http://hl7.org/fhir/imageRegion3D
 */
var imageRegion3D = 'http://hl7.org/fhir/imageRegion3D';
/**
 * _source
 *
 * (Modified) SubstanceDefinition.name.translation.source
 *
 * http://hl7.org/fhir/_source
 */
var _source = 'http://hl7.org/fhir/_source';
/**
 * _hoursOfOperation
 *
 * (Modified) Location.hoursOfOperation
 *
 * http://hl7.org/fhir/_hoursOfOperation
 */
var _hoursOfOperation = 'http://hl7.org/fhir/_hoursOfOperation';
/**
 * admission
 *
 * Encounter.admission: Details about the stay during which a healthcare service is provided.

This does not describe the event of admitting the patient, but rather any information that is relevant from the time of admittance until the time of discharge.
 *
 * http://hl7.org/fhir/admission
 */
var admission = 'http://hl7.org/fhir/admission';
/**
 * extension
 *
 * DomainResource.extension: May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and managable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.
 *
 * http://hl7.org/fhir/extension
 */
var extension = 'http://hl7.org/fhir/extension';
/**
 * _reAdmission
 *
 * (Modified) Encounter.admission.reAdmission
 *
 * http://hl7.org/fhir/_reAdmission
 */
var _reAdmission = 'http://hl7.org/fhir/_reAdmission';
/**
 * integer64
 *
 * A very large whole number
 *
 * http://hl7.org/fhir/integer64
 */
var integer64 = 'http://hl7.org/fhir/integer64';
/**
 * _Task
 *
 * (Modified) Task
 *
 * http://hl7.org/fhir/_Task
 */
var _Task = 'http://hl7.org/fhir/_Task';
/**
 * HealthcareService
 *
 * The details of a healthcare service available at a location or in a catalog.  In the case where there is a hierarchy of services (for example, Lab -> Pathology -> Wound Cultures), this can be represented using a set of linked HealthcareServices.
 *
 * http://hl7.org/fhir/HealthcareService
 */
var HealthcareService = 'http://hl7.org/fhir/HealthcareService';
/**
 * _Appointment
 *
 * (Modified) Appointment
 *
 * http://hl7.org/fhir/_Appointment
 */
var _Appointment = 'http://hl7.org/fhir/_Appointment';
/**
 * _crossReference
 *
 * (Modified) MedicinalProductDefinition.crossReference
 *
 * http://hl7.org/fhir/_crossReference
 */
var _crossReference = 'http://hl7.org/fhir/_crossReference';
/**
 * _hasPart
 *
 * (Modified) DeviceDefinition.hasPart
 *
 * http://hl7.org/fhir/_hasPart
 */
var _hasPart = 'http://hl7.org/fhir/_hasPart';
/**
 * _executionPeriod
 *
 * (Modified) Task.executionPeriod
 *
 * http://hl7.org/fhir/_executionPeriod
 */
var _executionPeriod = 'http://hl7.org/fhir/_executionPeriod';
/**
 * Expression
 *
 * A expression that is evaluated in a specified context and returns a value. The context of use of the expression must specify the context in which the expression is evaluated, and how the result of the expression is used.
 *
 * http://hl7.org/fhir/Expression
 */
var Expression = 'http://hl7.org/fhir/Expression';
/**
 * Class
 *
 * Coverage.Class: A suite of underwriter specific classifiers.
 *
 * http://hl7.org/fhir/Class
 */
var Class = 'http://hl7.org/fhir/Class';
/**
 * _operation
 *
 * (Modified) TestScript.test.action.operation
 *
 * http://hl7.org/fhir/_operation
 */
var _operation = 'http://hl7.org/fhir/_operation';
/**
 * _adjustmentReason
 *
 * (Modified) ExplanationOfBenefit.payment.adjustmentReason
 *
 * http://hl7.org/fhir/_adjustmentReason
 */
var _adjustmentReason = 'http://hl7.org/fhir/_adjustmentReason';
/**
 * notConsumed
 *
 * NutritionIntake.consumedItem.notConsumed: Indicator when a patient is in a setting where it is helpful to know if food was not consumed, such as it was refused, held (as in tube feedings), or otherwise not provided. If a consumption is being recorded from an app, such as MyFitnessPal, this indicator will likely not be used.
 *
 * http://hl7.org/fhir/notConsumed
 */
var notConsumed = 'http://hl7.org/fhir/notConsumed';
/**
 * relativePath
 *
 * ImplementationGuide.manifest.resource.relativePath: The relative path for primary page for this resource within the IG.
 *
 * http://hl7.org/fhir/relativePath
 */
var relativePath = 'http://hl7.org/fhir/relativePath';
/**
 * ImplementationGuideDefinitionComponent
 *
 * ImplementationGuideDefinitionComponent: The information needed by an IG publisher tool to publish the whole implementation guide.
 *
 * http://hl7.org/fhir/ImplementationGuideDefinitionComponent
 */
var ImplementationGuideDefinitionComponent = 'http://hl7.org/fhir/ImplementationGuideDefinitionComponent';
/**
 * geneSequenceOrigin
 *
 * SubstanceReferenceInformation.gene.geneSequenceOrigin: Todo.
 *
 * http://hl7.org/fhir/geneSequenceOrigin
 */
var geneSequenceOrigin = 'http://hl7.org/fhir/geneSequenceOrigin';
/**
 * level
 *
 * Evidence.statistic.modelCharacteristic.attributeEstimate.level: Use 95 for a 95% confidence interval.
 *
 * http://hl7.org/fhir/level
 */
var level = 'http://hl7.org/fhir/level';
/**
 * TestReportTestComponent
 *
 * TestReportTestComponent: A test executed from the test script.
 *
 * http://hl7.org/fhir/TestReportTestComponent
 */
var TestReportTestComponent = 'http://hl7.org/fhir/TestReportTestComponent';
/**
 * doseNumber
 *
 * ImmunizationRecommendation.recommendation.doseNumber: Nominal position of the recommended dose in a series as determined by the evaluation and forecasting process (e.g. dose 2 is the next recommended dose).
 *
 * http://hl7.org/fhir/doseNumber
 */
var doseNumber = 'http://hl7.org/fhir/doseNumber';
/**
 * ParametersParameterComponentParameterParameter
 *
 * A named part of a multi-part parameter.
 *
 * http://hl7.org/fhir/ParametersParameterComponentParameterParameter
 */
var ParametersParameterComponentParameterParameter = 'http://hl7.org/fhir/ParametersParameterComponentParameterParameter';
/**
 * age
 *
 * FamilyMemberHistory.age
 *
 * http://hl7.org/fhir/age
 */
var age = 'http://hl7.org/fhir/age';
/**
 * _payload
 *
 * (Modified) Endpoint.payload
 *
 * http://hl7.org/fhir/_payload
 */
var _payload = 'http://hl7.org/fhir/_payload';
/**
 * entityRelatedness
 *
 * AdverseEvent.suspectEntity.causality.entityRelatedness: The result of the assessment regarding the relatedness of the suspected entity to the event.
 *
 * http://hl7.org/fhir/entityRelatedness
 */
var entityRelatedness = 'http://hl7.org/fhir/entityRelatedness';
/**
 * startParam
 *
 * CompartmentDefinition.resource.startParam: Search Parameter for mapping requests made with $everything.start (e.g. on [Patient.$everything](patient-operation-everything.html)).
 *
 * http://hl7.org/fhir/startParam
 */
var startParam = 'http://hl7.org/fhir/startParam';
/**
 * _intraspecificDescription
 *
 * (Modified) SubstanceSourceMaterial.organism.intraspecificDescription
 *
 * http://hl7.org/fhir/_intraspecificDescription
 */
var _intraspecificDescription = 'http://hl7.org/fhir/_intraspecificDescription';
/**
 * _clinicalStatus
 *
 * (Modified) Condition.clinicalStatus
 *
 * http://hl7.org/fhir/_clinicalStatus
 */
var _clinicalStatus = 'http://hl7.org/fhir/_clinicalStatus';
/**
 * _compositeScoring
 *
 * (Modified) Measure.compositeScoring
 *
 * http://hl7.org/fhir/_compositeScoring
 */
var _compositeScoring = 'http://hl7.org/fhir/_compositeScoring';
/**
 * jurisdiction
 *
 * SubstanceDefinition.name.synonym.jurisdiction: The jurisdiction where this name applies.
 *
 * http://hl7.org/fhir/jurisdiction
 */
var jurisdiction = 'http://hl7.org/fhir/jurisdiction';
/**
 * Exemption
 *
 * Coverage.CostToBeneficiary.Exemption: A suite of codes indicating exceptions or reductions to patient costs and their effective periods.
 *
 * http://hl7.org/fhir/Exemption
 */
var Exemption = 'http://hl7.org/fhir/Exemption';
/**
 * _requestHeader
 *
 * (Modified) TestScript.teardown.action.operation.requestHeader
 *
 * http://hl7.org/fhir/_requestHeader
 */
var _requestHeader = 'http://hl7.org/fhir/_requestHeader';
/**
 * _certainty
 *
 * (Modified) Evidence.certainty
 *
 * http://hl7.org/fhir/_certainty
 */
var _certainty = 'http://hl7.org/fhir/_certainty';
/**
 * connectionType
 *
 * Endpoint.connectionType: A coded value that represents the technical details of the usage of this endpoint, such as what WSDLs should be used in what way. (e.g. XDS.b/DICOM/cds-hook).
 *
 * http://hl7.org/fhir/connectionType
 */
var connectionType = 'http://hl7.org/fhir/connectionType';
/**
 * _groupingBehavior
 *
 * (Modified) RequestOrchestration.action.action.groupingBehavior
 *
 * http://hl7.org/fhir/_groupingBehavior
 */
var _groupingBehavior = 'http://hl7.org/fhir/_groupingBehavior';
/**
 * _translations
 *
 * (Modified) TerminologyCapabilities.validateCode.translations
 *
 * http://hl7.org/fhir/_translations
 */
var _translations = 'http://hl7.org/fhir/_translations';
/**
 * photo
 *
 * Person.photo: An image that can be displayed as a thumbnail of the person to enhance the identification of the individual.
 *
 * http://hl7.org/fhir/photo
 */
var photo = 'http://hl7.org/fhir/photo';
/**
 * multipleAnd
 *
 * SearchParameter.multipleAnd: Whether multiple parameters are allowed - e.g. more than one parameter with the same name. The search matches if all the parameters match.
 *
 * http://hl7.org/fhir/multipleAnd
 */
var multipleAnd = 'http://hl7.org/fhir/multipleAnd';
/**
 * _gender
 *
 * (Modified) RelatedPerson.gender
 *
 * http://hl7.org/fhir/_gender
 */
var _gender = 'http://hl7.org/fhir/_gender';
/**
 * _coding
 *
 * (Modified) CodeableConcept.coding
 *
 * http://hl7.org/fhir/_coding
 */
var _coding = 'http://hl7.org/fhir/_coding';
/**
 * _system
 *
 * (Modified) Coding.system
 *
 * http://hl7.org/fhir/_system
 */
var _system = 'http://hl7.org/fhir/_system';
/**
 * _Slot
 *
 * (Modified) Slot
 *
 * http://hl7.org/fhir/_Slot
 */
var _Slot = 'http://hl7.org/fhir/_Slot';
/**
 * freeToShare
 *
 * ArtifactAssessment.content.component.freeToShare: Acceptable to publicly share the comment, classifier or rating.
 *
 * http://hl7.org/fhir/freeToShare
 */
var freeToShare = 'http://hl7.org/fhir/freeToShare';
/**
 * ElementDefinitionMappingComponent
 *
 * ElementDefinitionMappingComponent: Identifies a concept from an external specification that roughly corresponds to this element.
 *
 * http://hl7.org/fhir/ElementDefinitionMappingComponent
 */
var ElementDefinitionMappingComponent = 'http://hl7.org/fhir/ElementDefinitionMappingComponent';
/**
 * copackagedIndicator
 *
 * PackagedProductDefinition.copackagedIndicator: Identifies if the package contains different items, such as when a drug product is supplied with another item e.g. a diluent or adjuvant.
 *
 * http://hl7.org/fhir/copackagedIndicator
 */
var copackagedIndicator = 'http://hl7.org/fhir/copackagedIndicator';
/**
 * precheckBehavior
 *
 * RequestOrchestration.action.action.precheckBehavior: Defines whether the action should usually be preselected.
 *
 * http://hl7.org/fhir/precheckBehavior
 */
var precheckBehavior = 'http://hl7.org/fhir/precheckBehavior';
/**
 * map
 *
 * ElementDefinition.mapping.map: Expresses what part of the target specification corresponds to this element.
 *
 * http://hl7.org/fhir/map
 */
var map = 'http://hl7.org/fhir/map';
/**
 * additionalInfo
 *
 * VirtualServiceDetail.additionalInfo: Address to see alternative connection details.
 *
 * http://hl7.org/fhir/additionalInfo
 */
var additionalInfo = 'http://hl7.org/fhir/additionalInfo';
/**
 * preConditions
 *
 * ExampleScenario.process.step.alternative.step.process.preConditions: Description of the initial state of the actors, environment and data before the process starts.
 *
 * http://hl7.org/fhir/preConditions
 */
var preConditions = 'http://hl7.org/fhir/preConditions';
/**
 * numberOfSubunits
 *
 * SubstanceProtein.numberOfSubunits: Number of linear sequences of amino acids linked through peptide bonds. The number of subunits constituting the SubstanceProtein shall be described. It is possible that the number of subunits can be variable.
 *
 * http://hl7.org/fhir/numberOfSubunits
 */
var numberOfSubunits = 'http://hl7.org/fhir/numberOfSubunits';
/**
 * numberOfEvents
 *
 * Evidence.statistic.numberOfEvents: The number of events associated with the statistic, where the unit of analysis is different from numberAffected, sampleSize.knownDataCount and sampleSize.numberOfParticipants.
 *
 * http://hl7.org/fhir/numberOfEvents
 */
var numberOfEvents = 'http://hl7.org/fhir/numberOfEvents';
/**
 * _sender
 *
 * (Modified) MessageHeader.sender
 *
 * http://hl7.org/fhir/_sender
 */
var _sender = 'http://hl7.org/fhir/_sender';
/**
 * _validCodedValueSet
 *
 * (Modified) ObservationDefinition.component.qualifiedValue.validCodedValueSet
 *
 * http://hl7.org/fhir/_validCodedValueSet
 */
var _validCodedValueSet = 'http://hl7.org/fhir/_validCodedValueSet';
/**
 * _referenceInformation
 *
 * (Modified) SubstanceDefinition.referenceInformation
 *
 * http://hl7.org/fhir/_referenceInformation
 */
var _referenceInformation = 'http://hl7.org/fhir/_referenceInformation';
/**
 * longitude
 *
 * Location.position.longitude: Longitude. The value domain and the interpretation are the same as for the text of the longitude element in KML (see notes on Location main page).
 *
 * http://hl7.org/fhir/longitude
 */
var longitude = 'http://hl7.org/fhir/longitude';
/**
 * _contentDerivative
 *
 * (Modified) Contract.contentDerivative
 *
 * http://hl7.org/fhir/_contentDerivative
 */
var _contentDerivative = 'http://hl7.org/fhir/_contentDerivative';
/**
 * _reportedDateTime
 *
 * (Modified) InventoryReport.reportedDateTime
 *
 * http://hl7.org/fhir/_reportedDateTime
 */
var _reportedDateTime = 'http://hl7.org/fhir/_reportedDateTime';
/**
 * Primitive
 *
 * Types with only a value and no additional elements as children
 *
 * http://hl7.org/fhir/Primitive
 */
var Primitive = 'http://hl7.org/fhir/Primitive';
/**
 * _processingMode
 *
 * (Modified) SearchParameter.processingMode
 *
 * http://hl7.org/fhir/_processingMode
 */
var _processingMode = 'http://hl7.org/fhir/_processingMode';
/**
 * _composition
 *
 * (Modified) DiagnosticReport.composition
 *
 * http://hl7.org/fhir/_composition
 */
var _composition = 'http://hl7.org/fhir/_composition';
/**
 * _width
 *
 * (Modified) Attachment.width
 *
 * http://hl7.org/fhir/_width
 */
var _width = 'http://hl7.org/fhir/_width';
/**
 * _valueAlternatives
 *
 * (Modified) ElementDefinition.valueAlternatives
 *
 * http://hl7.org/fhir/_valueAlternatives
 */
var _valueAlternatives = 'http://hl7.org/fhir/_valueAlternatives';
/**
 * hint
 *
 * TestScript.variable.hint: Displayable text string with hint help information to the user when entering a default value.
 *
 * http://hl7.org/fhir/hint
 */
var hint = 'http://hl7.org/fhir/hint';
/**
 * license
 *
 * ImplementationGuide.license: The license that applies to this Implementation Guide, using an SPDX license code, or 'not-open-source'.
 *
 * http://hl7.org/fhir/license
 */
var license = 'http://hl7.org/fhir/license';
/**
 * created
 *
 * ExplanationOfBenefit.created: The date this resource was created.
 *
 * http://hl7.org/fhir/created
 */
var created = 'http://hl7.org/fhir/created';
/**
 * expectedInResearchStudy
 *
 * AdverseEvent.expectedInResearchStudy: Considered likely or probable or anticipated in the research study.  Whether the reported event matches any of the outcomes for the patient that are considered by the study as known or likely.
 *
 * http://hl7.org/fhir/expectedInResearchStudy
 */
var expectedInResearchStudy = 'http://hl7.org/fhir/expectedInResearchStudy';
/**
 * originalPrescription
 *
 * ExplanationOfBenefit.originalPrescription: Original prescription which has been superseded by this prescription to support the dispensing of pharmacy services, medications or products.
 *
 * http://hl7.org/fhir/originalPrescription
 */
var originalPrescription = 'http://hl7.org/fhir/originalPrescription';
/**
 * scoring
 *
 * MeasureReport.scoring: Indicates how the calculation is performed for the measure, including proportion, ratio, continuous-variable, and cohort. The value set is extensible, allowing additional measure scoring types to be represented. It is expected to be the same as the scoring element on the referenced Measure.
 *
 * http://hl7.org/fhir/scoring
 */
var scoring = 'http://hl7.org/fhir/scoring';
/**
 * ClinicalUseDefinitionInteractionComponent
 *
 * ClinicalUseDefinitionInteractionComponent: Specifics for when this is an interaction.
 *
 * http://hl7.org/fhir/ClinicalUseDefinitionInteractionComponent
 */
var ClinicalUseDefinitionInteractionComponent = 'http://hl7.org/fhir/ClinicalUseDefinitionInteractionComponent';
/**
 * PlanDefinitionActorComponent
 *
 * PlanDefinitionActorComponent: Actors represent the individuals or groups involved in the execution of the defined set of activities.
 *
 * http://hl7.org/fhir/PlanDefinitionActorComponent
 */
var PlanDefinitionActorComponent = 'http://hl7.org/fhir/PlanDefinitionActorComponent';
/**
 * subjectStatus
 *
 * EncounterHistory.subjectStatus: The subjectStatus value can be used to track the patient's status within the encounter. It details whether the patient has arrived or departed, has been triaged or is currently in a waiting status.
 *
 * http://hl7.org/fhir/subjectStatus
 */
var subjectStatus = 'http://hl7.org/fhir/subjectStatus';
/**
 * _qualitativeRisk
 *
 * (Modified) RiskAssessment.prediction.qualitativeRisk
 *
 * http://hl7.org/fhir/_qualitativeRisk
 */
var _qualitativeRisk = 'http://hl7.org/fhir/_qualitativeRisk';
/**
 * _header
 *
 * (Modified) Endpoint.header
 *
 * http://hl7.org/fhir/_header
 */
var _header = 'http://hl7.org/fhir/_header';
/**
 * recurrenceId
 *
 * AppointmentResponse.recurrenceId: The recurrence ID (sequence number) of the specific appointment when responding to a recurring request.
 *
 * http://hl7.org/fhir/recurrenceId
 */
var recurrenceId = 'http://hl7.org/fhir/recurrenceId';
/**
 * _author
 *
 * (Modified) EvidenceReport.section.section.author
 *
 * http://hl7.org/fhir/_author
 */
var _author = 'http://hl7.org/fhir/_author';
/**
 * responsibleOrganization
 *
 * InventoryItem.responsibleOrganization: Organization(s) responsible for the product.
 *
 * http://hl7.org/fhir/responsibleOrganization
 */
var responsibleOrganization = 'http://hl7.org/fhir/responsibleOrganization';
/**
 * TriggerDefinition
 *
 * A description of a triggering event. Triggering events can be named events, data events, or periodic, as determined by the type element.
 *
 * http://hl7.org/fhir/TriggerDefinition
 */
var TriggerDefinition = 'http://hl7.org/fhir/TriggerDefinition';
/**
 * _BackboneElement
 *
 * http://hl7.org/fhir/_BackboneElement
 */
var _BackboneElement = 'http://hl7.org/fhir/_BackboneElement';
/**
 * _offeredIn
 *
 * (Modified) HealthcareService.offeredIn
 *
 * http://hl7.org/fhir/_offeredIn
 */
var _offeredIn = 'http://hl7.org/fhir/_offeredIn';
/**
 * _accessionNumber
 *
 * (Modified) Citation.citedArtifact.publicationForm.accessionNumber
 *
 * http://hl7.org/fhir/_accessionNumber
 */
var _accessionNumber = 'http://hl7.org/fhir/_accessionNumber';
/**
 * legalState
 *
 * Contract.legalState: Legal states of the formation of a legal instrument, which is a formally executed written document that can be formally attributed to its author, records and formally expresses a legally enforceable act, process, or contractual duty, obligation, or right, and therefore evidences that act, process, or agreement.
 *
 * http://hl7.org/fhir/legalState
 */
var legalState = 'http://hl7.org/fhir/legalState';
/**
 * incomplete
 *
 * TerminologyCapabilities.expansion.incomplete: True if requests for incomplete expansions are allowed.
 *
 * http://hl7.org/fhir/incomplete
 */
var incomplete = 'http://hl7.org/fhir/incomplete';
/**
 * CodeableReference
 *
 * A reference to a resource (by instance), or instead, a reference to a concept defined in a terminology or ontology (by class).
 *
 * http://hl7.org/fhir/CodeableReference
 */
var CodeableReference = 'http://hl7.org/fhir/CodeableReference';
/**
 * activity
 *
 * Citation.citedArtifact.statusDate.activity: A definition of the status associated with a date or period.
 *
 * http://hl7.org/fhir/activity
 */
var activity = 'http://hl7.org/fhir/activity';
/**
 * availableEndTime
 *
 * Availability.availableTime.availableEndTime: Closing time of day (ignored if allDay = true).
 *
 * http://hl7.org/fhir/availableEndTime
 */
var availableEndTime = 'http://hl7.org/fhir/availableEndTime';
/**
 * mimeType
 *
 * Endpoint.payload.mimeType: The mime type to send the payload in - e.g. application/fhir+xml, application/fhir+json. If the mime type is not specified, then the sender could send any content (including no content depending on the connectionType).
 *
 * http://hl7.org/fhir/mimeType
 */
var mimeType = 'http://hl7.org/fhir/mimeType';
/**
 * NutritionOrderEnteralFormulaAdministrationComponent
 *
 * NutritionOrderEnteralFormulaComponent.NutritionOrderEnteralFormulaAdministrationComponent: Formula administration instructions as structured data.  This repeating structure allows for changing the administration rate or volume over time for both bolus and continuous feeding.  An example of this would be an instruction to increase the rate of continuous feeding every 2 hours.
 *
 * http://hl7.org/fhir/NutritionOrderEnteralFormulaAdministrationComponent
 */
var NutritionOrderEnteralFormulaAdministrationComponent = 'http://hl7.org/fhir/NutritionOrderEnteralFormulaAdministrationComponent';
/**
 * periodUnit
 *
 * Timing.repeat.periodUnit: The units of time for the period in UCUM units
 * Normal practice is to use the 'mo' code as a calendar month when calculating the next occurrence.
 *
 * http://hl7.org/fhir/periodUnit
 */
var periodUnit = 'http://hl7.org/fhir/periodUnit';
/**
 * EvidenceReportRelatesToComponent
 *
 * EvidenceReportRelatesToComponent: Relationships that this composition has with other compositions or documents that already exist.
 *
 * http://hl7.org/fhir/EvidenceReportRelatesToComponent
 */
var EvidenceReportRelatesToComponent = 'http://hl7.org/fhir/EvidenceReportRelatesToComponent';
/**
 * SubstanceDefinition
 *
 * The detailed description of a substance, typically at a level beyond what is used for prescribing.
 *
 * http://hl7.org/fhir/SubstanceDefinition
 */
var SubstanceDefinition = 'http://hl7.org/fhir/SubstanceDefinition';
/**
 * _useContext
 *
 * (Modified) Library.useContext
 *
 * http://hl7.org/fhir/_useContext
 */
var _useContext = 'http://hl7.org/fhir/_useContext';
/**
 * _instantiatesUri
 *
 * (Modified) Transport.instantiatesUri
 *
 * http://hl7.org/fhir/_instantiatesUri
 */
var _instantiatesUri = 'http://hl7.org/fhir/_instantiatesUri';
/**
 * authorizationUrl
 *
 * CoverageEligibilityResponse.insurance.item.authorizationUrl: A web location for obtaining requirements or descriptive information regarding the preauthorization.
 *
 * http://hl7.org/fhir/authorizationUrl
 */
var authorizationUrl = 'http://hl7.org/fhir/authorizationUrl';
/**
 * contributedToDeath
 *
 * FamilyMemberHistory.procedure.contributedToDeath: This procedure contributed to the cause of death of the related person. If contributedToDeath is not populated, then it is unknown.
 *
 * http://hl7.org/fhir/contributedToDeath
 */
var contributedToDeath = 'http://hl7.org/fhir/contributedToDeath';
/**
 * confidentialityIndicator
 *
 * MedicinalProductDefinition.operation.confidentialityIndicator: Specifies whether this particular business or manufacturing process is considered proprietary or confidential.
 *
 * http://hl7.org/fhir/confidentialityIndicator
 */
var confidentialityIndicator = 'http://hl7.org/fhir/confidentialityIndicator';
/**
 * _diagnosisSequence
 *
 * (Modified) ExplanationOfBenefit.item.diagnosisSequence
 *
 * http://hl7.org/fhir/_diagnosisSequence
 */
var _diagnosisSequence = 'http://hl7.org/fhir/_diagnosisSequence';
/**
 * selectionBehavior
 *
 * PlanDefinition.action.action.selectionBehavior: Defines the selection behavior for the action and its children.
 *
 * http://hl7.org/fhir/selectionBehavior
 */
var selectionBehavior = 'http://hl7.org/fhir/selectionBehavior';
/**
 * _time
 *
 * (Modified) Specimen.processing.time
 *
 * http://hl7.org/fhir/_time
 */
var _time = 'http://hl7.org/fhir/_time';
/**
 * addresses
 *
 * Goal.addresses: The identified conditions and other health record elements that are intended to be addressed by the goal.
 *
 * http://hl7.org/fhir/addresses
 */
var addresses = 'http://hl7.org/fhir/addresses';
/**
 * _dataRequirement
 *
 * (Modified) Library.dataRequirement
 *
 * http://hl7.org/fhir/_dataRequirement
 */
var _dataRequirement = 'http://hl7.org/fhir/_dataRequirement';
/**
 * CapabilityStatementRestResourceComponent
 *
 * CapabilityStatementRestComponent.CapabilityStatementRestResourceComponent: A specification of the restful capabilities of the solution for a specific resource type.
 *
 * http://hl7.org/fhir/CapabilityStatementRestResourceComponent
 */
var CapabilityStatementRestResourceComponent = 'http://hl7.org/fhir/CapabilityStatementRestResourceComponent';
/**
 * _lineItem
 *
 * (Modified) Invoice.lineItem
 *
 * http://hl7.org/fhir/_lineItem
 */
var _lineItem = 'http://hl7.org/fhir/_lineItem';
/**
 * _InventoryReport
 *
 * (Modified) InventoryReport
 *
 * http://hl7.org/fhir/_InventoryReport
 */
var _InventoryReport = 'http://hl7.org/fhir/_InventoryReport';
/**
 * _copyright
 *
 * (Modified) ArtifactAssessment.copyright
 *
 * http://hl7.org/fhir/_copyright
 */
var _copyright = 'http://hl7.org/fhir/_copyright';
/**
 * _Substance
 *
 * (Modified) Substance
 *
 * http://hl7.org/fhir/_Substance
 */
var _Substance = 'http://hl7.org/fhir/_Substance';
/**
 * _timing
 *
 * (Modified) PlanDefinition.action.timing
 *
 * http://hl7.org/fhir/_timing
 */
var _timing = 'http://hl7.org/fhir/_timing';
/**
 * wasSubstituted
 *
 * MedicationDispense.substitution.wasSubstituted: True if the dispenser dispensed a different drug or product from what was prescribed.
 *
 * http://hl7.org/fhir/wasSubstituted
 */
var wasSubstituted = 'http://hl7.org/fhir/wasSubstituted';
/**
 * aggregation
 *
 * ElementDefinition.type.aggregation: If the type is a reference to another resource, how the resource is or can be aggregated - is it a contained resource, or a reference, and if the context is a bundle, is it included in the bundle.
 *
 * http://hl7.org/fhir/aggregation
 */
var aggregation = 'http://hl7.org/fhir/aggregation';
/**
 * _authorDescription
 *
 * (Modified) SubstanceSourceMaterial.organism.author.authorDescription
 *
 * http://hl7.org/fhir/_authorDescription
 */
var _authorDescription = 'http://hl7.org/fhir/_authorDescription';
/**
 * _filter
 *
 * (Modified) ValueSet.compose.exclude.filter
 *
 * http://hl7.org/fhir/_filter
 */
var _filter = 'http://hl7.org/fhir/_filter';
/**
 * MedicinalProductDefinitionOperationComponent
 *
 * MedicinalProductDefinitionOperationComponent: A manufacturing or administrative process or step associated with (or performed on) the medicinal product.
 *
 * http://hl7.org/fhir/MedicinalProductDefinitionOperationComponent
 */
var MedicinalProductDefinitionOperationComponent = 'http://hl7.org/fhir/MedicinalProductDefinitionOperationComponent';
/**
 * _defaultValue
 *
 * (Modified) TestScript.variable.defaultValue
 *
 * http://hl7.org/fhir/_defaultValue
 */
var _defaultValue = 'http://hl7.org/fhir/_defaultValue';
/**
 * StructureMapStructureComponent
 *
 * StructureMapStructureComponent: A structure definition used by this map. The structure definition may describe instances that are converted, or the instances that are produced.
 *
 * http://hl7.org/fhir/StructureMapStructureComponent
 */
var StructureMapStructureComponent = 'http://hl7.org/fhir/StructureMapStructureComponent';
/**
 * recipient
 *
 * Task.restriction.recipient: For requests that are targeted to more than one potential recipient/target, to identify who is fulfillment is sought for.
 *
 * http://hl7.org/fhir/recipient
 */
var recipient = 'http://hl7.org/fhir/recipient';
/**
 * _lotNumber
 *
 * (Modified) NutritionProduct.instance.lotNumber
 *
 * http://hl7.org/fhir/_lotNumber
 */
var _lotNumber = 'http://hl7.org/fhir/_lotNumber';
/**
 * QuestionnaireItemAnswerOptionComponent
 *
 * QuestionnaireItemComponentItem.QuestionnaireItemAnswerOptionComponent: One of the permitted answers for the question.
 *
 * http://hl7.org/fhir/QuestionnaireItemAnswerOptionComponent
 */
var QuestionnaireItemAnswerOptionComponent = 'http://hl7.org/fhir/QuestionnaireItemAnswerOptionComponent';
/**
 * applies
 *
 * Contract.applies: Relevant time or time-period when this Contract is applicable.
 *
 * http://hl7.org/fhir/applies
 */
var applies = 'http://hl7.org/fhir/applies';
/**
 * caseSensitive
 *
 * CodeSystem.caseSensitive: If code comparison is case sensitive when codes within this system are compared to each other.
 *
 * http://hl7.org/fhir/caseSensitive
 */
var caseSensitive = 'http://hl7.org/fhir/caseSensitive';
/**
 * subtype
 *
 * Contract.term.group.asset.subtype: May be a subtype or part of an offered asset.
 *
 * http://hl7.org/fhir/subtype
 */
var subtype = 'http://hl7.org/fhir/subtype';
/**
 * _field
 *
 * (Modified) TestScript.teardown.action.operation.requestHeader.field
 *
 * http://hl7.org/fhir/_field
 */
var _field = 'http://hl7.org/fhir/_field';
/**
 * _hasIngredient
 *
 * (Modified) ManufacturedItemDefinition.component.component.constituent.hasIngredient
 *
 * http://hl7.org/fhir/_hasIngredient
 */
var _hasIngredient = 'http://hl7.org/fhir/_hasIngredient';
/**
 * strength
 *
 * OperationDefinition.parameter.part.binding.strength: Indicates the degree of conformance expectations associated with this binding - that is, the degree to which the provided value set must be adhered to in the instances.
 *
 * http://hl7.org/fhir/strength
 */
var strength = 'http://hl7.org/fhir/strength';
/**
 * linkId
 *
 * ResearchStudy.comparisonGroup.linkId: Allows the comparisonGroup for the study and the comparisonGroup for the subject to be linked easily.
 *
 * http://hl7.org/fhir/linkId
 */
var linkId = 'http://hl7.org/fhir/linkId';
/**
 * StructureMapGroupRuleTargetComponent
 *
 * StructureMapGroupComponent.StructureMapGroupRuleComponentRule.StructureMapGroupRuleTargetComponent: Content to create because of this mapping rule.
 *
 * http://hl7.org/fhir/StructureMapGroupRuleTargetComponent
 */
var StructureMapGroupRuleTargetComponent = 'http://hl7.org/fhir/StructureMapGroupRuleTargetComponent';
/**
 * _resultingEffect
 *
 * (Modified) AdverseEvent.resultingEffect
 *
 * http://hl7.org/fhir/_resultingEffect
 */
var _resultingEffect = 'http://hl7.org/fhir/_resultingEffect';
/**
 * altitude
 *
 * Location.position.altitude: Altitude. The value domain and the interpretation are the same as for the text of the altitude element in KML (see notes on Location main page).
 *
 * http://hl7.org/fhir/altitude
 */
var altitude = 'http://hl7.org/fhir/altitude';
/**
 * phase
 *
 * TestScript.scope.phase: The phase of testing for this artifact: unit - development / implementation phase, integration - internal system to system phase, production - live system to system phase (Note, this may involve pii/phi data).
 *
 * http://hl7.org/fhir/phase
 */
var phase = 'http://hl7.org/fhir/phase';
/**
 * _numberOfRepeatsAllowed
 *
 * (Modified) MedicationRequest.dispenseRequest.numberOfRepeatsAllowed
 *
 * http://hl7.org/fhir/_numberOfRepeatsAllowed
 */
var _numberOfRepeatsAllowed = 'http://hl7.org/fhir/_numberOfRepeatsAllowed';
/**
 * groupSize
 *
 * InsurancePlan.plan.generalCost.groupSize: Number of participants enrolled in the plan.
 *
 * http://hl7.org/fhir/groupSize
 */
var groupSize = 'http://hl7.org/fhir/groupSize';
/**
 * _oligoNucleotideType
 *
 * (Modified) SubstanceNucleicAcid.oligoNucleotideType
 *
 * http://hl7.org/fhir/_oligoNucleotideType
 */
var _oligoNucleotideType = 'http://hl7.org/fhir/_oligoNucleotideType';
/**
 * doseStatus
 *
 * ImmunizationEvaluation.doseStatus: Indicates if the dose is valid or not valid with respect to the published recommendations.
 *
 * http://hl7.org/fhir/doseStatus
 */
var doseStatus = 'http://hl7.org/fhir/doseStatus';
/**
 * directnessMatch
 *
 * Evidence.variableDefinition.directnessMatch: Indication of quality of match between intended variable to actual variable.
 *
 * http://hl7.org/fhir/directnessMatch
 */
var directnessMatch = 'http://hl7.org/fhir/directnessMatch';
/**
 * AppointmentParticipantComponent
 *
 * AppointmentParticipantComponent: List of participants involved in the appointment.
 *
 * http://hl7.org/fhir/AppointmentParticipantComponent
 */
var AppointmentParticipantComponent = 'http://hl7.org/fhir/AppointmentParticipantComponent';
/**
 * _continuous
 *
 * (Modified) Goal.continuous
 *
 * http://hl7.org/fhir/_continuous
 */
var _continuous = 'http://hl7.org/fhir/_continuous';
/**
 * _dispenseInterval
 *
 * (Modified) MedicationRequest.dispenseRequest.dispenseInterval
 *
 * http://hl7.org/fhir/_dispenseInterval
 */
var _dispenseInterval = 'http://hl7.org/fhir/_dispenseInterval';
/**
 * stage
 *
 * ConditionDefinition.stage: Clinical stage or grade of a condition. May include formal severity assessments.
 *
 * http://hl7.org/fhir/stage
 */
var stage = 'http://hl7.org/fhir/stage';
/**
 * associatedMedication
 *
 * MedicationKnowledge.associatedMedication: Links to associated medications that could be prescribed, dispensed or administered.
 *
 * http://hl7.org/fhir/associatedMedication
 */
var associatedMedication = 'http://hl7.org/fhir/associatedMedication';
/**
 * dateOfDiagnosis
 *
 * Account.diagnosis.dateOfDiagnosis: Ranking of the diagnosis (for each type).
 *
 * http://hl7.org/fhir/dateOfDiagnosis
 */
var dateOfDiagnosis = 'http://hl7.org/fhir/dateOfDiagnosis';
/**
 * _actualPeriod
 *
 * (Modified) EncounterHistory.actualPeriod
 *
 * http://hl7.org/fhir/_actualPeriod
 */
var _actualPeriod = 'http://hl7.org/fhir/_actualPeriod';
/**
 * ValueSet
 *
 * A ValueSet resource instance specifies a set of codes drawn from one or more code systems, intended for use in a particular context. Value sets link between [[[CodeSystem]]] definitions and their use in [coded elements](terminologies.html).
 *
 * http://hl7.org/fhir/ValueSet
 */
var ValueSet = 'http://hl7.org/fhir/ValueSet';
/**
 * lastOccurrence
 *
 * AllergyIntolerance.lastOccurrence: Represents the date and/or time of the last known occurrence of a reaction event.
 *
 * http://hl7.org/fhir/lastOccurrence
 */
var lastOccurrence = 'http://hl7.org/fhir/lastOccurrence';
/**
 * disulfideLinkage
 *
 * SubstanceProtein.disulfideLinkage: The disulphide bond between two cysteine residues either on the same subunit or on two different subunits shall be described. The position of the disulfide bonds in the SubstanceProtein shall be listed in increasing order of subunit number and position within subunit followed by the abbreviation of the amino acids involved. The disulfide linkage positions shall actually contain the amino acid Cysteine at the respective positions.
 *
 * http://hl7.org/fhir/disulfideLinkage
 */
var disulfideLinkage = 'http://hl7.org/fhir/disulfideLinkage';
/**
 * participatingOrganization
 *
 * OrganizationAffiliation.participatingOrganization: The Participating Organization provides/performs the role(s) defined by the code to the Primary Organization (e.g. providing services or is a member of).
 *
 * http://hl7.org/fhir/participatingOrganization
 */
var participatingOrganization = 'http://hl7.org/fhir/participatingOrganization';
/**
 * ResearchSubject
 *
 * A ResearchSubject is a participant or object which is the recipient of investigative activities in a research study.
 *
 * http://hl7.org/fhir/ResearchSubject
 */
var ResearchSubject = 'http://hl7.org/fhir/ResearchSubject';
/**
 * heartbeatPeriod
 *
 * Subscription.heartbeatPeriod: If present, a 'heartbeat' notification (keep-alive) is sent via this channel with an interval period equal to this elements integer value in seconds.  If not present, a heartbeat notification is not sent.
 *
 * http://hl7.org/fhir/heartbeatPeriod
 */
var heartbeatPeriod = 'http://hl7.org/fhir/heartbeatPeriod';
/**
 * OrganizationAffiliation
 *
 * Defines an affiliation/assotiation/relationship between 2 distinct organizations, that is not a part-of relationship/sub-division relationship.
 *
 * http://hl7.org/fhir/OrganizationAffiliation
 */
var OrganizationAffiliation = 'http://hl7.org/fhir/OrganizationAffiliation';
/**
 * _binding
 *
 * (Modified) OperationDefinition.parameter.part.binding
 *
 * http://hl7.org/fhir/_binding
 */
var _binding = 'http://hl7.org/fhir/_binding';
/**
 * SubstanceNucleicAcidSubunitLinkageComponent
 *
 * SubstanceNucleicAcidSubunitComponent.SubstanceNucleicAcidSubunitLinkageComponent: The linkages between sugar residues will also be captured.
 *
 * http://hl7.org/fhir/SubstanceNucleicAcidSubunitLinkageComponent
 */
var SubstanceNucleicAcidSubunitLinkageComponent = 'http://hl7.org/fhir/SubstanceNucleicAcidSubunitLinkageComponent';
/**
 * ImplementationGuideDefinitionPageComponent
 *
 * ImplementationGuideDefinitionComponent.ImplementationGuideDefinitionPageComponent: A page / section in the implementation guide. The root page is the implementation guide home page.
 *
 * http://hl7.org/fhir/ImplementationGuideDefinitionPageComponent
 */
var ImplementationGuideDefinitionPageComponent = 'http://hl7.org/fhir/ImplementationGuideDefinitionPageComponent';
/**
 * FamilyMemberHistoryProcedureComponent
 *
 * FamilyMemberHistoryProcedureComponent: The significant Procedures (or procedure) that the family member had. This is a repeating section to allow a system to represent more than one procedure per resource, though there is nothing stopping multiple resources - one per procedure.
 *
 * http://hl7.org/fhir/FamilyMemberHistoryProcedureComponent
 */
var FamilyMemberHistoryProcedureComponent = 'http://hl7.org/fhir/FamilyMemberHistoryProcedureComponent';
/**
 * subscriptionTopic
 *
 * TriggerDefinition.subscriptionTopic: A reference to a SubscriptionTopic resource that defines the event. If this element is provided, no other information about the trigger definition may be supplied.
 *
 * http://hl7.org/fhir/subscriptionTopic
 */
var subscriptionTopic = 'http://hl7.org/fhir/subscriptionTopic';
/**
 * _resource
 *
 * (Modified) RelatedArtifact.resource
 *
 * http://hl7.org/fhir/_resource
 */
var _resource = 'http://hl7.org/fhir/_resource';
/**
 * correspondingContact
 *
 * Citation.citedArtifact.contributorship.entry.correspondingContact: Whether the contributor is the corresponding contributor for the role.
 *
 * http://hl7.org/fhir/correspondingContact
 */
var correspondingContact = 'http://hl7.org/fhir/correspondingContact';
/**
 * graph
 *
 * MessageDefinition.graph: Graph is Canonical reference to a GraphDefinition. If a URL is provided, it is the canonical reference to a GraphDefinition that it controls what additional resources are to be added to the Bundle when building the message. The GraphDefinition can also specify profiles that apply to the various resources.
 *
 * http://hl7.org/fhir/graph
 */
var graph = 'http://hl7.org/fhir/graph';
/**
 * _QuestionnaireResponse
 *
 * (Modified) QuestionnaireResponse
 *
 * http://hl7.org/fhir/_QuestionnaireResponse
 */
var _QuestionnaireResponse = 'http://hl7.org/fhir/_QuestionnaireResponse';
/**
 * RequestOrchestrationActionComponentAction
 *
 * Sub actions.
 *
 * http://hl7.org/fhir/RequestOrchestrationActionComponentAction
 */
var RequestOrchestrationActionComponentAction = 'http://hl7.org/fhir/RequestOrchestrationActionComponentAction';
/**
 * issues
 *
 * Bundle.issues: Captures issues and warnings that relate to the construction of the Bundle and the content within it.
 *
 * http://hl7.org/fhir/issues
 */
var issues = 'http://hl7.org/fhir/issues';
/**
 * instances
 *
 * EvidenceVariable.characteristic.instances
 *
 * http://hl7.org/fhir/instances
 */
var instances = 'http://hl7.org/fhir/instances';
/**
 * _isDefining
 *
 * (Modified) SubstancePolymer.monomerSet.startingMaterial.isDefining
 *
 * http://hl7.org/fhir/_isDefining
 */
var _isDefining = 'http://hl7.org/fhir/_isDefining';
/**
 * primaryPurposeType
 *
 * ResearchStudy.primaryPurposeType: The type of study based upon the intent of the study activities. A classification of the intent of the study.
 *
 * http://hl7.org/fhir/primaryPurposeType
 */
var primaryPurposeType = 'http://hl7.org/fhir/primaryPurposeType';
/**
 * _specimenRequirement
 *
 * (Modified) ActivityDefinition.specimenRequirement
 *
 * http://hl7.org/fhir/_specimenRequirement
 */
var _specimenRequirement = 'http://hl7.org/fhir/_specimenRequirement';
/**
 * _sourceDocument
 *
 * (Modified) SubstanceDefinition.structure.sourceDocument
 *
 * http://hl7.org/fhir/_sourceDocument
 */
var _sourceDocument = 'http://hl7.org/fhir/_sourceDocument';
/**
 * SubstanceReferenceInformation
 *
 * Todo.
 *
 * http://hl7.org/fhir/SubstanceReferenceInformation
 */
var SubstanceReferenceInformation = 'http://hl7.org/fhir/SubstanceReferenceInformation';
/**
 * _multipleBirth
 *
 * (Modified) Patient.multipleBirth
 *
 * http://hl7.org/fhir/_multipleBirth
 */
var _multipleBirth = 'http://hl7.org/fhir/_multipleBirth';
/**
 * _InsurancePlan
 *
 * (Modified) InsurancePlan
 *
 * http://hl7.org/fhir/_InsurancePlan
 */
var _InsurancePlan = 'http://hl7.org/fhir/_InsurancePlan';
/**
 * repeatUnit
 *
 * SubstancePolymer.repeat.repeatUnit: An SRU - Structural Repeat Unit.
 *
 * http://hl7.org/fhir/repeatUnit
 */
var repeatUnit = 'http://hl7.org/fhir/repeatUnit';
/**
 * StructureDefinition
 *
 * A definition of a FHIR structure. This resource is used to describe the underlying resources, data types defined in FHIR, and also for describing extensions and constraints on resources and data types.
 *
 * http://hl7.org/fhir/StructureDefinition
 */
var StructureDefinition = 'http://hl7.org/fhir/StructureDefinition';
/**
 * _node
 *
 * (Modified) GraphDefinition.node
 *
 * http://hl7.org/fhir/_node
 */
var _node = 'http://hl7.org/fhir/_node';
/**
 * TestPlanTestCaseAssertionComponent
 *
 * TestPlanTestCaseComponent.TestPlanTestCaseAssertionComponent: The test assertions - the expectations of test results from the execution of the test case.
 *
 * http://hl7.org/fhir/TestPlanTestCaseAssertionComponent
 */
var TestPlanTestCaseAssertionComponent = 'http://hl7.org/fhir/TestPlanTestCaseAssertionComponent';
/**
 * relatedData
 *
 * PlanDefinition.action.input.relatedData: Points to an existing input or output element that provides data to this input.
 *
 * http://hl7.org/fhir/relatedData
 */
var relatedData = 'http://hl7.org/fhir/relatedData';
/**
 * _content
 *
 * (Modified) CommunicationRequest.payload.content
 *
 * http://hl7.org/fhir/_content
 */
var _content = 'http://hl7.org/fhir/_content';
/**
 * _associationType
 *
 * (Modified) InventoryItem.association.associationType
 *
 * http://hl7.org/fhir/_associationType
 */
var _associationType = 'http://hl7.org/fhir/_associationType';
/**
 * _regulatoryBasis
 *
 * (Modified) Consent.regulatoryBasis
 *
 * http://hl7.org/fhir/_regulatoryBasis
 */
var _regulatoryBasis = 'http://hl7.org/fhir/_regulatoryBasis';
/**
 * attachment
 *
 * SubstancePolymer.repeat.repeatUnit.structuralRepresentation.attachment: An attached file with the structural representation.
 *
 * http://hl7.org/fhir/attachment
 */
var attachment = 'http://hl7.org/fhir/attachment';
/**
 * ActionSubject
 *
 * Contract.Term.Action.ActionSubject: Entity of the action.
 *
 * http://hl7.org/fhir/ActionSubject
 */
var ActionSubject = 'http://hl7.org/fhir/ActionSubject';
/**
 * _packagedMedicinalProduct
 *
 * (Modified) MedicinalProductDefinition.packagedMedicinalProduct
 *
 * http://hl7.org/fhir/_packagedMedicinalProduct
 */
var _packagedMedicinalProduct = 'http://hl7.org/fhir/_packagedMedicinalProduct';
/**
 * _packagedProduct
 *
 * (Modified) MedicationKnowledge.packaging.packagedProduct
 *
 * http://hl7.org/fhir/_packagedProduct
 */
var _packagedProduct = 'http://hl7.org/fhir/_packagedProduct';
/**
 * _onset
 *
 * (Modified) FamilyMemberHistory.condition.onset
 *
 * http://hl7.org/fhir/_onset
 */
var _onset = 'http://hl7.org/fhir/_onset';
/**
 * _basedOn
 *
 * (Modified) DeviceUsage.basedOn
 *
 * http://hl7.org/fhir/_basedOn
 */
var _basedOn = 'http://hl7.org/fhir/_basedOn';
/**
 * CitationCitedArtifactRelatesToComponent
 *
 * CitationCitedArtifactComponent.CitationCitedArtifactRelatesToComponent: The artifact related to the cited artifact.
 *
 * http://hl7.org/fhir/CitationCitedArtifactRelatesToComponent
 */
var CitationCitedArtifactRelatesToComponent = 'http://hl7.org/fhir/CitationCitedArtifactRelatesToComponent';
/**
 * _backCurve
 *
 * (Modified) VisionPrescription.lensSpecification.backCurve
 *
 * http://hl7.org/fhir/_backCurve
 */
var _backCurve = 'http://hl7.org/fhir/_backCurve';
/**
 * AuditEventOutcomeComponent
 *
 * AuditEventOutcomeComponent: Indicates whether the event succeeded or failed. A free text descripiton can be given in outcome.text.
 *
 * http://hl7.org/fhir/AuditEventOutcomeComponent
 */
var AuditEventOutcomeComponent = 'http://hl7.org/fhir/AuditEventOutcomeComponent';
/**
 * payee
 *
 * PaymentNotice.payee: The party who will receive or has received payment that is the subject of this notification.
 *
 * http://hl7.org/fhir/payee
 */
var payee = 'http://hl7.org/fhir/payee';
/**
 * _reporter
 *
 * (Modified) PaymentNotice.reporter
 *
 * http://hl7.org/fhir/_reporter
 */
var _reporter = 'http://hl7.org/fhir/_reporter';
/**
 * SubstanceDefinitionStructureComponentMolecularWeight
 *
 * The molecular weight or weight range (for proteins, polymers or nucleic acids).
 *
 * http://hl7.org/fhir/SubstanceDefinitionStructureComponentMolecularWeight
 */
var SubstanceDefinitionStructureComponentMolecularWeight = 'http://hl7.org/fhir/SubstanceDefinitionStructureComponentMolecularWeight';
/**
 * biologicalSourceEvent
 *
 * BiologicallyDerivedProduct.biologicalSourceEvent: An identifier that supports traceability to the event during which material in this product from one or more biological entities was obtained or pooled.
 *
 * http://hl7.org/fhir/biologicalSourceEvent
 */
var biologicalSourceEvent = 'http://hl7.org/fhir/biologicalSourceEvent';
/**
 * RequestOrchestrationActionComponent
 *
 * RequestOrchestrationActionComponent: The actions, if any, produced by the evaluation of the artifact.
 *
 * http://hl7.org/fhir/RequestOrchestrationActionComponent
 */
var RequestOrchestrationActionComponent = 'http://hl7.org/fhir/RequestOrchestrationActionComponent';
/**
 * period
 *
 * RelatedPerson.period: The period of time during which this relationship is or was active. If there are no dates defined, then the interval is unknown.
 *
 * http://hl7.org/fhir/period
 */
var period = 'http://hl7.org/fhir/period';
/**
 * SearchParameterComponentComponent
 *
 * SearchParameterComponentComponent: Used to define the parts of a composite search parameter.
 *
 * http://hl7.org/fhir/SearchParameterComponentComponent
 */
var SearchParameterComponentComponent = 'http://hl7.org/fhir/SearchParameterComponentComponent';
/**
 * protocolPerformed
 *
 * GenomicStudy.analysis.protocolPerformed: The protocol that was performed for the analysis event.
 *
 * http://hl7.org/fhir/protocolPerformed
 */
var protocolPerformed = 'http://hl7.org/fhir/protocolPerformed';
/**
 * ResearchStudyLabelComponent
 *
 * ResearchStudyLabelComponent: Additional names for the study.
 *
 * http://hl7.org/fhir/ResearchStudyLabelComponent
 */
var ResearchStudyLabelComponent = 'http://hl7.org/fhir/ResearchStudyLabelComponent';
/**
 * _careTeamSequence
 *
 * (Modified) ExplanationOfBenefit.item.careTeamSequence
 *
 * http://hl7.org/fhir/_careTeamSequence
 */
var _careTeamSequence = 'http://hl7.org/fhir/_careTeamSequence';
/**
 * instantiates
 *
 * Observation.instantiates
 *
 * http://hl7.org/fhir/instantiates
 */
var instantiates = 'http://hl7.org/fhir/instantiates';
/**
 * _patientCharacteristic
 *
 * (Modified) MedicationKnowledge.indicationGuideline.dosingGuideline.patientCharacteristic
 *
 * http://hl7.org/fhir/_patientCharacteristic
 */
var _patientCharacteristic = 'http://hl7.org/fhir/_patientCharacteristic';
/**
 * _allowedType
 *
 * (Modified) OperationDefinition.parameter.part.allowedType
 *
 * http://hl7.org/fhir/_allowedType
 */
var _allowedType = 'http://hl7.org/fhir/_allowedType';
/**
 * Element
 *
 * Base definition for all elements in a resource.
 *
 * http://hl7.org/fhir/Element
 */
var Element = 'http://hl7.org/fhir/Element';
/**
 * DeviceMetric
 *
 * Describes a measurement, calculation or setting capability of a device.  The DeviceMetric resource is derived from the ISO/IEEE 11073-10201 Domain Information Model standard, but is more widely applicable.
 *
 * http://hl7.org/fhir/DeviceMetric
 */
var DeviceMetric = 'http://hl7.org/fhir/DeviceMetric';
/**
 * _maxTreatmentPeriod
 *
 * (Modified) AdministrableProductDefinition.routeOfAdministration.maxTreatmentPeriod
 *
 * http://hl7.org/fhir/_maxTreatmentPeriod
 */
var _maxTreatmentPeriod = 'http://hl7.org/fhir/_maxTreatmentPeriod';
/**
 * _InventoryItem
 *
 * (Modified) InventoryItem
 *
 * http://hl7.org/fhir/_InventoryItem
 */
var _InventoryItem = 'http://hl7.org/fhir/_InventoryItem';
/**
 * AppointmentRecurrenceTemplateComponent
 *
 * AppointmentRecurrenceTemplateComponent: The details of the recurrence pattern or template that is used to generate recurring appointments.
 *
 * http://hl7.org/fhir/AppointmentRecurrenceTemplateComponent
 */
var AppointmentRecurrenceTemplateComponent = 'http://hl7.org/fhir/AppointmentRecurrenceTemplateComponent';
/**
 * targetDisease
 *
 * ImmunizationRecommendation.recommendation.targetDisease: The targeted disease for the recommendation.
 *
 * http://hl7.org/fhir/targetDisease
 */
var targetDisease = 'http://hl7.org/fhir/targetDisease';
/**
 * PlanDefinitionActionComponentAction
 *
 * Sub actions that are contained within the action. The behavior of this action determines the functionality of the sub-actions. For example, a selection behavior of at-most-one indicates that of the sub-actions, at most one may be chosen as part of realizing the action definition.
 *
 * http://hl7.org/fhir/PlanDefinitionActionComponentAction
 */
var PlanDefinitionActionComponentAction = 'http://hl7.org/fhir/PlanDefinitionActionComponentAction';
/**
 * file
 *
 * SubstanceDefinition.characterization.file: The data produced by the analytical instrument or a pictorial representation of that data. Examples: a JCAMP, JDX, or ADX file, or a chromatogram or spectrum analysis.
 *
 * http://hl7.org/fhir/file
 */
var file = 'http://hl7.org/fhir/file';
/**
 * const
 *
 * StructureMap.const: Definition of a constant value used in the map rules.
 * Note that `const` is a reserved Javascript keyword, and is therefore suffixed by `__workaround`.
 * For a list of reserved keywords, see https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Lexical_grammar#Keywords.
 *
 * http://hl7.org/fhir/const
 */
var const__workaround = 'http://hl7.org/fhir/const';
/**
 * citedMedium
 *
 * Citation.citedArtifact.publicationForm.citedMedium: Describes the form of the medium cited. Common codes are "Internet" or "Print". The CitedMedium value set has 6 codes. The codes internet, print, and offline-digital-storage are the common codes for a typical publication form, though internet and print are more common for study citations. Three additional codes (each appending one of the primary codes with "-without-issue" are used for situations when a study is published both within an issue (of a periodical release as commonly done for journals) AND is published separately from the issue (as commonly done with early online publication), to represent specific identification of the publication form not associated with the issue.
 *
 * http://hl7.org/fhir/citedMedium
 */
var citedMedium = 'http://hl7.org/fhir/citedMedium';
/**
 * _frames
 *
 * (Modified) Attachment.frames
 *
 * http://hl7.org/fhir/_frames
 */
var _frames = 'http://hl7.org/fhir/_frames';
/**
 * multipleOr
 *
 * SearchParameter.multipleOr: Whether multiple values are allowed for each time the parameter exists. Values are separated by commas, and the parameter matches if any of the values match.
 *
 * http://hl7.org/fhir/multipleOr
 */
var multipleOr = 'http://hl7.org/fhir/multipleOr';
/**
 * inputParameters
 *
 * MeasureReport.inputParameters: A reference to a Parameters resource (typically represented using a contained resource) that represents any input parameters that were provided to the operation that generated the report.
 *
 * http://hl7.org/fhir/inputParameters
 */
var inputParameters = 'http://hl7.org/fhir/inputParameters';
/**
 * causality
 *
 * AdverseEvent.suspectEntity.causality: Information on the possible cause of the event.
 *
 * http://hl7.org/fhir/causality
 */
var causality = 'http://hl7.org/fhir/causality';
/**
 * SupplyDelivery
 *
 * Record of delivery of what is supplied.
 *
 * http://hl7.org/fhir/SupplyDelivery
 */
var SupplyDelivery = 'http://hl7.org/fhir/SupplyDelivery';
/**
 * minimumId
 *
 * TestScript.test.action.assert.minimumId: The ID of a fixture. Asserts that the response contains at a minimum the fixture specified by minimumId.
 *
 * http://hl7.org/fhir/minimumId
 */
var minimumId = 'http://hl7.org/fhir/minimumId';
/**
 * _processNote
 *
 * (Modified) PaymentReconciliation.processNote
 *
 * http://hl7.org/fhir/_processNote
 */
var _processNote = 'http://hl7.org/fhir/_processNote';
/**
 * Money
 *
 * An amount of economic utility in some recognized currency.
 *
 * http://hl7.org/fhir/Money
 */
var Money = 'http://hl7.org/fhir/Money';
/**
 * _BackboneType
 *
 * http://hl7.org/fhir/_BackboneType
 */
var _BackboneType = 'http://hl7.org/fhir/_BackboneType';
/**
 * _Endpoint
 *
 * (Modified) Endpoint
 *
 * http://hl7.org/fhir/_Endpoint
 */
var _Endpoint = 'http://hl7.org/fhir/_Endpoint';
/**
 * udiDeviceIdentifier
 *
 * DeviceDefinition.packaging.packaging.udiDeviceIdentifier: Unique Device Identifier (UDI) Barcode string on the packaging.
 *
 * http://hl7.org/fhir/udiDeviceIdentifier
 */
var udiDeviceIdentifier = 'http://hl7.org/fhir/udiDeviceIdentifier';
/**
 * EnteralFormulaSchedule
 *
 * NutritionOrderEnteralFormulaComponent.NutritionOrderEnteralFormulaAdministrationComponent.EnteralFormulaSchedule: Schedule information for an enteral formula.
 *
 * http://hl7.org/fhir/EnteralFormulaSchedule
 */
var EnteralFormulaSchedule = 'http://hl7.org/fhir/EnteralFormulaSchedule';
/**
 * diseaseStatus
 *
 * ClinicalUseDefinition.indication.diseaseStatus: The status of the disease or symptom for the indication, for example "chronic" or "metastatic".
 *
 * http://hl7.org/fhir/diseaseStatus
 */
var diseaseStatus = 'http://hl7.org/fhir/diseaseStatus';
/**
 * _expectedSupplyDuration
 *
 * (Modified) MedicationRequest.dispenseRequest.expectedSupplyDuration
 *
 * http://hl7.org/fhir/_expectedSupplyDuration
 */
var _expectedSupplyDuration = 'http://hl7.org/fhir/_expectedSupplyDuration';
/**
 * ifModifiedSince
 *
 * Bundle.entry.request.ifModifiedSince: Only perform the operation if the last updated date matches. See the API documentation for ["Conditional Read"](http.html#cread).
 *
 * http://hl7.org/fhir/ifModifiedSince
 */
var ifModifiedSince = 'http://hl7.org/fhir/ifModifiedSince';
/**
 * formCode
 *
 * PaymentReconciliation.formCode: A code for the form to be used for printing the content.
 *
 * http://hl7.org/fhir/formCode
 */
var formCode = 'http://hl7.org/fhir/formCode';
/**
 * _connectionType
 *
 * (Modified) Endpoint.connectionType
 *
 * http://hl7.org/fhir/_connectionType
 */
var _connectionType = 'http://hl7.org/fhir/_connectionType';
/**
 * ImplementationGuideDefinitionResourceComponent
 *
 * ImplementationGuideDefinitionComponent.ImplementationGuideDefinitionResourceComponent: A resource that is part of the implementation guide. Conformance resources (value set, structure definition, capability statements etc.) are obvious candidates for inclusion, but any kind of resource can be included as an example resource.
 *
 * http://hl7.org/fhir/ImplementationGuideDefinitionResourceComponent
 */
var ImplementationGuideDefinitionResourceComponent = 'http://hl7.org/fhir/ImplementationGuideDefinitionResourceComponent';
/**
 * _fundsReserveRequested
 *
 * (Modified) ExplanationOfBenefit.fundsReserveRequested
 *
 * http://hl7.org/fhir/_fundsReserveRequested
 */
var _fundsReserveRequested = 'http://hl7.org/fhir/_fundsReserveRequested';
/**
 * dateFilter
 *
 * DataRequirement.dateFilter: Date filters specify additional constraints on the data in terms of the applicable date range for specific elements. Each date filter specifies an additional constraint on the data, i.e. date filters are AND'ed, not OR'ed.
 *
 * http://hl7.org/fhir/dateFilter
 */
var dateFilter = 'http://hl7.org/fhir/dateFilter';
/**
 * matchStatus
 *
 * BiologicallyDerivedProductDispense.matchStatus: Indicates the type of matching associated with the dispense.
 *
 * http://hl7.org/fhir/matchStatus
 */
var matchStatus = 'http://hl7.org/fhir/matchStatus';
/**
 * usePeriod
 *
 * Contract.term.group.asset.usePeriod: Time period of asset use.
 *
 * http://hl7.org/fhir/usePeriod
 */
var usePeriod = 'http://hl7.org/fhir/usePeriod';
/**
 * _participant
 *
 * (Modified) PlanDefinition.action.participant
 *
 * http://hl7.org/fhir/_participant
 */
var _participant = 'http://hl7.org/fhir/_participant';
/**
 * MessageDestination
 *
 * MessageHeader.MessageDestination: The destination application which the message is intended for.
 *
 * http://hl7.org/fhir/MessageDestination
 */
var MessageDestination = 'http://hl7.org/fhir/MessageDestination';
/**
 * _additionalInfo
 *
 * (Modified) VirtualServiceDetail.additionalInfo
 *
 * http://hl7.org/fhir/_additionalInfo
 */
var _additionalInfo = 'http://hl7.org/fhir/_additionalInfo';
/**
 * _numberOfEvents
 *
 * (Modified) Evidence.statistic.numberOfEvents
 *
 * http://hl7.org/fhir/_numberOfEvents
 */
var _numberOfEvents = 'http://hl7.org/fhir/_numberOfEvents';
/**
 * _includedStructure
 *
 * (Modified) BodyStructure.includedStructure
 *
 * http://hl7.org/fhir/_includedStructure
 */
var _includedStructure = 'http://hl7.org/fhir/_includedStructure';
/**
 * _imageRegion2D
 *
 * (Modified) ImagingSelection.instance.imageRegion2D
 *
 * http://hl7.org/fhir/_imageRegion2D
 */
var _imageRegion2D = 'http://hl7.org/fhir/_imageRegion2D';
/**
 * _tax
 *
 * (Modified) ExplanationOfBenefit.item.detail.subDetail.tax
 *
 * http://hl7.org/fhir/_tax
 */
var _tax = 'http://hl7.org/fhir/_tax';
/**
 * _appointment
 *
 * (Modified) Encounter.appointment
 *
 * http://hl7.org/fhir/_appointment
 */
var _appointment = 'http://hl7.org/fhir/_appointment';
/**
 * treatmentIntent
 *
 * MedicationKnowledge.indicationGuideline.dosingGuideline.treatmentIntent: The overall intention of the treatment, for example, prophylactic, supporative, curative, etc.
 *
 * http://hl7.org/fhir/treatmentIntent
 */
var treatmentIntent = 'http://hl7.org/fhir/treatmentIntent';
/**
 * SubstanceDefinitionCodeComponent
 *
 * SubstanceDefinitionCodeComponent: Codes associated with the substance.
 *
 * http://hl7.org/fhir/SubstanceDefinitionCodeComponent
 */
var SubstanceDefinitionCodeComponent = 'http://hl7.org/fhir/SubstanceDefinitionCodeComponent';
/**
 * _study
 *
 * (Modified) ResearchSubject.study
 *
 * http://hl7.org/fhir/_study
 */
var _study = 'http://hl7.org/fhir/_study';
/**
 * _ratioType
 *
 * (Modified) SubstancePolymer.monomerSet.ratioType
 *
 * http://hl7.org/fhir/_ratioType
 */
var _ratioType = 'http://hl7.org/fhir/_ratioType';
/**
 * policyHolder
 *
 * Coverage.policyHolder: The party who 'owns' the insurance policy.
 *
 * http://hl7.org/fhir/policyHolder
 */
var policyHolder = 'http://hl7.org/fhir/policyHolder';
/**
 * region
 *
 * ResearchStudy.region: A country, state or other area where the study is taking place rather than its precise geographic location or address.
 *
 * http://hl7.org/fhir/region
 */
var region = 'http://hl7.org/fhir/region';
/**
 * operationType
 *
 * InventoryReport.operationType: What type of operation is being performed - addition or subtraction.
 *
 * http://hl7.org/fhir/operationType
 */
var operationType = 'http://hl7.org/fhir/operationType';
/**
 * _actuality
 *
 * (Modified) AdverseEvent.actuality
 *
 * http://hl7.org/fhir/_actuality
 */
var _actuality = 'http://hl7.org/fhir/_actuality';
/**
 * _definitionUri
 *
 * (Modified) ChargeItem.definitionUri
 *
 * http://hl7.org/fhir/_definitionUri
 */
var _definitionUri = 'http://hl7.org/fhir/_definitionUri';
/**
 * organismId
 *
 * SubstanceSourceMaterial.organismId: The unique identifier associated with the source material parent organism shall be specified.
 *
 * http://hl7.org/fhir/organismId
 */
var organismId = 'http://hl7.org/fhir/organismId';
/**
 * ManufacturedItemDefinitionComponentComponentComponentProperty
 *
 * General characteristics of this component.
 *
 * http://hl7.org/fhir/ManufacturedItemDefinitionComponentComponentComponentProperty
 */
var ManufacturedItemDefinitionComponentComponentComponentProperty = 'http://hl7.org/fhir/ManufacturedItemDefinitionComponentComponentComponentProperty';
/**
 * _consumedItem
 *
 * (Modified) NutritionIntake.consumedItem
 *
 * http://hl7.org/fhir/_consumedItem
 */
var _consumedItem = 'http://hl7.org/fhir/_consumedItem';
/**
 * thursday
 *
 * Appointment.recurrenceTemplate.weeklyTemplate.thursday: Indicates that recurring appointments should occur on Thursdays.
 *
 * http://hl7.org/fhir/thursday
 */
var thursday = 'http://hl7.org/fhir/thursday';
/**
 * _rules
 *
 * (Modified) ElementDefinition.slicing.rules
 *
 * http://hl7.org/fhir/_rules
 */
var _rules = 'http://hl7.org/fhir/_rules';
/**
 * dependent
 *
 * StructureMap.group.rule.dependent: Which other rules to apply in the context of this rule.
 *
 * http://hl7.org/fhir/dependent
 */
var dependent = 'http://hl7.org/fhir/dependent';
/**
 * deliverFrom
 *
 * SupplyRequest.deliverFrom: Where the supply is expected to come from.
 *
 * http://hl7.org/fhir/deliverFrom
 */
var deliverFrom = 'http://hl7.org/fhir/deliverFrom';
/**
 * ImmunizationProtocolAppliedComponent
 *
 * ImmunizationProtocolAppliedComponent: The protocol (set of recommendations) being followed by the provider who administered the dose.
 *
 * http://hl7.org/fhir/ImmunizationProtocolAppliedComponent
 */
var ImmunizationProtocolAppliedComponent = 'http://hl7.org/fhir/ImmunizationProtocolAppliedComponent';
/**
 * actualGroup
 *
 * ResearchStudy.recruitment.actualGroup: Group of participants who were enrolled in study.
 *
 * http://hl7.org/fhir/actualGroup
 */
var actualGroup = 'http://hl7.org/fhir/actualGroup';
/**
 * Age
 *
 * A duration of time during which an organism (or a process) has existed.
 *
 * http://hl7.org/fhir/Age
 */
var Age = 'http://hl7.org/fhir/Age';
/**
 * subsumption
 *
 * TerminologyCapabilities.codeSystem.subsumption: True if subsumption is supported for this version of the code system.
 *
 * http://hl7.org/fhir/subsumption
 */
var subsumption = 'http://hl7.org/fhir/subsumption';
/**
 * ElementDefinitionConstraintComponent
 *
 * ElementDefinitionConstraintComponent: Formal constraints such as co-occurrence and other constraints that can be computationally evaluated within the context of the instance.
 *
 * http://hl7.org/fhir/ElementDefinitionConstraintComponent
 */
var ElementDefinitionConstraintComponent = 'http://hl7.org/fhir/ElementDefinitionConstraintComponent';
/**
 * subjectResults
 *
 * MeasureReport.group.stratifier.stratum.population.subjectResults: This element refers to a List of individual level MeasureReport resources, one for each subject in this population in this stratum.
 *
 * http://hl7.org/fhir/subjectResults
 */
var subjectResults = 'http://hl7.org/fhir/subjectResults';
/**
 * OperationDefinitionOverloadComponent
 *
 * OperationDefinitionOverloadComponent: Defines an appropriate combination of parameters to use when invoking this operation, to help code generators when generating overloaded parameter sets for this operation.
 *
 * http://hl7.org/fhir/OperationDefinitionOverloadComponent
 */
var OperationDefinitionOverloadComponent = 'http://hl7.org/fhir/OperationDefinitionOverloadComponent';
/**
 * recurrenceTemplate
 *
 * Appointment.recurrenceTemplate: The details of the recurrence pattern or template that is used to generate recurring appointments.
 *
 * http://hl7.org/fhir/recurrenceTemplate
 */
var recurrenceTemplate = 'http://hl7.org/fhir/recurrenceTemplate';
/**
 * doseForm
 *
 * MedicationKnowledge.definitional.doseForm: Describes the form of the item.  Powder; tablets; capsule.
 *
 * http://hl7.org/fhir/doseForm
 */
var doseForm = 'http://hl7.org/fhir/doseForm';
/**
 * adherence
 *
 * MedicationStatement.adherence: Indicates whether the medication is or is not being consumed or administered.
 *
 * http://hl7.org/fhir/adherence
 */
var adherence = 'http://hl7.org/fhir/adherence';
/**
 * ServiceRequest
 *
 * A record of a request for service such as diagnostic investigations, treatments, or operations to be performed.
 *
 * http://hl7.org/fhir/ServiceRequest
 */
var ServiceRequest = 'http://hl7.org/fhir/ServiceRequest';
/**
 * deviceIdentifier
 *
 * Device.udiCarrier.deviceIdentifier: The device identifier (DI) is a mandatory, fixed portion of a UDI that identifies the labeler and the specific version or model of a device.
 *
 * http://hl7.org/fhir/deviceIdentifier
 */
var deviceIdentifier = 'http://hl7.org/fhir/deviceIdentifier';
/**
 * _reasonLinkId
 *
 * (Modified) Contract.term.group.action.reasonLinkId
 *
 * http://hl7.org/fhir/_reasonLinkId
 */
var _reasonLinkId = 'http://hl7.org/fhir/_reasonLinkId';
/**
 * versionId
 *
 * Meta.versionId: The version specific identifier, as it appears in the version portion of the URL. This value changes when the resource is created, updated, or deleted.
 *
 * http://hl7.org/fhir/versionId
 */
var versionId = 'http://hl7.org/fhir/versionId';
/**
 * componentPart
 *
 * PackagedProductDefinition.packaging.packaging.componentPart: Is this a part of the packaging (e.g. a cap or bottle stopper), rather than the packaging itself (e.g. a bottle or vial). The latter type are designed be a container, but the former are not.
 *
 * http://hl7.org/fhir/componentPart
 */
var componentPart = 'http://hl7.org/fhir/componentPart';
/**
 * _value
 *
 * (Modified) ResearchStudy.label.value
 *
 * http://hl7.org/fhir/_value
 */
var _value = 'http://hl7.org/fhir/_value';
/**
 * TestReportParticipantComponent
 *
 * TestReportParticipantComponent: A participant in the test execution, either the execution engine, a client, or a server.
 *
 * http://hl7.org/fhir/TestReportParticipantComponent
 */
var TestReportParticipantComponent = 'http://hl7.org/fhir/TestReportParticipantComponent';
/**
 * morphology
 *
 * BodyStructure.morphology: The kind of structure being represented by the body structure at `BodyStructure.location`.  This can define both normal and abnormal morphologies.
 *
 * http://hl7.org/fhir/morphology
 */
var morphology = 'http://hl7.org/fhir/morphology';
/**
 * date
 *
 * ResearchStudy.date: The date (and optionally time) when the ResearchStudy Resource was last significantly changed. The date must change when the business version changes and it must change if the status code changes. In addition, it should change when the substantive content of the ResearchStudy Resource changes.
 *
 * http://hl7.org/fhir/date
 */
var date = 'http://hl7.org/fhir/date';
/**
 * _isModifier
 *
 * (Modified) ElementDefinition.isModifier
 *
 * http://hl7.org/fhir/_isModifier
 */
var _isModifier = 'http://hl7.org/fhir/_isModifier';
/**
 * _allDay
 *
 * (Modified) Availability.availableTime.allDay
 *
 * http://hl7.org/fhir/_allDay
 */
var _allDay = 'http://hl7.org/fhir/_allDay';
/**
 * contentReference
 *
 * ElementDefinition.contentReference: Identifies an element defined elsewhere in the definition whose content rules should be applied to the current element. ContentReferences bring across all the rules that are in the ElementDefinition for the element, including definitions, cardinality constraints, bindings, invariants etc.
 *
 * http://hl7.org/fhir/contentReference
 */
var contentReference = 'http://hl7.org/fhir/contentReference';
/**
 * _sunday
 *
 * (Modified) Appointment.recurrenceTemplate.weeklyTemplate.sunday
 *
 * http://hl7.org/fhir/_sunday
 */
var _sunday = 'http://hl7.org/fhir/_sunday';
/**
 * DeviceUsageAdherenceComponent
 *
 * DeviceUsageAdherenceComponent: This indicates how or if the device is being used.
 *
 * http://hl7.org/fhir/DeviceUsageAdherenceComponent
 */
var DeviceUsageAdherenceComponent = 'http://hl7.org/fhir/DeviceUsageAdherenceComponent';
/**
 * maxSingleDose
 *
 * AdministrableProductDefinition.routeOfAdministration.maxSingleDose: The maximum single dose that can be administered, specified using a numerical value and its unit of measurement.
 *
 * http://hl7.org/fhir/maxSingleDose
 */
var maxSingleDose = 'http://hl7.org/fhir/maxSingleDose';
/**
 * referenceRange
 *
 * Observation.component.referenceRange: Guidance on how to interpret the value by comparison to a normal or recommended range.
 *
 * http://hl7.org/fhir/referenceRange
 */
var referenceRange = 'http://hl7.org/fhir/referenceRange';
/**
 * _pages
 *
 * (Modified) Attachment.pages
 *
 * http://hl7.org/fhir/_pages
 */
var _pages = 'http://hl7.org/fhir/_pages';
/**
 * DeviceDefinitionGuidelineComponent
 *
 * DeviceDefinitionGuidelineComponent: Information aimed at providing directions for the usage of this model of device.
 *
 * http://hl7.org/fhir/DeviceDefinitionGuidelineComponent
 */
var DeviceDefinitionGuidelineComponent = 'http://hl7.org/fhir/DeviceDefinitionGuidelineComponent';
/**
 * _temperatureRange
 *
 * (Modified) SpecimenDefinition.typeTested.handling.temperatureRange
 *
 * http://hl7.org/fhir/_temperatureRange
 */
var _temperatureRange = 'http://hl7.org/fhir/_temperatureRange';
/**
 * _sequenceType
 *
 * (Modified) SubstanceProtein.sequenceType
 *
 * http://hl7.org/fhir/_sequenceType
 */
var _sequenceType = 'http://hl7.org/fhir/_sequenceType';
/**
 * _partNumber
 *
 * (Modified) DeviceDefinition.partNumber
 *
 * http://hl7.org/fhir/_partNumber
 */
var _partNumber = 'http://hl7.org/fhir/_partNumber';
/**
 * _term
 *
 * (Modified) Measure.term
 *
 * http://hl7.org/fhir/_term
 */
var _term = 'http://hl7.org/fhir/_term';
/**
 * StructureDefinitionDifferentialComponent
 *
 * StructureDefinitionDifferentialComponent: A differential view is expressed relative to the base StructureDefinition - a statement of differences that it applies.
 *
 * http://hl7.org/fhir/StructureDefinitionDifferentialComponent
 */
var StructureDefinitionDifferentialComponent = 'http://hl7.org/fhir/StructureDefinitionDifferentialComponent';
/**
 * _udi
 *
 * (Modified) Claim.item.udi
 *
 * http://hl7.org/fhir/_udi
 */
var _udi = 'http://hl7.org/fhir/_udi';
/**
 * _telecom
 *
 * (Modified) Patient.telecom
 *
 * http://hl7.org/fhir/_telecom
 */
var _telecom = 'http://hl7.org/fhir/_telecom';
/**
 * CitationCitedArtifactPublicationFormPublishedInComponent
 *
 * CitationCitedArtifactComponent.CitationCitedArtifactPublicationFormComponent.CitationCitedArtifactPublicationFormPublishedInComponent: The collection the cited article or artifact is published in.
 *
 * http://hl7.org/fhir/CitationCitedArtifactPublicationFormPublishedInComponent
 */
var CitationCitedArtifactPublicationFormPublishedInComponent = 'http://hl7.org/fhir/CitationCitedArtifactPublicationFormPublishedInComponent';
/**
 * _wasSubstituted
 *
 * (Modified) MedicationDispense.substitution.wasSubstituted
 *
 * http://hl7.org/fhir/_wasSubstituted
 */
var _wasSubstituted = 'http://hl7.org/fhir/_wasSubstituted';
/**
 * initial
 *
 * Questionnaire.item.item.initial: One or more values that should be pre-populated in the answer when initially rendering the questionnaire for user input.
 *
 * http://hl7.org/fhir/initial
 */
var initial = 'http://hl7.org/fhir/initial';
/**
 * doNotPerform
 *
 * Contract.term.action.doNotPerform: True if the term prohibits the  action.
 *
 * http://hl7.org/fhir/doNotPerform
 */
var doNotPerform = 'http://hl7.org/fhir/doNotPerform';
/**
 * diameter
 *
 * VisionPrescription.lensSpecification.diameter: Contact lens diameter measured in millimetres.
 *
 * http://hl7.org/fhir/diameter
 */
var diameter = 'http://hl7.org/fhir/diameter';
/**
 * _property
 *
 * (Modified) ValueSet.compose.include.filter.property
 *
 * http://hl7.org/fhir/_property
 */
var _property = 'http://hl7.org/fhir/_property';
/**
 * MessageHeaderResponseComponent
 *
 * MessageHeaderResponseComponent: Information about the message that this message is a response to.  Only present if this message is a response.
 *
 * http://hl7.org/fhir/MessageHeaderResponseComponent
 */
var MessageHeaderResponseComponent = 'http://hl7.org/fhir/MessageHeaderResponseComponent';
/**
 * Linkage
 *
 * Identifies two or more records (resource instances) that refer to the same real-world "occurrence".
 *
 * http://hl7.org/fhir/Linkage
 */
var Linkage = 'http://hl7.org/fhir/Linkage';
/**
 * permittedUnit
 *
 * ObservationDefinition.component.permittedUnit: Units allowed for the valueQuantity element in the instance observations conforming to this ObservationDefinition.
 *
 * http://hl7.org/fhir/permittedUnit
 */
var permittedUnit = 'http://hl7.org/fhir/permittedUnit';
/**
 * _sex
 *
 * (Modified) FamilyMemberHistory.sex
 *
 * http://hl7.org/fhir/_sex
 */
var _sex = 'http://hl7.org/fhir/_sex';
/**
 * genomeBuild
 *
 * GenomicStudy.analysis.genomeBuild: The reference genome build that is used in this analysis.
 *
 * http://hl7.org/fhir/genomeBuild
 */
var genomeBuild = 'http://hl7.org/fhir/genomeBuild';
/**
 * changePattern
 *
 * ClinicalImpression.changePattern: Change in the status/pattern of a subject's condition since previously assessed, such as worsening, improving, or no change.  It is a subjective assessment of the direction of the change.
 *
 * http://hl7.org/fhir/changePattern
 */
var changePattern = 'http://hl7.org/fhir/changePattern';
/**
 * MedicationRequestSubstitutionComponent
 *
 * MedicationRequestSubstitutionComponent: Indicates whether or not substitution can or should be part of the dispense. In some cases, substitution must happen, in other cases substitution must not happen. This block explains the prescriber's intent. If nothing is specified substitution may be done.
 *
 * http://hl7.org/fhir/MedicationRequestSubstitutionComponent
 */
var MedicationRequestSubstitutionComponent = 'http://hl7.org/fhir/MedicationRequestSubstitutionComponent';
/**
 * _authority
 *
 * (Modified) SubstanceDefinition.name.official.authority
 *
 * http://hl7.org/fhir/_authority
 */
var _authority = 'http://hl7.org/fhir/_authority';
/**
 * onBehalfOf
 *
 * Provenance.entity.agent.onBehalfOf: The agent that delegated authority to perform the activity performed by the agent.who element.
 *
 * http://hl7.org/fhir/onBehalfOf
 */
var onBehalfOf = 'http://hl7.org/fhir/onBehalfOf';
/**
 * _rateAggregation
 *
 * (Modified) Measure.group.rateAggregation
 *
 * http://hl7.org/fhir/_rateAggregation
 */
var _rateAggregation = 'http://hl7.org/fhir/_rateAggregation';
/**
 * managingOrganization
 *
 * Patient.managingOrganization: Organization that is the custodian of the patient record.
 *
 * http://hl7.org/fhir/managingOrganization
 */
var managingOrganization = 'http://hl7.org/fhir/managingOrganization';
/**
 * handling
 *
 * SpecimenDefinition.typeTested.handling: Set of instructions for preservation/transport of the specimen at a defined temperature interval, prior the testing process.
 *
 * http://hl7.org/fhir/handling
 */
var handling = 'http://hl7.org/fhir/handling';
/**
 * notConsumedReason
 *
 * NutritionIntake.consumedItem.notConsumedReason: Document the reason the food or fluid was not consumed, such as refused, held, etc.
 *
 * http://hl7.org/fhir/notConsumedReason
 */
var notConsumedReason = 'http://hl7.org/fhir/notConsumedReason';
/**
 * axis
 *
 * VisionPrescription.lensSpecification.axis: Adjustment for astigmatism measured in integer degrees.
 *
 * http://hl7.org/fhir/axis
 */
var axis = 'http://hl7.org/fhir/axis';
/**
 * _udiCarrier
 *
 * (Modified) Device.udiCarrier
 *
 * http://hl7.org/fhir/_udiCarrier
 */
var _udiCarrier = 'http://hl7.org/fhir/_udiCarrier';
/**
 * paymentBy
 *
 * Coverage.paymentBy: Link to the paying party and optionally what specifically they will be responsible to pay.
 *
 * http://hl7.org/fhir/paymentBy
 */
var paymentBy = 'http://hl7.org/fhir/paymentBy';
/**
 * _insurancePlan
 *
 * (Modified) Coverage.insurancePlan
 *
 * http://hl7.org/fhir/_insurancePlan
 */
var _insurancePlan = 'http://hl7.org/fhir/_insurancePlan';
/**
 * subDetailSequence
 *
 * ExplanationOfBenefit.addItem.subDetailSequence: The sequence number of the sub-details woithin the details within the claim item which this line is intended to replace.
 *
 * http://hl7.org/fhir/subDetailSequence
 */
var subDetailSequence = 'http://hl7.org/fhir/subDetailSequence';
/**
 * DataRequirementValueFilterComponent
 *
 * DataRequirementValueFilterComponent: Value filters specify additional constraints on the data for elements other than code-valued or date-valued. Each value filter specifies an additional constraint on the data (i.e. valueFilters are AND'ed, not OR'ed).
 *
 * http://hl7.org/fhir/DataRequirementValueFilterComponent
 */
var DataRequirementValueFilterComponent = 'http://hl7.org/fhir/DataRequirementValueFilterComponent';
/**
 * problem
 *
 * ClinicalImpression.problem: A list of the relevant problems/conditions for a patient.
 *
 * http://hl7.org/fhir/problem
 */
var problem = 'http://hl7.org/fhir/problem';
/**
 * initialFill
 *
 * MedicationRequest.dispenseRequest.initialFill: Indicates the quantity or duration for the first dispense of the medication.
 *
 * http://hl7.org/fhir/initialFill
 */
var initialFill = 'http://hl7.org/fhir/initialFill';
/**
 * _ManufacturedItemDefinition
 *
 * (Modified) ManufacturedItemDefinition
 *
 * http://hl7.org/fhir/_ManufacturedItemDefinition
 */
var _ManufacturedItemDefinition = 'http://hl7.org/fhir/_ManufacturedItemDefinition';
/**
 * _improvementNotation
 *
 * (Modified) MeasureReport.improvementNotation
 *
 * http://hl7.org/fhir/_improvementNotation
 */
var _improvementNotation = 'http://hl7.org/fhir/_improvementNotation';
/**
 * ClinicalUseDefinitionIndicationComponentOtherTherapy
 *
 * Information about the use of the medicinal product in relation to other therapies described as part of the indication.
 *
 * http://hl7.org/fhir/ClinicalUseDefinitionIndicationComponentOtherTherapy
 */
var ClinicalUseDefinitionIndicationComponentOtherTherapy = 'http://hl7.org/fhir/ClinicalUseDefinitionIndicationComponentOtherTherapy';
/**
 * fraction
 *
 * SubstanceSourceMaterial.fractionDescription.fraction: This element is capturing information about the fraction of a plant part, or human plasma for fractionation.
 *
 * http://hl7.org/fhir/fraction
 */
var fraction = 'http://hl7.org/fhir/fraction';
/**
 * _lastOccurrence
 *
 * (Modified) AllergyIntolerance.lastOccurrence
 *
 * http://hl7.org/fhir/_lastOccurrence
 */
var _lastOccurrence = 'http://hl7.org/fhir/_lastOccurrence';
/**
 * _assessment
 *
 * (Modified) Condition.stage.assessment
 *
 * http://hl7.org/fhir/_assessment
 */
var _assessment = 'http://hl7.org/fhir/_assessment';
/**
 * Patient
 *
 * Demographics and other administrative information about an individual or animal receiving care or other health-related services.
 *
 * http://hl7.org/fhir/Patient
 */
var Patient = 'http://hl7.org/fhir/Patient';
/**
 * _identified
 *
 * (Modified) DetectedIssue.identified
 *
 * http://hl7.org/fhir/_identified
 */
var _identified = 'http://hl7.org/fhir/_identified';
/**
 * ExplanationOfBenefitAdjudication
 *
 * The adjudication results which are presented at the header level rather than at the line-item or add-item levels.
 *
 * http://hl7.org/fhir/ExplanationOfBenefitAdjudication
 */
var ExplanationOfBenefitAdjudication = 'http://hl7.org/fhir/ExplanationOfBenefitAdjudication';
/**
 * _Subscription
 *
 * (Modified) Subscription
 *
 * http://hl7.org/fhir/_Subscription
 */
var _Subscription = 'http://hl7.org/fhir/_Subscription';
/**
 * tag
 *
 * Meta.tag: Tags applied to this resource. Tags are intended to be used to identify and relate resources to process and workflow, and applications are not required to consider the tags when interpreting the meaning of a resource.
 *
 * http://hl7.org/fhir/tag
 */
var tag = 'http://hl7.org/fhir/tag';
/**
 * _performed
 *
 * (Modified) FamilyMemberHistory.procedure.performed
 *
 * http://hl7.org/fhir/_performed
 */
var _performed = 'http://hl7.org/fhir/_performed';
/**
 * _formOf
 *
 * (Modified) AdministrableProductDefinition.formOf
 *
 * http://hl7.org/fhir/_formOf
 */
var _formOf = 'http://hl7.org/fhir/_formOf';
/**
 * DeviceDefinitionPackagingComponentPackagingPackaging
 *
 * Allows packages within packages.
 *
 * http://hl7.org/fhir/DeviceDefinitionPackagingComponentPackagingPackaging
 */
var DeviceDefinitionPackagingComponentPackagingPackaging = 'http://hl7.org/fhir/DeviceDefinitionPackagingComponentPackagingPackaging';
/**
 * _subrogation
 *
 * (Modified) Coverage.subrogation
 *
 * http://hl7.org/fhir/_subrogation
 */
var _subrogation = 'http://hl7.org/fhir/_subrogation';
/**
 * _deceased
 *
 * (Modified) Practitioner.deceased
 *
 * http://hl7.org/fhir/_deceased
 */
var _deceased = 'http://hl7.org/fhir/_deceased';
/**
 * relatedAccount
 *
 * Account.relatedAccount: Other associated accounts related to this account.
 *
 * http://hl7.org/fhir/relatedAccount
 */
var relatedAccount = 'http://hl7.org/fhir/relatedAccount';
/**
 * Transport
 *
 * Record of transport.
 *
 * http://hl7.org/fhir/Transport
 */
var Transport = 'http://hl7.org/fhir/Transport';
/**
 * Measure
 *
 * The Measure resource provides the definition of a quality measure.
 *
 * http://hl7.org/fhir/Measure
 */
var Measure = 'http://hl7.org/fhir/Measure';
/**
 * RiskAssessment
 *
 * An assessment of the likely outcome(s) for a patient or other subject as well as the likelihood of each outcome.
 *
 * http://hl7.org/fhir/RiskAssessment
 */
var RiskAssessment = 'http://hl7.org/fhir/RiskAssessment';
/**
 * _teardown
 *
 * (Modified) TestScript.teardown
 *
 * http://hl7.org/fhir/_teardown
 */
var _teardown = 'http://hl7.org/fhir/_teardown';
/**
 * degreeOfPolymerisation
 *
 * SubstancePolymer.repeat.repeatUnit.degreeOfPolymerisation: Applies to homopolymer and block co-polymers where the degree of polymerisation within a block can be described.
 *
 * http://hl7.org/fhir/degreeOfPolymerisation
 */
var degreeOfPolymerisation = 'http://hl7.org/fhir/degreeOfPolymerisation';
/**
 * _CoverageEligibilityRequest
 *
 * (Modified) CoverageEligibilityRequest
 *
 * http://hl7.org/fhir/_CoverageEligibilityRequest
 */
var _CoverageEligibilityRequest = 'http://hl7.org/fhir/_CoverageEligibilityRequest';
/**
 * _Medication
 *
 * (Modified) Medication
 *
 * http://hl7.org/fhir/_Medication
 */
var _Medication = 'http://hl7.org/fhir/_Medication';
/**
 * manufacturedDoseForm
 *
 * ManufacturedItemDefinition.manufacturedDoseForm: Dose form as manufactured and before any transformation into the pharmaceutical product.
 *
 * http://hl7.org/fhir/manufacturedDoseForm
 */
var manufacturedDoseForm = 'http://hl7.org/fhir/manufacturedDoseForm';
/**
 * sliceName
 *
 * GraphDefinition.link.sliceName: Which slice (if profiled).
 *
 * http://hl7.org/fhir/sliceName
 */
var sliceName = 'http://hl7.org/fhir/sliceName';
/**
 * dateAsserted
 *
 * MedicationStatement.dateAsserted: The date when the Medication Statement was asserted by the information source.
 *
 * http://hl7.org/fhir/dateAsserted
 */
var dateAsserted = 'http://hl7.org/fhir/dateAsserted';
/**
 * ContractParty
 *
 * Contract.TermTerm.ContractOffer.ContractParty: Offer Recipient.
 *
 * http://hl7.org/fhir/ContractParty
 */
var ContractParty = 'http://hl7.org/fhir/ContractParty';
/**
 * validationStatus
 *
 * VerificationResult.primarySource.validationStatus: Status of the validation of the target against the primary source (successful; failed; unknown).
 *
 * http://hl7.org/fhir/validationStatus
 */
var validationStatus = 'http://hl7.org/fhir/validationStatus';
/**
 * TestScriptMetadataComponent
 *
 * TestScriptMetadataComponent: The required capability must exist and are assumed to function correctly on the FHIR server being tested.
 *
 * http://hl7.org/fhir/TestScriptMetadataComponent
 */
var TestScriptMetadataComponent = 'http://hl7.org/fhir/TestScriptMetadataComponent';
/**
 * _headerField
 *
 * (Modified) TestScript.test.action.assert.headerField
 *
 * http://hl7.org/fhir/_headerField
 */
var _headerField = 'http://hl7.org/fhir/_headerField';
/**
 * geographicalLocation
 *
 * SubstanceSourceMaterial.geographicalLocation: The place/region where the plant is harvested or the places/regions where the animal source material has its habitat.
 *
 * http://hl7.org/fhir/geographicalLocation
 */
var geographicalLocation = 'http://hl7.org/fhir/geographicalLocation';
/**
 * versionNeeded
 *
 * CodeSystem.versionNeeded: This flag is used to signify that the code system does not commit to concept permanence across versions. If true, a version must be specified when referencing this code system.
 *
 * http://hl7.org/fhir/versionNeeded
 */
var versionNeeded = 'http://hl7.org/fhir/versionNeeded';
/**
 * ConceptDefinition
 *
 * CodeSystem.ConceptDefinition: Concepts that are in the code system. The concept definitions are inherently hierarchical, but the definitions must be consulted to determine what the meanings of the hierarchical relationships are.
 *
 * http://hl7.org/fhir/ConceptDefinition
 */
var ConceptDefinition = 'http://hl7.org/fhir/ConceptDefinition';
/**
 * _sigFormat
 *
 * (Modified) Signature.sigFormat
 *
 * http://hl7.org/fhir/_sigFormat
 */
var _sigFormat = 'http://hl7.org/fhir/_sigFormat';
/**
 * publishedIn
 *
 * Citation.citedArtifact.publicationForm.publishedIn: The collection the cited article or artifact is published in.
 *
 * http://hl7.org/fhir/publishedIn
 */
var publishedIn = 'http://hl7.org/fhir/publishedIn';
/**
 * sphere
 *
 * VisionPrescription.lensSpecification.sphere: Lens power measured in dioptres (0.25 units).
 *
 * http://hl7.org/fhir/sphere
 */
var sphere = 'http://hl7.org/fhir/sphere';
/**
 * _SubstanceDefinition
 *
 * (Modified) SubstanceDefinition
 *
 * http://hl7.org/fhir/_SubstanceDefinition
 */
var _SubstanceDefinition = 'http://hl7.org/fhir/_SubstanceDefinition';
/**
 * SubstanceDefinitionNameOfficialComponent
 *
 * SubstanceDefinitionNameComponentName.SubstanceDefinitionNameOfficialComponent: Details of the official nature of this name.
 *
 * http://hl7.org/fhir/SubstanceDefinitionNameOfficialComponent
 */
var SubstanceDefinitionNameOfficialComponent = 'http://hl7.org/fhir/SubstanceDefinitionNameOfficialComponent';
/**
 * _listRuleId
 *
 * (Modified) StructureMap.group.rule.rule.target.listRuleId
 *
 * http://hl7.org/fhir/_listRuleId
 */
var _listRuleId = 'http://hl7.org/fhir/_listRuleId';
/**
 * started
 *
 * ImagingStudy.series.started: The date and time the series was started.
 *
 * http://hl7.org/fhir/started
 */
var started = 'http://hl7.org/fhir/started';
/**
 * EvidenceVariable
 *
 * The EvidenceVariable resource describes an element that knowledge (Evidence) is about.
 *
 * http://hl7.org/fhir/EvidenceVariable
 */
var EvidenceVariable = 'http://hl7.org/fhir/EvidenceVariable';
/**
 * ResearchStudyOutcomeMeasureComponent
 *
 * ResearchStudyOutcomeMeasureComponent: An "outcome measure", "endpoint", "effect measure" or "measure of effect" is a specific measurement or observation used to quantify the effect of experimental variables on the participants in a study, or for observational studies, to describe patterns of diseases or traits or associations with exposures, risk factors or treatment.
 *
 * http://hl7.org/fhir/ResearchStudyOutcomeMeasureComponent
 */
var ResearchStudyOutcomeMeasureComponent = 'http://hl7.org/fhir/ResearchStudyOutcomeMeasureComponent';
/**
 * allowedResponse
 *
 * MessageDefinition.allowedResponse: Indicates what types of messages may be sent as an application-level response to this message.
 *
 * http://hl7.org/fhir/allowedResponse
 */
var allowedResponse = 'http://hl7.org/fhir/allowedResponse';
/**
 * _ElementDefinition
 *
 * (Modified) ElementDefinition
 *
 * http://hl7.org/fhir/_ElementDefinition
 */
var _ElementDefinition = 'http://hl7.org/fhir/_ElementDefinition';
/**
 * CitationCitedArtifactContributorshipComponent
 *
 * CitationCitedArtifactComponent.CitationCitedArtifactContributorshipComponent: This element is used to list authors and other contributors, their contact information, specific contributions, and summary statements.
 *
 * http://hl7.org/fhir/CitationCitedArtifactContributorshipComponent
 */
var CitationCitedArtifactContributorshipComponent = 'http://hl7.org/fhir/CitationCitedArtifactContributorshipComponent';
/**
 * _contentType
 *
 * (Modified) TestScript.test.action.assert.contentType
 *
 * http://hl7.org/fhir/_contentType
 */
var _contentType = 'http://hl7.org/fhir/_contentType';
/**
 * _DeviceUsage
 *
 * (Modified) DeviceUsage
 *
 * http://hl7.org/fhir/_DeviceUsage
 */
var _DeviceUsage = 'http://hl7.org/fhir/_DeviceUsage';
/**
 * DeviceDefinitionUdiDeviceIdentifierComponent
 *
 * DeviceDefinitionUdiDeviceIdentifierComponent: Unique device identifier (UDI) assigned to device label or package.  Note that the Device may include multiple udiCarriers as it either may include just the udiCarrier for the jurisdiction it is sold, or for multiple jurisdictions it could have been sold.
 *
 * http://hl7.org/fhir/DeviceDefinitionUdiDeviceIdentifierComponent
 */
var DeviceDefinitionUdiDeviceIdentifierComponent = 'http://hl7.org/fhir/DeviceDefinitionUdiDeviceIdentifierComponent';
/**
 * document
 *
 * CapabilityStatement.document: A document definition.
 *
 * http://hl7.org/fhir/document
 */
var document = 'http://hl7.org/fhir/document';
/**
 * event
 *
 * Composition.event: The clinical service, such as a colonoscopy or an appendectomy, being documented.
 *
 * http://hl7.org/fhir/event
 */
var event = 'http://hl7.org/fhir/event';
/**
 * Guarantor
 *
 * Account.Guarantor: The parties responsible for balancing the account if other payment options fall short.
 *
 * http://hl7.org/fhir/Guarantor
 */
var Guarantor = 'http://hl7.org/fhir/Guarantor';
/**
 * molecularWeight
 *
 * SubstanceDefinition.structure.molecularWeight: The molecular weight or weight range (for proteins, polymers or nucleic acids).
 *
 * http://hl7.org/fhir/molecularWeight
 */
var molecularWeight = 'http://hl7.org/fhir/molecularWeight';
/**
 * substitution
 *
 * MedicationRequest.substitution: Indicates whether or not substitution can or should be part of the dispense. In some cases, substitution must happen, in other cases substitution must not happen. This block explains the prescriber's intent. If nothing is specified substitution may be done.
 *
 * http://hl7.org/fhir/substitution
 */
var substitution = 'http://hl7.org/fhir/substitution';
/**
 * NutritionOrderSupplementComponent
 *
 * NutritionOrderSupplementComponent: Oral nutritional products given in order to add further nutritional value to the patient's diet.
 *
 * http://hl7.org/fhir/NutritionOrderSupplementComponent
 */
var NutritionOrderSupplementComponent = 'http://hl7.org/fhir/NutritionOrderSupplementComponent';
/**
 * _relativeRisk
 *
 * (Modified) RiskAssessment.prediction.relativeRisk
 *
 * http://hl7.org/fhir/_relativeRisk
 */
var _relativeRisk = 'http://hl7.org/fhir/_relativeRisk';
/**
 * _volume
 *
 * (Modified) Citation.citedArtifact.publicationForm.volume
 *
 * http://hl7.org/fhir/_volume
 */
var _volume = 'http://hl7.org/fhir/_volume';
/**
 * _manager
 *
 * (Modified) Consent.manager
 *
 * http://hl7.org/fhir/_manager
 */
var _manager = 'http://hl7.org/fhir/_manager';
/**
 * _presentation
 *
 * (Modified) Ingredient.substance.strength.presentation
 *
 * http://hl7.org/fhir/_presentation
 */
var _presentation = 'http://hl7.org/fhir/_presentation';
/**
 * _linkage
 *
 * (Modified) SubstanceNucleicAcid.subunit.linkage
 *
 * http://hl7.org/fhir/_linkage
 */
var _linkage = 'http://hl7.org/fhir/_linkage';
/**
 * isDefault
 *
 * TerminologyCapabilities.codeSystem.version.isDefault: If this is the default version for this code system.
 *
 * http://hl7.org/fhir/isDefault
 */
var isDefault = 'http://hl7.org/fhir/isDefault';
/**
 * BodyStructure
 *
 * Record details about an anatomical structure.  This resource may be used when a coded concept does not provide the necessary detail needed for the use case.
 *
 * http://hl7.org/fhir/BodyStructure
 */
var BodyStructure = 'http://hl7.org/fhir/BodyStructure';
/**
 * _relationship
 *
 * (Modified) Contract.term.group.asset.relationship
 *
 * http://hl7.org/fhir/_relationship
 */
var _relationship = 'http://hl7.org/fhir/_relationship';
/**
 * _maxDispense
 *
 * (Modified) MedicationKnowledge.regulatory.maxDispense
 *
 * http://hl7.org/fhir/_maxDispense
 */
var _maxDispense = 'http://hl7.org/fhir/_maxDispense';
/**
 * ChargeItemDefinition
 *
 * The ChargeItemDefinition resource provides the properties that apply to the (billing) codes necessary to calculate costs and prices. The properties may differ largely depending on type and realm, therefore this resource gives only a rough structure and requires profiling for each type of billing code system.
 *
 * http://hl7.org/fhir/ChargeItemDefinition
 */
var ChargeItemDefinition = 'http://hl7.org/fhir/ChargeItemDefinition';
/**
 * _SupplyDelivery
 *
 * (Modified) SupplyDelivery
 *
 * http://hl7.org/fhir/_SupplyDelivery
 */
var _SupplyDelivery = 'http://hl7.org/fhir/_SupplyDelivery';
/**
 * _specialArrangement
 *
 * (Modified) Encounter.specialArrangement
 *
 * http://hl7.org/fhir/_specialArrangement
 */
var _specialArrangement = 'http://hl7.org/fhir/_specialArrangement';
/**
 * DosageDoseAndRateComponent
 *
 * DosageDoseAndRateComponent: Depending on the resource,this is the amount of medication administered, to  be administered or typical amount to be administered.
 *
 * http://hl7.org/fhir/DosageDoseAndRateComponent
 */
var DosageDoseAndRateComponent = 'http://hl7.org/fhir/DosageDoseAndRateComponent';
/**
 * _guideline
 *
 * (Modified) DeviceDefinition.guideline
 *
 * http://hl7.org/fhir/_guideline
 */
var _guideline = 'http://hl7.org/fhir/_guideline';
/**
 * _grantee
 *
 * (Modified) Consent.grantee
 *
 * http://hl7.org/fhir/_grantee
 */
var _grantee = 'http://hl7.org/fhir/_grantee';
/**
 * serviced
 *
 * ExplanationOfBenefit.addItem.serviced
 *
 * http://hl7.org/fhir/serviced
 */
var serviced = 'http://hl7.org/fhir/serviced';
/**
 * _active
 *
 * (Modified) Patient.active
 *
 * http://hl7.org/fhir/_active
 */
var _active = 'http://hl7.org/fhir/_active';
/**
 * _preference
 *
 * (Modified) SpecimenDefinition.typeTested.preference
 *
 * http://hl7.org/fhir/_preference
 */
var _preference = 'http://hl7.org/fhir/_preference';
/**
 * useContext
 *
 * ExampleScenario.useContext: The content was developed with a focus and intent of supporting the contexts that are listed. These contexts may be general categories (gender, age, ...) or may be references to specific programs (insurance plans, studies, ...) and may be used to assist with indexing and searching for appropriate example scenario instances.
 *
 * http://hl7.org/fhir/useContext
 */
var useContext = 'http://hl7.org/fhir/useContext';
/**
 * _container
 *
 * (Modified) SpecimenDefinition.typeTested.container
 *
 * http://hl7.org/fhir/_container
 */
var _container = 'http://hl7.org/fhir/_container';
/**
 * justification
 *
 * Permission.justification: The asserted justification for using the data.
 *
 * http://hl7.org/fhir/justification
 */
var justification = 'http://hl7.org/fhir/justification';
/**
 * oralDiet
 *
 * NutritionOrder.oralDiet: Diet given orally in contrast to enteral (tube) feeding.
 *
 * http://hl7.org/fhir/oralDiet
 */
var oralDiet = 'http://hl7.org/fhir/oralDiet';
/**
 * _testingDestination
 *
 * (Modified) SpecimenDefinition.typeTested.testingDestination
 *
 * http://hl7.org/fhir/_testingDestination
 */
var _testingDestination = 'http://hl7.org/fhir/_testingDestination';
/**
 * lastRevisionDate
 *
 * Citation.citedArtifact.publicationForm.lastRevisionDate: The date the article was last revised or updated in the database.
 *
 * http://hl7.org/fhir/lastRevisionDate
 */
var lastRevisionDate = 'http://hl7.org/fhir/lastRevisionDate';
/**
 * NutritionIntakeIngredientLabelComponent
 *
 * NutritionIntakeIngredientLabelComponent: Total nutrient amounts for the whole meal, product, serving, etc.
 *
 * http://hl7.org/fhir/NutritionIntakeIngredientLabelComponent
 */
var NutritionIntakeIngredientLabelComponent = 'http://hl7.org/fhir/NutritionIntakeIngredientLabelComponent';
/**
 * QuestionnaireResponseItemComponentItem
 *
 * Sub-questions, sub-groups or display items nested beneath a group.
 *
 * http://hl7.org/fhir/QuestionnaireResponseItemComponentItem
 */
var QuestionnaireResponseItemComponentItem = 'http://hl7.org/fhir/QuestionnaireResponseItemComponentItem';
/**
 * PermissionJustificationComponent
 *
 * PermissionJustificationComponent: The asserted justification for using the data.
 *
 * http://hl7.org/fhir/PermissionJustificationComponent
 */
var PermissionJustificationComponent = 'http://hl7.org/fhir/PermissionJustificationComponent';
/**
 * recorder
 *
 * Procedure.recorder: Individual who recorded the record and takes responsibility for its content.
 *
 * http://hl7.org/fhir/recorder
 */
var recorder = 'http://hl7.org/fhir/recorder';
/**
 * ImmunizationRecommendationRecommendationDateCriterionComponent
 *
 * ImmunizationRecommendationRecommendationComponent.ImmunizationRecommendationRecommendationDateCriterionComponent: Vaccine date recommendations.  For example, earliest date to administer, latest date to administer, etc.
 *
 * http://hl7.org/fhir/ImmunizationRecommendationRecommendationDateCriterionComponent
 */
var ImmunizationRecommendationRecommendationDateCriterionComponent = 'http://hl7.org/fhir/ImmunizationRecommendationRecommendationDateCriterionComponent';
/**
 * _focus
 *
 * (Modified) ServiceRequest.focus
 *
 * http://hl7.org/fhir/_focus
 */
var _focus = 'http://hl7.org/fhir/_focus';
/**
 * countingDateTime
 *
 * InventoryReport.inventoryListing.countingDateTime: The date and time when the items were counted.
 *
 * http://hl7.org/fhir/countingDateTime
 */
var countingDateTime = 'http://hl7.org/fhir/countingDateTime';
/**
 * MedicationKnowledge
 *
 * Information about a medication that is used to support knowledge.
 *
 * http://hl7.org/fhir/MedicationKnowledge
 */
var MedicationKnowledge = 'http://hl7.org/fhir/MedicationKnowledge';
/**
 * ConditionDefinition
 *
 * A definition of a condition and information relevant to managing it.
 *
 * http://hl7.org/fhir/ConditionDefinition
 */
var ConditionDefinition = 'http://hl7.org/fhir/ConditionDefinition';
/**
 * noMap
 *
 * ConceptMap.group.element.noMap: If noMap = true this indicates that no mapping to a target concept exists for this source concept.
 *
 * http://hl7.org/fhir/noMap
 */
var noMap = 'http://hl7.org/fhir/noMap';
/**
 * _userSelected
 *
 * (Modified) Coding.userSelected
 *
 * http://hl7.org/fhir/_userSelected
 */
var _userSelected = 'http://hl7.org/fhir/_userSelected';
/**
 * appointmentRequired
 *
 * HealthcareService.appointmentRequired: Indicates whether or not a prospective consumer will require an appointment for a particular service at a site to be provided by the Organization. Indicates if an appointment is required for access to this service.
 *
 * http://hl7.org/fhir/appointmentRequired
 */
var appointmentRequired = 'http://hl7.org/fhir/appointmentRequired';
/**
 * _numberOfStudies
 *
 * (Modified) Evidence.statistic.sampleSize.numberOfStudies
 *
 * http://hl7.org/fhir/_numberOfStudies
 */
var _numberOfStudies = 'http://hl7.org/fhir/_numberOfStudies';
/**
 * capabilities
 *
 * TestScript.metadata.capability.capabilities: Minimum capabilities required of server for test script to execute successfully.   If server does not meet at a minimum the referenced capability statement, then all tests in this script are skipped.
 *
 * http://hl7.org/fhir/capabilities
 */
var capabilities = 'http://hl7.org/fhir/capabilities';
/**
 * Benefit
 *
 * CoverageEligibilityResponse.Insurance.Items.Benefit: Benefits used to date.
 *
 * http://hl7.org/fhir/Benefit
 */
var Benefit = 'http://hl7.org/fhir/Benefit';
/**
 * _uri
 *
 * (Modified) ImplementationGuide.dependsOn.uri
 *
 * http://hl7.org/fhir/_uri
 */
var _uri = 'http://hl7.org/fhir/_uri';
/**
 * _max
 *
 * (Modified) StructureMap.group.rule.rule.source.max
 *
 * http://hl7.org/fhir/_max
 */
var _max = 'http://hl7.org/fhir/_max';
/**
 * inactive
 *
 * ValueSet.expansion.contains.contains.inactive: If the concept is inactive in the code system that defines it. Inactive codes are those that are no longer to be used, but are maintained by the code system for understanding legacy data. It might not be known or specified whether a concept is inactive (and it may depend on the context of use).
 *
 * http://hl7.org/fhir/inactive
 */
var inactive = 'http://hl7.org/fhir/inactive';
/**
 * other
 *
 * Patient.link.other: Link to a Patient or RelatedPerson resource that concerns the same actual individual.
 *
 * http://hl7.org/fhir/other
 */
var other = 'http://hl7.org/fhir/other';
/**
 * dependsOn
 *
 * ImplementationGuide.dependsOn: Another implementation guide that this implementation depends on. Typically, an implementation guide uses value sets, profiles etc.defined in other implementation guides.
 *
 * http://hl7.org/fhir/dependsOn
 */
var dependsOn = 'http://hl7.org/fhir/dependsOn';
/**
 * citedArtifact
 *
 * Citation.citedArtifact: The article or artifact being described.
 *
 * http://hl7.org/fhir/citedArtifact
 */
var citedArtifact = 'http://hl7.org/fhir/citedArtifact';
/**
 * fixture
 *
 * TestScript.fixture: Fixture in the test script - by reference (uri). All fixtures are required for the test script to execute.
 *
 * http://hl7.org/fhir/fixture
 */
var fixture = 'http://hl7.org/fhir/fixture';
/**
 * _insurer
 *
 * (Modified) ExplanationOfBenefit.insurer
 *
 * http://hl7.org/fhir/_insurer
 */
var _insurer = 'http://hl7.org/fhir/_insurer';
/**
 * _endParam
 *
 * (Modified) CompartmentDefinition.resource.endParam
 *
 * http://hl7.org/fhir/_endParam
 */
var _endParam = 'http://hl7.org/fhir/_endParam';
/**
 * continuous
 *
 * Goal.continuous: After meeting the goal, ongoing activity is needed to sustain the goal objective.
 *
 * http://hl7.org/fhir/continuous
 */
var continuous = 'http://hl7.org/fhir/continuous';
/**
 * SubstancePolymerRepeatRepeatUnitStructuralRepresentationComponent
 *
 * SubstancePolymerRepeatComponent.SubstancePolymerRepeatRepeatUnitComponent.SubstancePolymerRepeatRepeatUnitStructuralRepresentationComponent: A graphical structure for this SRU.
 *
 * http://hl7.org/fhir/SubstancePolymerRepeatRepeatUnitStructuralRepresentationComponent
 */
var SubstancePolymerRepeatRepeatUnitStructuralRepresentationComponent = 'http://hl7.org/fhir/SubstancePolymerRepeatRepeatUnitStructuralRepresentationComponent';
/**
 * _responsibleOrganization
 *
 * (Modified) InventoryItem.responsibleOrganization
 *
 * http://hl7.org/fhir/_responsibleOrganization
 */
var _responsibleOrganization = 'http://hl7.org/fhir/_responsibleOrganization';
/**
 * url
 *
 * ChargeItemDefinition.url: An absolute URI that is used to identify this charge item definition when it is referenced in a specification, model, design or an instance; also called its canonical identifier. This SHOULD be globally unique and SHOULD be a literal address at which an authoritative instance of this charge item definition is (or will be) published. This URL can be the target of a canonical reference. It SHALL remain the same when the charge item definition is stored on different servers.
 *
 * http://hl7.org/fhir/url
 */
var url = 'http://hl7.org/fhir/url';
/**
 * compareToSourceExpression
 *
 * TestScript.test.action.assert.compareToSourceExpression: The FHIRPath expression for a specific value to evaluate against the source fixture. When compareToSourceId is defined, either compareToSourceExpression or compareToSourcePath must be defined, but not both.
 *
 * http://hl7.org/fhir/compareToSourceExpression
 */
var compareToSourceExpression = 'http://hl7.org/fhir/compareToSourceExpression';
/**
 * nutrient
 *
 * NutritionProduct.nutrient: The product's nutritional information expressed by the nutrients.
 *
 * http://hl7.org/fhir/nutrient
 */
var nutrient = 'http://hl7.org/fhir/nutrient';
/**
 * _subjectResults
 *
 * (Modified) MeasureReport.group.stratifier.stratum.population.subjectResults
 *
 * http://hl7.org/fhir/_subjectResults
 */
var _subjectResults = 'http://hl7.org/fhir/_subjectResults';
/**
 * DocumentReferenceRelatesToComponent
 *
 * DocumentReferenceRelatesToComponent: Relationships that this document has with other document references that already exist.
 *
 * http://hl7.org/fhir/DocumentReferenceRelatesToComponent
 */
var DocumentReferenceRelatesToComponent = 'http://hl7.org/fhir/DocumentReferenceRelatesToComponent';
/**
 * ImagingStudy
 *
 * Representation of the content produced in a DICOM imaging study. A study comprises a set of series, each of which includes a set of Service-Object Pair Instances (SOP Instances - images or other data) acquired or produced in a common context.  A series is of only one modality (e.g. X-ray, CT, MR, ultrasound), but a study may have multiple series of different modalities.
 *
 * http://hl7.org/fhir/ImagingStudy
 */
var ImagingStudy = 'http://hl7.org/fhir/ImagingStudy';
/**
 * AppointmentRecurrenceTemplateYearlyTemplateComponent
 *
 * AppointmentRecurrenceTemplateComponent.AppointmentRecurrenceTemplateYearlyTemplateComponent: Information about yearly recurring appointments.
 *
 * http://hl7.org/fhir/AppointmentRecurrenceTemplateYearlyTemplateComponent
 */
var AppointmentRecurrenceTemplateYearlyTemplateComponent = 'http://hl7.org/fhir/AppointmentRecurrenceTemplateYearlyTemplateComponent';
/**
 * SpecimenFeatureComponent
 *
 * SpecimenFeatureComponent: A physical feature or landmark on a specimen, highlighted for context by the collector of the specimen (e.g. surgeon), that identifies the type of feature as well as its meaning (e.g. the red ink indicating the resection margin of the right lobe of the excised prostate tissue or wire loop at radiologically suspected tumor location).
 *
 * http://hl7.org/fhir/SpecimenFeatureComponent
 */
var SpecimenFeatureComponent = 'http://hl7.org/fhir/SpecimenFeatureComponent';
/**
 * _ServiceRequest
 *
 * (Modified) ServiceRequest
 *
 * http://hl7.org/fhir/_ServiceRequest
 */
var _ServiceRequest = 'http://hl7.org/fhir/_ServiceRequest';
/**
 * tester
 *
 * TestReport.tester: Name of the tester producing this report (Organization or individual).
 *
 * http://hl7.org/fhir/tester
 */
var tester = 'http://hl7.org/fhir/tester';
/**
 * seriousness
 *
 * AdverseEvent.seriousness: Assessment whether this event, or averted event, was of clinical importance.
 *
 * http://hl7.org/fhir/seriousness
 */
var seriousness = 'http://hl7.org/fhir/seriousness';
/**
 * isDefining
 *
 * SubstancePolymer.monomerSet.startingMaterial.isDefining: Used to specify whether the attribute described is a defining element for the unique identification of the polymer.
 *
 * http://hl7.org/fhir/isDefining
 */
var isDefining = 'http://hl7.org/fhir/isDefining';
/**
 * contributingFactor
 *
 * AdverseEvent.contributingFactor: The contributing factors suspected to have increased the probability or severity of the adverse event.
 *
 * http://hl7.org/fhir/contributingFactor
 */
var contributingFactor = 'http://hl7.org/fhir/contributingFactor';
/**
 * CapabilityStatement
 *
 * A Capability Statement documents a set of capabilities (behaviors) of a FHIR Server or Client for a particular version of FHIR that may be used as a statement of actual server functionality or a statement of required or desired server implementation.
 *
 * http://hl7.org/fhir/CapabilityStatement
 */
var CapabilityStatement = 'http://hl7.org/fhir/CapabilityStatement';
/**
 * _ImagingSelection
 *
 * (Modified) ImagingSelection
 *
 * http://hl7.org/fhir/_ImagingSelection
 */
var _ImagingSelection = 'http://hl7.org/fhir/_ImagingSelection';
/**
 * _unmapped
 *
 * (Modified) ConceptMap.group.unmapped
 *
 * http://hl7.org/fhir/_unmapped
 */
var _unmapped = 'http://hl7.org/fhir/_unmapped';
/**
 * compositional
 *
 * TerminologyCapabilities.codeSystem.version.compositional: If the compositional grammar defined by the code system is supported.
 *
 * http://hl7.org/fhir/compositional
 */
var compositional = 'http://hl7.org/fhir/compositional';
/**
 * fundsReserveRequested
 *
 * ExplanationOfBenefit.fundsReserveRequested: A code to indicate whether and for whom funds are to be reserved for future claims.
 *
 * http://hl7.org/fhir/fundsReserveRequested
 */
var fundsReserveRequested = 'http://hl7.org/fhir/fundsReserveRequested';
/**
 * Total
 *
 * ExplanationOfBenefit.Total: Categorized monetary totals for the adjudication.
 *
 * http://hl7.org/fhir/Total
 */
var Total = 'http://hl7.org/fhir/Total';
/**
 * _citeAs
 *
 * (Modified) EvidenceReport.citeAs
 *
 * http://hl7.org/fhir/_citeAs
 */
var _citeAs = 'http://hl7.org/fhir/_citeAs';
/**
 * _protein
 *
 * (Modified) SubstanceDefinition.protein
 *
 * http://hl7.org/fhir/_protein
 */
var _protein = 'http://hl7.org/fhir/_protein';
/**
 * _referenceRange
 *
 * (Modified) Observation.component.referenceRange
 *
 * http://hl7.org/fhir/_referenceRange
 */
var _referenceRange = 'http://hl7.org/fhir/_referenceRange';
/**
 * complication
 *
 * Procedure.complication: Any complications that occurred during the procedure, or in the immediate post-performance period. These are generally tracked separately from the notes, which will typically describe the procedure itself rather than any 'post procedure' issues.
 *
 * http://hl7.org/fhir/complication
 */
var complication = 'http://hl7.org/fhir/complication';
/**
 * SubscriptionTopicResourceTriggerComponent
 *
 * SubscriptionTopicResourceTriggerComponent: A definition of a resource-based event that triggers a notification based on the SubscriptionTopic. The criteria may be just a human readable description and/or a full FHIR search string or FHIRPath expression. Multiple triggers are considered OR joined (e.g., a resource update matching ANY of the definitions will trigger a notification).
 *
 * http://hl7.org/fhir/SubscriptionTopicResourceTriggerComponent
 */
var SubscriptionTopicResourceTriggerComponent = 'http://hl7.org/fhir/SubscriptionTopicResourceTriggerComponent';
/**
 * estimate
 *
 * Account.balance.estimate: The amount is only an estimated value - this is likely common for `current` term balances, but not with known terms (that were generated by a backend process).
 *
 * http://hl7.org/fhir/estimate
 */
var estimate = 'http://hl7.org/fhir/estimate';
/**
 * _material
 *
 * (Modified) SpecimenDefinition.typeTested.container.material
 *
 * http://hl7.org/fhir/_material
 */
var _material = 'http://hl7.org/fhir/_material';
/**
 * Item
 *
 * ClaimResponse.Item: A claim line. Either a simple (a product or service) or a 'group' of details which can also be a simple items or groups of sub-details.
 *
 * http://hl7.org/fhir/Item
 */
var Item = 'http://hl7.org/fhir/Item';
/**
 * encodeRequestUrl
 *
 * TestScript.teardown.action.operation.encodeRequestUrl: Whether or not to implicitly send the request url in encoded format. The default is true to match the standard RESTful client behavior. Set to false when communicating with a server that does not support encoded url paths.
 *
 * http://hl7.org/fhir/encodeRequestUrl
 */
var encodeRequestUrl = 'http://hl7.org/fhir/encodeRequestUrl';
/**
 * _currentLocation
 *
 * (Modified) Transport.currentLocation
 *
 * http://hl7.org/fhir/_currentLocation
 */
var _currentLocation = 'http://hl7.org/fhir/_currentLocation';
/**
 * style
 *
 * Citation.citedArtifact.contributorship.summary.style: The format for the display string, such as author last name with first letter capitalized followed by forename initials.
 *
 * http://hl7.org/fhir/style
 */
var style = 'http://hl7.org/fhir/style';
/**
 * method
 *
 * TestScript.test.action.operation.method: The HTTP method the test engine MUST use for this operation regardless of any other operation details.
 *
 * http://hl7.org/fhir/method
 */
var method = 'http://hl7.org/fhir/method';
/**
 * _MarketingStatus
 *
 * (Modified) MarketingStatus
 *
 * http://hl7.org/fhir/_MarketingStatus
 */
var _MarketingStatus = 'http://hl7.org/fhir/_MarketingStatus';
/**
 * group
 *
 * StructureMap.group: Organizes the mapping into managable chunks for human review/ease of maintenance.
 *
 * http://hl7.org/fhir/group
 */
var group = 'http://hl7.org/fhir/group';
/**
 * achievementStatus
 *
 * Goal.achievementStatus: Describes the progression, or lack thereof, towards the goal against the target.
 *
 * http://hl7.org/fhir/achievementStatus
 */
var achievementStatus = 'http://hl7.org/fhir/achievementStatus';
/**
 * evaluatedResource
 *
 * MeasureReport.evaluatedResource: Evaluated resources are used to capture what data was involved in the calculation of a measure. This usage is only allowed for individual reports to ensure that the size of the MeasureReport resource is bounded.
 *
 * http://hl7.org/fhir/evaluatedResource
 */
var evaluatedResource = 'http://hl7.org/fhir/evaluatedResource';
/**
 * _udiDeviceIdentifier
 *
 * (Modified) DeviceDefinition.packaging.packaging.udiDeviceIdentifier
 *
 * http://hl7.org/fhir/_udiDeviceIdentifier
 */
var _udiDeviceIdentifier = 'http://hl7.org/fhir/_udiDeviceIdentifier';
/**
 * _RelatedPerson
 *
 * (Modified) RelatedPerson
 *
 * http://hl7.org/fhir/_RelatedPerson
 */
var _RelatedPerson = 'http://hl7.org/fhir/_RelatedPerson';
/**
 * dateTime
 *
 * A date, date-time or partial date (e.g. just year or year + month).  If hours and minutes are specified, a UTC offset SHALL be populated. The format is a union of the schema types gYear, gYearMonth, date and dateTime. Seconds must be provided due to schema type constraints but may be zero-filled and may be ignored.                 Dates SHALL be valid dates.
 *
 * http://hl7.org/fhir/dateTime
 */
var dateTime = 'http://hl7.org/fhir/dateTime';
/**
 * _intervalUnit
 *
 * (Modified) SampledData.intervalUnit
 *
 * http://hl7.org/fhir/_intervalUnit
 */
var _intervalUnit = 'http://hl7.org/fhir/_intervalUnit';
/**
 * text
 *
 * Annotation.text: The text of the annotation in markdown format.
 *
 * http://hl7.org/fhir/text
 */
var text = 'http://hl7.org/fhir/text';
/**
 * _contact
 *
 * (Modified) DeviceDefinition.contact
 *
 * http://hl7.org/fhir/_contact
 */
var _contact = 'http://hl7.org/fhir/_contact';
/**
 * searchInclude
 *
 * CapabilityStatement.rest.resource.searchInclude: A list of _include values supported by the server.
 *
 * http://hl7.org/fhir/searchInclude
 */
var searchInclude = 'http://hl7.org/fhir/searchInclude';
/**
 * _fivePrime
 *
 * (Modified) SubstanceNucleicAcid.subunit.fivePrime
 *
 * http://hl7.org/fhir/_fivePrime
 */
var _fivePrime = 'http://hl7.org/fhir/_fivePrime';
/**
 * timeOfDay
 *
 * Timing.repeat.timeOfDay: Specified time of day for action to take place.
 *
 * http://hl7.org/fhir/timeOfDay
 */
var timeOfDay = 'http://hl7.org/fhir/timeOfDay';
/**
 * originRelationshipType
 *
 * BiologicallyDerivedProductDispense.originRelationshipType: Indicates the relationship between the donor of the biologically derived product and the intended recipient.
 *
 * http://hl7.org/fhir/originRelationshipType
 */
var originRelationshipType = 'http://hl7.org/fhir/originRelationshipType';
/**
 * CitationClassificationComponent
 *
 * CitationClassificationComponent: The assignment to an organizing scheme.
 *
 * http://hl7.org/fhir/CitationClassificationComponent
 */
var CitationClassificationComponent = 'http://hl7.org/fhir/CitationClassificationComponent';
/**
 * _plannedStartDate
 *
 * (Modified) EncounterHistory.plannedStartDate
 *
 * http://hl7.org/fhir/_plannedStartDate
 */
var _plannedStartDate = 'http://hl7.org/fhir/_plannedStartDate';
/**
 * documentType
 *
 * Consent.provision.provision.documentType: The documentType(s) covered by this provision. The type can be a CDA document, or some other type that indicates what sort of information the consent relates to.
 *
 * http://hl7.org/fhir/documentType
 */
var documentType = 'http://hl7.org/fhir/documentType';
/**
 * CoverageEligibilityRequestEventComponent
 *
 * CoverageEligibilityRequestEventComponent: Information code for an event with a corresponding date or period.
 *
 * http://hl7.org/fhir/CoverageEligibilityRequestEventComponent
 */
var CoverageEligibilityRequestEventComponent = 'http://hl7.org/fhir/CoverageEligibilityRequestEventComponent';
/**
 * _milestone
 *
 * (Modified) ResearchSubject.progress.milestone
 *
 * http://hl7.org/fhir/_milestone
 */
var _milestone = 'http://hl7.org/fhir/_milestone';
/**
 * page
 *
 * ImplementationGuide.definition.page.page: Nested Pages/Sections under this page.
 *
 * http://hl7.org/fhir/page
 */
var page = 'http://hl7.org/fhir/page';
/**
 * params
 *
 * TestScript.setup.action.operation.params: Path plus parameters after [type].  Used to set parts of the request URL explicitly.
 *
 * http://hl7.org/fhir/params
 */
var params = 'http://hl7.org/fhir/params';
/**
 * regionsCalled
 *
 * GenomicStudy.analysis.regionsCalled: Genomic regions actually called in the analysis event (BED file).
 *
 * http://hl7.org/fhir/regionsCalled
 */
var regionsCalled = 'http://hl7.org/fhir/regionsCalled';
/**
 * conditionalCreate
 *
 * CapabilityStatement.rest.resource.conditionalCreate: A flag that indicates that the server supports conditional create.
 *
 * http://hl7.org/fhir/conditionalCreate
 */
var conditionalCreate = 'http://hl7.org/fhir/conditionalCreate';
/**
 * lensSpecification
 *
 * VisionPrescription.lensSpecification: Contain the details of  the individual lens specifications and serves as the authorization for the fullfillment by certified professionals.
 *
 * http://hl7.org/fhir/lensSpecification
 */
var lensSpecification = 'http://hl7.org/fhir/lensSpecification';
/**
 * _grantor
 *
 * (Modified) Consent.grantor
 *
 * http://hl7.org/fhir/_grantor
 */
var _grantor = 'http://hl7.org/fhir/_grantor';
/**
 * coverage
 *
 * Account.coverage.coverage: The party(s) that contribute to payment (or part of) of the charges applied to this account (including self-pay).
 *
 * A coverage may only be responsible for specific types of charges, and the sequence of the coverages in the account could be important when processing billing.
 *
 * http://hl7.org/fhir/coverage
 */
var coverage = 'http://hl7.org/fhir/coverage';
/**
 * authorizationSupporting
 *
 * CoverageEligibilityResponse.insurance.item.authorizationSupporting: Codes or comments regarding information or actions associated with the preauthorization.
 *
 * http://hl7.org/fhir/authorizationSupporting
 */
var authorizationSupporting = 'http://hl7.org/fhir/authorizationSupporting';
/**
 * ElementDefinitionBindingAdditionalComponent
 *
 * ElementDefinitionBindingComponent.ElementDefinitionBindingAdditionalComponent: Additional bindings that help applications implementing this element. Additional bindings do not replace the main binding but provide more information and/or context.
 *
 * http://hl7.org/fhir/ElementDefinitionBindingAdditionalComponent
 */
var ElementDefinitionBindingAdditionalComponent = 'http://hl7.org/fhir/ElementDefinitionBindingAdditionalComponent';
/**
 * _benefit
 *
 * (Modified) InsurancePlan.plan.specificCost.benefit
 *
 * http://hl7.org/fhir/_benefit
 */
var _benefit = 'http://hl7.org/fhir/_benefit';
/**
 * _testData
 *
 * (Modified) TestPlan.testCase.testData
 *
 * http://hl7.org/fhir/_testData
 */
var _testData = 'http://hl7.org/fhir/_testData';
/**
 * _OrganizationAffiliation
 *
 * (Modified) OrganizationAffiliation
 *
 * http://hl7.org/fhir/_OrganizationAffiliation
 */
var _OrganizationAffiliation = 'http://hl7.org/fhir/_OrganizationAffiliation';
/**
 * excludedStructure
 *
 * BodyStructure.excludedStructure: The anatomical location(s) or region(s) not occupied or represented by the specimen, lesion, or body structure.
 *
 * http://hl7.org/fhir/excludedStructure
 */
var excludedStructure = 'http://hl7.org/fhir/excludedStructure';
/**
 * _searchRevInclude
 *
 * (Modified) CapabilityStatement.rest.resource.searchRevInclude
 *
 * http://hl7.org/fhir/_searchRevInclude
 */
var _searchRevInclude = 'http://hl7.org/fhir/_searchRevInclude';
/**
 * serviceProvisionCode
 *
 * HealthcareService.serviceProvisionCode: The code(s) that detail the conditions under which the healthcare service is available/offered.
 *
 * http://hl7.org/fhir/serviceProvisionCode
 */
var serviceProvisionCode = 'http://hl7.org/fhir/serviceProvisionCode';
/**
 * typeMode
 *
 * StructureMap.group.typeMode: If this is the default rule set to apply for the source type or this combination of types.
 *
 * http://hl7.org/fhir/typeMode
 */
var typeMode = 'http://hl7.org/fhir/typeMode';
/**
 * ValueSetScopeComponent
 *
 * ValueSetScopeComponent: Description of the semantic space the Value Set Expansion is intended to cover and should further clarify the text in ValueSet.description.
 *
 * http://hl7.org/fhir/ValueSetScopeComponent
 */
var ValueSetScopeComponent = 'http://hl7.org/fhir/ValueSetScopeComponent';
/**
 * SupplyRequestParameterComponent
 *
 * SupplyRequestParameterComponent: Specific parameters for the ordered item.  For example, the size of the indicated item.
 *
 * http://hl7.org/fhir/SupplyRequestParameterComponent
 */
var SupplyRequestParameterComponent = 'http://hl7.org/fhir/SupplyRequestParameterComponent';
/**
 * attributeEstimate
 *
 * Evidence.statistic.modelCharacteristic.attributeEstimate: An attribute of the statistic used as a model characteristic.
 *
 * http://hl7.org/fhir/attributeEstimate
 */
var attributeEstimate = 'http://hl7.org/fhir/attributeEstimate';
/**
 * immutable
 *
 * ValueSet.immutable: If this is set to 'true', then no new versions of the content logical definition can be created.  Note: Other metadata might still change.
 *
 * http://hl7.org/fhir/immutable
 */
var immutable = 'http://hl7.org/fhir/immutable';
/**
 * _relatedAccount
 *
 * (Modified) Account.relatedAccount
 *
 * http://hl7.org/fhir/_relatedAccount
 */
var _relatedAccount = 'http://hl7.org/fhir/_relatedAccount';
/**
 * _RiskAssessment
 *
 * (Modified) RiskAssessment
 *
 * http://hl7.org/fhir/_RiskAssessment
 */
var _RiskAssessment = 'http://hl7.org/fhir/_RiskAssessment';
/**
 * BiologicallyDerivedProductPropertyComponent
 *
 * BiologicallyDerivedProductPropertyComponent: A property that is specific to this BiologicallyDerviedProduct instance.
 *
 * http://hl7.org/fhir/BiologicallyDerivedProductPropertyComponent
 */
var BiologicallyDerivedProductPropertyComponent = 'http://hl7.org/fhir/BiologicallyDerivedProductPropertyComponent';
/**
 * _totalVolume
 *
 * (Modified) Medication.totalVolume
 *
 * http://hl7.org/fhir/_totalVolume
 */
var _totalVolume = 'http://hl7.org/fhir/_totalVolume';
/**
 * _adjudication
 *
 * (Modified) ExplanationOfBenefit.adjudication
 *
 * http://hl7.org/fhir/_adjudication
 */
var _adjudication = 'http://hl7.org/fhir/_adjudication';
/**
 * history
 *
 * Transport.history: The transport event prior to this one.
 *
 * http://hl7.org/fhir/history
 */
var history = 'http://hl7.org/fhir/history';
/**
 * _isSubpotent
 *
 * (Modified) Immunization.isSubpotent
 *
 * http://hl7.org/fhir/_isSubpotent
 */
var _isSubpotent = 'http://hl7.org/fhir/_isSubpotent';
/**
 * _longitude
 *
 * (Modified) Location.position.longitude
 *
 * http://hl7.org/fhir/_longitude
 */
var _longitude = 'http://hl7.org/fhir/_longitude';
/**
 * _sliceIsConstraining
 *
 * (Modified) ElementDefinition.sliceIsConstraining
 *
 * http://hl7.org/fhir/_sliceIsConstraining
 */
var _sliceIsConstraining = 'http://hl7.org/fhir/_sliceIsConstraining';
/**
 * collected
 *
 * Specimen.collection.collected
 *
 * http://hl7.org/fhir/collected
 */
var collected = 'http://hl7.org/fhir/collected';
/**
 * medicineClassification
 *
 * MedicationKnowledge.medicineClassification: Categorization of the medication within a formulary or classification system.
 *
 * http://hl7.org/fhir/medicineClassification
 */
var medicineClassification = 'http://hl7.org/fhir/medicineClassification';
/**
 * Signature
 *
 * A signature along with supporting context. The signature may be a digital signature that is cryptographic in nature, or some other signature acceptable to the domain. This other signature may be as simple as a graphical image representing a hand-written signature, or a signature ceremony Different signature approaches have different utilities.
 *
 * http://hl7.org/fhir/Signature
 */
var Signature = 'http://hl7.org/fhir/Signature';
/**
 * ConceptReference
 *
 * ValueSetComposeComponent.ConceptSet.ConceptReference: Specifies a concept to be included or excluded.
 *
 * http://hl7.org/fhir/ConceptReference
 */
var ConceptReference = 'http://hl7.org/fhir/ConceptReference';
/**
 * TransportRestrictionComponent
 *
 * TransportRestrictionComponent: If the Transport.focus is a request resource and the transport is seeking fulfillment (i.e. is asking for the request to be actioned), this element identifies any limitations on what parts of the referenced request should be actioned.
 *
 * http://hl7.org/fhir/TransportRestrictionComponent
 */
var TransportRestrictionComponent = 'http://hl7.org/fhir/TransportRestrictionComponent';
/**
 * _rank
 *
 * (Modified) ContactPoint.rank
 *
 * http://hl7.org/fhir/_rank
 */
var _rank = 'http://hl7.org/fhir/_rank';
/**
 * _inResponseTo
 *
 * (Modified) Communication.inResponseTo
 *
 * http://hl7.org/fhir/_inResponseTo
 */
var _inResponseTo = 'http://hl7.org/fhir/_inResponseTo';
/**
 * CitationCitedArtifactAbstractComponent
 *
 * CitationCitedArtifactComponent.CitationCitedArtifactAbstractComponent: The abstract may be used to convey article-contained abstracts, externally-created abstracts, or other descriptive summaries.
 *
 * http://hl7.org/fhir/CitationCitedArtifactAbstractComponent
 */
var CitationCitedArtifactAbstractComponent = 'http://hl7.org/fhir/CitationCitedArtifactAbstractComponent';
/**
 * _error
 *
 * (Modified) SubscriptionStatus.error
 *
 * http://hl7.org/fhir/_error
 */
var _error = 'http://hl7.org/fhir/_error';
/**
 * origin
 *
 * TestScript.test.action.operation.origin: The server where the request message originates from.  Must be one of the server numbers listed in TestScript.origin section.
 *
 * http://hl7.org/fhir/origin
 */
var origin = 'http://hl7.org/fhir/origin';
/**
 * treeRoot
 *
 * http://hl7.org/fhir/treeRoot
 */
var treeRoot = 'http://hl7.org/fhir/treeRoot';
/**
 * _sourceMaterialType
 *
 * (Modified) SubstanceSourceMaterial.sourceMaterialType
 *
 * http://hl7.org/fhir/_sourceMaterialType
 */
var _sourceMaterialType = 'http://hl7.org/fhir/_sourceMaterialType';
/**
 * bodyStructure
 *
 * ServiceRequest.bodyStructure: Anatomic location where the procedure should be performed. This is the target site.
 *
 * http://hl7.org/fhir/bodyStructure
 */
var bodyStructure = 'http://hl7.org/fhir/bodyStructure';
/**
 * _releaseDate
 *
 * (Modified) CapabilityStatement.software.releaseDate
 *
 * http://hl7.org/fhir/_releaseDate
 */
var _releaseDate = 'http://hl7.org/fhir/_releaseDate';
/**
 * normalValue
 *
 * Observation.component.referenceRange.normalValue: The value of the normal value of the reference range.
 *
 * http://hl7.org/fhir/normalValue
 */
var normalValue = 'http://hl7.org/fhir/normalValue';
/**
 * PractitionerCommunicationComponent
 *
 * PractitionerCommunicationComponent: A language which may be used to communicate with the practitioner, often for correspondence/administrative purposes.

The `PractitionerRole.communication` property should be used for publishing the languages that a practitioner is able to communicate with patients (on a per Organization/Role basis).
 *
 * http://hl7.org/fhir/PractitionerCommunicationComponent
 */
var PractitionerCommunicationComponent = 'http://hl7.org/fhir/PractitionerCommunicationComponent';
/**
 * targetProfile
 *
 * OperationDefinition.parameter.part.targetProfile: Used when the type is "Reference" or "canonical", and identifies a profile structure or implementation Guide that applies to the target of the reference this parameter refers to. If any profiles are specified, then the content must conform to at least one of them. The URL can be a local reference - to a contained StructureDefinition, or a reference to another StructureDefinition or Implementation Guide by a canonical URL. When an implementation guide is specified, the target resource SHALL conform to at least one profile defined in the implementation guide.
 *
 * http://hl7.org/fhir/targetProfile
 */
var targetProfile = 'http://hl7.org/fhir/targetProfile';
/**
 * bounds
 *
 * Timing.repeat.bounds
 *
 * http://hl7.org/fhir/bounds
 */
var bounds = 'http://hl7.org/fhir/bounds';
/**
 * _op
 *
 * (Modified) ValueSet.compose.exclude.filter.op
 *
 * http://hl7.org/fhir/_op
 */
var _op = 'http://hl7.org/fhir/_op';
/**
 * OperationDefinitionParameterComponentParameterParameter
 *
 * The parts of a nested Parameter.
 *
 * http://hl7.org/fhir/OperationDefinitionParameterComponentParameterParameter
 */
var OperationDefinitionParameterComponentParameterParameter = 'http://hl7.org/fhir/OperationDefinitionParameterComponentParameterParameter';
/**
 * plannedActivityReference
 *
 * CarePlan.activity.plannedActivityReference: The details of the proposed activity represented in a specific resource.
 *
 * http://hl7.org/fhir/plannedActivityReference
 */
var plannedActivityReference = 'http://hl7.org/fhir/plannedActivityReference';
/**
 * _preAuthRef
 *
 * (Modified) ExplanationOfBenefit.addItem.detail.subDetail.reviewOutcome.preAuthRef
 *
 * http://hl7.org/fhir/_preAuthRef
 */
var _preAuthRef = 'http://hl7.org/fhir/_preAuthRef';
/**
 * _imageRegion3D
 *
 * (Modified) ImagingSelection.instance.imageRegion3D
 *
 * http://hl7.org/fhir/_imageRegion3D
 */
var _imageRegion3D = 'http://hl7.org/fhir/_imageRegion3D';
/**
 * _object
 *
 * (Modified) TestPlan.testCase.assertion.object
 *
 * http://hl7.org/fhir/_object
 */
var _object = 'http://hl7.org/fhir/_object';
/**
 * DocumentReferenceAttesterComponent
 *
 * DocumentReferenceAttesterComponent: A participant who has authenticated the accuracy of the document.
 *
 * http://hl7.org/fhir/DocumentReferenceAttesterComponent
 */
var DocumentReferenceAttesterComponent = 'http://hl7.org/fhir/DocumentReferenceAttesterComponent';
/**
 * _recall
 *
 * (Modified) DeviceDefinition.correctiveAction.recall
 *
 * http://hl7.org/fhir/_recall
 */
var _recall = 'http://hl7.org/fhir/_recall';
/**
 * fastingStatus
 *
 * Specimen.collection.fastingStatus
 *
 * http://hl7.org/fhir/fastingStatus
 */
var fastingStatus = 'http://hl7.org/fhir/fastingStatus';
/**
 * seriesUid
 *
 * ImagingSelection.seriesUid: The Series Instance UID for the DICOM Series from which the images were selected.
 *
 * http://hl7.org/fhir/seriesUid
 */
var seriesUid = 'http://hl7.org/fhir/seriesUid';
/**
 * SubstanceSourceMaterialPartDescriptionComponent
 *
 * SubstanceSourceMaterialPartDescriptionComponent: To do.
 *
 * http://hl7.org/fhir/SubstanceSourceMaterialPartDescriptionComponent
 */
var SubstanceSourceMaterialPartDescriptionComponent = 'http://hl7.org/fhir/SubstanceSourceMaterialPartDescriptionComponent';
/**
 * _geneElement
 *
 * (Modified) SubstanceReferenceInformation.geneElement
 *
 * http://hl7.org/fhir/_geneElement
 */
var _geneElement = 'http://hl7.org/fhir/_geneElement';
/**
 * publicationDateText
 *
 * Citation.citedArtifact.publicationForm.publicationDateText: Text representation of the date on which the issue of the cited artifact was published.
 *
 * http://hl7.org/fhir/publicationDateText
 */
var publicationDateText = 'http://hl7.org/fhir/publicationDateText';
/**
 * EpisodeOfCareStatusHistoryComponent
 *
 * EpisodeOfCareStatusHistoryComponent: The history of statuses that the EpisodeOfCare has been through (without requiring processing the history of the resource).
 *
 * http://hl7.org/fhir/EpisodeOfCareStatusHistoryComponent
 */
var EpisodeOfCareStatusHistoryComponent = 'http://hl7.org/fhir/EpisodeOfCareStatusHistoryComponent';
/**
 * evaluationMessage
 *
 * GuidanceResponse.evaluationMessage: Messages resulting from the evaluation of the artifact or artifacts. As part of evaluating the request, the engine may produce informational or warning messages. These messages will be provided by this element.
 *
 * http://hl7.org/fhir/evaluationMessage
 */
var evaluationMessage = 'http://hl7.org/fhir/evaluationMessage';
/**
 * division
 *
 * BiologicallyDerivedProduct.division: A unique identifier for an aliquot of a product.  Used to distinguish individual aliquots of a product carrying the same biologicalSource and productCode identifiers.
 *
 * http://hl7.org/fhir/division
 */
var division = 'http://hl7.org/fhir/division';
/**
 * windowEnd
 *
 * MolecularSequence.relative.startingSequence.windowEnd: End position of the window on the starting sequence. This value should honor the rules of the  coordinateSystem.
 *
 * http://hl7.org/fhir/windowEnd
 */
var windowEnd = 'http://hl7.org/fhir/windowEnd';
/**
 * _foodType
 *
 * (Modified) NutritionOrder.oralDiet.texture.foodType
 *
 * http://hl7.org/fhir/_foodType
 */
var _foodType = 'http://hl7.org/fhir/_foodType';
/**
 * _repeats
 *
 * (Modified) Questionnaire.item.item.repeats
 *
 * http://hl7.org/fhir/_repeats
 */
var _repeats = 'http://hl7.org/fhir/_repeats';
/**
 * _Observation
 *
 * (Modified) Observation
 *
 * http://hl7.org/fhir/_Observation
 */
var _Observation = 'http://hl7.org/fhir/_Observation';
/**
 * validateCode
 *
 * TerminologyCapabilities.validateCode: Information about the [ValueSet/$validate-code](valueset-operation-validate-code.html) operation.
 *
 * http://hl7.org/fhir/validateCode
 */
var validateCode = 'http://hl7.org/fhir/validateCode';
/**
 * parameterName
 *
 * OperationDefinition.overload.parameterName: Name of parameter to include in overload.
 *
 * http://hl7.org/fhir/parameterName
 */
var parameterName = 'http://hl7.org/fhir/parameterName';
/**
 * source
 *
 * MedicationKnowledge.medicineClassification.source
 *
 * http://hl7.org/fhir/source
 */
var source = 'http://hl7.org/fhir/source';
/**
 * currentState
 *
 * Citation.citedArtifact.currentState: The status of the cited artifact.
 *
 * http://hl7.org/fhir/currentState
 */
var currentState = 'http://hl7.org/fhir/currentState';
/**
 * publicationStatus
 *
 * Contract.contentDefinition.publicationStatus: amended | appended | cancelled | disputed | entered-in-error | executable +.
 *
 * http://hl7.org/fhir/publicationStatus
 */
var publicationStatus = 'http://hl7.org/fhir/publicationStatus';
/**
 * _license
 *
 * (Modified) ImplementationGuide.license
 *
 * http://hl7.org/fhir/_license
 */
var _license = 'http://hl7.org/fhir/_license';
/**
 * _created
 *
 * (Modified) EnrollmentResponse.created
 *
 * http://hl7.org/fhir/_created
 */
var _created = 'http://hl7.org/fhir/_created';
/**
 * ClinicalUseDefinitionContraindicationOtherTherapyComponent
 *
 * ClinicalUseDefinitionContraindicationComponent.ClinicalUseDefinitionContraindicationOtherTherapyComponent: Information about the use of the medicinal product in relation to other therapies described as part of the contraindication.
 *
 * http://hl7.org/fhir/ClinicalUseDefinitionContraindicationOtherTherapyComponent
 */
var ClinicalUseDefinitionContraindicationOtherTherapyComponent = 'http://hl7.org/fhir/ClinicalUseDefinitionContraindicationOtherTherapyComponent';
/**
 * isModifier
 *
 * ElementDefinition.isModifier: If true, the value of this element affects the interpretation of the element or resource that contains it, and the value of the element cannot be ignored. Typically, this is used for status, negation and qualification codes. The effect of this is that the element cannot be ignored by systems: they SHALL either recognize the element and process it, and/or a pre-determination has been made that it is not relevant to their particular system. When used on the root element in an extension definition, this indicates whether or not the extension is a modifier extension.
 *
 * http://hl7.org/fhir/isModifier
 */
var isModifier = 'http://hl7.org/fhir/isModifier';
/**
 * _needsMap
 *
 * (Modified) TerminologyCapabilities.translation.needsMap
 *
 * http://hl7.org/fhir/_needsMap
 */
var _needsMap = 'http://hl7.org/fhir/_needsMap';
/**
 * performerType
 *
 * ObservationDefinition.performerType: The type of individual/organization/device that is expected to act upon instances of this definition.
 *
 * http://hl7.org/fhir/performerType
 */
var performerType = 'http://hl7.org/fhir/performerType';
/**
 * unitPrice
 *
 * ExplanationOfBenefit.item.detail.subDetail.unitPrice: If the item is not a group then this is the fee for the product or service, otherwise this is the total of the fees for the details of the group.
 *
 * http://hl7.org/fhir/unitPrice
 */
var unitPrice = 'http://hl7.org/fhir/unitPrice';
/**
 * _topic
 *
 * (Modified) Contract.term.group.topic
 *
 * http://hl7.org/fhir/_topic
 */
var _topic = 'http://hl7.org/fhir/_topic';
/**
 * _lastUpdated
 *
 * (Modified) Meta.lastUpdated
 *
 * http://hl7.org/fhir/_lastUpdated
 */
var _lastUpdated = 'http://hl7.org/fhir/_lastUpdated';
/**
 * preparedDate
 *
 * DeviceDispense.preparedDate: The time when the dispensed product was packaged and reviewed.
 *
 * http://hl7.org/fhir/preparedDate
 */
var preparedDate = 'http://hl7.org/fhir/preparedDate';
/**
 * accident
 *
 * ExplanationOfBenefit.accident: Details of a accident which resulted in injuries which required the products and services listed in the claim.
 *
 * http://hl7.org/fhir/accident
 */
var accident = 'http://hl7.org/fhir/accident';
/**
 * code
 *
 * ChargeItemDefinition.code: The defined billing details in this resource pertain to the given billing code.
 *
 * http://hl7.org/fhir/code
 */
var code = 'http://hl7.org/fhir/code';
/**
 * _designation
 *
 * (Modified) ValueSet.expansion.contains.contains.designation
 *
 * http://hl7.org/fhir/_designation
 */
var _designation = 'http://hl7.org/fhir/_designation';
/**
 * _creation
 *
 * (Modified) Invoice.creation
 *
 * http://hl7.org/fhir/_creation
 */
var _creation = 'http://hl7.org/fhir/_creation';
/**
 * verificationType
 *
 * Consent.verification.verificationType: Extensible list of verification type starting with verification and re-validation.
 *
 * http://hl7.org/fhir/verificationType
 */
var verificationType = 'http://hl7.org/fhir/verificationType';
/**
 * DeviceDefinitionPackagingComponentPackagingUdiDeviceIdentifier
 *
 * Unique Device Identifier (UDI) Barcode string on the packaging.
 *
 * http://hl7.org/fhir/DeviceDefinitionPackagingComponentPackagingUdiDeviceIdentifier
 */
var DeviceDefinitionPackagingComponentPackagingUdiDeviceIdentifier = 'http://hl7.org/fhir/DeviceDefinitionPackagingComponentPackagingUdiDeviceIdentifier';
/**
 * _containedInstance
 *
 * (Modified) ExampleScenario.instance.containedInstance
 *
 * http://hl7.org/fhir/_containedInstance
 */
var _containedInstance = 'http://hl7.org/fhir/_containedInstance';
/**
 * PackagedProductDefinitionLegalStatusOfSupplyComponent
 *
 * PackagedProductDefinitionLegalStatusOfSupplyComponent: The legal status of supply of the packaged item as classified by the regulator.
 *
 * http://hl7.org/fhir/PackagedProductDefinitionLegalStatusOfSupplyComponent
 */
var PackagedProductDefinitionLegalStatusOfSupplyComponent = 'http://hl7.org/fhir/PackagedProductDefinitionLegalStatusOfSupplyComponent';
/**
 * _recipient
 *
 * (Modified) Communication.recipient
 *
 * http://hl7.org/fhir/_recipient
 */
var _recipient = 'http://hl7.org/fhir/_recipient';
/**
 * ifMatch
 *
 * Bundle.entry.request.ifMatch: Only perform the operation if the Etag value matches. For more information, see the API section ["Managing Resource Contention"](http.html#concurrency).
 *
 * http://hl7.org/fhir/ifMatch
 */
var ifMatch = 'http://hl7.org/fhir/ifMatch';
/**
 * partNumber
 *
 * DeviceDefinition.partNumber: The part number or catalog number of the device.
 *
 * http://hl7.org/fhir/partNumber
 */
var partNumber = 'http://hl7.org/fhir/partNumber';
/**
 * _severity
 *
 * (Modified) OperationOutcome.issue.severity
 *
 * http://hl7.org/fhir/_severity
 */
var _severity = 'http://hl7.org/fhir/_severity';
/**
 * _filterBy
 *
 * (Modified) Subscription.filterBy
 *
 * http://hl7.org/fhir/_filterBy
 */
var _filterBy = 'http://hl7.org/fhir/_filterBy';
/**
 * _NutritionIntake
 *
 * (Modified) NutritionIntake
 *
 * http://hl7.org/fhir/_NutritionIntake
 */
var _NutritionIntake = 'http://hl7.org/fhir/_NutritionIntake';
/**
 * BundleEntrySearchComponent
 *
 * BundleEntryComponent.BundleEntrySearchComponent: Information about the search process that lead to the creation of this entry.
 *
 * http://hl7.org/fhir/BundleEntrySearchComponent
 */
var BundleEntrySearchComponent = 'http://hl7.org/fhir/BundleEntrySearchComponent';
/**
 * _responseCode
 *
 * (Modified) TestScript.test.action.assert.responseCode
 *
 * http://hl7.org/fhir/_responseCode
 */
var _responseCode = 'http://hl7.org/fhir/_responseCode';
/**
 * _eventHistory
 *
 * (Modified) MedicationRequest.eventHistory
 *
 * http://hl7.org/fhir/_eventHistory
 */
var _eventHistory = 'http://hl7.org/fhir/_eventHistory';
/**
 * _rejectionCriterion
 *
 * (Modified) SpecimenDefinition.typeTested.rejectionCriterion
 *
 * http://hl7.org/fhir/_rejectionCriterion
 */
var _rejectionCriterion = 'http://hl7.org/fhir/_rejectionCriterion';
/**
 * notPerformedReason
 *
 * MedicationDispense.notPerformedReason: Indicates the reason why a dispense was not performed.
 *
 * http://hl7.org/fhir/notPerformedReason
 */
var notPerformedReason = 'http://hl7.org/fhir/notPerformedReason';
/**
 * _entryType
 *
 * (Modified) Device.udiCarrier.entryType
 *
 * http://hl7.org/fhir/_entryType
 */
var _entryType = 'http://hl7.org/fhir/_entryType';
/**
 * EncounterHistory
 *
 * A record of significant events/milestones key data throughout the history of an Encounter
 *
 * http://hl7.org/fhir/EncounterHistory
 */
var EncounterHistory = 'http://hl7.org/fhir/EncounterHistory';
/**
 * _specialPrecautionsForStorage
 *
 * (Modified) ProductShelfLife.specialPrecautionsForStorage
 *
 * http://hl7.org/fhir/_specialPrecautionsForStorage
 */
var _specialPrecautionsForStorage = 'http://hl7.org/fhir/_specialPrecautionsForStorage';
/**
 * SearchParameter
 *
 * A search parameter that defines a named search item that can be used to search/filter on a resource.
 *
 * http://hl7.org/fhir/SearchParameter
 */
var SearchParameter = 'http://hl7.org/fhir/SearchParameter';
/**
 * gender
 *
 * ObservationDefinition.qualifiedValue.gender: The gender this  set of qualified values applies to.
 *
 * http://hl7.org/fhir/gender
 */
var gender = 'http://hl7.org/fhir/gender';
/**
 * coding
 *
 * CodeableConcept.coding: A reference to a code defined by a terminology system.
 *
 * http://hl7.org/fhir/coding
 */
var coding = 'http://hl7.org/fhir/coding';
/**
 * ProductShelfLife
 *
 * The shelf-life and storage information for a medicinal product item or container can be described using this class.
 *
 * http://hl7.org/fhir/ProductShelfLife
 */
var ProductShelfLife = 'http://hl7.org/fhir/ProductShelfLife';
/**
 * system
 *
 * ValueSet.expansion.contains.contains.system: An absolute URI which is the code system in which the code for this item in the expansion is defined.
 *
 * http://hl7.org/fhir/system
 */
var system = 'http://hl7.org/fhir/system';
/**
 * _tissue
 *
 * (Modified) AdministrableProductDefinition.routeOfAdministration.targetSpecies.withdrawalPeriod.tissue
 *
 * http://hl7.org/fhir/_tissue
 */
var _tissue = 'http://hl7.org/fhir/_tissue';
/**
 * associatedParty
 *
 * ResearchStudy.associatedParty: Sponsors, collaborators, and other parties.
 *
 * http://hl7.org/fhir/associatedParty
 */
var associatedParty = 'http://hl7.org/fhir/associatedParty';
/**
 * statistic
 *
 * Evidence.statistic: Values and parameters for a single statistic.
 *
 * http://hl7.org/fhir/statistic
 */
var statistic = 'http://hl7.org/fhir/statistic';
/**
 * DataRequirement
 *
 * Describes a required data item for evaluation in terms of the type of data, and optional code or date-based filters of the data.
 *
 * http://hl7.org/fhir/DataRequirement
 */
var DataRequirement = 'http://hl7.org/fhir/DataRequirement';
/**
 * MedicationKnowledgeRegulatoryMaxDispenseComponent
 *
 * MedicationKnowledgeRegulatoryComponent.MedicationKnowledgeRegulatoryMaxDispenseComponent: The maximum number of units of the medication that can be dispensed in a period.
 *
 * http://hl7.org/fhir/MedicationKnowledgeRegulatoryMaxDispenseComponent
 */
var MedicationKnowledgeRegulatoryMaxDispenseComponent = 'http://hl7.org/fhir/MedicationKnowledgeRegulatoryMaxDispenseComponent';
/**
 * udiCarrier
 *
 * Device.udiCarrier: Unique device identifier (UDI) assigned to device label or package.  Note that the Device may include multiple udiCarriers as it either may include just the udiCarrier for the jurisdiction it is sold, or for multiple jurisdictions it could have been sold.
 *
 * http://hl7.org/fhir/udiCarrier
 */
var udiCarrier = 'http://hl7.org/fhir/udiCarrier';
/**
 * Availability
 *
 * Availability data for an {item}.
 *
 * http://hl7.org/fhir/Availability
 */
var Availability = 'http://hl7.org/fhir/Availability';
/**
 * sender
 *
 * MessageHeader.sender: Identifies the sending system to allow the use of a trust relationship.
 *
 * http://hl7.org/fhir/sender
 */
var sender = 'http://hl7.org/fhir/sender';
/**
 * _strand
 *
 * (Modified) MolecularSequence.relative.startingSequence.strand
 *
 * http://hl7.org/fhir/_strand
 */
var _strand = 'http://hl7.org/fhir/_strand';
/**
 * IngredientSubstanceStrengthComponent
 *
 * IngredientSubstanceComponent.IngredientSubstanceStrengthComponent: The quantity of substance in the unit of presentation, or in the volume (or mass) of the single pharmaceutical product or manufactured item. The allowed repetitions do not represent different strengths, but are different representations - mathematically equivalent - of a single strength.
 *
 * http://hl7.org/fhir/IngredientSubstanceStrengthComponent
 */
var IngredientSubstanceStrengthComponent = 'http://hl7.org/fhir/IngredientSubstanceStrengthComponent';
/**
 * MedicationKnowledgeMonitoringProgramComponent
 *
 * MedicationKnowledgeMonitoringProgramComponent: The program under which the medication is reviewed.
 *
 * http://hl7.org/fhir/MedicationKnowledgeMonitoringProgramComponent
 */
var MedicationKnowledgeMonitoringProgramComponent = 'http://hl7.org/fhir/MedicationKnowledgeMonitoringProgramComponent';
/**
 * _derivation
 *
 * (Modified) StructureDefinition.derivation
 *
 * http://hl7.org/fhir/_derivation
 */
var _derivation = 'http://hl7.org/fhir/_derivation';
/**
 * Condition
 *
 * A clinical condition, problem, diagnosis, or other event, situation, issue, or clinical concept that has risen to a level of concern.
 *
 * http://hl7.org/fhir/Condition
 */
var Condition = 'http://hl7.org/fhir/Condition';
/**
 * AdministrableProductDefinitionRouteOfAdministrationTargetSpeciesWithdrawalPeriodComponent
 *
 * AdministrableProductDefinitionRouteOfAdministrationComponent.AdministrableProductDefinitionRouteOfAdministrationTargetSpeciesComponent.AdministrableProductDefinitionRouteOfAdministrationTargetSpeciesWithdrawalPeriodComponent: A species specific time during which consumption of animal product is not appropriate.
 *
 * http://hl7.org/fhir/AdministrableProductDefinitionRouteOfAdministrationTargetSpeciesWithdrawalPeriodComponent
 */
var AdministrableProductDefinitionRouteOfAdministrationTargetSpeciesWithdrawalPeriodComponent = 'http://hl7.org/fhir/AdministrableProductDefinitionRouteOfAdministrationTargetSpeciesWithdrawalPeriodComponent';
/**
 * diagnostics
 *
 * OperationOutcome.issue.diagnostics: Additional diagnostic information about the issue.
 *
 * http://hl7.org/fhir/diagnostics
 */
var diagnostics = 'http://hl7.org/fhir/diagnostics';
/**
 * assessment
 *
 * Condition.stage.assessment: Reference to a formal record of the evidence on which the staging assessment is based.
 *
 * http://hl7.org/fhir/assessment
 */
var assessment = 'http://hl7.org/fhir/assessment';
/**
 * _clockFacePosition
 *
 * (Modified) BodyStructure.excludedStructure.bodyLandmarkOrientation.clockFacePosition
 *
 * http://hl7.org/fhir/_clockFacePosition
 */
var _clockFacePosition = 'http://hl7.org/fhir/_clockFacePosition';
/**
 * attestation
 *
 * VerificationResult.attestation: Information about the entity attesting to information.
 *
 * http://hl7.org/fhir/attestation
 */
var attestation = 'http://hl7.org/fhir/attestation';
/**
 * identified
 *
 * DetectedIssue.identified
 *
 * http://hl7.org/fhir/identified
 */
var identified = 'http://hl7.org/fhir/identified';

var fhirImport = /*#__PURE__*/Object.freeze({
	constituent: constituent,
	_careTeam: _careTeam,
	ClinicalUseDefinitionWarningComponent: ClinicalUseDefinitionWarningComponent,
	PlanDefinitionActionParticipantComponent: PlanDefinitionActionParticipantComponent,
	VisionPrescriptionLensSpecificationComponent: VisionPrescriptionLensSpecificationComponent,
	_answerOption: _answerOption,
	decimal: decimal,
	_applies: _applies,
	serviceProvider: serviceProvider,
	NutritionProductIngredientComponent: NutritionProductIngredientComponent,
	Error__workaround: Error__workaround,
	productStatus: productStatus,
	ImagingStudySeriesPerformerComponent: ImagingStudySeriesPerformerComponent,
	_lowerLimit: _lowerLimit,
	Medication: Medication,
	header: header,
	StructureMapGroupRuleComponent: StructureMapGroupRuleComponent,
	_productType: _productType,
	_relatedItem: _relatedItem,
	author: author,
	_direction: _direction,
	_frequencyOfOccurrence: _frequencyOfOccurrence,
	RequestOrchestration: RequestOrchestration,
	Detail: Detail,
	numberOfRepeatsAllowed: numberOfRepeatsAllowed,
	_communicationRequest: _communicationRequest,
	DocumentReferenceContentProfileComponent: DocumentReferenceContentProfileComponent,
	_masterFile: _masterFile,
	comment: comment,
	availableTime: availableTime,
	_assert: _assert,
	listRuleId: listRuleId,
	preAdmissionIdentifier: preAdmissionIdentifier,
	participantType: participantType,
	_related: _related,
	SupplementSchedule: SupplementSchedule,
	reAdmission: reAdmission,
	_requestURL: _requestURL,
	_caseSensitive: _caseSensitive,
	_chargeItem: _chargeItem,
	_withdrawalPeriod: _withdrawalPeriod,
	CapabilityStatementImplementationComponent: CapabilityStatementImplementationComponent,
	analysis: analysis,
	monitoringProgram: monitoringProgram,
	_date: _date,
	satisfiedBy: satisfiedBy,
	artifact: artifact,
	timing: timing,
	appliesToAll: appliesToAll,
	_appointmentRequired: _appointmentRequired,
	_canFilterBy: _canFilterBy,
	filter: filter,
	_targetNumber: _targetNumber,
	_additive: _additive,
	_management: _management,
	_phylum: _phylum,
	_distributor: _distributor,
	_clinicalRecommendationStatement: _clinicalRecommendationStatement,
	_manifest: _manifest,
	cancellationDate: cancellationDate,
	_doseQuantity: _doseQuantity,
	DeviceDefinitionPackagingComponentUdiDeviceIdentifier: DeviceDefinitionPackagingComponentUdiDeviceIdentifier,
	VerificationResult: VerificationResult,
	preference: preference,
	_asserter: _asserter,
	_regulatoryIdentifier: _regulatoryIdentifier,
	molecularFormula: molecularFormula,
	isActive: isActive,
	dispenserInstruction: dispenserInstruction,
	MedicationKnowledgeRelatedMedicationKnowledgeComponent: MedicationKnowledgeRelatedMedicationKnowledgeComponent,
	CapabilityStatementRestSecurityComponent: CapabilityStatementRestSecurityComponent,
	initialSelected: initialSelected,
	_preventiveAction: _preventiveAction,
	DeviceDefinitionConformsToComponent: DeviceDefinitionConformsToComponent,
	_MedicationStatement: _MedicationStatement,
	_availableStartTime: _availableStartTime,
	validationType: validationType,
	_axis: _axis,
	_serialNumber: _serialNumber,
	Narrative: Narrative,
	_dependency: _dependency,
	endDate: endDate,
	_prognosisReference: _prognosisReference,
	_recruitment: _recruitment,
	searchParam: searchParam,
	_usageInstruction: _usageInstruction,
	_generation: _generation,
	artifactAssessment: artifactAssessment,
	complete: complete,
	_dependent: _dependent,
	_due: _due,
	_replaces: _replaces,
	EvidenceStatisticModelCharacteristicComponent: EvidenceStatisticModelCharacteristicComponent,
	_friday: _friday,
	orderedBy: orderedBy,
	_modality: _modality,
	expirationType: expirationType,
	party: party,
	_objective: _objective,
	_totalNet: _totalNet,
	_adherence: _adherence,
	_cardinalityBehavior: _cardinalityBehavior,
	startDate: startDate,
	basis: basis,
	_minutesDuration: _minutesDuration,
	instruction: instruction,
	_targetDisease: _targetDisease,
	eventTrigger: eventTrigger,
	closure: closure,
	numberOfParticipants: numberOfParticipants,
	businessArrangement: businessArrangement,
	requesterLinkId: requesterLinkId,
	_programEligibility: _programEligibility,
	_average: _average,
	proxySignature: proxySignature,
	_assessmentMethod: _assessmentMethod,
	_series: _series,
	_performingOrganization: _performingOrganization,
	frames: frames,
	_paternalOrganismName: _paternalOrganismName,
	inputProfile: inputProfile,
	_guarantor: _guarantor,
	_human: _human,
	NutritionProductCharacteristicComponent: NutritionProductCharacteristicComponent,
	_orderDetail: _orderDetail,
	maxParticipants: maxParticipants,
	ClinicalUseDefinitionUndesirableEffectComponent: ClinicalUseDefinitionUndesirableEffectComponent,
	_observed: _observed,
	validityPeriod: validityPeriod,
	ComputableLanguage: ComputableLanguage,
	surfaceOrientation: surfaceOrientation,
	_Provenance: _Provenance,
	testRun: testRun,
	SubstanceProtein: SubstanceProtein,
	_focalDevice: _focalDevice,
	_operationType: _operationType,
	context: context,
	occurrenceDateTime: occurrenceDateTime,
	DetectedIssueEvidenceComponent: DetectedIssueEvidenceComponent,
	_ExplanationOfBenefit: _ExplanationOfBenefit,
	validated: validated,
	_subunit: _subunit,
	EvidenceStatisticAttributeEstimateComponent: EvidenceStatisticAttributeEstimateComponent,
	replacedSequence: replacedSequence,
	specimen: specimen,
	rater: rater,
	relatedMedicationKnowledge: relatedMedicationKnowledge,
	lastModified: lastModified,
	RequestOrchestrationActionParticipantComponent: RequestOrchestrationActionParticipantComponent,
	_informationType: _informationType,
	citation: citation,
	paymentStatus: paymentStatus,
	treatment: treatment,
	_initial: _initial,
	priceComponent: priceComponent,
	_Linkage: _Linkage,
	_indicationGuideline: _indicationGuideline,
	SubstanceSourceMaterial: SubstanceSourceMaterial,
	_conditionalRead: _conditionalRead,
	managingEntity: managingEntity,
	EvidenceVariableCharacteristicDefinitionByTypeAndValueComponent: EvidenceVariableCharacteristicDefinitionByTypeAndValueComponent,
	operationalStatus: operationalStatus,
	_module: _module,
	MedicationAdministration: MedicationAdministration,
	UdiDeviceIdentifierMarketDistribution: UdiDeviceIdentifierMarketDistribution,
	_probability: _probability,
	clinicalRecommendationStatement: clinicalRecommendationStatement,
	_image: _image,
	SubscriptionTopicNotificationShapeComponent: SubscriptionTopicNotificationShapeComponent,
	_componentPart: _componentPart,
	op: op,
	_processingFacility: _processingFacility,
	unit: unit,
	_problem: _problem,
	SubstanceDefinitionPropertyComponent: SubstanceDefinitionPropertyComponent,
	_fluidConsistencyType: _fluidConsistencyType,
	_SubstancePolymer: _SubstancePolymer,
	ValueSetComposeIncludeConceptDesignationComponent: ValueSetComposeIncludeConceptDesignationComponent,
	versionReference: versionReference,
	_maxSingleDose: _maxSingleDose,
	meaning: meaning,
	measurementPoint: measurementPoint,
	diagnosisRelatedGroup: diagnosisRelatedGroup,
	_relative: _relative,
	_publicationForm: _publicationForm,
	_Patient: _Patient,
	GuidanceResponse: GuidanceResponse,
	entity: entity,
	sourceReference: sourceReference,
	valueFilter: valueFilter,
	_useBy: _useBy,
	bodyLandmarkOrientation: bodyLandmarkOrientation,
	SubstanceDefinitionNameComponentName: SubstanceDefinitionNameComponentName,
	_policyText: _policyText,
	_changePattern: _changePattern,
	subDetail: subDetail,
	allDay: allDay,
	_modification: _modification,
	_nodeId: _nodeId,
	AdverseEventContributingFactorComponent: AdverseEventContributingFactorComponent,
	TestPlanTestCaseComponent: TestPlanTestCaseComponent,
	sunday: sunday,
	cancellationReason: cancellationReason,
	_title: _title,
	_sourceId: _sourceId,
	_entityRelatedness: _entityRelatedness,
	line: line,
	_effectivePeriod: _effectivePeriod,
	preAuthRef: preAuthRef,
	requestId: requestId,
	_autodelete: _autodelete,
	_fundsReserve: _fundsReserve,
	BundleEntryComponentLink: BundleEntryComponentLink,
	DocumentReferenceContentComponent: DocumentReferenceContentComponent,
	_holder: _holder,
	_qualifiers: _qualifiers,
	_Specimen: _Specimen,
	CodeSystemFilterComponent: CodeSystemFilterComponent,
	_replacementSequence: _replacementSequence,
	serviceCategory: serviceCategory,
	_next: _next,
	paymentTerms: paymentTerms,
	_started: _started,
	offer: offer,
	coordinateSystem: coordinateSystem,
	DeviceDefinition: DeviceDefinition,
	_intent: _intent,
	_text: _text,
	_level: _level,
	facility: facility,
	qualifiedValue: qualifiedValue,
	ManifestResource: ManifestResource,
	prism: prism,
	MedicationBatchComponent: MedicationBatchComponent,
	resultForDelete: resultForDelete,
	_accept: _accept,
	overbooked: overbooked,
	_plan: _plan,
	ReviewOutcome: ReviewOutcome,
	CitationCitedArtifactContributorshipEntryComponent: CitationCitedArtifactContributorshipEntryComponent,
	discriminator: discriminator,
	ordered: ordered,
	LegalLanguage: LegalLanguage,
	frequencyOfOccurrence: frequencyOfOccurrence,
	_validationType: _validationType,
	PermissionRuleDataComponent: PermissionRuleDataComponent,
	_versionNeeded: _versionNeeded,
	PackagedProductDefinitionPackagingContainedItemComponent: PackagedProductDefinitionPackagingContainedItemComponent,
	predecessor: predecessor,
	ArtifactAssessment: ArtifactAssessment,
	_dependsOn: _dependsOn,
	evidence: evidence,
	MeasureGroupPopulationComponent: MeasureGroupPopulationComponent,
	opticalActivity: opticalActivity,
	nutritionProduct: nutritionProduct,
	specialMeasures: specialMeasures,
	packageId: packageId,
	TerminologyCapabilitiesCodeSystemVersionFilterComponent: TerminologyCapabilitiesCodeSystemVersionFilterComponent,
	SubDetail: SubDetail,
	_received: _received,
	CapabilityStatementDocumentComponent: CapabilityStatementDocumentComponent,
	observationResultRequirement: observationResultRequirement,
	FriendlyLanguage: FriendlyLanguage,
	_observedGroup: _observedGroup,
	cancelledReason: cancelledReason,
	_expirationType: _expirationType,
	_actualNumber: _actualNumber,
	derivation: derivation,
	AdverseEventSuspectEntityComponent: AdverseEventSuspectEntityComponent,
	ImmunizationRecommendation: ImmunizationRecommendation,
	_BiologicallyDerivedProductDispense: _BiologicallyDerivedProductDispense,
	_definitionId: _definitionId,
	_authoredOn: _authoredOn,
	keyword: keyword,
	characteristic: characteristic,
	_note: _note,
	ImagingStudySeriesInstanceComponent: ImagingStudySeriesInstanceComponent,
	_signature: _signature,
	slicing: slicing,
	_population: _population,
	cap: cap,
	given: given,
	account: account,
	_organism: _organism,
	_need: _need,
	environmentalSetting: environmentalSetting,
	volume: volume,
	weeklyTemplate: weeklyTemplate,
	lowerLimit: lowerLimit,
	_justification: _justification,
	_fixture: _fixture,
	unitPriceComponent: unitPriceComponent,
	availabilityStatus: availabilityStatus,
	_proxySignature: _proxySignature,
	statusChanged: statusChanged,
	_about: _about,
	occurence: occurence,
	actualPeriod: actualPeriod,
	_originalPrescription: _originalPrescription,
	_dosage: _dosage,
	returnedAmount: returnedAmount,
	_cTerminalModification: _cTerminalModification,
	name: name,
	masterFile: masterFile,
	baseFormulaType: baseFormulaType,
	threshold: threshold,
	active: active,
	IngredientSubstanceComponent: IngredientSubstanceComponent,
	size: size,
	_validityPeriod: _validityPeriod,
	who: who,
	ExampleScenarioProcessStepAlternativeComponent: ExampleScenarioProcessStepAlternativeComponent,
	InsurancePlanPlanSpecificCostComponent: InsurancePlanPlanSpecificCostComponent,
	interaction: interaction,
	_beneficiary: _beneficiary,
	requestURL: requestURL,
	transform: transform,
	sugar: sugar,
	_subscriptionTopic: _subscriptionTopic,
	_usageStatus: _usageStatus,
	_recurring: _recurring,
	chargeItem: chargeItem,
	DiagnosticReportMediaComponent: DiagnosticReportMediaComponent,
	validationProcess: validationProcess,
	_DiagnosticReport: _DiagnosticReport,
	moiety: moiety,
	_marketingStatus: _marketingStatus,
	_citedArtifact: _citedArtifact,
	CitationCitedArtifactPartComponent: CitationCitedArtifactPartComponent,
	TerminologyCapabilitiesImplementationComponent: TerminologyCapabilitiesImplementationComponent,
	_immutable: _immutable,
	_requester: _requester,
	regionsStudied: regionsStudied,
	_code: _code,
	sourceMaterial: sourceMaterial,
	subrogation: subrogation,
	_structureVersion: _structureVersion,
	_priceComponent: _priceComponent,
	management: management,
	_additionalInstruction: _additionalInstruction,
	_managingEntity: _managingEntity,
	patchFormat: patchFormat,
	proxyIdentityCertificate: proxyIdentityCertificate,
	DeviceVersionComponent: DeviceVersionComponent,
	TaskRestrictionComponent: TaskRestrictionComponent,
	_frameOfReferenceUid: _frameOfReferenceUid,
	MedicinalProductDefinition: MedicinalProductDefinition,
	paternalOrganismId: paternalOrganismId,
	averageMolecularFormula: averageMolecularFormula,
	EvidenceStatisticSampleSizeComponent: EvidenceStatisticSampleSizeComponent,
	_occurred: _occurred,
	definitionByCombination: definitionByCombination,
	_compositional: _compositional,
	financial: financial,
	_bodysite: _bodysite,
	sourceScope: sourceScope,
	parameter: parameter,
	lineItem: lineItem,
	_businessArrangement: _businessArrangement,
	_ordinalPosition: _ordinalPosition,
	dependency: dependency,
	DeviceUsage: DeviceUsage,
	sent: sent,
	_associatedMedication: _associatedMedication,
	ParametersParameterComponentParameter: ParametersParameterComponentParameter,
	executionPeriod: executionPeriod,
	_custodian: _custodian,
	specification: specification,
	HumanName: HumanName,
	ObservationDefinitionComponentComponentQualifiedValue: ObservationDefinitionComponentComponentQualifiedValue,
	_searchInclude: _searchInclude,
	_technique: _technique,
	legalStatusOfSupply: legalStatusOfSupply,
	short: short,
	generation: generation,
	doseAndRate: doseAndRate,
	_condition: _condition,
	_followUp: _followUp,
	manufacturer: manufacturer,
	BiologicallyDerivedProductDispense: BiologicallyDerivedProductDispense,
	_seriesUid: _seriesUid,
	relatesTo: relatesTo,
	temperatureQualifier: temperatureQualifier,
	_PackagedProductDefinition: _PackagedProductDefinition,
	_correspondingContact: _correspondingContact,
	citeAs: citeAs,
	_DeviceAssociation: _DeviceAssociation,
	requireBoth: requireBoth,
	provisionData: provisionData,
	_characterization: _characterization,
	criticality: criticality,
	ConditionDefinitionPlanComponent: ConditionDefinitionPlanComponent,
	canPushUpdates: canPushUpdates,
	_nTerminalModificationId: _nTerminalModificationId,
	_regionsCalled: _regionsCalled,
	TestPlanTestCaseTestRunComponent: TestPlanTestCaseTestRunComponent,
	_productOrService: _productOrService,
	reviewOutcome: reviewOutcome,
	maxDispense: maxDispense,
	filterDefinition: filterDefinition,
	sourceAttachment: sourceAttachment,
	provisionActor: provisionActor,
	NamingSystem: NamingSystem,
	dateOfService: dateOfService,
	VisionPrescription: VisionPrescription,
	_unitPrice: _unitPrice,
	resource: resource,
	_response: _response,
	_agent: _agent,
	contraindicatedVaccineCode: contraindicatedVaccineCode,
	collector: collector,
	enterer: enterer,
	_supportedInteraction: _supportedInteraction,
	_differential: _differential,
	_qualifiedValue: _qualifiedValue,
	ManufacturedItemDefinitionComponentConstituentComponent: ManufacturedItemDefinitionComponentConstituentComponent,
	_additionalMonitoringIndicator: _additionalMonitoringIndicator,
	_position: _position,
	limit: limit,
	_reason: _reason,
	_planningHorizon: _planningHorizon,
	_safety: _safety,
	Identifier: Identifier,
	_mitigation: _mitigation,
	_specialCourtesy: _specialCourtesy,
	ExampleScenarioInstanceContainedInstanceComponent: ExampleScenarioInstanceContainedInstanceComponent,
	edit: edit,
	qualitativeRisk: qualitativeRisk,
	immunizationEvent: immunizationEvent,
	reference: reference,
	reporter: reporter,
	BackboneElement: BackboneElement,
	_hasMember: _hasMember,
	Provenance: Provenance,
	reasonLinkId: reasonLinkId,
	owner: owner,
	_assignedComparisonGroup: _assignedComparisonGroup,
	_Condition: _Condition,
	ConsentPolicyBasisComponent: ConsentPolicyBasisComponent,
	communicationMethod: communicationMethod,
	_param: _param,
	_power: _power,
	_issue: _issue,
	concept: concept,
	decisionMode: decisionMode,
	instantiatesUri: instantiatesUri,
	_ifMatch: _ifMatch,
	sequenceType: sequenceType,
	_fastingStatus: _fastingStatus,
	preferredReportName: preferredReportName,
	_numberOfSeries: _numberOfSeries,
	rankingOrder: rankingOrder,
	_currency: _currency,
	testTools: testTools,
	_warning: _warning,
	CoverageEligibilityResponseEventComponent: CoverageEligibilityResponseEventComponent,
	_characteristic: _characteristic,
	dataRequirement: dataRequirement,
	_domain: _domain,
	InventoryReport: InventoryReport,
	_parameterName: _parameterName,
	progressStatus: progressStatus,
	_narrative: _narrative,
	Endpoint: Endpoint,
	subjectState: subjectState,
	entry: entry,
	_weeklyTemplate: _weeklyTemplate,
	what: what,
	whenPrepared: whenPrepared,
	Action: Action,
	_observationRequirement: _observationRequirement,
	focal: focal,
	verification: verification,
	_availability: _availability,
	resultingEffect: resultingEffect,
	timeout: timeout,
	CapabilityStatementMessagingSupportedMessageComponent: CapabilityStatementMessagingSupportedMessageComponent,
	_revenue: _revenue,
	_returnedAmount: _returnedAmount,
	MedicationKnowledgeDefinitionalIngredientComponent: MedicationKnowledgeDefinitionalIngredientComponent,
	candidate: candidate,
	Subscription: Subscription,
	relatedAction: relatedAction,
	textPresentation: textPresentation,
	_supplements: _supplements,
	result: result,
	policyText: policyText,
	_regionType: _regionType,
	StratifierGroup: StratifierGroup,
	_contract: _contract,
	_timeFromEvent: _timeFromEvent,
	notificationEvent: notificationEvent,
	_inclusionCriteria: _inclusionCriteria,
	_orderMeaning: _orderMeaning,
	autodelete: autodelete,
	qualifiers: qualifiers,
	_regionsStudied: _regionsStudied,
	_application: _application,
	frequency: frequency,
	_sourceMaterial: _sourceMaterial,
	regulatoryBasis: regulatoryBasis,
	associationType: associationType,
	_software: _software,
	_copolymerConnectivity: _copolymerConnectivity,
	_approvalDate: _approvalDate,
	totalVolume: totalVolume,
	AppointmentRecurrenceTemplateWeeklyTemplateComponent: AppointmentRecurrenceTemplateWeeklyTemplateComponent,
	_requestedPerformer: _requestedPerformer,
	packagedProduct: packagedProduct,
	tissue: tissue,
	isSubpotent: isSubpotent,
	_supportingInfoSequence: _supportingInfoSequence,
	_rating: _rating,
	maternalOrganismName: maternalOrganismName,
	CommunicationRequest: CommunicationRequest,
	polymer: polymer,
	initiatorActive: initiatorActive,
	_productStatus: _productStatus,
	strand: strand,
	_outputParameters: _outputParameters,
	participantStatus: participantStatus,
	label: label,
	manipulated: manipulated,
	_geometry: _geometry,
	Coding: Coding,
	requisition: requisition,
	InventoryReportInventoryListingComponent: InventoryReportInventoryListingComponent,
	_parent: _parent,
	_net: _net,
	presentation: presentation,
	flag: flag,
	hoursOfOperation: hoursOfOperation,
	encounter: encounter,
	applicability: applicability,
	releaseDate: releaseDate,
	_relationshipType: _relationshipType,
	_managingOrganization: _managingOrganization,
	derivedFromCanonical: derivedFromCanonical,
	_hasSeverity: _hasSeverity,
	cTerminalModification: cTerminalModification,
	ContentDefinition: ContentDefinition,
	_bodyLandmarkOrientation: _bodyLandmarkOrientation,
	relationship: relationship,
	goal: goal,
	_connectivity: _connectivity,
	_listMode: _listMode,
	_availableTime: _availableTime,
	property: property,
	_calibration: _calibration,
	TerminologyCapabilitiesExpansionParameterComponent: TerminologyCapabilitiesExpansionParameterComponent,
	adjustmentReason: adjustmentReason,
	AdministrableProductDefinitionRouteOfAdministrationTargetSpeciesComponent: AdministrableProductDefinitionRouteOfAdministrationTargetSpeciesComponent,
	Basic: Basic,
	_isDerived: _isDerived,
	hierarchical: hierarchical,
	_resultForCreate: _resultForCreate,
	_deviceName: _deviceName,
	_startDate: _startDate,
	Attachment: Attachment,
	_patientPreparation: _patientPreparation,
	CitationCitedArtifactPublicationFormComponent: CitationCitedArtifactPublicationFormComponent,
	windowStart: windowStart,
	_propertyGroup: _propertyGroup,
	languageCode: languageCode,
	_canPushUpdates: _canPushUpdates,
	groupingBehavior: groupingBehavior,
	for__workaround: for__workaround,
	_studyUid: _studyUid,
	_event: _event,
	informationProvider: informationProvider,
	network: network,
	_manufacturedDoseForm: _manufacturedDoseForm,
	assert: assert,
	_warningOnly: _warningOnly,
	isSummary: isSummary,
	attachedDocument: attachedDocument,
	_unit: _unit,
	_endDate: _endDate,
	authoredOn: authoredOn,
	_geographicalLocation: _geographicalLocation,
	CitationCitedArtifactClassificationComponent: CitationCitedArtifactClassificationComponent,
	userSelected: userSelected,
	_prognosisCodeableConcept: _prognosisCodeableConcept,
	dateCriterion: dateCriterion,
	additionalInstruction: additionalInstruction,
	specialPrecautionsForStorage: specialPrecautionsForStorage,
	population: population,
	_member: _member,
	securityLabel: securityLabel,
	_renderedDosageInstruction: _renderedDosageInstruction,
	Notes: Notes,
	_dynamicValue: _dynamicValue,
	_confidentialityIndicator: _confidentialityIndicator,
	_intendedUse: _intendedUse,
	lastUpdated: lastUpdated,
	deceased: deceased,
	NutritionOrderEnteralFormulaAdditiveComponent: NutritionOrderEnteralFormulaAdditiveComponent,
	designation: designation,
	reportedDateTime: reportedDateTime,
	productOrServiceEnd: productOrServiceEnd,
	teardown: teardown,
	securityLabelNumber: securityLabelNumber,
	_manufactureDate: _manufactureDate,
	_textFilter: _textFilter,
	_route: _route,
	parentSubstanceName: parentSubstanceName,
	_docStatus: _docStatus,
	ArtifactAssessmentContentComponentContentContent: ArtifactAssessmentContentComponentContentContent,
	_subscriber: _subscriber,
	workflowStatus: workflowStatus,
	phylum: phylum,
	_mustSupport: _mustSupport,
	forecastStatus: forecastStatus,
	_closure: _closure,
	_abstract: _abstract,
	relatedClinicalInformation: relatedClinicalInformation,
	PersonCommunicationComponent: PersonCommunicationComponent,
	_relativePath: _relativePath,
	CitationCitedArtifactVersionComponent: CitationCitedArtifactVersionComponent,
	_paging: _paging,
	_uniqueId: _uniqueId,
	_readOnly: _readOnly,
	_jurisdiction: _jurisdiction,
	_treatment: _treatment,
	_responsibleParty: _responsibleParty,
	RequestOrchestrationActionComponentActionAction: RequestOrchestrationActionComponentActionAction,
	_role: _role,
	TestPlanDependencyComponent: TestPlanDependencyComponent,
	Binary: Binary,
	contentDerivative: contentDerivative,
	inforce: inforce,
	RiskAssessmentPredictionComponent: RiskAssessmentPredictionComponent,
	_enteredDate: _enteredDate,
	_legalStatusOfSupply: _legalStatusOfSupply,
	valueAlternatives: valueAlternatives,
	subject: subject,
	_publicationDate: _publicationDate,
	occurrenceChanged: occurrenceChanged,
	_referralRequest: _referralRequest,
	friday: friday,
	productType: productType,
	_payeeType: _payeeType,
	_fixed: _fixed,
	_nTerminalModification: _nTerminalModification,
	_progressStatus: _progressStatus,
	_age: _age,
	_verificationDate: _verificationDate,
	CompartmentDefinitionResourceComponent: CompartmentDefinitionResourceComponent,
	_questionnaire: _questionnaire,
	TestScript: TestScript,
	billingStatus: billingStatus,
	_resourceTrigger: _resourceTrigger,
	compose: compose,
	_submitter: _submitter,
	_productReference: _productReference,
	payment: payment,
	rateAggregation: rateAggregation,
	OrganizationQualificationComponent: OrganizationQualificationComponent,
	identityCertificate: identityCertificate,
	_subDetail: _subDetail,
	contextInvariant: contextInvariant,
	_suffix: _suffix,
	_recurrenceId: _recurrenceId,
	dispenseInterval: dispenseInterval,
	_map: _map,
	_lensSpecification: _lensSpecification,
	allergyIntolerance: allergyIntolerance,
	asset: asset,
	CoverageEligibilityResponse: CoverageEligibilityResponse,
	OperationDefinitionParameterComponentParameter: OperationDefinitionParameterComponentParameter,
	packagedMedicinalProduct: packagedMedicinalProduct,
	_count: _count,
	SubstancePolymerRepeatRepeatUnitDegreeOfPolymerisationComponent: SubstancePolymerRepeatRepeatUnitDegreeOfPolymerisationComponent,
	adjudication: adjudication,
	RequestOrchestrationActionConditionComponent: RequestOrchestrationActionConditionComponent,
	validator: validator,
	_gene: _gene,
	_length: _length,
	series: series,
	maxDosePerAdministration: maxDosePerAdministration,
	_performerRole: _performerRole,
	_balance: _balance,
	_correctiveAction: _correctiveAction,
	dispenser: dispenser,
	NutritionOrderOralDietComponent: NutritionOrderOralDietComponent,
	_meaning: _meaning,
	endParam: endParam,
	_provider: _provider,
	inResponseTo: inResponseTo,
	authorDescription: authorDescription,
	_intendedExposure: _intendedExposure,
	_cycle: _cycle,
	ProvenanceEntityComponentAgent: ProvenanceEntityComponentAgent,
	high: high,
	_paymentStatus: _paymentStatus,
	TestScriptVariableComponent: TestScriptVariableComponent,
	_comparator: _comparator,
	_instantiatesCanonical: _instantiatesCanonical,
	class__workaround: class__workaround,
	_countryOfOrigin: _countryOfOrigin,
	structuralRepresentation: structuralRepresentation,
	_communicationMethod: _communicationMethod,
	_size: _size,
	_averageMolecularFormula: _averageMolecularFormula,
	_ingredientLabel: _ingredientLabel,
	_landmarkDescription: _landmarkDescription,
	_criticalCodedValueSet: _criticalCodedValueSet,
	unmapped: unmapped,
	_productCategory: _productCategory,
	SubstanceReferenceInformationTargetComponent: SubstanceReferenceInformationTargetComponent,
	_preferredReportName: _preferredReportName,
	_maternalOrganismId: _maternalOrganismId,
	_order: _order,
	qualifier: qualifier,
	recruitment: recruitment,
	mitigation: mitigation,
	Procedure: Procedure,
	material: material,
	_packageId: _packageId,
	address: address,
	module: module,
	SubstanceNucleicAcidSubunitComponent: SubstanceNucleicAcidSubunitComponent,
	_healthcareService: _healthcareService,
	check: check,
	_serviceProvisionCode: _serviceProvisionCode,
	DeviceDefinitionHasPartComponent: DeviceDefinitionHasPartComponent,
	hybrid: hybrid,
	DeviceDefinitionPackagingComponentPackaging: DeviceDefinitionPackagingComponentPackaging,
	extends__workaround: extends__workaround,
	AdverseEventSupportingInfoComponent: AdverseEventSupportingInfoComponent,
	_MedicationRequest: _MedicationRequest,
	startingSequence: startingSequence,
	MedicationKnowledgeMonographComponent: MedicationKnowledgeMonographComponent,
	DetectedIssue: DetectedIssue,
	targetLocation: targetLocation,
	MedicinalProductDefinitionCrossReferenceComponent: MedicinalProductDefinitionCrossReferenceComponent,
	_alternateMaterial: _alternateMaterial,
	_ordered: _ordered,
	_List: _List,
	_gateway: _gateway,
	_effect: _effect,
	_coordinate: _coordinate,
	case__workaround: case__workaround,
	QuestionnaireItemComponentItem: QuestionnaireItemComponentItem,
	DeviceConformsToComponent: DeviceConformsToComponent,
	PatientLinkComponent: PatientLinkComponent,
	testData: testData,
	ProcedureFocalDeviceComponent: ProcedureFocalDeviceComponent,
	_typeCanonical: _typeCanonical,
	nodeId: nodeId,
	CapabilityStatementSoftwareComponent: CapabilityStatementSoftwareComponent,
	_preparation: _preparation,
	_subType: _subType,
	_definitionCodeableConcept: _definitionCodeableConcept,
	benefitBalance: benefitBalance,
	exclusionCriteria: exclusionCriteria,
	numberOfStudies: numberOfStudies,
	start: start,
	AccountRelatedAccountComponent: AccountRelatedAccountComponent,
	_OperationOutcome: _OperationOutcome,
	orientation: orientation,
	holder: holder,
	_mitigatingAction: _mitigatingAction,
	include: include,
	_conditionalPatch: _conditionalPatch,
	NamingSystemUniqueIdComponent: NamingSystemUniqueIdComponent,
	_threshold: _threshold,
	Count: Count,
	_instantiates: _instantiates,
	media: media,
	appliesTo: appliesTo,
	_implementationGuide: _implementationGuide,
	RequestOrchestrationActionInputComponent: RequestOrchestrationActionInputComponent,
	_discriminator: _discriminator,
	ClaimResponse: ClaimResponse,
	section: section,
	_workflowStatus: _workflowStatus,
	_DeviceMetric: _DeviceMetric,
	diseaseSymptomProcedure: diseaseSymptomProcedure,
	_keyword: _keyword,
	_forecastStatus: _forecastStatus,
	Bundle: Bundle,
	_excluded: _excluded,
	_transform: _transform,
	intent: intent,
	_slicing: _slicing,
	generalPractitioner: generalPractitioner,
	gestationalAge: gestationalAge,
	_account: _account,
	_administeredProduct: _administeredProduct,
	answerOption: answerOption,
	regionType: regionType,
	_association: _association,
	_messaging: _messaging,
	organismType: organismType,
	accept: accept,
	_methodType: _methodType,
	_authorizationRequired: _authorizationRequired,
	includedStructure: includedStructure,
	sourceIdentityCertificate: sourceIdentityCertificate,
	foodType: foodType,
	temperatureRange: temperatureRange,
	ManifestPage: ManifestPage,
	DeviceRequest: DeviceRequest,
	_contextLinkId: _contextLinkId,
	ExampleScenarioProcessStepOperationComponent: ExampleScenarioProcessStepOperationComponent,
	SubstanceDefinitionStructureComponent: SubstanceDefinitionStructureComponent,
	calculatedAt: calculatedAt,
	MarketingStatus: MarketingStatus,
	_emptyReason: _emptyReason,
	_offsets: _offsets,
	_financial: _financial,
	_exposureRoute: _exposureRoute,
	_policyHolder: _policyHolder,
	SupplyDeliverySuppliedItemComponent: SupplyDeliverySuppliedItemComponent,
	intendedRoute: intendedRoute,
	_paymentDate: _paymentDate,
	GenomicStudyAnalysisDeviceComponent: GenomicStudyAnalysisDeviceComponent,
	_informationProvider: _informationProvider,
	_outsideFoodAllowed: _outsideFoodAllowed,
	feature: feature,
	needsMap: needsMap,
	_dataAbsentReason: _dataAbsentReason,
	_definition: _definition,
	creation: creation,
	_minValue: _minValue,
	width: width,
	_Permission: _Permission,
	AllergyIntolerance: AllergyIntolerance,
	_Encounter: _Encounter,
	targetNumber: targetNumber,
	severity: severity,
	ObservationDefinitionQualifiedValueComponent: ObservationDefinitionQualifiedValueComponent,
	filterBy: filterBy,
	packaging: packaging,
	endorser: endorser,
	_relatesTo: _relatesTo,
	_sourceSignature: _sourceSignature,
	abnormalCodedValueSet: abnormalCodedValueSet,
	lastOccurrenceDate: lastOccurrenceDate,
	_securityLabelNumber: _securityLabelNumber,
	_queryCriteria: _queryCriteria,
	_multipleResultsAllowed: _multipleResultsAllowed,
	_allowed: _allowed,
	_TestReport: _TestReport,
	_Location: _Location,
	deviceName: deviceName,
	ImmunizationReactionComponent: ImmunizationReactionComponent,
	ConceptMap: ConceptMap,
	_daysOfWeek: _daysOfWeek,
	ParameterDefinition: ParameterDefinition,
	_packageCode: _packageCode,
	Insurance: Insurance,
	lastPerformed: lastPerformed,
	IngredientManufacturerComponent: IngredientManufacturerComponent,
	nthWeekOfMonth: nthWeekOfMonth,
	targetSpecies: targetSpecies,
	authorization: authorization,
	_RequestOrchestration: _RequestOrchestration,
	_endpoint: _endpoint,
	triggeredBy: triggeredBy,
	_Dosage: _Dosage,
	_doNotPerform: _doNotPerform,
	careTeam: careTeam,
	_meta: _meta,
	TerminologyCapabilitiesCodeSystemVersionComponent: TerminologyCapabilitiesCodeSystemVersionComponent,
	entryQuantity: entryQuantity,
	CapabilityStatementMessagingEndpointComponent: CapabilityStatementMessagingEndpointComponent,
	nTerminalModification: nTerminalModification,
	_asNeededFor: _asNeededFor,
	_link: _link,
	attribute: attribute,
	Note: Note,
	textFilter: textFilter,
	disposition: disposition,
	PackagedProductDefinition: PackagedProductDefinition,
	Accident: Accident,
	_reference: _reference,
	StructureMapGroupRuleTargetParameterComponent: StructureMapGroupRuleTargetParameterComponent,
	subscriber: subscriber,
	structureType: structureType,
	_detail: _detail,
	meaningWhenMissing: meaningWhenMissing,
	modelCharacteristic: modelCharacteristic,
	mapping: mapping,
	_Person: _Person,
	_eligibility: _eligibility,
	SubstanceSourceMaterialFractionDescriptionComponent: SubstanceSourceMaterialFractionDescriptionComponent,
	typeCollected: typeCollected,
	timestamp: timestamp,
	_subpotentReason: _subpotentReason,
	_relatedMedicationKnowledge: _relatedMedicationKnowledge,
	_inventoryStatus: _inventoryStatus,
	synonym: synonym,
	_category: _category,
	_regulatory: _regulatory,
	birthDate: birthDate,
	_priorPrescription: _priorPrescription,
	Base: Base,
	_testTools: _testTools,
	_targetLocation: _targetLocation,
	substanceDefinition: substanceDefinition,
	_medication: _medication,
	_vaccineCode: _vaccineCode,
	_dateAsserted: _dateAsserted,
	DeviceDefinitionMaterialComponent: DeviceDefinitionMaterialComponent,
	_codeSearch: _codeSearch,
	range: range,
	NutritionOrder: NutritionOrder,
	_dispenserInstruction: _dispenserInstruction,
	_summary: _summary,
	_synthesisType: _synthesisType,
	productName: productName,
	_reviewOutcome: _reviewOutcome,
	claimResponse: claimResponse,
	path: path,
	additive: additive,
	ElementDefinition: ElementDefinition,
	fundingSource: fundingSource,
	instantiatesCanonical: instantiatesCanonical,
	family: family,
	NutritionIntake: NutritionIntake,
	EvidenceReport: EvidenceReport,
	billablePeriod: billablePeriod,
	_otherTherapy: _otherTherapy,
	_dateOfService: _dateOfService,
	_benefitBalance: _benefitBalance,
	_information: _information,
	_CareTeam: _CareTeam,
	_aggregateMethod: _aggregateMethod,
	generatedBy: generatedBy,
	_tag: _tag,
	asserter: asserter,
	_revInclude: _revInclude,
	onset: onset,
	criticalCodedValueSet: criticalCodedValueSet,
	_mode: _mode,
	anchor: anchor,
	_substitution: _substitution,
	_consent: _consent,
	_candidate: _candidate,
	_concept: _concept,
	MeasureReportGroupStratifierStratumComponentComponent: MeasureReportGroupStratifierStratumComponentComponent,
	ifNoneExist: ifNoneExist,
	GraphDefinitionNodeComponent: GraphDefinitionNodeComponent,
	_answer: _answer,
	_schedule: _schedule,
	administrationTreatment: administrationTreatment,
	_baseFormulaProductName: _baseFormulaProductName,
	PermissionRuleDataResourceComponent: PermissionRuleDataResourceComponent,
	_gestationalAge: _gestationalAge,
	carrierAIDC: carrierAIDC,
	_capability: _capability,
	usageStatus: usageStatus,
	_knownAllergen: _knownAllergen,
	storageTempRequirements: storageTempRequirements,
	definitionReference: definitionReference,
	experimental: experimental,
	_numberOfParticipants: _numberOfParticipants,
	_repeat: _repeat,
	displayName: displayName,
	replaces: replaces,
	_distanceFromLandmark: _distanceFromLandmark,
	_frequency: _frequency,
	shortDoco: shortDoco,
	ImagingSelection: ImagingSelection,
	modality: modality,
	_targetId: _targetId,
	_amount: _amount,
	species: species,
	totalNet: totalNet,
	observationRequirement: observationRequirement,
	InsurancePlanPlanGeneralCostComponent: InsurancePlanPlanGeneralCostComponent,
	InvoiceLineItemComponent: InvoiceLineItemComponent,
	requestor: requestor,
	dietPreference: dietPreference,
	comparator: comparator,
	_combinedPharmaceuticalDoseForm: _combinedPharmaceuticalDoseForm,
	servicePeriod: servicePeriod,
	_rater: _rater,
	receiverActive: receiverActive,
	modification: modification,
	practitioner: practitioner,
	_normalCodedValueSet: _normalCodedValueSet,
	TestCaseDependency: TestCaseDependency,
	_costToBeneficiary: _costToBeneficiary,
	MessageHeader: MessageHeader,
	ResearchStudyRecruitmentComponent: ResearchStudyRecruitmentComponent,
	_forenameInitials: _forenameInitials,
	plannedStartDate: plannedStartDate,
	study: study,
	groupIdentifier: groupIdentifier,
	_participatingOrganization: _participatingOrganization,
	MeasureGroupStratifierComponent: MeasureGroupStratifierComponent,
	wednesday: wednesday,
	_diameter: _diameter,
	enteralFormula: enteralFormula,
	_stabilityDuration: _stabilityDuration,
	integer: integer,
	domain: domain,
	_periodType: _periodType,
	_ImagingStudy: _ImagingStudy,
	searchRevInclude: searchRevInclude,
	_relatedAction: _relatedAction,
	observed: observed,
	born: born,
	_ImmunizationRecommendation: _ImmunizationRecommendation,
	service: service,
	_requestIdentifier: _requestIdentifier,
	maxDosePerLifetime: maxDosePerLifetime,
	format: format,
	_isSummary: _isSummary,
	supportingInfoSequence: supportingInfoSequence,
	EvidenceStatisticModelCharacteristicVariableComponent: EvidenceStatisticModelCharacteristicVariableComponent,
	ManufacturedItemDefinitionPropertyComponent: ManufacturedItemDefinitionPropertyComponent,
	_concentration: _concentration,
	coordinate: coordinate,
	AddedItemDetailSubDetail: AddedItemDetailSubDetail,
	TerminologyCapabilitiesTranslationComponent: TerminologyCapabilitiesTranslationComponent,
	_generalPractitioner: _generalPractitioner,
	_protocol: _protocol,
	_exception: _exception,
	_complication: _complication,
	value: value,
	_nthWeekOfMonth: _nthWeekOfMonth,
	_url: _url,
	SubstanceSourceMaterialOrganismHybridComponent: SubstanceSourceMaterialOrganismHybridComponent,
	SubscriptionTopicEventTriggerComponent: SubscriptionTopicEventTriggerComponent,
	MedicinalProductDefinitionNameComponent: MedicinalProductDefinitionNameComponent,
	SubstanceSourceMaterialOrganismComponent: SubstanceSourceMaterialOrganismComponent,
	overrideReason: overrideReason,
	pages: pages,
	_conclusion: _conclusion,
	_combined: _combined,
	_contains: _contains,
	_documentType: _documentType,
	MeasureGroupStratifierComponentComponent: MeasureGroupStratifierComponentComponent,
	_numberOfInstances: _numberOfInstances,
	PlanDefinitionActionComponent: PlanDefinitionActionComponent,
	_processor: _processor,
	actualNumber: actualNumber,
	_network: _network,
	effective: effective,
	textEquivalent: textEquivalent,
	preferred: preferred,
	ImplementationGuide: ImplementationGuide,
	EvidenceReportRelatesToTargetComponent: EvidenceReportRelatesToTargetComponent,
	_applicability: _applicability,
	min: min,
	DeviceNameComponent: DeviceNameComponent,
	Payment: Payment,
	organismName: organismName,
	relative: relative,
	Ratio: Ratio,
	item: item,
	rating: rating,
	_numerator: _numerator,
	TestScriptScopeComponent: TestScriptScopeComponent,
	_aggregation: _aggregation,
	minutesDuration: minutesDuration,
	AuditEventEntityComponent: AuditEventEntityComponent,
	rate: rate,
	CompartmentDefinition: CompartmentDefinition,
	renderedDosageInstruction: renderedDosageInstruction,
	methodType: methodType,
	parent: parent,
	sourceId: sourceId,
	_requestedPeriod: _requestedPeriod,
	_chromosome: _chromosome,
	isSubPotent: isSubPotent,
	presentedForm: presentedForm,
	repetitions: repetitions,
	aggregate: aggregate,
	EvidenceStatisticComponent: EvidenceStatisticComponent,
	ImplementationGuideDefinitionParameterComponent: ImplementationGuideDefinitionParameterComponent,
	CompositionEventComponent: CompositionEventComponent,
	_NutritionOrder: _NutritionOrder,
	TaskInputComponent: TaskInputComponent,
	rule: rule,
	Specimen: Specimen,
	_MedicinalProductDefinition: _MedicinalProductDefinition,
	OperationDefinition: OperationDefinition,
	process: process,
	CitationCitedArtifactContributorshipEntryContributionInstanceComponent: CitationCitedArtifactContributorshipEntryContributionInstanceComponent,
	EncounterAdmissionComponent: EncounterAdmissionComponent,
	_MedicationDispense: _MedicationDispense,
	translation: translation,
	ObservationTriggeredByComponent: ObservationTriggeredByComponent,
	_etag: _etag,
	_dateCriterion: _dateCriterion,
	_administrationInstruction: _administrationInstruction,
	part: part,
	_billablePeriod: _billablePeriod,
	requestHeader: requestHeader,
	_shortTitle: _shortTitle,
	_securityLabel: _securityLabel,
	_procedure: _procedure,
	periodMax: periodMax,
	monograph: monograph,
	_eventsSinceSubscriptionStart: _eventsSinceSubscriptionStart,
	QuestionnaireResponseItemAnswerComponent: QuestionnaireResponseItemAnswerComponent,
	formatted: formatted,
	restoreDate: restoreDate,
	_grouping: _grouping,
	definition: definition,
	BodyStructureIncludedStructureBodyLandmarkOrientationDistanceFromLandmarkComponent: BodyStructureIncludedStructureBodyLandmarkOrientationDistanceFromLandmarkComponent,
	dayOfWeek: dayOfWeek,
	_variableDefinition: _variableDefinition,
	nodeRole: nodeRole,
	Permission: Permission,
	dateWritten: dateWritten,
	ratioHighLimitAmount: ratioHighLimitAmount,
	_relatedData: _relatedData,
	_inforce: _inforce,
	_reportingVendor: _reportingVendor,
	_sequenceRange: _sequenceRange,
	member: member,
	_versionAlgorithm: _versionAlgorithm,
	_subject: _subject,
	_case: _case,
	_ClinicalUseDefinition: _ClinicalUseDefinition,
	_cylinder: _cylinder,
	_saturday: _saturday,
	ConceptMapGroupUnmappedComponent: ConceptMapGroupUnmappedComponent,
	Address: Address,
	_validateCode: _validateCode,
	_dispenser: _dispenser,
	_issued: _issued,
	TestReport: TestReport,
	conditionalRead: conditionalRead,
	fullUrl: fullUrl,
	parameterFocus: parameterFocus,
	_currentState: _currentState,
	ActivityDefinition: ActivityDefinition,
	daysOfWeek: daysOfWeek,
	containedInstance: containedInstance,
	StructureMapGroupRuleSourceComponent: StructureMapGroupRuleSourceComponent,
	application: application,
	received: received,
	AuditEventEntityComponentAgent: AuditEventEntityComponentAgent,
	element: element,
	_compose: _compose,
	_environmentalSetting: _environmentalSetting,
	_payment: _payment,
	_preparedDate: _preparedDate,
	ImagingSelectionInstanceComponent: ImagingSelectionInstanceComponent,
	_responseRequired: _responseRequired,
	_contraindication: _contraindication,
	_operator: _operator,
	ActivityDefinitionParticipantComponent: ActivityDefinitionParticipantComponent,
	_contraindicatedVaccineCode: _contraindicatedVaccineCode,
	_membership: _membership,
	_recordedDate: _recordedDate,
	_provision: _provision,
	_dietPreference: _dietPreference,
	_laterality: _laterality,
	_parentSubstanceId: _parentSubstanceId,
	_report: _report,
	MedicationDispensePerformerComponent: MedicationDispensePerformerComponent,
	FamilyMemberHistoryConditionComponent: FamilyMemberHistoryConditionComponent,
	_editor: _editor,
	instant: instant,
	paging: paging,
	_receiverActive: _receiverActive,
	publicationForm: publicationForm,
	operation: operation,
	organism: organism,
	focus: focus,
	_reviewer: _reviewer,
	validCodedValueSet: validCodedValueSet,
	Signatory: Signatory,
	clockFacePosition: clockFacePosition,
	_instanceReference: _instanceReference,
	withdrawalPeriod: withdrawalPeriod,
	conformance: conformance,
	effectivePeriod: effectivePeriod,
	_matchStatus: _matchStatus,
	virtualService: virtualService,
	Communication: Communication,
	_enteralFormula: _enteralFormula,
	whenHandedOver: whenHandedOver,
	EvidenceReportSubjectComponent: EvidenceReportSubjectComponent,
	substance: substance,
	Section: Section,
	_valueRange: _valueRange,
	regulatoryIdentifier: regulatoryIdentifier,
	kind: kind,
	hasIngredient: hasIngredient,
	detailSequence: detailSequence,
	NutritionProductNutrientComponent: NutritionProductNutrientComponent,
	_fractionDescription: _fractionDescription,
	_degreeOfPolymerisation: _degreeOfPolymerisation,
	_Account: _Account,
	rangeCategory: rangeCategory,
	_index: _index,
	ValueSetComposeComponentInclude: ValueSetComposeComponentInclude,
	regulatory: regulatory,
	_modifier: _modifier,
	_short: _short,
	medication: medication,
	codeSearch: codeSearch,
	suffix: suffix,
	MedicationDispenseSubstitutionComponent: MedicationDispenseSubstitutionComponent,
	foodPreferenceModifier: foodPreferenceModifier,
	Immunization: Immunization,
	AppointmentRecurrenceTemplateMonthlyTemplateComponent: AppointmentRecurrenceTemplateMonthlyTemplateComponent,
	preventiveAction: preventiveAction,
	_AdministrableProductDefinition: _AdministrableProductDefinition,
	_deliverFrom: _deliverFrom,
	_address: _address,
	intendedUse: intendedUse,
	ElementDefinitionSlicingDiscriminatorComponent: ElementDefinitionSlicingDiscriminatorComponent,
	SubscriptionTopic: SubscriptionTopic,
	GenomicStudy: GenomicStudy,
	_partLocation: _partLocation,
	_subsumption: _subsumption,
	BenefitBalance: BenefitBalance,
	script: script,
	_resourceReference: _resourceReference,
	lastReviewDate: lastReviewDate,
	SubstanceDefinitionNameComponentNameName: SubstanceDefinitionNameComponentNameName,
	length: length,
	_overrideReason: _overrideReason,
	_period: _period,
	TerminologyCapabilities: TerminologyCapabilities,
	_supportingPatientInformation: _supportingPatientInformation,
	OperationDefinitionParameterBindingComponent: OperationDefinitionParameterBindingComponent,
	Task: Task,
	MeasureReportGroupPopulationComponent: MeasureReportGroupPopulationComponent,
	revInclude: revInclude,
	_appliesTo: _appliesTo,
	MedicationKnowledgeDefinitionalComponent: MedicationKnowledgeDefinitionalComponent,
	usageInstruction: usageInstruction,
	trigger: trigger,
	mustSupport: mustSupport,
	TimingRepeatComponent: TimingRepeatComponent,
	effectiveDosePeriod: effectiveDosePeriod,
	_textEquivalent: _textEquivalent,
	bodysite: bodysite,
	_appliesToAll: _appliesToAll,
	comorbidity: comorbidity,
	TestScriptFixtureComponent: TestScriptFixtureComponent,
	oligoNucleotideType: oligoNucleotideType,
	intendedEffect: intendedEffect,
	_conformsTo: _conformsTo,
	copyright: copyright,
	_insurance: _insurance,
	_partDescription: _partDescription,
	_genomeBuild: _genomeBuild,
	Slot: Slot,
	_medium: _medium,
	followUp: followUp,
	maxDuration: maxDuration,
	lotNumber: lotNumber,
	EncounterHistoryLocationComponent: EncounterHistoryLocationComponent,
	_owner: _owner,
	InventoryItem: InventoryItem,
	content: content,
	DeviceDefinitionPropertyComponent: DeviceDefinitionPropertyComponent,
	enteredDate: enteredDate,
	_district: _district,
	QuestionnaireItemComponentItemItem: QuestionnaireItemComponentItemItem,
	eye: eye,
	facilityType: facilityType,
	markdown: markdown,
	_friendly: _friendly,
	ManufacturedItemDefinitionComponentComponentComponent: ManufacturedItemDefinitionComponentComponentComponent,
	basedOn: basedOn,
	assessmentMethod: assessmentMethod,
	_sourceMaterialClass: _sourceMaterialClass,
	CarePlanActivityComponent: CarePlanActivityComponent,
	response: response,
	_singleUse: _singleUse,
	ProvenanceAgentComponent: ProvenanceAgentComponent,
	_kingdom: _kingdom,
	error: error,
	effect: effect,
	verifiedWith: verifiedWith,
	_packaging: _packaging,
	position: position,
	EvidenceCertaintyComponentCertainty: EvidenceCertaintyComponentCertainty,
	low: low,
	_Device: _Device,
	AddedItemSubDetail: AddedItemSubDetail,
	_responsible: _responsible,
	excludingDate: excludingDate,
	_verified: _verified,
	TestScriptMetadataCapabilityComponent: TestScriptMetadataCapabilityComponent,
	marketingStatus: marketingStatus,
	_ClaimResponse: _ClaimResponse,
	request: request,
	MolecularSequenceRelativeEditComponent: MolecularSequenceRelativeEditComponent,
	periodType: periodType,
	approvalDate: approvalDate,
	_monomerSet: _monomerSet,
	_eventTrigger: _eventTrigger,
	_ingredient: _ingredient,
	_biologicalSourceEvent: _biologicalSourceEvent,
	durationMax: durationMax,
	_MolecularSequence: _MolecularSequence,
	_permittedDataType: _permittedDataType,
	subtitle: subtitle,
	_SubscriptionStatus: _SubscriptionStatus,
	maxTreatmentPeriod: maxTreatmentPeriod,
	_relatedIdentifier: _relatedIdentifier,
	_feature: _feature,
	ValueSetExpansionComponent: ValueSetExpansionComponent,
	_parameterFocus: _parameterFocus,
	_maxDosePerDay: _maxDosePerDay,
	CapabilityStatementMessagingComponent: CapabilityStatementMessagingComponent,
	ResearchStudyObjectiveComponent: ResearchStudyObjectiveComponent,
	MedicationIngredientComponent: MedicationIngredientComponent,
	SourceElement: SourceElement,
	_sequence: _sequence,
	_validateProfileId: _validateProfileId,
	responsibility: responsibility,
	containedItem: containedItem,
	completionTime: completionTime,
	_identifier: _identifier,
	_scope: _scope,
	currency: currency,
	_inputProfile: _inputProfile,
	TestAction: TestAction,
	_performer: _performer,
	QuestionnaireResponseItemComponentItemItem: QuestionnaireResponseItemComponentItemItem,
	_pushTypeAvailable: _pushTypeAvailable,
	communication: communication,
	interpretation: interpretation,
	_capacity: _capacity,
	topic: topic,
	_undesirableEffect: _undesirableEffect,
	_noteNumber: _noteNumber,
	_DeviceRequest: _DeviceRequest,
	courseOfTherapyType: courseOfTherapyType,
	ordinalPosition: ordinalPosition,
	ObservationComponentComponentReferenceRange: ObservationComponentComponentReferenceRange,
	_actorId: _actorId,
	conclusion: conclusion,
	Resource: Resource,
	accountNumber: accountNumber,
	deliverTo: deliverTo,
	multipleResultsAllowed: multipleResultsAllowed,
	_asNeeded: _asNeeded,
	_onHold: _onHold,
	genomeAssembly: genomeAssembly,
	_preAuthRefPeriod: _preAuthRefPeriod,
	itemSequence: itemSequence,
	_relatedClinicalInformation: _relatedClinicalInformation,
	ResearchStudy: ResearchStudy,
	_action: _action,
	_DocumentReference: _DocumentReference,
	_coverageArea: _coverageArea,
	DataType: DataType,
	Duration: Duration,
	_Consent: _Consent,
	_referencePolicy: _referencePolicy,
	_virtualService: _virtualService,
	_lastModified: _lastModified,
	destination: destination,
	_whenHandedOver: _whenHandedOver,
	_typeTested: _typeTested,
	product: product,
	_referrer: _referrer,
	plannedEndDate: plannedEndDate,
	_birthDate: _birthDate,
	_mustHaveValue: _mustHaveValue,
	ClinicalUseDefinition: ClinicalUseDefinition,
	dynamicValue: dynamicValue,
	_detailSequence: _detailSequence,
	SupportingInformation: SupportingInformation,
	CitationStatusDateComponent: CitationStatusDateComponent,
	subscriberId: subscriberId,
	node: node,
	details: details,
	GenomicStudyAnalysisInputComponent: GenomicStudyAnalysisInputComponent,
	contract: contract,
	_paymentIssuer: _paymentIssuer,
	_clinicalTrial: _clinicalTrial,
	Adjudication: Adjudication,
	AdverseEventMitigatingActionComponent: AdverseEventMitigatingActionComponent,
	ratioType: ratioType,
	authoritative: authoritative,
	chromosome: chromosome,
	referralMethod: referralMethod,
	MedicationKnowledgeDefinitionalDrugCharacteristicComponent: MedicationKnowledgeDefinitionalDrugCharacteristicComponent,
	_filterParameter: _filterParameter,
	_costCenter: _costCenter,
	_maternalOrganismName: _maternalOrganismName,
	_CommunicationRequest: _CommunicationRequest,
	_mapping: _mapping,
	_spatialReference: _spatialReference,
	_AppointmentResponse: _AppointmentResponse,
	preparation: preparation,
	_outcome: _outcome,
	_policy: _policy,
	planningHorizon: planningHorizon,
	_targetSpecies: _targetSpecies,
	EvidenceVariableCharacteristicComponent: EvidenceVariableCharacteristicComponent,
	_authorization: _authorization,
	software: software,
	_lastReviewDate: _lastReviewDate,
	_derivedFromCanonical: _derivedFromCanonical,
	specialCourtesy: specialCourtesy,
	intraspecificType: intraspecificType,
	shortTitle: shortTitle,
	channelType: channelType,
	_subSite: _subSite,
	use: use,
	webLocation: webLocation,
	PlanDefinitionGoalTargetComponent: PlanDefinitionGoalTargetComponent,
	_entryQuantity: _entryQuantity,
	_seriousness: _seriousness,
	_born: _born,
	initiator: initiator,
	geometry: geometry,
	_organismGeneral: _organismGeneral,
	TestReportSetupComponent: TestReportSetupComponent,
	message: message,
	PlanDefinitionActionInputComponent: PlanDefinitionActionInputComponent,
	Dosage: Dosage,
	_structureType: _structureType,
	onAdmission: onAdmission,
	EncounterLocationComponent: EncounterLocationComponent,
	statusHistory: statusHistory,
	CitationCitedArtifactComponent: CitationCitedArtifactComponent,
	_paymentTerms: _paymentTerms,
	_intendedEffect: _intendedEffect,
	SubstanceSourceMaterialOrganismAuthorComponent: SubstanceSourceMaterialOrganismAuthorComponent,
	listMode: listMode,
	_typeCollected: _typeCollected,
	definitional: definitional,
	improvementNotation: improvementNotation,
	ValuedItem: ValuedItem,
	ElementDefinitionBaseComponent: ElementDefinitionBaseComponent,
	Errors: Errors,
	pattern: pattern,
	TestScriptDestinationComponent: TestScriptDestinationComponent,
	CoveragePaymentByComponent: CoveragePaymentByComponent,
	_AuditEvent: _AuditEvent,
	requirements: requirements,
	authority: authority,
	_compareToSourceId: _compareToSourceId,
	_Contract: _Contract,
	_occurrenceChanged: _occurrenceChanged,
	typeReference: typeReference,
	detail: detail,
	_alternative: _alternative,
	ClaimResponseAdjudication: ClaimResponseAdjudication,
	Person: Person,
	readHistory: readHistory,
	_subjects: _subjects,
	membership: membership,
	studyUid: studyUid,
	GraphDefinitionLinkCompartmentComponent: GraphDefinitionLinkCompartmentComponent,
	_occurrence: _occurrence,
	_dayOfMonth: _dayOfMonth,
	Extension: Extension,
	_proxyIdentityCertificate: _proxyIdentityCertificate,
	emptyReason: emptyReason,
	ConceptMapGroupComponent: ConceptMapGroupComponent,
	laterality: laterality,
	_previous: _previous,
	_claimResponse: _claimResponse,
	dataUpdateType: dataUpdateType,
	paymentDate: paymentDate,
	baseFormulaProductName: baseFormulaProductName,
	performed: performed,
	ServiceRequestOrderDetailComponent: ServiceRequestOrderDetailComponent,
	_informationSequence: _informationSequence,
	_wednesday: _wednesday,
	_id: _id,
	nucleicAcid: nucleicAcid,
	implementation: implementation,
	_species: _species,
	_goalId: _goalId,
	manager: manager,
	Meta: Meta,
	interpreter: interpreter,
	situation: situation,
	_recorded: _recorded,
	DiagnosticReport: DiagnosticReport,
	drugCharacteristic: drugCharacteristic,
	SubstanceDefinitionStructureRepresentationComponent: SubstanceDefinitionStructureRepresentationComponent,
	RequestOrchestrationActionRelatedActionComponent: RequestOrchestrationActionRelatedActionComponent,
	variableRole: variableRole,
	failureAction: failureAction,
	suppliedItem: suppliedItem,
	abstract: abstract,
	valueRange: valueRange,
	_query: _query,
	sigFormat: sigFormat,
	VirtualServiceDetail: VirtualServiceDetail,
	_rest: _rest,
	packageCode: packageCode,
	_reaction: _reaction,
	_contributor: _contributor,
	_normalValue: _normalValue,
	_resultsInterpreter: _resultsInterpreter,
	_tester: _tester,
	denominator: denominator,
	uniqueId: uniqueId,
	readOnly: readOnly,
	_effectiveDosePeriod: _effectiveDosePeriod,
	_patientInstruction: _patientInstruction,
	focusReference: focusReference,
	_sopClass: _sopClass,
	_brand: _brand,
	SubscriptionStatusNotificationEventComponent: SubscriptionStatusNotificationEventComponent,
	specialArrangement: specialArrangement,
	_autocreate: _autocreate,
	_responsibility: _responsibility,
	any: any,
	protocolApplied: protocolApplied,
	PaymentNotice: PaymentNotice,
	_completionTime: _completionTime,
	_preAdmissionIdentifier: _preAdmissionIdentifier,
	_interpretation: _interpretation,
	testingDestination: testingDestination,
	ExtendedContactDetail: ExtendedContactDetail,
	administrableDoseForm: administrableDoseForm,
	repeat: repeat,
	CapabilityStatementRestResourceSearchParamComponent: CapabilityStatementRestResourceSearchParamComponent,
	interactant: interactant,
	_groupDefinition: _groupDefinition,
	_effective: _effective,
	_service: _service,
	admitSource: admitSource,
	_cap: _cap,
	_structure: _structure,
	_preferred: _preferred,
	human: human,
	_genomeAssembly: _genomeAssembly,
	_dimensions: _dimensions,
	Reason: Reason,
	eligibility: eligibility,
	resultForCreate: resultForCreate,
	PersonLinkComponent: PersonLinkComponent,
	EvidenceCertaintyComponent: EvidenceCertaintyComponent,
	texture: texture,
	characterization: characterization,
	TerminologyCapabilitiesExpansionComponent: TerminologyCapabilitiesExpansionComponent,
	DataRequirementCodeFilterComponent: DataRequirementCodeFilterComponent,
	_derivedFrom: _derivedFrom,
	_doseAdministrationAid: _doseAdministrationAid,
	productOrService: productOrService,
	_plannedEndDate: _plannedEndDate,
	conformsTo: conformsTo,
	_detected: _detected,
	_threePrime: _threePrime,
	referencedFrom: referencedFrom,
	targetFormat: targetFormat,
	_characteristicType: _characteristicType,
	StructureDefinitionMappingComponent: StructureDefinitionMappingComponent,
	_initiatorActive: _initiatorActive,
	supportedInteraction: supportedInteraction,
	vaccineCode: vaccineCode,
	seriesNumber: seriesNumber,
	pageCount: pageCount,
	_who: _who,
	PermissionRuleActivityComponent: PermissionRuleActivityComponent,
	careManager: careManager,
	CodeSystem: CodeSystem,
	MedicinalProductDefinitionNamePartComponent: MedicinalProductDefinitionNamePartComponent,
	_requestingOrganization: _requestingOrganization,
	_referralMethod: _referralMethod,
	_suspectEntity: _suspectEntity,
	_exclusionCriteria: _exclusionCriteria,
	ObservationComponentComponent: ObservationComponentComponent,
	_testScript: _testScript,
	manufactureDate: manufactureDate,
	_textPresentation: _textPresentation,
	TestReportSetupActionOperationComponent: TestReportSetupActionOperationComponent,
	legal: legal,
	provider: provider,
	exitCriteria: exitCriteria,
	image: image,
	SupplyRequest: SupplyRequest,
	_periodMax: _periodMax,
	_monograph: _monograph,
	_decision: _decision,
	_diagnostics: _diagnostics,
	_origin: _origin,
	_durationUnit: _durationUnit,
	contact: contact,
	_disabledDisplay: _disabledDisplay,
	_attestation: _attestation,
	PackagedProductDefinitionPackagingComponentPackaging: PackagedProductDefinitionPackagingComponentPackaging,
	OperationOutcomeIssueComponent: OperationOutcomeIssueComponent,
	_hash: _hash,
	_pageString: _pageString,
	_constituent: _constituent,
	DeviceAssociation: DeviceAssociation,
	_dayOfWeek: _dayOfWeek,
	_inventoryListing: _inventoryListing,
	_hierarchyMeaning: _hierarchyMeaning,
	_dispenseRequest: _dispenseRequest,
	legallyBinding: legallyBinding,
	_manufacturer: _manufacturer,
	_answerConstraint: _answerConstraint,
	_when: _when,
	_form: _form,
	businessStatus: businessStatus,
	comparisonGroup: comparisonGroup,
	_instance: _instance,
	_itemStatus: _itemStatus,
	_conditionalDelete: _conditionalDelete,
	_grade: _grade,
	_process: _process,
	_articleDate: _articleDate,
	additionalMonitoringIndicator: additionalMonitoringIndicator,
	title: title,
	_courseOfTherapyType: _courseOfTherapyType,
	_identity: _identity,
	CapabilityStatementRestComponent: CapabilityStatementRestComponent,
	additionalAttribute: additionalAttribute,
	monomerSet: monomerSet,
	ingredient: ingredient,
	_subPotentReason: _subPotentReason,
	_supportedMessage: _supportedMessage,
	DataRequirementDateFilterComponent: DataRequirementDateFilterComponent,
	_performedActivity: _performedActivity,
	_specialty: _specialty,
	_weekInterval: _weekInterval,
	publicationDate: publicationDate,
	administrationInstruction: administrationInstruction,
	fivePrime: fivePrime,
	_points: _points,
	TestScriptSetupActionAssertComponent: TestScriptSetupActionAssertComponent,
	referralRequest: referralRequest,
	_timeAspect: _timeAspect,
	_presentedForm: _presentedForm,
	_seriesDoses: _seriesDoses,
	milestone: milestone,
	MedicationAdministrationPerformerComponent: MedicationAdministrationPerformerComponent,
	Invoice: Invoice,
	additionalContext: additionalContext,
	_satisfiedBy: _satisfiedBy,
	identifier: identifier,
	SubstanceNucleicAcid: SubstanceNucleicAcid,
	resourceTrigger: resourceTrigger,
	_overload: _overload,
	organization: organization,
	PlanDefinitionActionConditionComponent: PlanDefinitionActionConditionComponent,
	RegulatedAuthorizationCaseComponentCaseCase: RegulatedAuthorizationCaseComponentCaseCase,
	sliceIsConstraining: sliceIsConstraining,
	_dataUpdateType: _dataUpdateType,
	noteNumber: noteNumber,
	installDate: installDate,
	cardBrand: cardBrand,
	_fullUrl: _fullUrl,
	codeMap: codeMap,
	ConditionDefinitionObservationComponent: ConditionDefinitionObservationComponent,
	FamilyMemberHistory: FamilyMemberHistory,
	operationTypeReason: operationTypeReason,
	SpecimenDefinitionTypeTestedContainerAdditiveComponent: SpecimenDefinitionTypeTestedContainerAdditiveComponent,
	_element: _element,
	_attachedDocument: _attachedDocument,
	_implementation: _implementation,
	sourceMaterialType: sourceMaterialType,
	_substance: _substance,
	_qualification: _qualification,
	_countType: _countType,
	sourceMaterialState: sourceMaterialState,
	_observationResultRequirement: _observationResultRequirement,
	attestationSignature: attestationSignature,
	PackagedProductDefinitionPackagingComponentPackagingPackaging: PackagedProductDefinitionPackagingComponentPackagingPackaging,
	_marketingAuthorizationHolder: _marketingAuthorizationHolder,
	_decisionMode: _decisionMode,
	repeats: repeats,
	typeTested: typeTested,
	_rankingOrder: _rankingOrder,
	end: end,
	GenomicStudyAnalysisComponent: GenomicStudyAnalysisComponent,
	excluded: excluded,
	BundleEntryRequestComponent: BundleEntryRequestComponent,
	DeviceDefinitionDeviceNameComponent: DeviceDefinitionDeviceNameComponent,
	_eventNumber: _eventNumber,
	FormularyItem: FormularyItem,
	_marketDistribution: _marketDistribution,
	_searchParam: _searchParam,
	countryOfOrigin: countryOfOrigin,
	AuditEventAgentComponent: AuditEventAgentComponent,
	_regulatoryAuthority: _regulatoryAuthority,
	_subjectState: _subjectState,
	actualComparisonGroup: actualComparisonGroup,
	_focusReference: _focusReference,
	_statusReason: _statusReason,
	ingredientLabel: ingredientLabel,
	_whenPrepared: _whenPrepared,
	costCenter: costCenter,
	outputParameters: outputParameters,
	DevicePropertyComponent: DevicePropertyComponent,
	productCategory: productCategory,
	serviceType: serviceType,
	_verification: _verification,
	reliableCache: reliableCache,
	_Flag: _Flag,
	numberAffected: numberAffected,
	StructureMapGroupRuleDependentComponent: StructureMapGroupRuleDependentComponent,
	relationshipType: relationshipType,
	_statement: _statement,
	_Goal: _Goal,
	issued: issued,
	_instruction: _instruction,
	inclusionCriteria: inclusionCriteria,
	about: about,
	Practitioner: Practitioner,
	prognosisCodeableConcept: prognosisCodeableConcept,
	AdverseEventParticipantComponent: AdverseEventParticipantComponent,
	_maxValue: _maxValue,
	ItemDetail: ItemDetail,
	_hasBodySite: _hasBodySite,
	_metadata: _metadata,
	rejectionCriterion: rejectionCriterion,
	cors: cors,
	_option: _option,
	TypeRefComponent: TypeRefComponent,
	minValue: minValue,
	_tuesday: _tuesday,
	_offset: _offset,
	report: report,
	_fhirPathCriteria: _fhirPathCriteria,
	editor: editor,
	_firstDose: _firstDose,
	procedureSequence: procedureSequence,
	MedicinalProductDefinitionContactComponent: MedicinalProductDefinitionContactComponent,
	_Communication: _Communication,
	_controller: _controller,
	TestScriptSetupActionAssertRequirementComponent: TestScriptSetupActionAssertRequirementComponent,
	_allocation: _allocation,
	otherTherapy: otherTherapy,
	_requestedLocation: _requestedLocation,
	_referencedFrom: _referencedFrom,
	eventsSinceSubscriptionStart: eventsSinceSubscriptionStart,
	_question: _question,
	_drugCharacteristic: _drugCharacteristic,
	_total: _total,
	AuditEvent: AuditEvent,
	_environmentType: _environmentType,
	AssetContext: AssetContext,
	_rangeCategory: _rangeCategory,
	Location: Location,
	rank: rank,
	PlanDefinitionActionComponentActionAction: PlanDefinitionActionComponentActionAction,
	_occurrenceCount: _occurrenceCount,
	entryType: entryType,
	_trigger: _trigger,
	_contextInvariant: _contextInvariant,
	id: id,
	_productionIdentifierInUDI: _productionIdentifierInUDI,
	_variable: _variable,
	occurrence: occurrence,
	dayOfMonth: dayOfMonth,
	_maxDosePerPeriod: _maxDosePerPeriod,
	_MeasureReport: _MeasureReport,
	MedicationKnowledgeCostComponent: MedicationKnowledgeCostComponent,
	uuid: uuid,
	_range: _range,
	related: related,
	endpoint: endpoint,
	ValueSetExpansionParameterComponent: ValueSetExpansionParameterComponent,
	_logMessage: _logMessage,
	SubscriptionTopicResourceTriggerQueryCriteriaComponent: SubscriptionTopicResourceTriggerQueryCriteriaComponent,
	_supportingImmunization: _supportingImmunization,
	StructureMapConstComponent: StructureMapConstComponent,
	NutritionIntakeConsumedItemComponent: NutritionIntakeConsumedItemComponent,
	PlanDefinitionGoalComponent: PlanDefinitionGoalComponent,
	precondition: precondition,
	_CoverageEligibilityResponse: _CoverageEligibilityResponse,
	_duration: _duration,
	_routeOfAdministration: _routeOfAdministration,
	_legallyBinding: _legallyBinding,
	rendering: rendering,
	_hierarchical: _hierarchical,
	_nameType: _nameType,
	_businessStatus: _businessStatus,
	_maxLength: _maxLength,
	SubstancePolymerRepeatComponent: SubstancePolymerRepeatComponent,
	responsibleParty: responsibleParty,
	BundleEntryComponent: BundleEntryComponent,
	_input: _input,
	_languageCode: _languageCode,
	_patient: _patient,
	direction: direction,
	_publicationDateSeason: _publicationDateSeason,
	maritalStatus: maritalStatus,
	AllergyIntoleranceReactionComponent: AllergyIntoleranceReactionComponent,
	_observer: _observer,
	SubscriptionParameterComponent: SubscriptionParameterComponent,
	doseAdministrationAid: doseAdministrationAid,
	DeviceDefinitionClassificationComponent: DeviceDefinitionClassificationComponent,
	_measure: _measure,
	_maxDosePerAdministration: _maxDosePerAdministration,
	CompositionAttesterComponent: CompositionAttesterComponent,
	_valueFilter: _valueFilter,
	studyDesign: studyDesign,
	_relation: _relation,
	_priority: _priority,
	MessageDefinition: MessageDefinition,
	_description: _description,
	TestPlanTestCaseTestDataComponent: TestPlanTestCaseTestDataComponent,
	HealthcareServiceEligibilityComponent: HealthcareServiceEligibilityComponent,
	category: category,
	Details: Details,
	verificationDate: verificationDate,
	ExampleScenarioActorComponent: ExampleScenarioActorComponent,
	_specimenQuantity: _specimenQuantity,
	DeviceDefinitionPackagingComponent: DeviceDefinitionPackagingComponent,
	autocreate: autocreate,
	_structuralRepresentation: _structuralRepresentation,
	agent: agent,
	_request: _request,
	_deliverTo: _deliverTo,
	_textConcentration: _textConcentration,
	benefitPeriod: benefitPeriod,
	SpecimenDefinitionTypeTestedContainerComponent: SpecimenDefinitionTypeTestedContainerComponent,
	ServiceRequestPatientInstructionComponent: ServiceRequestPatientInstructionComponent,
	_adjustment: _adjustment,
	_guidance: _guidance,
	productReference: productReference,
	_for: _for,
	_intended: _intended,
	_additionalUse: _additionalUse,
	MetadataResource: MetadataResource,
	_startingSequence: _startingSequence,
	MedicationStatement: MedicationStatement,
	medium: medium,
	_baseUnit: _baseUnit,
	_doseStatusReason: _doseStatusReason,
	unitOfPresentation: unitOfPresentation,
	CareTeam: CareTeam,
	sourceSignature: sourceSignature,
	availableStartTime: availableStartTime,
	_effectiveDate: _effectiveDate,
	_relevantHistory: _relevantHistory,
	ParametersParameterComponent: ParametersParameterComponent,
	MessageDefinitionFocusComponent: MessageDefinitionFocusComponent,
	EnrollmentResponse: EnrollmentResponse,
	ListEntryComponent: ListEntryComponent,
	_subset: _subset,
	dimensions: dimensions,
	_function: _function,
	recommendation: recommendation,
	_prescription: _prescription,
	prognosisReference: prognosisReference,
	_hint: _hint,
	_ownedBy: _ownedBy,
	measurementFrequency: measurementFrequency,
	_traceNumber: _traceNumber,
	_excludingDate: _excludingDate,
	_required: _required,
	correctiveAction: correctiveAction,
	schedule: schedule,
	_referral: _referral,
	alternate: alternate,
	intendedExposure: intendedExposure,
	threePrime: threePrime,
	param: param,
	_proposedNewTime: _proposedNewTime,
	power: power,
	cardinalityBehavior: cardinalityBehavior,
	supportingPatientInformation: supportingPatientInformation,
	_predecessor: _predecessor,
	allergenicIndicator: allergenicIndicator,
	_regulator: _regulator,
	issue: issue,
	_admission: _admission,
	_extension: _extension,
	_notificationShape: _notificationShape,
	Device: Device,
	Range: Range,
	ItemBodySite: ItemBodySite,
	average: average,
	SubstanceNucleicAcidSubunitSugarComponent: SubstanceNucleicAcidSubunitSugarComponent,
	Composition: Composition,
	_otherMap: _otherMap,
	Rule: Rule,
	testScript: testScript,
	targetId: targetId,
	_additionalAttribute: _additionalAttribute,
	_validity: _validity,
	_product: _product,
	objective: objective,
	_containedItem: _containedItem,
	MedicationKnowledgePackagingComponentCost: MedicationKnowledgePackagingComponentCost,
	relatedDevice: relatedDevice,
	QuestionnaireItemEnableWhenComponent: QuestionnaireItemEnableWhenComponent,
	_numberAffected: _numberAffected,
	_batch: _batch,
	preparationInstruction: preparationInstruction,
	EpisodeOfCare: EpisodeOfCare,
	_entity: _entity,
	_initiator: _initiator,
	_communication: _communication,
	programEligibility: programEligibility,
	addItem: addItem,
	_details: _details,
	pageString: pageString,
	expansion: expansion,
	MedicationKnowledgeRegulatoryComponent: MedicationKnowledgeRegulatoryComponent,
	_affiliation: _affiliation,
	_contentDefinition: _contentDefinition,
	marketPeriod: marketPeriod,
	_reportingPeriod: _reportingPeriod,
	_accountNumber: _accountNumber,
	_geneSequenceOrigin: _geneSequenceOrigin,
	subpotentReason: subpotentReason,
	inventoryStatus: inventoryStatus,
	subunit: subunit,
	orderer: orderer,
	ExampleScenarioInstanceVersionComponent: ExampleScenarioInstanceVersionComponent,
	itemStatus: itemStatus,
	_ResearchStudy: _ResearchStudy,
	resourceType: resourceType,
	Quantity: Quantity,
	contained: contained,
	_appointmentType: _appointmentType,
	SpecimenDefinitionTypeTestedComponent: SpecimenDefinitionTypeTestedComponent,
	_actual: _actual,
	CostToBeneficiary: CostToBeneficiary,
	_Schedule: _Schedule,
	programCode: programCode,
	_PractitionerRole: _PractitionerRole,
	guarantor: guarantor,
	_FamilyMemberHistory: _FamilyMemberHistory,
	_operationTypeReason: _operationTypeReason,
	_programStatus: _programStatus,
	_performerLinkId: _performerLinkId,
	onHold: onHold,
	_copackagedIndicator: _copackagedIndicator,
	storageGuideline: storageGuideline,
	_receiver: _receiver,
	_whyStopped: _whyStopped,
	_packageFor: _packageFor,
	action: action,
	_sourceMaterialState: _sourceMaterialState,
	indicationGuideline: indicationGuideline,
	_interaction: _interaction,
	aggregateMethod: aggregateMethod,
	_authorizingPrescription: _authorizingPrescription,
	_authoritative: _authoritative,
	timeAspect: timeAspect,
	_valueSet: _valueSet,
	OperationOutcome: OperationOutcome,
	Contributor: Contributor,
	_message: _message,
	import__workaround: import__workaround,
	definitionByTypeAndValue: definitionByTypeAndValue,
	TestScriptSetupActionOperationComponent: TestScriptSetupActionOperationComponent,
	mitigatingAction: mitigatingAction,
	validationDate: validationDate,
	healthcareService: healthcareService,
	conditionalPatch: conditionalPatch,
	minimumVolume: minimumVolume,
	_practiceSetting: _practiceSetting,
	protocol: protocol,
	_structureProfile: _structureProfile,
	_Coverage: _Coverage,
	_issuerType: _issuerType,
	MedicationRequest: MedicationRequest,
	_pattern: _pattern,
	processingFacility: processingFacility,
	_situation: _situation,
	_patchFormat: _patchFormat,
	alternateMaterial: alternateMaterial,
	responsible: responsible,
	PlanDefinitionActionRelatedActionComponent: PlanDefinitionActionRelatedActionComponent,
	_security: _security,
	combined: combined,
	contains: contains,
	_addresses: _addresses,
	expirationDate: expirationDate,
	compartment: compartment,
	_scoring: _scoring,
	policy: policy,
	recordedDate: recordedDate,
	_sourceScope: _sourceScope,
	_chain: _chain,
	ImplementationGuideManifestComponent: ImplementationGuideManifestComponent,
	_contributedToDeath: _contributedToDeath,
	_diagnosisRelatedGroup: _diagnosisRelatedGroup,
	_referenceNumber: _referenceNumber,
	_template: _template,
	_preConditions: _preConditions,
	_score: _score,
	SubstancePolymerMonomerSetComponent: SubstancePolymerMonomerSetComponent,
	_requiredBehavior: _requiredBehavior,
	_statusHistory: _statusHistory,
	replacementSequence: replacementSequence,
	_file: _file,
	_height: _height,
	_groupSize: _groupSize,
	observedGroup: observedGroup,
	receivedTime: receivedTime,
	_doseAndRate: _doseAndRate,
	definitionCanonical: definitionCanonical,
	QuestionnaireResponseItemComponent: QuestionnaireResponseItemComponent,
	_typeReference: _typeReference,
	PractitionerQualificationComponent: PractitionerQualificationComponent,
	cTerminalModificationId: cTerminalModificationId,
	_requireBoth: _requireBoth,
	dataAbsentReason: dataAbsentReason,
	_criticality: _criticality,
	_subjectStatus: _subjectStatus,
	_expiry: _expiry,
	usage: usage,
	city: city,
	_instances: _instances,
	stratum: stratum,
	MeasureReportGroupStratifierComponent: MeasureReportGroupStratifierComponent,
	_ratioHighLimitAmount: _ratioHighLimitAmount,
	route: route,
	TestScriptMetadataLinkComponent: TestScriptMetadataLinkComponent,
	DeviceDispensePerformerComponent: DeviceDispensePerformerComponent,
	frequencyMax: frequencyMax,
	_number: _number,
	QuestionnaireResponse: QuestionnaireResponse,
	MappingProperty: MappingProperty,
	_securityContext: _securityContext,
	display: display,
	yearlyTemplate: yearlyTemplate,
	ChargeItemPerformerComponent: ChargeItemPerformerComponent,
	Contact: Contact,
	EndpointPayloadComponent: EndpointPayloadComponent,
	_relatedArtifact: _relatedArtifact,
	updateCreate: updateCreate,
	_subtype: _subtype,
	_stereochemistry: _stereochemistry,
	_upperLimit: _upperLimit,
	routeOfAdministration: routeOfAdministration,
	_amountType: _amountType,
	_organismType: _organismType,
	bodySite: bodySite,
	_moiety: _moiety,
	_recommendation: _recommendation,
	grouping: grouping,
	_pause: _pause,
	_primaryPurposeType: _primaryPurposeType,
	ConceptSubProperty: ConceptSubProperty,
	subscription: subscription,
	_lastPage: _lastPage,
	partLocation: partLocation,
	controller: controller,
	publicationDateSeason: publicationDateSeason,
	imports: imports,
	allocation: allocation,
	_pageCount: _pageCount,
	_failureAction: _failureAction,
	profile: profile,
	cylinder: cylinder,
	deleted: deleted,
	episodeOfCare: episodeOfCare,
	saturday: saturday,
	_expectedInResearchStudy: _expectedInResearchStudy,
	CommunicationRequestPayloadComponent: CommunicationRequestPayloadComponent,
	_calculatedAt: _calculatedAt,
	_impurity: _impurity,
	type: type,
	goalId: goalId,
	ObservationDefinitionComponentComponent: ObservationDefinitionComponentComponent,
	TestScriptSetupComponent: TestScriptSetupComponent,
	Appointment: Appointment,
	_groupIdentifier: _groupIdentifier,
	_countMax: _countMax,
	patientCharacteristic: patientCharacteristic,
	lowNumerator: lowNumerator,
	_texture: _texture,
	_causality: _causality,
	operator: operator,
	fixed: fixed,
	nTerminalModificationId: nTerminalModificationId,
	InventoryItemNameComponent: InventoryItemNameComponent,
	_minimumId: _minimumId,
	verificationStatus: verificationStatus,
	_PaymentNotice: _PaymentNotice,
	_dateAccessed: _dateAccessed,
	logMessage: logMessage,
	ResearchStudyProgressStatusComponent: ResearchStudyProgressStatusComponent,
	_residueSite: _residueSite,
	MonetaryComponent: MonetaryComponent,
	TeardownAction: TeardownAction,
	clinicalUseIssue: clinicalUseIssue,
	classification: classification,
	_lifecycleStatus: _lifecycleStatus,
	signature: signature,
	reviewer: reviewer,
	_usePeriod: _usePeriod,
	BodyStructureIncludedStructureComponent: BodyStructureIncludedStructureComponent,
	next: next,
	_changeType: _changeType,
	_ImmunizationEvaluation: _ImmunizationEvaluation,
	requestingOrganization: requestingOrganization,
	_unitOfPresentation: _unitOfPresentation,
	requestedPeriod: requestedPeriod,
	Answer: Answer,
	count: count,
	ContractOffer: ContractOffer,
	composition: composition,
	_EnrollmentResponse: _EnrollmentResponse,
	ConditionStageComponent: ConditionStageComponent,
	ResearchSubjectProgressComponent: ResearchSubjectProgressComponent,
	key: key,
	assertion: assertion,
	MedicationKnowledgeIndicationGuidelineDosingGuidelinePatientCharacteristicComponent: MedicationKnowledgeIndicationGuidelineDosingGuidelinePatientCharacteristicComponent,
	alternative: alternative,
	plan: plan,
	_criteria: _criteria,
	cycle: cycle,
	_latitude: _latitude,
	modifier: modifier,
	_scoringUnit: _scoringUnit,
	subJurisdiction: subJurisdiction,
	_search: _search,
	assignedComparisonGroup: assignedComparisonGroup,
	_alias: _alias,
	_status: _status,
	recurring: recurring,
	InventoryItemInstanceComponent: InventoryItemInstanceComponent,
	frameOfReferenceUid: frameOfReferenceUid,
	_validationDate: _validationDate,
	NutritionOrderEnteralFormulaComponent: NutritionOrderEnteralFormulaComponent,
	deliveryDevice: deliveryDevice,
	_cardBrand: _cardBrand,
	adjustment: adjustment,
	_cors: _cors,
	_allergenicIndicator: _allergenicIndicator,
	_timezone: _timezone,
	_actor: _actor,
	valueQuantity: valueQuantity,
	_versionId: _versionId,
	requester: requester,
	_SupplyRequest: _SupplyRequest,
	MeasureTermComponent: MeasureTermComponent,
	_containedItemQuantity: _containedItemQuantity,
	_daysSupply: _daysSupply,
	reportingVendor: reportingVendor,
	current: current,
	uid: uid,
	order: order,
	priorPrescription: priorPrescription,
	distanceFromLandmark: distanceFromLandmark,
	VerificationResultValidatorComponent: VerificationResultValidatorComponent,
	_recurrenceTemplate: _recurrenceTemplate,
	tenderedAmount: tenderedAmount,
	_diseaseStatus: _diseaseStatus,
	_expirationDate: _expirationDate,
	_dataPeriod: _dataPeriod,
	note: note,
	_manipulated: _manipulated,
	_Invoice: _Invoice,
	RatioRange: RatioRange,
	_requisition: _requisition,
	ClinicalImpression: ClinicalImpression,
	_claim: _claim,
	need: need,
	contributor: contributor,
	ConceptProperty: ConceptProperty,
	ConsentVerificationComponent: ConsentVerificationComponent,
	TestReportTeardownComponent: TestReportTeardownComponent,
	_genus: _genus,
	extraDetails: extraDetails,
	_location: _location,
	_reported: _reported,
	_codeMap: _codeMap,
	firstPage: firstPage,
	_setup: _setup,
	_paymentBy: _paymentBy,
	custodian: custodian,
	estimatedAge: estimatedAge,
	_observation: _observation,
	technique: technique,
	Requirements: Requirements,
	supplementalData: supplementalData,
	SimpleQuantity: SimpleQuantity,
	ProvenanceEntityComponent: ProvenanceEntityComponent,
	condition: condition,
	excludeFoodModifier: excludeFoodModifier,
	coverageArea: coverageArea,
	contributionInstance: contributionInstance,
	_productCode: _productCode,
	_language: _language,
	base: base,
	_windowStart: _windowStart,
	district: district,
	forenameInitials: forenameInitials,
	_state: _state,
	friendly: friendly,
	AdditionalAttribute: AdditionalAttribute,
	_Transport: _Transport,
	xhtml: xhtml,
	_official: _official,
	CodeSystemConceptDesignationComponent: CodeSystemConceptDesignationComponent,
	_precedence: _precedence,
	_result: _result,
	_sliceName: _sliceName,
	points: points,
	finding: finding,
	_yearlyTemplate: _yearlyTemplate,
	_isModifierReason: _isModifierReason,
	_experimental: _experimental,
	_overbooked: _overbooked,
	ExampleScenario: ExampleScenario,
	AvailabilityNotAvailableTimeComponent: AvailabilityNotAvailableTimeComponent,
	derivedFrom: derivedFrom,
	_postalCode: _postalCode,
	_endorser: _endorser,
	modifierExtension: modifierExtension,
	verified: verified,
	warning: warning,
	_color: _color,
	_global: _global,
	_policyBasis: _policyBasis,
	timeFromEvent: timeFromEvent,
	costToBeneficiary: costToBeneficiary,
	Questionnaire: Questionnaire,
	_FormularyItem: _FormularyItem,
	_permittedUnit: _permittedUnit,
	data: data,
	_targetItem: _targetItem,
	whyStopped: whyStopped,
	_practitioner: _practitioner,
	packageFor: packageFor,
	_informationSource: _informationSource,
	hasMember: hasMember,
	_paymentIdentifier: _paymentIdentifier,
	allowedType: allowedType,
	_intraspecificType: _intraspecificType,
	_isDefault: _isDefault,
	_supportedProfile: _supportedProfile,
	_authored: _authored,
	stabilityDuration: stabilityDuration,
	InsurancePlanCoverageBenefitLimitComponent: InsurancePlanCoverageBenefitLimitComponent,
	compareToSourcePath: compareToSourcePath,
	_dosageInstruction: _dosageInstruction,
	sequence: sequence,
	revenue: revenue,
	SystemInteraction: SystemInteraction,
	SubscriptionFilterByComponent: SubscriptionFilterByComponent,
	_requirement: _requirement,
	_reliableCache: _reliableCache,
	nextScheduled: nextScheduled,
	MeasureGroupComponent: MeasureGroupComponent,
	processNote: processNote,
	StratifierGroupPopulation: StratifierGroupPopulation,
	issuerType: issuerType,
	capacity: capacity,
	_rendering: _rendering,
	TestScriptTeardownComponent: TestScriptTeardownComponent,
	requestIdentifier: requestIdentifier,
	_definitionCanonical: _definitionCanonical,
	v: v,
	_classification: _classification,
	Claim: Claim,
	asNeeded: asNeeded,
	defaultManualCompletion: defaultManualCompletion,
	partDescription: partDescription,
	articleDate: articleDate,
	narrative: narrative,
	participant: participant,
	incidence: incidence,
	div: div,
	_versioning: _versioning,
	RelatedClaim: RelatedClaim,
	_page: _page,
	appointment: appointment,
	AuditEventEntityDetailComponent: AuditEventEntityDetailComponent,
	productionIdentifierInUDI: productionIdentifierInUDI,
	_photo: _photo,
	formOf: formOf,
	referrer: referrer,
	_subdetailSequence: _subdetailSequence,
	CareTeamParticipantComponent: CareTeamParticipantComponent,
	SpecimenDefinition: SpecimenDefinition,
	_affectsState: _affectsState,
	_inputPopulationId: _inputPopulationId,
	outputProfile: outputProfile,
	MessageDefinitionAllowedResponseComponent: MessageDefinitionAllowedResponseComponent,
	numberOfInstances: numberOfInstances,
	Term: Term,
	supportingImmunization: supportingImmunization,
	previousAppointment: previousAppointment,
	seriesDoses: seriesDoses,
	propertyGroup: propertyGroup,
	option: option,
	component: component,
	offset: offset,
	materialType: materialType,
	marketingAuthorizationHolder: marketingAuthorizationHolder,
	requestedPerformer: requestedPerformer,
	developmentStage: developmentStage,
	_deliveryDevice: _deliveryDevice,
	_Timing: _Timing,
	AdverseEventSuspectEntityCausalityComponent: AdverseEventSuspectEntityCausalityComponent,
	add: add,
	ImmunizationPerformerComponent: ImmunizationPerformerComponent,
	_BodyStructure: _BodyStructure,
	_organismName: _organismName,
	_monthlyTemplate: _monthlyTemplate,
	versionAlgorithm: versionAlgorithm,
	_deliverFor: _deliverFor,
	ElementDefinitionSlicingComponent: ElementDefinitionSlicingComponent,
	_responseId: _responseId,
	_tenderedAmount: _tenderedAmount,
	upperLimit: upperLimit,
	_verificationStatus: _verificationStatus,
	amountType: amountType,
	_patientPaid: _patientPaid,
	RequestOrchestrationActionOutputComponent: RequestOrchestrationActionOutputComponent,
	_quantity: _quantity,
	InsurancePlanPlanSpecificCostBenefitCostComponent: InsurancePlanPlanSpecificCostBenefitCostComponent,
	_alternate: _alternate,
	_contributingFactor: _contributingFactor,
	_sourceIdentityCertificate: _sourceIdentityCertificate,
	eventNumber: eventNumber,
	AdministrableProductDefinitionPropertyComponent: AdministrableProductDefinitionPropertyComponent,
	responseRequired: responseRequired,
	_verifiedBy: _verifiedBy,
	_maritalStatus: _maritalStatus,
	_timeOfDay: _timeOfDay,
	contraindication: contraindication,
	patientPreparation: patientPreparation,
	_expression: _expression,
	_min: _min,
	_attester: _attester,
	_progress: _progress,
	_collection: _collection,
	base64Binary: base64Binary,
	ExampleScenarioProcessStepComponent: ExampleScenarioProcessStepComponent,
	_comprisedOf: _comprisedOf,
	_factor: _factor,
	_endRelationship: _endRelationship,
	_startingMaterial: _startingMaterial,
	expectedSupplyDuration: expectedSupplyDuration,
	totalPriceComponent: totalPriceComponent,
	_signer: _signer,
	enableBehavior: enableBehavior,
	Contract: Contract,
	_cTerminalModificationId: _cTerminalModificationId,
	ObservationReferenceRangeComponent: ObservationReferenceRangeComponent,
	maxVolumeToDeliver: maxVolumeToDeliver,
	CapabilityStatementRestResourceOperationComponent: CapabilityStatementRestResourceOperationComponent,
	isDerived: isDerived,
	conditionalUpdate: conditionalUpdate,
	repeatUnitAmountType: repeatUnitAmountType,
	subjects: subjects,
	EvidenceVariableCharacteristicTimeFromEventComponent: EvidenceVariableCharacteristicTimeFromEventComponent,
	_expansion: _expansion,
	_Ingredient: _Ingredient,
	_phase: _phase,
	_benefitPeriod: _benefitPeriod,
	Organization: Organization,
	_referenceStrength: _referenceStrength,
	StructureMapGroupComponent: StructureMapGroupComponent,
	referencePolicy: referencePolicy,
	previous: previous,
	_stage: _stage,
	PlanDefinitionActionOutputComponent: PlanDefinitionActionOutputComponent,
	_publisherLocation: _publisherLocation,
	MedicationKnowledgeIndicationGuidelineDosingGuidelineDosageComponent: MedicationKnowledgeIndicationGuidelineDosingGuidelineDosageComponent,
	containedItemQuantity: containedItemQuantity,
	copyrightLabel: copyrightLabel,
	BodyStructureIncludedStructureBodyLandmarkOrientationComponent: BodyStructureIncludedStructureBodyLandmarkOrientationComponent,
	hasBodySite: hasBodySite,
	_valuedItem: _valuedItem,
	Period: Period,
	questionnaire: questionnaire,
	specificCost: specificCost,
	_collected: _collected,
	_notAvailableTime: _notAvailableTime,
	AllergyIntoleranceParticipantComponent: AllergyIntoleranceParticipantComponent,
	headerField: headerField,
	_contained: _contained,
	_assigner: _assigner,
	_ifNoneMatch: _ifNoneMatch,
	DeviceAssociationOperationComponent: DeviceAssociationOperationComponent,
	_graph: _graph,
	changeType: changeType,
	_orientation: _orientation,
	parentSubstanceId: parentSubstanceId,
	recorded: recorded,
	_contributionType: _contributionType,
	filterParameter: filterParameter,
	positiveInt: positiveInt,
	docStatus: docStatus,
	CoverageBenefit: CoverageBenefit,
	durationUnit: durationUnit,
	contentType: contentType,
	_addItem: _addItem,
	MedicationKnowledgeIndicationGuidelineDosingGuidelineComponent: MedicationKnowledgeIndicationGuidelineDosingGuidelineComponent,
	dateRange: dateRange,
	used: used,
	_city: _city,
	reaction: reaction,
	subset: subset,
	performerRole: performerRole,
	retentionTime: retentionTime,
	_ClinicalImpression: _ClinicalImpression,
	_generalCost: _generalCost,
	instanceReference: instanceReference,
	_history: _history,
	molecularFormulaByMoiety: molecularFormulaByMoiety,
	_orderer: _orderer,
	_payee: _payee,
	_windowEnd: _windowEnd,
	_maxDosePerTreatmentPeriod: _maxDosePerTreatmentPeriod,
	sopClass: sopClass,
	PlanDefinitionActorOptionComponent: PlanDefinitionActorOptionComponent,
	ExampleScenarioInstanceComponent: ExampleScenarioInstanceComponent,
	organismGeneral: organismGeneral,
	abatement: abatement,
	_relatedDevice: _relatedDevice,
	daysSupply: daysSupply,
	_legal: _legal,
	_EpisodeOfCare: _EpisodeOfCare,
	_excludeFoodModifier: _excludeFoodModifier,
	weekInterval: weekInterval,
	_measureScore: _measureScore,
	_const: _const,
	_hybrid: _hybrid,
	PackagedProductDefinitionPackagingComponent: PackagedProductDefinitionPackagingComponent,
	_prefix: _prefix,
	_publicationDateText: _publicationDateText,
	ConceptSet: ConceptSet,
	payeeType: payeeType,
	_shelfLifeStorage: _shelfLifeStorage,
	balance: balance,
	_type: _type,
	dataPeriod: dataPeriod,
	_Immunization: _Immunization,
	resourceReference: resourceReference,
	_providedBy: _providedBy,
	_fhirVersion: _fhirVersion,
	_HealthcareService: _HealthcareService,
	submitter: submitter,
	description: description,
	combinedPharmaceuticalDoseForm: combinedPharmaceuticalDoseForm,
	_targetScope: _targetScope,
	Parameter: Parameter,
	BiologicallyDerivedProduct: BiologicallyDerivedProduct,
	_GenomicStudy: _GenomicStudy,
	_NutritionProduct: _NutritionProduct,
	_additionalContext: _additionalContext,
	version: version,
	detected: detected,
	_statistic: _statistic,
	_bodyStructure: _bodyStructure,
	_definitionExpression: _definitionExpression,
	translations: translations,
	_targetProfile: _targetProfile,
	_notPerformedReason: _notPerformedReason,
	ArtifactAssessmentContentComponent: ArtifactAssessmentContentComponent,
	cost: cost,
	CanonicalResource: CanonicalResource,
	_authorizationSupporting: _authorizationSupporting,
	team: team,
	actual: actual,
	landmarkDescription: landmarkDescription,
	typeCanonical: typeCanonical,
	ArtifactAssessmentContentComponentContent: ArtifactAssessmentContentComponentContent,
	_organizationReference: _organizationReference,
	_minimumVolume: _minimumVolume,
	precedence: precedence,
	CitationSummaryComponent: CitationSummaryComponent,
	decision: decision,
	role: role,
	maternalOrganismId: maternalOrganismId,
	_triggeredBy: _triggeredBy,
	MedicationKnowledgeStorageGuidelineComponent: MedicationKnowledgeStorageGuidelineComponent,
	dischargeDisposition: dischargeDisposition,
	_output: _output,
	QuestionnaireItemComponent: QuestionnaireItemComponent,
	_compareToSourcePath: _compareToSourcePath,
	traceNumber: traceNumber,
	InsurancePlanPlanComponent: InsurancePlanPlanComponent,
	object: object,
	statusReason: statusReason,
	recall: recall,
	_codeSystem: _codeSystem,
	_processing: _processing,
	gateway: gateway,
	_performerType: _performerType,
	_subcomponent: _subcomponent,
	postalCode: postalCode,
	AddedItemDetail: AddedItemDetail,
	instance: instance,
	_disposition: _disposition,
	_statusDate: _statusDate,
	_facilityType: _facilityType,
	_stratum: _stratum,
	Payee: Payee,
	_measurementType: _measurementType,
	RelatedArtifact: RelatedArtifact,
	RequestOrchestrationActionDynamicValueComponent: RequestOrchestrationActionDynamicValueComponent,
	identity: identity,
	subType: subType,
	ValueSetExpansionContainsComponent: ValueSetExpansionContainsComponent,
	MedicationKnowledgePackagingComponent: MedicationKnowledgePackagingComponent,
	_display: _display,
	ImplementationGuideGlobalComponent: ImplementationGuideGlobalComponent,
	_SubstanceNucleicAcid: _SubstanceNucleicAcid,
	TestScriptSetupActionOperationRequestHeaderComponent: TestScriptSetupActionOperationRequestHeaderComponent,
	targetItem: targetItem,
	_dosingGuideline: _dosingGuideline,
	_totalGross: _totalGross,
	Reference: Reference,
	_precheckBehavior: _precheckBehavior,
	_enableBehavior: _enableBehavior,
	slot: slot,
	groupDefinition: groupDefinition,
	_verifiedWith: _verifiedWith,
	ResourceInteraction: ResourceInteraction,
	_numberOfSubunits: _numberOfSubunits,
	numberOfSeries: numberOfSeries,
	preAuthRefPeriod: preAuthRefPeriod,
	_excludingRecurrenceId: _excludingRecurrenceId,
	_baseCitation: _baseCitation,
	ContractAsset: ContractAsset,
	ClinicalImpressionFindingComponent: ClinicalImpressionFindingComponent,
	stopTestOnFail: stopTestOnFail,
	_selectionBehavior: _selectionBehavior,
	_imports: _imports,
	contextLinkId: contextLinkId,
	_eye: _eye,
	affiliation: affiliation,
	defaultValue: defaultValue,
	MolecularSequence: MolecularSequence,
	overload: overload,
	_productName: _productName,
	_comment: _comment,
	_profile: _profile,
	_deleted: _deleted,
	_workflow: _workflow,
	_attestationSignature: _attestationSignature,
	permittedDataType: permittedDataType,
	gene: gene,
	_prediction: _prediction,
	exposureRoute: exposureRoute,
	height: height,
	_entryClassifier: _entryClassifier,
	test: test,
	_previousAppointment: _previousAppointment,
	implementationGuide: implementationGuide,
	UsageContext: UsageContext,
	EventDefinition: EventDefinition,
	relatedIdentifier: relatedIdentifier,
	ImplementationGuideDependsOnComponent: ImplementationGuideDependsOnComponent,
	_procedureSequence: _procedureSequence,
	_copyrightLabel: _copyrightLabel,
	_navigationLinks: _navigationLinks,
	_generatedBy: _generatedBy,
	administeredProduct: administeredProduct,
	validateProfileId: validateProfileId,
	MedicationKnowledgeIndicationGuidelineComponent: MedicationKnowledgeIndicationGuidelineComponent,
	intraspecificDescription: intraspecificDescription,
	_protocolApplied: _protocolApplied,
	_VerificationResult: _VerificationResult,
	monthInterval: monthInterval,
	expiry: expiry,
	versioning: versioning,
	pushTypeAvailable: pushTypeAvailable,
	CitationCitedArtifactStatusDateComponent: CitationCitedArtifactStatusDateComponent,
	_assertion: _assertion,
	diagnosis: diagnosis,
	_ifNoneExist: _ifNoneExist,
	_low: _low,
	undesirableEffect: undesirableEffect,
	_base: _base,
	queryCriteria: queryCriteria,
	_availableEndTime: _availableEndTime,
	number: number,
	spatialReference: spatialReference,
	conditionality: conditionality,
	_codeFilter: _codeFilter,
	SubstanceDefinitionCharacterizationComponent: SubstanceDefinitionCharacterizationComponent,
	offsets: offsets,
	_orderedBy: _orderedBy,
	_authorizationUrl: _authorizationUrl,
	_carrierAIDC: _carrierAIDC,
	_episodeOfCare: _episodeOfCare,
	disabledDisplay: disabledDisplay,
	DocumentReference: DocumentReference,
	compositeScoring: compositeScoring,
	_yearInterval: _yearInterval,
	RelatedPersonCommunicationComponent: RelatedPersonCommunicationComponent,
	_displayName: _displayName,
	_monday: _monday,
	messaging: messaging,
	geneElement: geneElement,
	exclude: exclude,
	_itemSequence: _itemSequence,
	_artifactAssessment: _artifactAssessment,
	dispenseRequest: dispenseRequest,
	intendedJurisdiction: intendedJurisdiction,
	_restriction: _restriction,
	ImmunizationEvaluation: ImmunizationEvaluation,
	Observation: Observation,
	_supplier: _supplier,
	NutritionIntakePerformerComponent: NutritionIntakePerformerComponent,
	CapabilityStatementRestComponentSearchParam: CapabilityStatementRestComponentSearchParam,
	_SubstanceReferenceInformation: _SubstanceReferenceInformation,
	_CarePlan: _CarePlan,
	AdverseEventPreventiveActionComponent: AdverseEventPreventiveActionComponent,
	outsideFoodAllowed: outsideFoodAllowed,
	_maxVolumeToDeliver: _maxVolumeToDeliver,
	InventoryItemAssociationComponent: InventoryItemAssociationComponent,
	deliverFor: deliverFor,
	ElementDefinitionExampleComponent: ElementDefinitionExampleComponent,
	_totalPriceComponent: _totalPriceComponent,
	_carrierHRF: _carrierHRF,
	_subProperty: _subProperty,
	allowed: allowed,
	_searchType: _searchType,
	List: List,
	responseId: responseId,
	_defaultManualCompletion: _defaultManualCompletion,
	_subscriberId: _subscriberId,
	_groupingId: _groupingId,
	_protocolPerformed: _protocolPerformed,
	subPotentReason: subPotentReason,
	maxValue: maxValue,
	_data: _data,
	_disulfideLinkage: _disulfideLinkage,
	metadata: metadata,
	ConditionParticipantComponent: ConditionParticipantComponent,
	rationale: rationale,
	tax: tax,
	_line: _line,
	index: index,
	_firstPage: _firstPage,
	verifiedBy: verifiedBy,
	_requestProvider: _requestProvider,
	Diagnosis: Diagnosis,
	_hybridType: _hybridType,
	_abnormalCodedValueSet: _abnormalCodedValueSet,
	Encounter: Encounter,
	expression: expression,
	_current: _current,
	BackboneType: BackboneType,
	collection: collection,
	_family: _family,
	_validated: _validated,
	question: question,
	_noMap: _noMap,
	_comparisonGroup: _comparisonGroup,
	EnrollmentRequest: EnrollmentRequest,
	_surfaceOrientation: _surfaceOrientation,
	prescription: prescription,
	_contributorship: _contributorship,
	synthesisType: synthesisType,
	_anchor: _anchor,
	_suppress: _suppress,
	_other: _other,
	variable: variable,
	MolecularSequenceRelativeComponent: MolecularSequenceRelativeComponent,
	Ingredient: Ingredient,
	_occurrenceDateTime: _occurrenceDateTime,
	Annotation: Annotation,
	SubstanceReferenceInformationGeneComponent: SubstanceReferenceInformationGeneComponent,
	_valueQuantity: _valueQuantity,
	DeviceDefinitionCorrectiveActionComponent: DeviceDefinitionCorrectiveActionComponent,
	OperationDefinitionParameterComponent: OperationDefinitionParameterComponent,
	EvidenceVariableCharacteristicDefinitionByCombinationComponent: EvidenceVariableCharacteristicDefinitionByCombinationComponent,
	SpecimenDefinitionTypeTestedHandlingComponent: SpecimenDefinitionTypeTestedHandlingComponent,
	_testRun: _testRun,
	compareToSourceId: compareToSourceId,
	_definitional: _definitional,
	_testCase: _testCase,
	_PaymentReconciliation: _PaymentReconciliation,
	valuedItem: valuedItem,
	relatedItem: relatedItem,
	consumedItem: consumedItem,
	search: search,
	duration: duration,
	status: status,
	_context: _context,
	_requirements: _requirements,
	_subjectType: _subjectType,
	_use: _use,
	udi: udi,
	nameType: nameType,
	_producedFrom: _producedFrom,
	_interval: _interval,
	summary: summary,
	MedicinalProductDefinitionCharacteristicComponent: MedicinalProductDefinitionCharacteristicComponent,
	sex: sex,
	AdministrableProductDefinition: AdministrableProductDefinition,
	SecurityLabel: SecurityLabel,
	SubstanceDefinitionRelationshipComponent: SubstanceDefinitionRelationshipComponent,
	knownAllergen: knownAllergen,
	knownDataCount: knownDataCount,
	observer: observer,
	_subtitle: _subtitle,
	accessionNumber: accessionNumber,
	_finding: _finding,
	_style: _style,
	relation: relation,
	priority: priority,
	_requestId: _requestId,
	ElementDefinitionBindingComponent: ElementDefinitionBindingComponent,
	sequenceAttachment: sequenceAttachment,
	AddedItemBodySite: AddedItemBodySite,
	_group: _group,
	publisher: publisher,
	consent: consent,
	site: site,
	canFilterBy: canFilterBy,
	TerminologyCapabilitiesValidateCodeComponent: TerminologyCapabilitiesValidateCodeComponent,
	_isSubPotent: _isSubPotent,
	EncounterParticipantComponent: EncounterParticipantComponent,
	_cancellationReason: _cancellationReason,
	_repetitions: _repetitions,
	TestPlanTestCaseTestRunScriptComponent: TestPlanTestCaseTestRunScriptComponent,
	distributor: distributor,
	_stopTestOnFail: _stopTestOnFail,
	organizationReference: organizationReference,
	residueSite: residueSite,
	guidance: guidance,
	_originatingAppointment: _originatingAppointment,
	intended: intended,
	_measurementFrequency: _measurementFrequency,
	_variableRole: _variableRole,
	assurance: assurance,
	literal: literal,
	_suppliedItem: _suppliedItem,
	ProcedurePerformerComponent: ProcedurePerformerComponent,
	baseUnit: baseUnit,
	_translation: _translation,
	StructureDefinitionSnapshotComponent: StructureDefinitionSnapshotComponent,
	_name: _name,
	MedicationRequestDispenseRequestInitialFillComponent: MedicationRequestDispenseRequestInitialFillComponent,
	_incidence: _incidence,
	_during: _during,
	_snapshot: _snapshot,
	SubstancePolymerRepeatRepeatUnitComponent: SubstancePolymerRepeatRepeatUnitComponent,
	_format: _format,
	PlanBenefit: PlanBenefit,
	_foodPreferenceModifier: _foodPreferenceModifier,
	function__workaround: function__workaround,
	environmentType: environmentType,
	SubscriptionTopicCanFilterByComponent: SubscriptionTopicCanFilterByComponent,
	occurrenceCount: occurrenceCount,
	careTeamSequence: careTeamSequence,
	_notConsumedReason: _notConsumedReason,
	_restoreDate: _restoreDate,
	providedBy: providedBy,
	meta: meta,
	_subDetailSequence: _subDetailSequence,
	required: required,
	_dateWritten: _dateWritten,
	_deviceIdentifier: _deviceIdentifier,
	referral: referral,
	_conditionality: _conditionality,
	AuditEventSourceComponent: AuditEventSourceComponent,
	_component: _component,
	link: link,
	_hasStage: _hasStage,
	_contentReference: _contentReference,
	program: program,
	OtherElement: OtherElement,
	scoringUnit: scoringUnit,
	_maxCount: _maxCount,
	ExplanationOfBenefitEventComponent: ExplanationOfBenefitEventComponent,
	_ArtifactAssessment: _ArtifactAssessment,
	scope: scope,
	inventoryListing: inventoryListing,
	concentration: concentration,
	_device: _device,
	hierarchyMeaning: hierarchyMeaning,
	CapabilityStatementRestComponentOperation: CapabilityStatementRestComponentOperation,
	otherMap: otherMap,
	answerConstraint: answerConstraint,
	normalCodedValueSet: normalCodedValueSet,
	global: global,
	excludingRecurrenceId: excludingRecurrenceId,
	_SubstanceSourceMaterial: _SubstanceSourceMaterial,
	validity: validity,
	subjectReport: subjectReport,
	_any: _any,
	_nextScheduled: _nextScheduled,
	administration: administration,
	sort: sort,
	ManufacturedItemDefinitionComponentComponentProperty: ManufacturedItemDefinitionComponentComponentProperty,
	_sent: _sent,
	_directnessMatch: _directnessMatch,
	_targetFormat: _targetFormat,
	_used: _used,
	_occurence: _occurence,
	_partOf: _partOf,
	relativeRisk: relativeRisk,
	supportedMessage: supportedMessage,
	_dateOfDiagnosis: _dateOfDiagnosis,
	_seriesNumber: _seriesNumber,
	DataRequirementSortComponent: DataRequirementSortComponent,
	ChargeItemDefinitionPropertyGroupComponentApplicability: ChargeItemDefinitionPropertyGroupComponentApplicability,
	codeSystem: codeSystem,
	processing: processing,
	_ResearchSubject: _ResearchSubject,
	_heartbeatPeriod: _heartbeatPeriod,
	ValueSetExpansionPropertyComponent: ValueSetExpansionPropertyComponent,
	orderDetail: orderDetail,
	Group: Group,
	statusDate: statusDate,
	uri: uri,
	max: max,
	_conformance: _conformance,
	_unitPriceComponent: _unitPriceComponent,
	_availabilityStatus: _availabilityStatus,
	_exitCriteria: _exitCriteria,
	Schedule: Schedule,
	BiologicallyDerivedProductCollectionComponent: BiologicallyDerivedProductCollectionComponent,
	DomainResource: DomainResource,
	_AdverseEvent: _AdverseEvent,
	focalDevice: focalDevice,
	_authorType: _authorType,
	mode: mode,
	observation: observation,
	_issuer: _issuer,
	ClaimEventComponent: ClaimEventComponent,
	FamilyMemberHistoryParticipantComponent: FamilyMemberHistoryParticipantComponent,
	_validationStatus: _validationStatus,
	string: string,
	productCode: productCode,
	receiver: receiver,
	CitationCitedArtifactTitleComponent: CitationCitedArtifactTitleComponent,
	totalGross: totalGross,
	_outputProfile: _outputProfile,
	conditionalDelete: conditionalDelete,
	baseDefinition: baseDefinition,
	NutritionProductInstanceComponent: NutritionProductInstanceComponent,
	ClinicalUseDefinitionIndicationComponent: ClinicalUseDefinitionIndicationComponent,
	relevantHistory: relevantHistory,
	referenceInformation: referenceInformation,
	valueSet: valueSet,
	library: library,
	InventoryReportInventoryListingItemComponent: InventoryReportInventoryListingItemComponent,
	performedActivity: performedActivity,
	Coverage: Coverage,
	probability: probability,
	TerminologyCapabilitiesSoftwareComponent: TerminologyCapabilitiesSoftwareComponent,
	_activity: _activity,
	prediction: prediction,
	_mimeType: _mimeType,
	exception: exception,
	ImplementationGuideDefinitionTemplateComponent: ImplementationGuideDefinitionTemplateComponent,
	_edit: _edit,
	_usage: _usage,
	proposedNewTime: proposedNewTime,
	security: security,
	_parameter: _parameter,
	InventoryItemDescriptionComponent: InventoryItemDescriptionComponent,
	ConditionDefinitionPreconditionComponent: ConditionDefinitionPreconditionComponent,
	LocationPositionComponent: LocationPositionComponent,
	sequenceRange: sequenceRange,
	policyBasis: policyBasis,
	_inputParameters: _inputParameters,
	_dateRange: _dateRange,
	_cost: _cost,
	Timing: Timing,
	_team: _team,
	_paternalOrganismId: _paternalOrganismId,
	_statusChanged: _statusChanged,
	ActivityDefinitionDynamicValueComponent: ActivityDefinitionDynamicValueComponent,
	processor: processor,
	_constraint: _constraint,
	_sampleSize: _sampleSize,
	ClinicalUseDefinitionContraindicationComponent: ClinicalUseDefinitionContraindicationComponent,
	_comorbidity: _comorbidity,
	_knownDataCount: _knownDataCount,
	template: template,
	codeFilter: codeFilter,
	dateAccessed: dateAccessed,
	_organization: _organization,
	_ifModifiedSince: _ifModifiedSince,
	_lastRevisionDate: _lastRevisionDate,
	_strength: _strength,
	numerator: numerator,
	_altitude: _altitude,
	_countingDateTime: _countingDateTime,
	MedicationDispense: MedicationDispense,
	_maxDuration: _maxDuration,
	requirement: requirement,
	SubstanceProteinSubunitComponent: SubstanceProteinSubunitComponent,
	_abatement: _abatement,
	reportingPeriod: reportingPeriod,
	dosage: dosage,
	_supplement: _supplement,
	_treatmentIntent: _treatmentIntent,
	performingOrganization: performingOrganization,
	_what: _what,
	intervalUnit: intervalUnit,
	preAuthPeriod: preAuthPeriod,
	fhirPathCriteria: fhirPathCriteria,
	administeredBy: administeredBy,
	factor: factor,
	ContactPoint: ContactPoint,
	appointmentType: appointmentType,
	_collector: _collector,
	answerValueSet: answerValueSet,
	_achievementStatus: _achievementStatus,
	carrierHRF: carrierHRF,
	_evaluatedResource: _evaluatedResource,
	signer: signer,
	_usageReason: _usageReason,
	variableDefinition: variableDefinition,
	manifestation: manifestation,
	searchType: searchType,
	PaymentReconciliation: PaymentReconciliation,
	_modelNumber: _modelNumber,
	groupingId: groupingId,
	_VisionPrescription: _VisionPrescription,
	performerLinkId: performerLinkId,
	procedure: procedure,
	implicitRules: implicitRules,
	query: query,
	Items: Items,
	_slot: _slot,
	_conditionalCreate: _conditionalCreate,
	PatientCommunicationComponent: PatientCommunicationComponent,
	ConditionDefinitionMedicationComponent: ConditionDefinitionMedicationComponent,
	documentation: documentation,
	maxDosePerTreatmentPeriod: maxDosePerTreatmentPeriod,
	example: example,
	_sessionKey: _sessionKey,
	lastPage: lastPage,
	hybridType: hybridType,
	field: field,
	maxDosePerPeriod: maxDosePerPeriod,
	_excludedStructure: _excludedStructure,
	_script: _script,
	acceptLanguage: acceptLanguage,
	practiceSetting: practiceSetting,
	brand: brand,
	_attributeEstimate: _attributeEstimate,
	_end: _end,
	diagnosisSequence: diagnosisSequence,
	_specification: _specification,
	_test: _test,
	_durationMax: _durationMax,
	impurity: impurity,
	_Practitioner: _Practitioner,
	SubstanceIngredientComponent: SubstanceIngredientComponent,
	control: control,
	_enterer: _enterer,
	TransportOutputComponent: TransportOutputComponent,
	_retentionTime: _retentionTime,
	_encodeRequestUrl: _encodeRequestUrl,
	countMax: countMax,
	_netContent: _netContent,
	AccountBalanceComponent: AccountBalanceComponent,
	_sequenceAttachment: _sequenceAttachment,
	requestedLocation: requestedLocation,
	DeviceDefinitionRegulatoryIdentifierComponent: DeviceDefinitionRegulatoryIdentifierComponent,
	_target: _target,
	_implicated: _implicated,
	_administration: _administration,
	_flag: _flag,
	_party: _party,
	_version: _version,
	provision: provision,
	patientPaid: patientPaid,
	referenceNumber: referenceNumber,
	manifest: manifest,
	Account: Account,
	_goal: _goal,
	_basis: _basis,
	MessageSource: MessageSource,
	_formCode: _formCode,
	_disclaimer: _disclaimer,
	_definitionByCombination: _definitionByCombination,
	step: step,
	fractionDescription: fractionDescription,
	valueCategory: valueCategory,
	requestMethod: requestMethod,
	BodySite: BodySite,
	etag: etag,
	specimenQuantity: specimenQuantity,
	comprisedOf: comprisedOf,
	_pediatricUseIndicator: _pediatricUseIndicator,
	_destination: _destination,
	_evaluationMessage: _evaluationMessage,
	ResearchStudyComparisonGroupComponent: ResearchStudyComparisonGroupComponent,
	_DomainResource: _DomainResource,
	CitationCitedArtifactWebLocationComponent: CitationCitedArtifactWebLocationComponent,
	beneficiary: beneficiary,
	prefix: prefix,
	effectiveTime: effectiveTime,
	RegulatedAuthorizationCaseComponent: RegulatedAuthorizationCaseComponent,
	AccountProcedureComponent: AccountProcedureComponent,
	doseStatusReason: doseStatusReason,
	ResearchStudyAssociatedPartyComponent: ResearchStudyAssociatedPartyComponent,
	reason: reason,
	_precondition: _precondition,
	criteria: criteria,
	MedicationAdministrationDosageComponent: MedicationAdministrationDosageComponent,
	latitude: latitude,
	IngredientSubstanceStrengthReferenceStrengthComponent: IngredientSubstanceStrengthReferenceStrengthComponent,
	_thursday: _thursday,
	securityContext: securityContext,
	_baseDefinition: _baseDefinition,
	_publicationStatus: _publicationStatus,
	relatedArtifact: relatedArtifact,
	safety: safety,
	stereochemistry: stereochemistry,
	_timeout: _timeout,
	primarySource: primarySource,
	NutritionOrderOralDietNutrientComponent: NutritionOrderOralDietNutrientComponent,
	responseCode: responseCode,
	eventHistory: eventHistory,
	_doseForm: _doseForm,
	_allowedResponse: _allowedResponse,
	_storageGuideline: _storageGuideline,
	timezone: timezone,
	copolymerConnectivity: copolymerConnectivity,
	GenomicStudyAnalysisOutputComponent: GenomicStudyAnalysisOutputComponent,
	_molecularWeight: _molecularWeight,
	ObservationDefinition: ObservationDefinition,
	ifNoneMatch: ifNoneMatch,
	_notConsumed: _notConsumed,
	grade: grade,
	OralDietSchedule: OralDietSchedule,
	_diagnosis: _diagnosis,
	_channelType: _channelType,
	_encounter: _encounter,
	SubstancePolymerMonomerSetStartingMaterialComponent: SubstancePolymerMonomerSetStartingMaterialComponent,
	statisticType: statisticType,
	_webLocation: _webLocation,
	SubstanceSourceMaterialOrganismOrganismGeneralComponent: SubstanceSourceMaterialOrganismOrganismGeneralComponent,
	textConcentration: textConcentration,
	_multipleAnd: _multipleAnd,
	_freeToShare: _freeToShare,
	_contributionInstance: _contributionInstance,
	MedicationStatementAdherenceComponent: MedicationStatementAdherenceComponent,
	_onAdmission: _onAdmission,
	output: output,
	_indication: _indication,
	DeviceDefinitionChargeItemComponent: DeviceDefinitionChargeItemComponent,
	location: location,
	generalCost: generalCost,
	_plannedActivityReference: _plannedActivityReference,
	rules: rules,
	reported: reported,
	maxDosePerDay: maxDosePerDay,
	NutritionOrderOralDietTextureComponent: NutritionOrderOralDietTextureComponent,
	_definitionByTypeAndValue: _definitionByTypeAndValue,
	GroupMemberComponent: GroupMemberComponent,
	_verificationType: _verificationType,
	_supportingInformation: _supportingInformation,
	kingdom: kingdom,
	sourceMaterialClass: sourceMaterialClass,
	_polymer: _polymer,
	insurance: insurance,
	_handling: _handling,
	supportingInfo: supportingInfo,
	lifecycleStatus: lifecycleStatus,
	_symptomConditionEffect: _symptomConditionEffect,
	_fraction: _fraction,
	language: language,
	combining: combining,
	country: country,
	isExample: isExample,
	_readHistory: _readHistory,
	BundleLinkComponent: BundleLinkComponent,
	currentLocation: currentLocation,
	official: official,
	_EncounterHistory: _EncounterHistory,
	EvidenceVariableCategoryComponent: EvidenceVariableCategoryComponent,
	_administeredBy: _administeredBy,
	_ProductShelfLife: _ProductShelfLife,
	SubstanceDefinitionMolecularWeightComponent: SubstanceDefinitionMolecularWeightComponent,
	affectsState: affectsState,
	notificationShape: notificationShape,
	descriptionSummary: descriptionSummary,
	_answerValueSet: _answerValueSet,
	PractitionerRole: PractitionerRole,
	_rationale: _rationale,
	_ChargeItem: _ChargeItem,
	_offer: _offer,
	OperationDefinitionParameterReferencedFromComponent: OperationDefinitionParameterReferencedFromComponent,
	singleUse: singleUse,
	_exclude: _exclude,
	fhirVersion: fhirVersion,
	_nucleicAcid: _nucleicAcid,
	CodeableConcept: CodeableConcept,
	_Claim: _Claim,
	_site: _site,
	targetScope: targetScope,
	_monthInterval: _monthInterval,
	_monitoringProgram: _monitoringProgram,
	mustHaveValue: mustHaveValue,
	_interpreter: _interpreter,
	SubscriptionStatus: SubscriptionStatus,
	_productOrServiceEnd: _productOrServiceEnd,
	doseQuantity: doseQuantity,
	_prism: _prism,
	highNumerator: highNumerator,
	contentDefinition: contentDefinition,
	due: due,
	structureProfile: structureProfile,
	_acceptLanguage: _acceptLanguage,
	_RegulatedAuthorization: _RegulatedAuthorization,
	authorType: authorType,
	paymentIssuer: paymentIssuer,
	clinicalTrial: clinicalTrial,
	_parentSubstanceName: _parentSubstanceName,
	_high: _high,
	actorId: actorId,
	_document: _document,
	_marketPeriod: _marketPeriod,
	_denominator: _denominator,
	accessionIdentifier: accessionIdentifier,
	VerificationResultPrimarySourceComponent: VerificationResultPrimarySourceComponent,
	authored: authored,
	serialNumber: serialNumber,
	Consent: Consent,
	_resourceType: _resourceType,
	outcomeMeasure: outcomeMeasure,
	purpose: purpose,
	DiagnosticReportSupportingInfoComponent: DiagnosticReportSupportingInfoComponent,
	Citation: Citation,
	_serviced: _serviced,
	performer: performer,
	_stratifier: _stratifier,
	InvoiceParticipantComponent: InvoiceParticipantComponent,
	requiredBehavior: requiredBehavior,
	_oralDiet: _oralDiet,
	monday: monday,
	MedicationRequestDispenseRequestComponent: MedicationRequestDispenseRequestComponent,
	_subJurisdiction: _subJurisdiction,
	_interactant: _interactant,
	_admitSource: _admitSource,
	TargetElement: TargetElement,
	_given: _given,
	_recorder: _recorder,
	hasPart: hasPart,
	_cancellationDate: _cancellationDate,
	supplements: supplements,
	constraint: constraint,
	total: total,
	outcome: outcome,
	sampleSize: sampleSize,
	ContributorshipSummary: ContributorshipSummary,
	PrimitiveType: PrimitiveType,
	caloricDensity: caloricDensity,
	MedicationKnowledgeStorageGuidelineEnvironmentalSettingComponent: MedicationKnowledgeStorageGuidelineEnvironmentalSettingComponent,
	_clinicalUseIssue: _clinicalUseIssue,
	LinkageItemComponent: LinkageItemComponent,
	AdministrableProductDefinitionRouteOfAdministrationComponent: AdministrableProductDefinitionRouteOfAdministrationComponent,
	_conditionalUpdate: _conditionalUpdate,
	_publisher: _publisher,
	MolecularSequenceRelativeStartingSequenceComponent: MolecularSequenceRelativeStartingSequenceComponent,
	_validator: _validator,
	_inactive: _inactive,
	AppointmentResponse: AppointmentResponse,
	_molecularFormula: _molecularFormula,
	payload: payload,
	subSite: subSite,
	_sort: _sort,
	TestScriptOriginComponent: TestScriptOriginComponent,
	_allergyIntolerance: _allergyIntolerance,
	_identityCertificate: _identityCertificate,
	_additional: _additional,
	_assurance: _assurance,
	_careManager: _careManager,
	ImageRegion2D: ImageRegion2D,
	forecastReason: forecastReason,
	supplement: supplement,
	_nutrient: _nutrient,
	_sugar: _sugar,
	entryReference: entryReference,
	_citedMedium: _citedMedium,
	MeasureSupplementalDataComponent: MeasureSupplementalDataComponent,
	input: input,
	ManufacturedItemDefinition: ManufacturedItemDefinition,
	Prism: Prism,
	GroupCharacteristicComponent: GroupCharacteristicComponent,
	_qualifier: _qualifier,
	GraphDefinition: GraphDefinition,
	_BiologicallyDerivedProduct: _BiologicallyDerivedProduct,
	_Procedure: _Procedure,
	_receivedTime: _receivedTime,
	quantity: quantity,
	_linkId: _linkId,
	ManufacturedItemDefinitionComponentComponentComponentComponent: ManufacturedItemDefinitionComponentComponentComponentComponent,
	_prescriber: _prescriber,
	EvidenceReportSubjectCharacteristicComponent: EvidenceReportSubjectCharacteristicComponent,
	hasSeverity: hasSeverity,
	_estimate: _estimate,
	certainty: certainty,
	_billingStatus: _billingStatus,
	ContactDetail: ContactDetail,
	sessionKey: sessionKey,
	calibration: calibration,
	_literal: _literal,
	ConditionDefinitionQuestionnaireComponent: ConditionDefinitionQuestionnaireComponent,
	_dateTime: _dateTime,
	CoverageEligibilityRequest: CoverageEligibilityRequest,
	_repeatUnitAmountType: _repeatUnitAmountType,
	pediatricUseIndicator: pediatricUseIndicator,
	SampledData: SampledData,
	attester: attester,
	originatingAppointment: originatingAppointment,
	progress: progress,
	_frequencyMax: _frequencyMax,
	measureScore: measureScore,
	InsurancePlanCoverageComponent: InsurancePlanCoverageComponent,
	Evidence: Evidence,
	_operationalStatus: _operationalStatus,
	ImagingSelectionPerformerComponent: ImagingSelectionPerformerComponent,
	restriction: restriction,
	_issues: _issues,
	dose: dose,
	_updateCreate: _updateCreate,
	_supportingInfo: _supportingInfo,
	warningOnly: warningOnly,
	_coverage: _coverage,
	informationSequence: informationSequence,
	netContent: netContent,
	representation: representation,
	_typeMode: _typeMode,
	subProperty: subProperty,
	_subscription: _subscription,
	Library: Library,
	DeviceMetricCalibrationComponent: DeviceMetricCalibrationComponent,
	implicated: implicated,
	_actualGroup: _actualGroup,
	_SubstanceProtein: _SubstanceProtein,
	_capabilities: _capabilities,
	_associatedParty: _associatedParty,
	_supplementalData: _supplementalData,
	_program: _program,
	offeredIn: offeredIn,
	TerminologyCapabilitiesCodeSystemComponent: TerminologyCapabilitiesCodeSystemComponent,
	multipleBirth: multipleBirth,
	_replacedSequence: _replacedSequence,
	disclaimer: disclaimer,
	InsurancePlan: InsurancePlan,
	_installDate: _installDate,
	_extends: _extends,
	fundsReserve: fundsReserve,
	assigner: assigner,
	SpecimenProcessingComponent: SpecimenProcessingComponent,
	occurred: occurred,
	_lockedDate: _lockedDate,
	GenomicStudyAnalysisPerformerComponent: GenomicStudyAnalysisPerformerComponent,
	_lowNumerator: _lowNumerator,
	_classifier: _classifier,
	resultsInterpreter: resultsInterpreter,
	_limit: _limit,
	_serviceProvider: _serviceProvider,
	patientInstruction: patientInstruction,
	binding: binding,
	recurrenceType: recurrenceType,
	during: during,
	capability: capability,
	Substance: Substance,
	suspectEntity: suspectEntity,
	QuestionnaireItemInitialComponent: QuestionnaireItemInitialComponent,
	occurrenceDate: occurrenceDate,
	monthlyTemplate: monthlyTemplate,
	supportingInformation: supportingInformation,
	authorizationRequired: authorizationRequired,
	_versionReference: _versionReference,
	ImmunizationRecommendationRecommendationComponent: ImmunizationRecommendationRecommendationComponent,
	_measurementPoint: _measurementPoint,
	batch: batch,
	_include: _include,
	ValueSetComposeIncludeFilterComponent: ValueSetComposeIncludeFilterComponent,
	subcomponent: subcomponent,
	_DetectedIssue: _DetectedIssue,
	_GuidanceResponse: _GuidanceResponse,
	_participantType: _participantType,
	_division: _division,
	_section: _section,
	_MedicationAdministration: _MedicationAdministration,
	_outcomeMeasure: _outcomeMeasure,
	PackagingDistributor: PackagingDistributor,
	_serviceType: _serviceType,
	_subjectReport: _subjectReport,
	_initialFill: _initialFill,
	_administrableDoseForm: _administrableDoseForm,
	areaOfHybridisation: areaOfHybridisation,
	subjectType: subjectType,
	device: device,
	AddedItem: AddedItem,
	_region: _region,
	MedicationKnowledgeRegulatorySubstitutionComponent: MedicationKnowledgeRegulatorySubstitutionComponent,
	MeasureReportGroupComponent: MeasureReportGroupComponent,
	_accident: _accident,
	endRelationship: endRelationship,
	structure: structure,
	_library: _library,
	_descriptionSummary: _descriptionSummary,
	baseCitation: baseCitation,
	definitionId: definitionId,
	_coordinateSystem: _coordinateSystem,
	characteristicType: characteristicType,
	_entry: _entry,
	imageRegion2D: imageRegion2D,
	_DeviceDefinition: _DeviceDefinition,
	conclusionCode: conclusionCode,
	BiologicallyDerivedProductDispensePerformerComponent: BiologicallyDerivedProductDispensePerformerComponent,
	_caloricDensity: _caloricDensity,
	ManufacturedItemDefinitionComponentComponent: ManufacturedItemDefinitionComponentComponent,
	_focal: _focal,
	indication: indication,
	_AllergyIntolerance: _AllergyIntolerance,
	_publishedIn: _publishedIn,
	partOf: partOf,
	_initialSelected: _initialSelected,
	_key: _key,
	backCurve: backCurve,
	_path: _path,
	definitionUri: definitionUri,
	ExplanationOfBenefitItemReviewOutcomeComponent: ExplanationOfBenefitItemReviewOutcomeComponent,
	DetectedIssueMitigationComponent: DetectedIssueMitigationComponent,
	_lastOccurrenceDate: _lastOccurrenceDate,
	_enableWhen: _enableWhen,
	time: time,
	MedicinalProductDefinitionNameUsageComponent: MedicinalProductDefinitionNameUsageComponent,
	ChargeItemDefinitionApplicabilityComponent: ChargeItemDefinitionApplicabilityComponent,
	InventoryItemCharacteristicComponent: InventoryItemCharacteristicComponent,
	_dischargeDisposition: _dischargeDisposition,
	isModifierReason: isModifierReason,
	StructureDefinitionContextComponent: StructureDefinitionContextComponent,
	_forecastReason: _forecastReason,
	SubstanceDefinitionMoietyComponent: SubstanceDefinitionMoietyComponent,
	_step: _step,
	rest: rest,
	issuer: issuer,
	_nutritionProduct: _nutritionProduct,
	SubstancePolymer: SubstancePolymer,
	ValueSetComposeComponent: ValueSetComposeComponent,
	_doseNumber: _doseNumber,
	SubstanceDefinitionNameComponent: SubstanceDefinitionNameComponent,
	derivedFromUri: derivedFromUri,
	_startParam: _startParam,
	_attribute: _attribute,
	_extraDetails: _extraDetails,
	_accessionIdentifier: _accessionIdentifier,
	_entryReference: _entryReference,
	Parameters: Parameters,
	ChargeItem: ChargeItem,
	_uid: _uid,
	chain: chain,
	_bodySite: _bodySite,
	qualification: qualification,
	yearInterval: yearInterval,
	_developmentStage: _developmentStage,
	riskAdjustment: riskAdjustment,
	_estimatedAge: _estimatedAge,
	RequirementsStatementComponent: RequirementsStatementComponent,
	_intendedRoute: _intendedRoute,
	score: score,
	DeviceRequestParameterComponent: DeviceRequestParameterComponent,
	_diseaseSymptomProcedure: _diseaseSymptomProcedure,
	_validationProcess: _validationProcess,
	ExampleScenarioProcessComponent: ExampleScenarioProcessComponent,
	_timestamp: _timestamp,
	supportedProfile: supportedProfile,
	TestReportSetupActionAssertComponent: TestReportSetupActionAssertComponent,
	_label: _label,
	_preparationInstruction: _preparationInstruction,
	InventoryItemResponsibleOrganizationComponent: InventoryItemResponsibleOrganizationComponent,
	informationType: informationType,
	BodyStructureIncludedStructure: BodyStructureIncludedStructure,
	_requesterLinkId: _requesterLinkId,
	PlanDefinition: PlanDefinition,
	postConditions: postConditions,
	EvidenceVariableDefinitionComponent: EvidenceVariableDefinitionComponent,
	_meaningWhenMissing: _meaningWhenMissing,
	DeviceDispense: DeviceDispense,
	_modelCharacteristic: _modelCharacteristic,
	SetupAction: SetupAction,
	_studyDesign: _studyDesign,
	_analysis: _analysis,
	insurancePlan: insurancePlan,
	communicationRequest: communicationRequest,
	specialty: specialty,
	_artifact: _artifact,
	chargeItemCode: chargeItemCode,
	actuality: actuality,
	_maxParticipants: _maxParticipants,
	_Basic: _Basic,
	_example: _example,
	_representation: _representation,
	telecom: telecom,
	EvidenceCertaintyComponentCertaintyCertainty: EvidenceCertaintyComponentCertaintyCertainty,
	_lastPerformed: _lastPerformed,
	_legalState: _legalState,
	_preAuthPeriod: _preAuthPeriod,
	GraphDefinitionLinkComponent: GraphDefinitionLinkComponent,
	workflow: workflow,
	_incomplete: _incomplete,
	_sphere: _sphere,
	_substanceDefinition: _substanceDefinition,
	informationSource: informationSource,
	_periodUnit: _periodUnit,
	paymentIdentifier: paymentIdentifier,
	stratifier: stratifier,
	pause: pause,
	_isActive: _isActive,
	_synonym: _synonym,
	_manifestation: _manifestation,
	_control: _control,
	RegulatedAuthorizationCaseComponentCase: RegulatedAuthorizationCaseComponentCase,
	dosageInstruction: dosageInstruction,
	_implicitRules: _implicitRules,
	AvailabilityAvailableTimeComponent: AvailabilityAvailableTimeComponent,
	SpecimenCollectionComponent: SpecimenCollectionComponent,
	regulatoryAuthority: regulatoryAuthority,
	_EnrollmentRequest: _EnrollmentRequest,
	hash: hash,
	marketDistribution: marketDistribution,
	countType: countType,
	_documentation: _documentation,
	association: association,
	_intendedJurisdiction: _intendedJurisdiction,
	_recurrenceType: _recurrenceType,
	when: when,
	form: form,
	_complete: _complete,
	_shortDoco: _shortDoco,
	differential: differential,
	_occurrenceDate: _occurrenceDate,
	additional: additional,
	canonical: canonical,
	_actualComparisonGroup: _actualComparisonGroup,
	_requestor: _requestor,
	CommunicationPayloadComponent: CommunicationPayloadComponent,
	AccountDiagnosisComponent: AccountDiagnosisComponent,
	_doseStatus: _doseStatus,
	TestScriptTestComponent: TestScriptTestComponent,
	TaskOutputComponent: TaskOutputComponent,
	MeasureReport: MeasureReport,
	producedFrom: producedFrom,
	tuesday: tuesday,
	_sourceReference: _sourceReference,
	crossReference: crossReference,
	_Composition: _Composition,
	subdetailSequence: subdetailSequence,
	_definitionReference: _definitionReference,
	supplier: supplier,
	inputPopulationId: inputPopulationId,
	CarePlan: CarePlan,
	clinicalStatus: clinicalStatus,
	measurementType: measurementType,
	ImplementationGuideDefinitionGroupingComponent: ImplementationGuideDefinitionGroupingComponent,
	_fundingSource: _fundingSource,
	_immunizationEvent: _immunizationEvent,
	ClaimResponseEventComponent: ClaimResponseEventComponent,
	statement: statement,
	ImageRegion3D: ImageRegion3D,
	_item: _item,
	_repeatUnit: _repeatUnit,
	startingMaterial: startingMaterial,
	_temperatureQualifier: _temperatureQualifier,
	dosingGuideline: dosingGuideline,
	_serviceCategory: _serviceCategory,
	_rate: _rate,
	_filterDefinition: _filterDefinition,
	prescriber: prescriber,
	oid: oid,
	_attachment: _attachment,
	_sourceAttachment: _sourceAttachment,
	_materialType: _materialType,
	target: target,
	_valueCategory: _valueCategory,
	_requestMethod: _requestMethod,
	linkage: linkage,
	DeviceUdiCarrierComponent: DeviceUdiCarrierComponent,
	TerminologyCapabilitiesClosureComponent: TerminologyCapabilitiesClosureComponent,
	_conclusionCode: _conclusionCode,
	_div: _div,
	processingMode: processingMode,
	_rule: _rule,
	StructureMap: StructureMap,
	_molecularFormulaByMoiety: _molecularFormulaByMoiety,
	firstDose: firstDose,
	BundleEntryResponseComponent: BundleEntryResponseComponent,
	structureVersion: structureVersion,
	alias: alias,
	_programCode: _programCode,
	_resultForDelete: _resultForDelete,
	grantee: grantee,
	_effectiveTime: _effectiveTime,
	definitionCodeableConcept: definitionCodeableConcept,
	Property: Property,
	entryClassifier: entryClassifier,
	_combining: _combining,
	paternalOrganismName: paternalOrganismName,
	_asset: _asset,
	PaymentReconciliationAllocationComponent: PaymentReconciliationAllocationComponent,
	_part: _part,
	actor: actor,
	_isExample: _isExample,
	navigationLinks: navigationLinks,
	availability: availability,
	_specimen: _specimen,
	term: term,
	notAvailableTime: notAvailableTime,
	specimenRequirement: specimenRequirement,
	answer: answer,
	_citation: _citation,
	patient: patient,
	suppress: suppress,
	additionalUse: additionalUse,
	_maxDosePerLifetime: _maxDosePerLifetime,
	Distance: Distance,
	_primarySource: _primarySource,
	_opticalActivity: _opticalActivity,
	_multipleOr: _multipleOr,
	_specialMeasures: _specialMeasures,
	usageReason: usageReason,
	GoalTargetComponent: GoalTargetComponent,
	measure: measure,
	contributionType: contributionType,
	modelNumber: modelNumber,
	_derivedFromUri: _derivedFromUri,
	_method: _method,
	effectiveDate: effectiveDate,
	_servicePeriod: _servicePeriod,
	asNeededFor: asNeededFor,
	ExplanationOfBenefit: ExplanationOfBenefit,
	_add: _add,
	_cancelledReason: _cancelledReason,
	orderMeaning: orderMeaning,
	testCase: testCase,
	net: net,
	VerificationResultAttestationComponent: VerificationResultAttestationComponent,
	_class: _class,
	claim: claim,
	Flag: Flag,
	_riskAdjustment: _riskAdjustment,
	_compareToSourceExpression: _compareToSourceExpression,
	_notificationEvent: _notificationEvent,
	guideline: guideline,
	amount: amount,
	_dateFilter: _dateFilter,
	_statisticType: _statisticType,
	genus: genus,
	_MessageHeader: _MessageHeader,
	_administrationTreatment: _administrationTreatment,
	_country: _country,
	insurer: insurer,
	DeviceDefinitionLinkComponent: DeviceDefinitionLinkComponent,
	container: container,
	_params: _params,
	Goal: Goal,
	lockedDate: lockedDate,
	symptomConditionEffect: symptomConditionEffect,
	referenceStrength: referenceStrength,
	interval: interval,
	_compartment: _compartment,
	classifier: classifier,
	PackagedProductDefinitionPackagingPropertyComponent: PackagedProductDefinitionPackagingPropertyComponent,
	setup: setup,
	_areaOfHybridisation: _areaOfHybridisation,
	maxLength: maxLength,
	publisherLocation: publisherLocation,
	RelatedPerson: RelatedPerson,
	_storageTempRequirements: _storageTempRequirements,
	_Organization: _Organization,
	_postConditions: _postConditions,
	_DeviceDispense: _DeviceDispense,
	state: state,
	SubstanceDefinitionSourceMaterialComponent: SubstanceDefinitionSourceMaterialComponent,
	_aggregate: _aggregate,
	fluidConsistencyType: fluidConsistencyType,
	MoneyQuantity: MoneyQuantity,
	_specificCost: _specificCost,
	_organismId: _organismId,
	StructureMapGroupInputComponent: StructureMapGroupInputComponent,
	_check: _check,
	_chargeItemCode: _chargeItemCode,
	ownedBy: ownedBy,
	_participantStatus: _participantStatus,
	_baseFormulaType: _baseFormulaType,
	shelfLifeStorage: shelfLifeStorage,
	authorizingPrescription: authorizingPrescription,
	protein: protein,
	connectivity: connectivity,
	information: information,
	DeviceDefinitionVersionComponent: DeviceDefinitionVersionComponent,
	AdverseEvent: AdverseEvent,
	_originRelationshipType: _originRelationshipType,
	definitionExpression: definitionExpression,
	ServiceRequestOrderDetailParameterComponent: ServiceRequestOrderDetailParameterComponent,
	TestPlan: TestPlan,
	requestProvider: requestProvider,
	_formatted: _formatted,
	NutritionProduct: NutritionProduct,
	ActorDefinition: ActorDefinition,
	RegulatedAuthorization: RegulatedAuthorization,
	_facility: _facility,
	sourceDocument: sourceDocument,
	_morphology: _morphology,
	_kind: _kind,
	color: color,
	_bounds: _bounds,
	snapshot: snapshot,
	SpecimenContainerComponent: SpecimenContainerComponent,
	unsignedInt: unsignedInt,
	MedicationKnowledgeMedicineClassificationComponent: MedicationKnowledgeMedicineClassificationComponent,
	ImmunizationProgramEligibilityComponent: ImmunizationProgramEligibilityComponent,
	_dose: _dose,
	useBy: useBy,
	_start: _start,
	_import: _import,
	TaskPerformerComponent: TaskPerformerComponent,
	grantor: grantor,
	_purpose: _purpose,
	benefit: benefit,
	contributorship: contributorship,
	PlanDefinitionActionDynamicValueComponent: PlanDefinitionActionDynamicValueComponent,
	ImagingStudySeriesComponent: ImagingStudySeriesComponent,
	programStatus: programStatus,
	_evidence: _evidence,
	ClinicalUseDefinitionInteractionInteractantComponent: ClinicalUseDefinitionInteractionInteractantComponent,
	_highNumerator: _highNumerator,
	ChargeItemDefinitionPropertyGroupComponent: ChargeItemDefinitionPropertyGroupComponent,
	boolean: boolean,
	PackagedProductDefinitionProperty: PackagedProductDefinitionProperty,
	_Group: _Group,
	_media: _media,
	hasStage: hasStage,
	TestReportSetupActionAssertRequirementComponent: TestReportSetupActionAssertRequirementComponent,
	_onBehalfOf: _onBehalfOf,
	SubstanceReferenceInformationGeneElementComponent: SubstanceReferenceInformationGeneElementComponent,
	maxCount: maxCount,
	enableWhen: enableWhen,
	regulator: regulator,
	_medicineClassification: _medicineClassification,
	imageRegion3D: imageRegion3D,
	_source: _source,
	_hoursOfOperation: _hoursOfOperation,
	admission: admission,
	extension: extension,
	_reAdmission: _reAdmission,
	integer64: integer64,
	_Task: _Task,
	HealthcareService: HealthcareService,
	_Appointment: _Appointment,
	_crossReference: _crossReference,
	_hasPart: _hasPart,
	_executionPeriod: _executionPeriod,
	Expression: Expression,
	Class: Class,
	_operation: _operation,
	_adjustmentReason: _adjustmentReason,
	notConsumed: notConsumed,
	relativePath: relativePath,
	ImplementationGuideDefinitionComponent: ImplementationGuideDefinitionComponent,
	geneSequenceOrigin: geneSequenceOrigin,
	level: level,
	TestReportTestComponent: TestReportTestComponent,
	doseNumber: doseNumber,
	ParametersParameterComponentParameterParameter: ParametersParameterComponentParameterParameter,
	age: age,
	_payload: _payload,
	entityRelatedness: entityRelatedness,
	startParam: startParam,
	_intraspecificDescription: _intraspecificDescription,
	_clinicalStatus: _clinicalStatus,
	_compositeScoring: _compositeScoring,
	jurisdiction: jurisdiction,
	Exemption: Exemption,
	_requestHeader: _requestHeader,
	_certainty: _certainty,
	connectionType: connectionType,
	_groupingBehavior: _groupingBehavior,
	_translations: _translations,
	photo: photo,
	multipleAnd: multipleAnd,
	_gender: _gender,
	_coding: _coding,
	_system: _system,
	_Slot: _Slot,
	freeToShare: freeToShare,
	ElementDefinitionMappingComponent: ElementDefinitionMappingComponent,
	copackagedIndicator: copackagedIndicator,
	precheckBehavior: precheckBehavior,
	map: map,
	additionalInfo: additionalInfo,
	preConditions: preConditions,
	numberOfSubunits: numberOfSubunits,
	numberOfEvents: numberOfEvents,
	_sender: _sender,
	_validCodedValueSet: _validCodedValueSet,
	_referenceInformation: _referenceInformation,
	longitude: longitude,
	_contentDerivative: _contentDerivative,
	_reportedDateTime: _reportedDateTime,
	Primitive: Primitive,
	_processingMode: _processingMode,
	_composition: _composition,
	_width: _width,
	_valueAlternatives: _valueAlternatives,
	hint: hint,
	license: license,
	created: created,
	expectedInResearchStudy: expectedInResearchStudy,
	originalPrescription: originalPrescription,
	scoring: scoring,
	ClinicalUseDefinitionInteractionComponent: ClinicalUseDefinitionInteractionComponent,
	PlanDefinitionActorComponent: PlanDefinitionActorComponent,
	subjectStatus: subjectStatus,
	_qualitativeRisk: _qualitativeRisk,
	_header: _header,
	recurrenceId: recurrenceId,
	_author: _author,
	responsibleOrganization: responsibleOrganization,
	TriggerDefinition: TriggerDefinition,
	_BackboneElement: _BackboneElement,
	_offeredIn: _offeredIn,
	_accessionNumber: _accessionNumber,
	legalState: legalState,
	incomplete: incomplete,
	CodeableReference: CodeableReference,
	activity: activity,
	availableEndTime: availableEndTime,
	mimeType: mimeType,
	NutritionOrderEnteralFormulaAdministrationComponent: NutritionOrderEnteralFormulaAdministrationComponent,
	periodUnit: periodUnit,
	EvidenceReportRelatesToComponent: EvidenceReportRelatesToComponent,
	SubstanceDefinition: SubstanceDefinition,
	_useContext: _useContext,
	_instantiatesUri: _instantiatesUri,
	authorizationUrl: authorizationUrl,
	contributedToDeath: contributedToDeath,
	confidentialityIndicator: confidentialityIndicator,
	_diagnosisSequence: _diagnosisSequence,
	selectionBehavior: selectionBehavior,
	_time: _time,
	addresses: addresses,
	_dataRequirement: _dataRequirement,
	CapabilityStatementRestResourceComponent: CapabilityStatementRestResourceComponent,
	_lineItem: _lineItem,
	_InventoryReport: _InventoryReport,
	_copyright: _copyright,
	_Substance: _Substance,
	_timing: _timing,
	wasSubstituted: wasSubstituted,
	aggregation: aggregation,
	_authorDescription: _authorDescription,
	_filter: _filter,
	MedicinalProductDefinitionOperationComponent: MedicinalProductDefinitionOperationComponent,
	_defaultValue: _defaultValue,
	StructureMapStructureComponent: StructureMapStructureComponent,
	recipient: recipient,
	_lotNumber: _lotNumber,
	QuestionnaireItemAnswerOptionComponent: QuestionnaireItemAnswerOptionComponent,
	applies: applies,
	caseSensitive: caseSensitive,
	subtype: subtype,
	_field: _field,
	_hasIngredient: _hasIngredient,
	strength: strength,
	linkId: linkId,
	StructureMapGroupRuleTargetComponent: StructureMapGroupRuleTargetComponent,
	_resultingEffect: _resultingEffect,
	altitude: altitude,
	phase: phase,
	_numberOfRepeatsAllowed: _numberOfRepeatsAllowed,
	groupSize: groupSize,
	_oligoNucleotideType: _oligoNucleotideType,
	doseStatus: doseStatus,
	directnessMatch: directnessMatch,
	AppointmentParticipantComponent: AppointmentParticipantComponent,
	_continuous: _continuous,
	_dispenseInterval: _dispenseInterval,
	stage: stage,
	associatedMedication: associatedMedication,
	dateOfDiagnosis: dateOfDiagnosis,
	_actualPeriod: _actualPeriod,
	ValueSet: ValueSet,
	lastOccurrence: lastOccurrence,
	disulfideLinkage: disulfideLinkage,
	participatingOrganization: participatingOrganization,
	ResearchSubject: ResearchSubject,
	heartbeatPeriod: heartbeatPeriod,
	OrganizationAffiliation: OrganizationAffiliation,
	_binding: _binding,
	SubstanceNucleicAcidSubunitLinkageComponent: SubstanceNucleicAcidSubunitLinkageComponent,
	ImplementationGuideDefinitionPageComponent: ImplementationGuideDefinitionPageComponent,
	FamilyMemberHistoryProcedureComponent: FamilyMemberHistoryProcedureComponent,
	subscriptionTopic: subscriptionTopic,
	_resource: _resource,
	correspondingContact: correspondingContact,
	graph: graph,
	_QuestionnaireResponse: _QuestionnaireResponse,
	RequestOrchestrationActionComponentAction: RequestOrchestrationActionComponentAction,
	issues: issues,
	instances: instances,
	_isDefining: _isDefining,
	primaryPurposeType: primaryPurposeType,
	_specimenRequirement: _specimenRequirement,
	_sourceDocument: _sourceDocument,
	SubstanceReferenceInformation: SubstanceReferenceInformation,
	_multipleBirth: _multipleBirth,
	_InsurancePlan: _InsurancePlan,
	repeatUnit: repeatUnit,
	StructureDefinition: StructureDefinition,
	_node: _node,
	TestPlanTestCaseAssertionComponent: TestPlanTestCaseAssertionComponent,
	relatedData: relatedData,
	_content: _content,
	_associationType: _associationType,
	_regulatoryBasis: _regulatoryBasis,
	attachment: attachment,
	ActionSubject: ActionSubject,
	_packagedMedicinalProduct: _packagedMedicinalProduct,
	_packagedProduct: _packagedProduct,
	_onset: _onset,
	_basedOn: _basedOn,
	CitationCitedArtifactRelatesToComponent: CitationCitedArtifactRelatesToComponent,
	_backCurve: _backCurve,
	AuditEventOutcomeComponent: AuditEventOutcomeComponent,
	payee: payee,
	_reporter: _reporter,
	SubstanceDefinitionStructureComponentMolecularWeight: SubstanceDefinitionStructureComponentMolecularWeight,
	biologicalSourceEvent: biologicalSourceEvent,
	RequestOrchestrationActionComponent: RequestOrchestrationActionComponent,
	period: period,
	SearchParameterComponentComponent: SearchParameterComponentComponent,
	protocolPerformed: protocolPerformed,
	ResearchStudyLabelComponent: ResearchStudyLabelComponent,
	_careTeamSequence: _careTeamSequence,
	instantiates: instantiates,
	_patientCharacteristic: _patientCharacteristic,
	_allowedType: _allowedType,
	Element: Element,
	DeviceMetric: DeviceMetric,
	_maxTreatmentPeriod: _maxTreatmentPeriod,
	_InventoryItem: _InventoryItem,
	AppointmentRecurrenceTemplateComponent: AppointmentRecurrenceTemplateComponent,
	targetDisease: targetDisease,
	PlanDefinitionActionComponentAction: PlanDefinitionActionComponentAction,
	file: file,
	const__workaround: const__workaround,
	citedMedium: citedMedium,
	_frames: _frames,
	multipleOr: multipleOr,
	inputParameters: inputParameters,
	causality: causality,
	SupplyDelivery: SupplyDelivery,
	minimumId: minimumId,
	_processNote: _processNote,
	Money: Money,
	_BackboneType: _BackboneType,
	_Endpoint: _Endpoint,
	udiDeviceIdentifier: udiDeviceIdentifier,
	EnteralFormulaSchedule: EnteralFormulaSchedule,
	diseaseStatus: diseaseStatus,
	_expectedSupplyDuration: _expectedSupplyDuration,
	ifModifiedSince: ifModifiedSince,
	formCode: formCode,
	_connectionType: _connectionType,
	ImplementationGuideDefinitionResourceComponent: ImplementationGuideDefinitionResourceComponent,
	_fundsReserveRequested: _fundsReserveRequested,
	dateFilter: dateFilter,
	matchStatus: matchStatus,
	usePeriod: usePeriod,
	_participant: _participant,
	MessageDestination: MessageDestination,
	_additionalInfo: _additionalInfo,
	_numberOfEvents: _numberOfEvents,
	_includedStructure: _includedStructure,
	_imageRegion2D: _imageRegion2D,
	_tax: _tax,
	_appointment: _appointment,
	treatmentIntent: treatmentIntent,
	SubstanceDefinitionCodeComponent: SubstanceDefinitionCodeComponent,
	_study: _study,
	_ratioType: _ratioType,
	policyHolder: policyHolder,
	region: region,
	operationType: operationType,
	_actuality: _actuality,
	_definitionUri: _definitionUri,
	organismId: organismId,
	ManufacturedItemDefinitionComponentComponentComponentProperty: ManufacturedItemDefinitionComponentComponentComponentProperty,
	_consumedItem: _consumedItem,
	thursday: thursday,
	_rules: _rules,
	dependent: dependent,
	deliverFrom: deliverFrom,
	ImmunizationProtocolAppliedComponent: ImmunizationProtocolAppliedComponent,
	actualGroup: actualGroup,
	Age: Age,
	subsumption: subsumption,
	ElementDefinitionConstraintComponent: ElementDefinitionConstraintComponent,
	subjectResults: subjectResults,
	OperationDefinitionOverloadComponent: OperationDefinitionOverloadComponent,
	recurrenceTemplate: recurrenceTemplate,
	doseForm: doseForm,
	adherence: adherence,
	ServiceRequest: ServiceRequest,
	deviceIdentifier: deviceIdentifier,
	_reasonLinkId: _reasonLinkId,
	versionId: versionId,
	componentPart: componentPart,
	_value: _value,
	TestReportParticipantComponent: TestReportParticipantComponent,
	morphology: morphology,
	date: date,
	_isModifier: _isModifier,
	_allDay: _allDay,
	contentReference: contentReference,
	_sunday: _sunday,
	DeviceUsageAdherenceComponent: DeviceUsageAdherenceComponent,
	maxSingleDose: maxSingleDose,
	referenceRange: referenceRange,
	_pages: _pages,
	DeviceDefinitionGuidelineComponent: DeviceDefinitionGuidelineComponent,
	_temperatureRange: _temperatureRange,
	_sequenceType: _sequenceType,
	_partNumber: _partNumber,
	_term: _term,
	StructureDefinitionDifferentialComponent: StructureDefinitionDifferentialComponent,
	_udi: _udi,
	_telecom: _telecom,
	CitationCitedArtifactPublicationFormPublishedInComponent: CitationCitedArtifactPublicationFormPublishedInComponent,
	_wasSubstituted: _wasSubstituted,
	initial: initial,
	doNotPerform: doNotPerform,
	diameter: diameter,
	_property: _property,
	MessageHeaderResponseComponent: MessageHeaderResponseComponent,
	Linkage: Linkage,
	permittedUnit: permittedUnit,
	_sex: _sex,
	genomeBuild: genomeBuild,
	changePattern: changePattern,
	MedicationRequestSubstitutionComponent: MedicationRequestSubstitutionComponent,
	_authority: _authority,
	onBehalfOf: onBehalfOf,
	_rateAggregation: _rateAggregation,
	managingOrganization: managingOrganization,
	handling: handling,
	notConsumedReason: notConsumedReason,
	axis: axis,
	_udiCarrier: _udiCarrier,
	paymentBy: paymentBy,
	_insurancePlan: _insurancePlan,
	subDetailSequence: subDetailSequence,
	DataRequirementValueFilterComponent: DataRequirementValueFilterComponent,
	problem: problem,
	initialFill: initialFill,
	_ManufacturedItemDefinition: _ManufacturedItemDefinition,
	_improvementNotation: _improvementNotation,
	ClinicalUseDefinitionIndicationComponentOtherTherapy: ClinicalUseDefinitionIndicationComponentOtherTherapy,
	fraction: fraction,
	_lastOccurrence: _lastOccurrence,
	_assessment: _assessment,
	Patient: Patient,
	_identified: _identified,
	ExplanationOfBenefitAdjudication: ExplanationOfBenefitAdjudication,
	_Subscription: _Subscription,
	tag: tag,
	_performed: _performed,
	_formOf: _formOf,
	DeviceDefinitionPackagingComponentPackagingPackaging: DeviceDefinitionPackagingComponentPackagingPackaging,
	_subrogation: _subrogation,
	_deceased: _deceased,
	relatedAccount: relatedAccount,
	Transport: Transport,
	Measure: Measure,
	RiskAssessment: RiskAssessment,
	_teardown: _teardown,
	degreeOfPolymerisation: degreeOfPolymerisation,
	_CoverageEligibilityRequest: _CoverageEligibilityRequest,
	_Medication: _Medication,
	manufacturedDoseForm: manufacturedDoseForm,
	sliceName: sliceName,
	dateAsserted: dateAsserted,
	ContractParty: ContractParty,
	validationStatus: validationStatus,
	TestScriptMetadataComponent: TestScriptMetadataComponent,
	_headerField: _headerField,
	geographicalLocation: geographicalLocation,
	versionNeeded: versionNeeded,
	ConceptDefinition: ConceptDefinition,
	_sigFormat: _sigFormat,
	publishedIn: publishedIn,
	sphere: sphere,
	_SubstanceDefinition: _SubstanceDefinition,
	SubstanceDefinitionNameOfficialComponent: SubstanceDefinitionNameOfficialComponent,
	_listRuleId: _listRuleId,
	started: started,
	EvidenceVariable: EvidenceVariable,
	ResearchStudyOutcomeMeasureComponent: ResearchStudyOutcomeMeasureComponent,
	allowedResponse: allowedResponse,
	_ElementDefinition: _ElementDefinition,
	CitationCitedArtifactContributorshipComponent: CitationCitedArtifactContributorshipComponent,
	_contentType: _contentType,
	_DeviceUsage: _DeviceUsage,
	DeviceDefinitionUdiDeviceIdentifierComponent: DeviceDefinitionUdiDeviceIdentifierComponent,
	document: document,
	event: event,
	Guarantor: Guarantor,
	molecularWeight: molecularWeight,
	substitution: substitution,
	NutritionOrderSupplementComponent: NutritionOrderSupplementComponent,
	_relativeRisk: _relativeRisk,
	_volume: _volume,
	_manager: _manager,
	_presentation: _presentation,
	_linkage: _linkage,
	isDefault: isDefault,
	BodyStructure: BodyStructure,
	_relationship: _relationship,
	_maxDispense: _maxDispense,
	ChargeItemDefinition: ChargeItemDefinition,
	_SupplyDelivery: _SupplyDelivery,
	_specialArrangement: _specialArrangement,
	DosageDoseAndRateComponent: DosageDoseAndRateComponent,
	_guideline: _guideline,
	_grantee: _grantee,
	serviced: serviced,
	_active: _active,
	_preference: _preference,
	useContext: useContext,
	_container: _container,
	justification: justification,
	oralDiet: oralDiet,
	_testingDestination: _testingDestination,
	lastRevisionDate: lastRevisionDate,
	NutritionIntakeIngredientLabelComponent: NutritionIntakeIngredientLabelComponent,
	QuestionnaireResponseItemComponentItem: QuestionnaireResponseItemComponentItem,
	PermissionJustificationComponent: PermissionJustificationComponent,
	recorder: recorder,
	ImmunizationRecommendationRecommendationDateCriterionComponent: ImmunizationRecommendationRecommendationDateCriterionComponent,
	_focus: _focus,
	countingDateTime: countingDateTime,
	MedicationKnowledge: MedicationKnowledge,
	ConditionDefinition: ConditionDefinition,
	noMap: noMap,
	_userSelected: _userSelected,
	appointmentRequired: appointmentRequired,
	_numberOfStudies: _numberOfStudies,
	capabilities: capabilities,
	Benefit: Benefit,
	_uri: _uri,
	_max: _max,
	inactive: inactive,
	other: other,
	dependsOn: dependsOn,
	citedArtifact: citedArtifact,
	fixture: fixture,
	_insurer: _insurer,
	_endParam: _endParam,
	continuous: continuous,
	SubstancePolymerRepeatRepeatUnitStructuralRepresentationComponent: SubstancePolymerRepeatRepeatUnitStructuralRepresentationComponent,
	_responsibleOrganization: _responsibleOrganization,
	url: url,
	compareToSourceExpression: compareToSourceExpression,
	nutrient: nutrient,
	_subjectResults: _subjectResults,
	DocumentReferenceRelatesToComponent: DocumentReferenceRelatesToComponent,
	ImagingStudy: ImagingStudy,
	AppointmentRecurrenceTemplateYearlyTemplateComponent: AppointmentRecurrenceTemplateYearlyTemplateComponent,
	SpecimenFeatureComponent: SpecimenFeatureComponent,
	_ServiceRequest: _ServiceRequest,
	tester: tester,
	seriousness: seriousness,
	isDefining: isDefining,
	contributingFactor: contributingFactor,
	CapabilityStatement: CapabilityStatement,
	_ImagingSelection: _ImagingSelection,
	_unmapped: _unmapped,
	compositional: compositional,
	fundsReserveRequested: fundsReserveRequested,
	Total: Total,
	_citeAs: _citeAs,
	_protein: _protein,
	_referenceRange: _referenceRange,
	complication: complication,
	SubscriptionTopicResourceTriggerComponent: SubscriptionTopicResourceTriggerComponent,
	estimate: estimate,
	_material: _material,
	Item: Item,
	encodeRequestUrl: encodeRequestUrl,
	_currentLocation: _currentLocation,
	style: style,
	method: method,
	_MarketingStatus: _MarketingStatus,
	group: group,
	achievementStatus: achievementStatus,
	evaluatedResource: evaluatedResource,
	_udiDeviceIdentifier: _udiDeviceIdentifier,
	_RelatedPerson: _RelatedPerson,
	dateTime: dateTime,
	_intervalUnit: _intervalUnit,
	text: text,
	_contact: _contact,
	searchInclude: searchInclude,
	_fivePrime: _fivePrime,
	timeOfDay: timeOfDay,
	originRelationshipType: originRelationshipType,
	CitationClassificationComponent: CitationClassificationComponent,
	_plannedStartDate: _plannedStartDate,
	documentType: documentType,
	CoverageEligibilityRequestEventComponent: CoverageEligibilityRequestEventComponent,
	_milestone: _milestone,
	page: page,
	params: params,
	regionsCalled: regionsCalled,
	conditionalCreate: conditionalCreate,
	lensSpecification: lensSpecification,
	_grantor: _grantor,
	coverage: coverage,
	authorizationSupporting: authorizationSupporting,
	ElementDefinitionBindingAdditionalComponent: ElementDefinitionBindingAdditionalComponent,
	_benefit: _benefit,
	_testData: _testData,
	_OrganizationAffiliation: _OrganizationAffiliation,
	excludedStructure: excludedStructure,
	_searchRevInclude: _searchRevInclude,
	serviceProvisionCode: serviceProvisionCode,
	typeMode: typeMode,
	ValueSetScopeComponent: ValueSetScopeComponent,
	SupplyRequestParameterComponent: SupplyRequestParameterComponent,
	attributeEstimate: attributeEstimate,
	immutable: immutable,
	_relatedAccount: _relatedAccount,
	_RiskAssessment: _RiskAssessment,
	BiologicallyDerivedProductPropertyComponent: BiologicallyDerivedProductPropertyComponent,
	_totalVolume: _totalVolume,
	_adjudication: _adjudication,
	history: history,
	_isSubpotent: _isSubpotent,
	_longitude: _longitude,
	_sliceIsConstraining: _sliceIsConstraining,
	collected: collected,
	medicineClassification: medicineClassification,
	Signature: Signature,
	ConceptReference: ConceptReference,
	TransportRestrictionComponent: TransportRestrictionComponent,
	_rank: _rank,
	_inResponseTo: _inResponseTo,
	CitationCitedArtifactAbstractComponent: CitationCitedArtifactAbstractComponent,
	_error: _error,
	origin: origin,
	treeRoot: treeRoot,
	_sourceMaterialType: _sourceMaterialType,
	bodyStructure: bodyStructure,
	_releaseDate: _releaseDate,
	normalValue: normalValue,
	PractitionerCommunicationComponent: PractitionerCommunicationComponent,
	targetProfile: targetProfile,
	bounds: bounds,
	_op: _op,
	OperationDefinitionParameterComponentParameterParameter: OperationDefinitionParameterComponentParameterParameter,
	plannedActivityReference: plannedActivityReference,
	_preAuthRef: _preAuthRef,
	_imageRegion3D: _imageRegion3D,
	_object: _object,
	DocumentReferenceAttesterComponent: DocumentReferenceAttesterComponent,
	_recall: _recall,
	fastingStatus: fastingStatus,
	seriesUid: seriesUid,
	SubstanceSourceMaterialPartDescriptionComponent: SubstanceSourceMaterialPartDescriptionComponent,
	_geneElement: _geneElement,
	publicationDateText: publicationDateText,
	EpisodeOfCareStatusHistoryComponent: EpisodeOfCareStatusHistoryComponent,
	evaluationMessage: evaluationMessage,
	division: division,
	windowEnd: windowEnd,
	_foodType: _foodType,
	_repeats: _repeats,
	_Observation: _Observation,
	validateCode: validateCode,
	parameterName: parameterName,
	source: source,
	currentState: currentState,
	publicationStatus: publicationStatus,
	_license: _license,
	_created: _created,
	ClinicalUseDefinitionContraindicationOtherTherapyComponent: ClinicalUseDefinitionContraindicationOtherTherapyComponent,
	isModifier: isModifier,
	_needsMap: _needsMap,
	performerType: performerType,
	unitPrice: unitPrice,
	_topic: _topic,
	_lastUpdated: _lastUpdated,
	preparedDate: preparedDate,
	accident: accident,
	code: code,
	_designation: _designation,
	_creation: _creation,
	verificationType: verificationType,
	DeviceDefinitionPackagingComponentPackagingUdiDeviceIdentifier: DeviceDefinitionPackagingComponentPackagingUdiDeviceIdentifier,
	_containedInstance: _containedInstance,
	PackagedProductDefinitionLegalStatusOfSupplyComponent: PackagedProductDefinitionLegalStatusOfSupplyComponent,
	_recipient: _recipient,
	ifMatch: ifMatch,
	partNumber: partNumber,
	_severity: _severity,
	_filterBy: _filterBy,
	_NutritionIntake: _NutritionIntake,
	BundleEntrySearchComponent: BundleEntrySearchComponent,
	_responseCode: _responseCode,
	_eventHistory: _eventHistory,
	_rejectionCriterion: _rejectionCriterion,
	notPerformedReason: notPerformedReason,
	_entryType: _entryType,
	EncounterHistory: EncounterHistory,
	_specialPrecautionsForStorage: _specialPrecautionsForStorage,
	SearchParameter: SearchParameter,
	gender: gender,
	coding: coding,
	ProductShelfLife: ProductShelfLife,
	system: system,
	_tissue: _tissue,
	associatedParty: associatedParty,
	statistic: statistic,
	DataRequirement: DataRequirement,
	MedicationKnowledgeRegulatoryMaxDispenseComponent: MedicationKnowledgeRegulatoryMaxDispenseComponent,
	udiCarrier: udiCarrier,
	Availability: Availability,
	sender: sender,
	_strand: _strand,
	IngredientSubstanceStrengthComponent: IngredientSubstanceStrengthComponent,
	MedicationKnowledgeMonitoringProgramComponent: MedicationKnowledgeMonitoringProgramComponent,
	_derivation: _derivation,
	Condition: Condition,
	AdministrableProductDefinitionRouteOfAdministrationTargetSpeciesWithdrawalPeriodComponent: AdministrableProductDefinitionRouteOfAdministrationTargetSpeciesWithdrawalPeriodComponent,
	diagnostics: diagnostics,
	assessment: assessment,
	_clockFacePosition: _clockFacePosition,
	attestation: attestation,
	identified: identified
});

export { _additive as $, _maxDosePerLifetime as $$, CarePlan as $0, clinicalStatus as $1, measurementType as $2, ImplementationGuideDefinitionGroupingComponent as $3, _fundingSource as $4, _immunizationEvent as $5, ClaimResponseEventComponent as $6, statement as $7, ImageRegion3D as $8, _item as $9, structureVersion as $A, alias as $B, _programCode as $C, _resultForDelete as $D, grantee as $E, _effectiveTime as $F, definitionCodeableConcept as $G, Property as $H, entryClassifier as $I, _combining as $J, paternalOrganismName as $K, _asset as $L, PaymentReconciliationAllocationComponent as $M, _part as $N, actor as $O, _isExample as $P, navigationLinks as $Q, availability as $R, _specimen as $S, term as $T, notAvailableTime as $U, specimenRequirement as $V, answer as $W, _citation as $X, patient as $Y, suppress as $Z, additionalUse as $_, _repeatUnit as $a, startingMaterial as $b, _temperatureQualifier as $c, dosingGuideline as $d, _serviceCategory as $e, _rate as $f, _filterDefinition as $g, prescriber as $h, oid as $i, _attachment as $j, _sourceAttachment as $k, _materialType as $l, target as $m, _valueCategory as $n, _requestMethod as $o, linkage as $p, DeviceUdiCarrierComponent as $q, TerminologyCapabilitiesClosureComponent as $r, _conclusionCode as $s, _div as $t, processingMode as $u, _rule as $v, StructureMap as $w, _molecularFormulaByMoiety as $x, firstDose as $y, BundleEntryResponseComponent as $z, _requestURL as A, responsibleParty as A$, _option as A0, TypeRefComponent as A1, minValue as A2, _tuesday as A3, _offset as A4, report as A5, _fhirPathCriteria as A6, editor as A7, _firstDose as A8, procedureSequence as A9, occurrence as AA, dayOfMonth as AB, _maxDosePerPeriod as AC, _MeasureReport as AD, MedicationKnowledgeCostComponent as AE, uuid as AF, _range as AG, related as AH, endpoint as AI, ValueSetExpansionParameterComponent as AJ, _logMessage as AK, SubscriptionTopicResourceTriggerQueryCriteriaComponent as AL, _supportingImmunization as AM, StructureMapConstComponent as AN, NutritionIntakeConsumedItemComponent as AO, PlanDefinitionGoalComponent as AP, precondition as AQ, _CoverageEligibilityResponse as AR, _duration as AS, _routeOfAdministration as AT, _legallyBinding as AU, rendering as AV, _hierarchical as AW, _nameType as AX, _businessStatus as AY, _maxLength as AZ, SubstancePolymerRepeatComponent as A_, MedicinalProductDefinitionContactComponent as Aa, _Communication as Ab, _controller as Ac, TestScriptSetupActionAssertRequirementComponent as Ad, _allocation as Ae, otherTherapy as Af, _requestedLocation as Ag, _referencedFrom as Ah, eventsSinceSubscriptionStart as Ai, _question as Aj, _drugCharacteristic as Ak, _total as Al, AuditEvent as Am, _environmentType as An, AssetContext as Ao, _rangeCategory as Ap, Location as Aq, rank as Ar, PlanDefinitionActionComponentActionAction as As, _occurrenceCount as At, entryType as Au, _trigger as Av, _contextInvariant as Aw, id as Ax, _productionIdentifierInUDI as Ay, _variable as Az, _caseSensitive as B, recommendation as B$, BundleEntryComponent as B0, _input as B1, _languageCode as B2, _patient as B3, direction as B4, _publicationDateSeason as B5, maritalStatus as B6, AllergyIntoleranceReactionComponent as B7, _observer as B8, SubscriptionParameterComponent as B9, SpecimenDefinitionTypeTestedContainerComponent as BA, ServiceRequestPatientInstructionComponent as BB, _adjustment as BC, _guidance as BD, productReference as BE, _for as BF, _intended as BG, _additionalUse as BH, MetadataResource as BI, _startingSequence as BJ, MedicationStatement as BK, medium as BL, _baseUnit as BM, _doseStatusReason as BN, unitOfPresentation as BO, CareTeam as BP, sourceSignature as BQ, availableStartTime as BR, _effectiveDate as BS, _relevantHistory as BT, ParametersParameterComponent as BU, MessageDefinitionFocusComponent as BV, EnrollmentResponse as BW, ListEntryComponent as BX, _subset as BY, dimensions as BZ, _function as B_, doseAdministrationAid as Ba, DeviceDefinitionClassificationComponent as Bb, _measure as Bc, _maxDosePerAdministration as Bd, CompositionAttesterComponent as Be, _valueFilter as Bf, studyDesign as Bg, _relation as Bh, _priority as Bi, MessageDefinition as Bj, _description as Bk, TestPlanTestCaseTestDataComponent as Bl, HealthcareServiceEligibilityComponent as Bm, category as Bn, Details as Bo, verificationDate as Bp, ExampleScenarioActorComponent as Bq, _specimenQuantity as Br, DeviceDefinitionPackagingComponent as Bs, autocreate as Bt, _structuralRepresentation as Bu, agent as Bv, _request as Bw, _deliverTo as Bx, _textConcentration as By, benefitPeriod as Bz, ClinicalUseDefinitionWarningComponent as C, subpotentReason as C$, _prescription as C0, prognosisReference as C1, _hint as C2, _ownedBy as C3, measurementFrequency as C4, _traceNumber as C5, _excludingDate as C6, _required as C7, correctiveAction as C8, schedule as C9, _additionalAttribute as CA, _validity as CB, _product as CC, objective as CD, _containedItem as CE, MedicationKnowledgePackagingComponentCost as CF, relatedDevice as CG, QuestionnaireItemEnableWhenComponent as CH, _numberAffected as CI, _batch as CJ, preparationInstruction as CK, EpisodeOfCare as CL, _entity as CM, _initiator as CN, _communication as CO, programEligibility as CP, addItem as CQ, _details as CR, pageString as CS, expansion as CT, MedicationKnowledgeRegulatoryComponent as CU, _affiliation as CV, _contentDefinition as CW, marketPeriod as CX, _reportingPeriod as CY, _accountNumber as CZ, _geneSequenceOrigin as C_, _referral as Ca, alternate as Cb, intendedExposure as Cc, threePrime as Cd, param as Ce, _proposedNewTime as Cf, power as Cg, cardinalityBehavior as Ch, supportingPatientInformation as Ci, _predecessor as Cj, allergenicIndicator as Ck, _regulator as Cl, issue as Cm, _admission as Cn, _extension as Co, _notificationShape as Cp, Device as Cq, Range as Cr, ItemBodySite as Cs, average as Ct, SubstanceNucleicAcidSubunitSugarComponent as Cu, Composition as Cv, _otherMap as Cw, Rule as Cx, testScript as Cy, targetId as Cz, Detail as D, _addresses as D$, inventoryStatus as D0, subunit as D1, orderer as D2, ExampleScenarioInstanceVersionComponent as D3, itemStatus as D4, _ResearchStudy as D5, resourceType as D6, Quantity as D7, contained as D8, _appointmentType as D9, OperationOutcome as DA, Contributor as DB, _message as DC, import__workaround as DD, definitionByTypeAndValue as DE, TestScriptSetupActionOperationComponent as DF, mitigatingAction as DG, validationDate as DH, healthcareService as DI, conditionalPatch as DJ, minimumVolume as DK, _practiceSetting as DL, protocol as DM, _structureProfile as DN, _Coverage as DO, _issuerType as DP, MedicationRequest as DQ, _pattern as DR, processingFacility as DS, _situation as DT, _patchFormat as DU, alternateMaterial as DV, responsible as DW, PlanDefinitionActionRelatedActionComponent as DX, _security as DY, combined as DZ, contains as D_, SpecimenDefinitionTypeTestedComponent as Da, _actual as Db, CostToBeneficiary as Dc, _Schedule as Dd, programCode as De, _PractitionerRole as Df, guarantor as Dg, _FamilyMemberHistory as Dh, _operationTypeReason as Di, _programStatus as Dj, _performerLinkId as Dk, onHold as Dl, _copackagedIndicator as Dm, storageGuideline as Dn, _receiver as Do, _whyStopped as Dp, _packageFor as Dq, action as Dr, _sourceMaterialState as Ds, indicationGuideline as Dt, _interaction as Du, aggregateMethod as Dv, _authorizingPrescription as Dw, _authoritative as Dx, timeAspect as Dy, _valueSet as Dz, Error__workaround as E, _recommendation as E$, expirationDate as E0, compartment as E1, _scoring as E2, policy as E3, recordedDate as E4, _sourceScope as E5, _chain as E6, ImplementationGuideManifestComponent as E7, _contributedToDeath as E8, _diagnosisRelatedGroup as E9, _instances as EA, stratum as EB, MeasureReportGroupStratifierComponent as EC, _ratioHighLimitAmount as ED, route as EE, TestScriptMetadataLinkComponent as EF, DeviceDispensePerformerComponent as EG, frequencyMax as EH, _number as EI, QuestionnaireResponse as EJ, MappingProperty as EK, _securityContext as EL, display as EM, yearlyTemplate as EN, ChargeItemPerformerComponent as EO, Contact as EP, EndpointPayloadComponent as EQ, _relatedArtifact as ER, updateCreate as ES, _subtype as ET, _stereochemistry as EU, _upperLimit as EV, routeOfAdministration as EW, _amountType as EX, _organismType as EY, bodySite as EZ, _moiety as E_, _referenceNumber as Ea, _template as Eb, _preConditions as Ec, _score as Ed, SubstancePolymerMonomerSetComponent as Ee, _requiredBehavior as Ef, _statusHistory as Eg, replacementSequence as Eh, _file as Ei, _height as Ej, _groupSize as Ek, observedGroup as El, receivedTime as Em, _doseAndRate as En, definitionCanonical as Eo, QuestionnaireResponseItemComponent as Ep, _typeReference as Eq, PractitionerQualificationComponent as Er, cTerminalModificationId as Es, _requireBoth as Et, dataAbsentReason as Eu, _criticality as Ev, _subjectStatus as Ew, _expiry as Ex, usage as Ey, city as Ez, _chargeItem as F, _EnrollmentResponse as F$, grouping as F0, _pause as F1, _primaryPurposeType as F2, ConceptSubProperty as F3, subscription as F4, _lastPage as F5, partLocation as F6, controller as F7, publicationDateSeason as F8, imports as F9, InventoryItemNameComponent as FA, _minimumId as FB, verificationStatus as FC, _PaymentNotice as FD, _dateAccessed as FE, logMessage as FF, ResearchStudyProgressStatusComponent as FG, _residueSite as FH, MonetaryComponent as FI, TeardownAction as FJ, clinicalUseIssue as FK, classification as FL, _lifecycleStatus as FM, signature as FN, reviewer as FO, _usePeriod as FP, BodyStructureIncludedStructureComponent as FQ, next as FR, _changeType as FS, _ImmunizationEvaluation as FT, requestingOrganization as FU, _unitOfPresentation as FV, requestedPeriod as FW, Answer as FX, count as FY, ContractOffer as FZ, composition as F_, allocation as Fa, _pageCount as Fb, _failureAction as Fc, profile as Fd, cylinder as Fe, deleted as Ff, episodeOfCare as Fg, saturday as Fh, _expectedInResearchStudy as Fi, CommunicationRequestPayloadComponent as Fj, _calculatedAt as Fk, _impurity as Fl, type as Fm, goalId as Fn, ObservationDefinitionComponentComponent as Fo, TestScriptSetupComponent as Fp, Appointment as Fq, _groupIdentifier as Fr, _countMax as Fs, patientCharacteristic as Ft, lowNumerator as Fu, _texture as Fv, _causality as Fw, operator as Fx, fixed as Fy, nTerminalModificationId as Fz, _withdrawalPeriod as G, _reported as G$, ConditionStageComponent as G0, ResearchSubjectProgressComponent as G1, key as G2, assertion as G3, MedicationKnowledgeIndicationGuidelineDosingGuidelinePatientCharacteristicComponent as G4, alternative as G5, plan as G6, _criteria as G7, cycle as G8, _latitude as G9, reportingVendor as GA, current as GB, uid as GC, order as GD, priorPrescription as GE, distanceFromLandmark as GF, VerificationResultValidatorComponent as GG, _recurrenceTemplate as GH, tenderedAmount as GI, _diseaseStatus as GJ, _expirationDate as GK, _dataPeriod as GL, note as GM, _manipulated as GN, _Invoice as GO, RatioRange as GP, _requisition as GQ, ClinicalImpression as GR, _claim as GS, need as GT, contributor as GU, ConceptProperty as GV, ConsentVerificationComponent as GW, TestReportTeardownComponent as GX, _genus as GY, extraDetails as GZ, _location as G_, modifier as Ga, _scoringUnit as Gb, subJurisdiction as Gc, _search as Gd, assignedComparisonGroup as Ge, _alias as Gf, _status as Gg, recurring as Gh, InventoryItemInstanceComponent as Gi, frameOfReferenceUid as Gj, _validationDate as Gk, NutritionOrderEnteralFormulaComponent as Gl, deliveryDevice as Gm, _cardBrand as Gn, adjustment as Go, _cors as Gp, _allergenicIndicator as Gq, _timezone as Gr, _actor as Gs, valueQuantity as Gt, _versionId as Gu, requester as Gv, _SupplyRequest as Gw, MeasureTermComponent as Gx, _containedItemQuantity as Gy, _daysSupply as Gz, CapabilityStatementImplementationComponent as H, _intraspecificType as H$, _codeMap as H0, firstPage as H1, _setup as H2, _paymentBy as H3, custodian as H4, estimatedAge as H5, _observation as H6, technique as H7, Requirements as H8, supplementalData as H9, _experimental as HA, _overbooked as HB, ExampleScenario as HC, AvailabilityNotAvailableTimeComponent as HD, derivedFrom as HE, _postalCode as HF, _endorser as HG, modifierExtension as HH, verified as HI, warning as HJ, _color as HK, _global as HL, _policyBasis as HM, timeFromEvent as HN, costToBeneficiary as HO, Questionnaire as HP, _FormularyItem as HQ, _permittedUnit as HR, data as HS, _targetItem as HT, whyStopped as HU, _practitioner as HV, packageFor as HW, _informationSource as HX, hasMember as HY, _paymentIdentifier as HZ, allowedType as H_, SimpleQuantity as Ha, ProvenanceEntityComponent as Hb, condition as Hc, excludeFoodModifier as Hd, coverageArea as He, contributionInstance as Hf, _productCode as Hg, _language as Hh, base as Hi, _windowStart as Hj, district as Hk, forenameInitials as Hl, _state as Hm, friendly as Hn, AdditionalAttribute as Ho, _Transport as Hp, xhtml as Hq, _official as Hr, CodeSystemConceptDesignationComponent as Hs, _precedence as Ht, _result as Hu, _sliceName as Hv, points as Hw, finding as Hx, _yearlyTemplate as Hy, _isModifierReason as Hz, ImagingStudySeriesPerformerComponent as I, _deliveryDevice as I$, _isDefault as I0, _supportedProfile as I1, _authored as I2, stabilityDuration as I3, InsurancePlanCoverageBenefitLimitComponent as I4, compareToSourcePath as I5, _dosageInstruction as I6, sequence as I7, revenue as I8, SystemInteraction as I9, _page as IA, appointment as IB, AuditEventEntityDetailComponent as IC, productionIdentifierInUDI as ID, _photo as IE, formOf as IF, referrer as IG, _subdetailSequence as IH, CareTeamParticipantComponent as II, SpecimenDefinition as IJ, _affectsState as IK, _inputPopulationId as IL, outputProfile as IM, MessageDefinitionAllowedResponseComponent as IN, numberOfInstances as IO, Term as IP, supportingImmunization as IQ, previousAppointment as IR, seriesDoses as IS, propertyGroup as IT, option as IU, component as IV, offset as IW, materialType as IX, marketingAuthorizationHolder as IY, requestedPerformer as IZ, developmentStage as I_, SubscriptionFilterByComponent as Ia, _requirement as Ib, _reliableCache as Ic, nextScheduled as Id, MeasureGroupComponent as Ie, processNote as If, StratifierGroupPopulation as Ig, issuerType as Ih, capacity as Ii, _rendering as Ij, TestScriptTeardownComponent as Ik, requestIdentifier as Il, _definitionCanonical as Im, v as In, _classification as Io, Claim as Ip, asNeeded as Iq, defaultManualCompletion as Ir, partDescription as Is, articleDate as It, narrative as Iu, participant as Iv, incidence as Iw, div as Ix, _versioning as Iy, RelatedClaim as Iz, analysis as J, previous as J$, _Timing as J0, AdverseEventSuspectEntityCausalityComponent as J1, add as J2, ImmunizationPerformerComponent as J3, _BodyStructure as J4, _organismName as J5, _monthlyTemplate as J6, versionAlgorithm as J7, _deliverFor as J8, ElementDefinitionSlicingComponent as J9, ExampleScenarioProcessStepComponent as JA, _comprisedOf as JB, _factor as JC, _endRelationship as JD, _startingMaterial as JE, expectedSupplyDuration as JF, totalPriceComponent as JG, _signer as JH, enableBehavior as JI, Contract as JJ, _cTerminalModificationId as JK, ObservationReferenceRangeComponent as JL, maxVolumeToDeliver as JM, CapabilityStatementRestResourceOperationComponent as JN, isDerived as JO, conditionalUpdate as JP, repeatUnitAmountType as JQ, subjects as JR, EvidenceVariableCharacteristicTimeFromEventComponent as JS, _expansion as JT, _Ingredient as JU, _phase as JV, _benefitPeriod as JW, Organization as JX, _referenceStrength as JY, StructureMapGroupComponent as JZ, referencePolicy as J_, _responseId as Ja, _tenderedAmount as Jb, upperLimit as Jc, _verificationStatus as Jd, amountType as Je, _patientPaid as Jf, RequestOrchestrationActionOutputComponent as Jg, _quantity as Jh, InsurancePlanPlanSpecificCostBenefitCostComponent as Ji, _alternate as Jj, _contributingFactor as Jk, _sourceIdentityCertificate as Jl, eventNumber as Jm, AdministrableProductDefinitionPropertyComponent as Jn, responseRequired as Jo, _verifiedBy as Jp, _maritalStatus as Jq, _timeOfDay as Jr, contraindication as Js, patientPreparation as Jt, _expression as Ju, _min as Jv, _attester as Jw, _progress as Jx, _collection as Jy, base64Binary as Jz, monitoringProgram as K, _hybrid as K$, _stage as K0, PlanDefinitionActionOutputComponent as K1, _publisherLocation as K2, MedicationKnowledgeIndicationGuidelineDosingGuidelineDosageComponent as K3, containedItemQuantity as K4, copyrightLabel as K5, BodyStructureIncludedStructureBodyLandmarkOrientationComponent as K6, hasBodySite as K7, _valuedItem as K8, Period as K9, _city as KA, reaction as KB, subset as KC, performerRole as KD, retentionTime as KE, _ClinicalImpression as KF, _generalCost as KG, instanceReference as KH, _history as KI, molecularFormulaByMoiety as KJ, _orderer as KK, _payee as KL, _windowEnd as KM, _maxDosePerTreatmentPeriod as KN, sopClass as KO, PlanDefinitionActorOptionComponent as KP, ExampleScenarioInstanceComponent as KQ, organismGeneral as KR, abatement as KS, _relatedDevice as KT, daysSupply as KU, _legal as KV, _EpisodeOfCare as KW, _excludeFoodModifier as KX, weekInterval as KY, _measureScore as KZ, _const as K_, questionnaire as Ka, specificCost as Kb, _collected as Kc, _notAvailableTime as Kd, AllergyIntoleranceParticipantComponent as Ke, headerField as Kf, _contained as Kg, _assigner as Kh, _ifNoneMatch as Ki, DeviceAssociationOperationComponent as Kj, _graph as Kk, changeType as Kl, _orientation as Km, parentSubstanceId as Kn, recorded as Ko, _contributionType as Kp, filterParameter as Kq, positiveInt as Kr, docStatus as Ks, CoverageBenefit as Kt, durationUnit as Ku, contentType as Kv, _addItem as Kw, MedicationKnowledgeIndicationGuidelineDosingGuidelineComponent as Kx, dateRange as Ky, used as Kz, _date as L, postalCode as L$, PackagedProductDefinitionPackagingComponent as L0, _prefix as L1, _publicationDateText as L2, ConceptSet as L3, payeeType as L4, _shelfLifeStorage as L5, balance as L6, _type as L7, dataPeriod as L8, _Immunization as L9, actual as LA, landmarkDescription as LB, typeCanonical as LC, ArtifactAssessmentContentComponentContent as LD, _organizationReference as LE, _minimumVolume as LF, precedence as LG, CitationSummaryComponent as LH, decision as LI, role as LJ, maternalOrganismId as LK, _triggeredBy as LL, MedicationKnowledgeStorageGuidelineComponent as LM, dischargeDisposition as LN, _output as LO, QuestionnaireItemComponent as LP, _compareToSourcePath as LQ, traceNumber as LR, InsurancePlanPlanComponent as LS, object as LT, statusReason as LU, recall as LV, _codeSystem as LW, _processing as LX, gateway as LY, _performerType as LZ, _subcomponent as L_, resourceReference as La, _providedBy as Lb, _fhirVersion as Lc, _HealthcareService as Ld, submitter as Le, description as Lf, combinedPharmaceuticalDoseForm as Lg, _targetScope as Lh, Parameter as Li, BiologicallyDerivedProduct as Lj, _GenomicStudy as Lk, _NutritionProduct as Ll, _additionalContext as Lm, version as Ln, detected as Lo, _statistic as Lp, _bodyStructure as Lq, _definitionExpression as Lr, translations as Ls, _targetProfile as Lt, _notPerformedReason as Lu, ArtifactAssessmentContentComponent as Lv, cost as Lw, CanonicalResource as Lx, _authorizationSupporting as Ly, team as Lz, Medication as M, _procedureSequence as M$, AddedItemDetail as M0, instance as M1, _disposition as M2, _statusDate as M3, _facilityType as M4, _stratum as M5, Payee as M6, _measurementType as M7, RelatedArtifact as M8, RequestOrchestrationActionDynamicValueComponent as M9, _selectionBehavior as MA, _imports as MB, contextLinkId as MC, _eye as MD, affiliation as ME, defaultValue as MF, MolecularSequence as MG, overload as MH, _productName as MI, _comment as MJ, _profile as MK, _deleted as ML, _workflow as MM, _attestationSignature as MN, permittedDataType as MO, gene as MP, _prediction as MQ, exposureRoute as MR, height as MS, _entryClassifier as MT, test as MU, _previousAppointment as MV, implementationGuide as MW, UsageContext as MX, EventDefinition as MY, relatedIdentifier as MZ, ImplementationGuideDependsOnComponent as M_, identity as Ma, subType as Mb, ValueSetExpansionContainsComponent as Mc, MedicationKnowledgePackagingComponent as Md, _display as Me, ImplementationGuideGlobalComponent as Mf, _SubstanceNucleicAcid as Mg, TestScriptSetupActionOperationRequestHeaderComponent as Mh, targetItem as Mi, _dosingGuideline as Mj, _totalGross as Mk, Reference as Ml, _precheckBehavior as Mm, _enableBehavior as Mn, slot as Mo, groupDefinition as Mp, _verifiedWith as Mq, ResourceInteraction as Mr, _numberOfSubunits as Ms, numberOfSeries as Mt, preAuthRefPeriod as Mu, _excludingRecurrenceId as Mv, _baseCitation as Mw, ContractAsset as Mx, ClinicalImpressionFindingComponent as My, stopTestOnFail as Mz, NutritionProductIngredientComponent as N, allowed as N$, _copyrightLabel as N0, _navigationLinks as N1, _generatedBy as N2, administeredProduct as N3, validateProfileId as N4, MedicationKnowledgeIndicationGuidelineComponent as N5, intraspecificDescription as N6, _protocolApplied as N7, _VerificationResult as N8, monthInterval as N9, RelatedPersonCommunicationComponent as NA, _displayName as NB, _monday as NC, messaging as ND, geneElement as NE, exclude as NF, _itemSequence as NG, _artifactAssessment as NH, dispenseRequest as NI, intendedJurisdiction as NJ, _restriction as NK, ImmunizationEvaluation as NL, Observation as NM, _supplier as NN, NutritionIntakePerformerComponent as NO, CapabilityStatementRestComponentSearchParam as NP, _SubstanceReferenceInformation as NQ, _CarePlan as NR, AdverseEventPreventiveActionComponent as NS, outsideFoodAllowed as NT, _maxVolumeToDeliver as NU, InventoryItemAssociationComponent as NV, deliverFor as NW, ElementDefinitionExampleComponent as NX, _totalPriceComponent as NY, _carrierHRF as NZ, _subProperty as N_, expiry as Na, versioning as Nb, pushTypeAvailable as Nc, CitationCitedArtifactStatusDateComponent as Nd, _assertion as Ne, diagnosis as Nf, _ifNoneExist as Ng, _low as Nh, undesirableEffect as Ni, _base as Nj, queryCriteria as Nk, _availableEndTime as Nl, number as Nm, spatialReference as Nn, conditionality as No, _codeFilter as Np, SubstanceDefinitionCharacterizationComponent as Nq, offsets as Nr, _orderedBy as Ns, _authorizationUrl as Nt, _carrierAIDC as Nu, _episodeOfCare as Nv, disabledDisplay as Nw, DocumentReference as Nx, compositeScoring as Ny, _yearInterval as Nz, satisfiedBy as O, _context as O$, _searchType as O0, List as O1, responseId as O2, _defaultManualCompletion as O3, _subscriberId as O4, _groupingId as O5, _protocolPerformed as O6, subPotentReason as O7, maxValue as O8, _data as O9, _contributorship as OA, synthesisType as OB, _anchor as OC, _suppress as OD, _other as OE, variable as OF, MolecularSequenceRelativeComponent as OG, Ingredient as OH, _occurrenceDateTime as OI, Annotation as OJ, SubstanceReferenceInformationGeneComponent as OK, _valueQuantity as OL, DeviceDefinitionCorrectiveActionComponent as OM, OperationDefinitionParameterComponent as ON, EvidenceVariableCharacteristicDefinitionByCombinationComponent as OO, SpecimenDefinitionTypeTestedHandlingComponent as OP, _testRun as OQ, compareToSourceId as OR, _definitional as OS, _testCase as OT, _PaymentReconciliation as OU, valuedItem as OV, relatedItem as OW, consumedItem as OX, search as OY, duration as OZ, status as O_, _disulfideLinkage as Oa, metadata as Ob, ConditionParticipantComponent as Oc, rationale as Od, tax as Oe, _line as Of, index as Og, _firstPage as Oh, verifiedBy as Oi, _requestProvider as Oj, Diagnosis as Ok, _hybridType as Ol, _abnormalCodedValueSet as Om, Encounter as On, expression as Oo, _current as Op, BackboneType as Oq, collection as Or, _family as Os, _validated as Ot, question as Ou, _noMap as Ov, _comparisonGroup as Ow, EnrollmentRequest as Ox, _surfaceOrientation as Oy, prescription as Oz, PlanDefinitionActionParticipantComponent as P, environmentType as P$, _requirements as P0, _subjectType as P1, _use as P2, udi as P3, nameType as P4, _producedFrom as P5, _interval as P6, summary as P7, MedicinalProductDefinitionCharacteristicComponent as P8, sex as P9, TestPlanTestCaseTestRunScriptComponent as PA, distributor as PB, _stopTestOnFail as PC, organizationReference as PD, residueSite as PE, guidance as PF, _originatingAppointment as PG, intended as PH, _measurementFrequency as PI, _variableRole as PJ, assurance as PK, literal as PL, _suppliedItem as PM, ProcedurePerformerComponent as PN, baseUnit as PO, _translation as PP, StructureDefinitionSnapshotComponent as PQ, _name as PR, MedicationRequestDispenseRequestInitialFillComponent as PS, _incidence as PT, _during as PU, _snapshot as PV, SubstancePolymerRepeatRepeatUnitComponent as PW, _format as PX, PlanBenefit as PY, _foodPreferenceModifier as PZ, function__workaround as P_, AdministrableProductDefinition as Pa, SecurityLabel as Pb, SubstanceDefinitionRelationshipComponent as Pc, knownAllergen as Pd, knownDataCount as Pe, observer as Pf, _subtitle as Pg, accessionNumber as Ph, _finding as Pi, _style as Pj, relation as Pk, priority as Pl, _requestId as Pm, ElementDefinitionBindingComponent as Pn, sequenceAttachment as Po, AddedItemBodySite as Pp, _group as Pq, publisher as Pr, consent as Ps, site as Pt, canFilterBy as Pu, TerminologyCapabilitiesValidateCodeComponent as Pv, _isSubPotent as Pw, EncounterParticipantComponent as Px, _cancellationReason as Py, _repetitions as Pz, artifact as Q, uri as Q$, SubscriptionTopicCanFilterByComponent as Q0, occurrenceCount as Q1, careTeamSequence as Q2, _notConsumedReason as Q3, _restoreDate as Q4, providedBy as Q5, meta as Q6, _subDetailSequence as Q7, required as Q8, _dateWritten as Q9, validity as QA, subjectReport as QB, _any as QC, _nextScheduled as QD, administration as QE, sort as QF, ManufacturedItemDefinitionComponentComponentProperty as QG, _sent as QH, _directnessMatch as QI, _targetFormat as QJ, _used as QK, _occurence as QL, _partOf as QM, relativeRisk as QN, supportedMessage as QO, _dateOfDiagnosis as QP, _seriesNumber as QQ, DataRequirementSortComponent as QR, ChargeItemDefinitionPropertyGroupComponentApplicability as QS, codeSystem as QT, processing as QU, _ResearchSubject as QV, _heartbeatPeriod as QW, ValueSetExpansionPropertyComponent as QX, orderDetail as QY, Group as QZ, statusDate as Q_, _deviceIdentifier as Qa, referral as Qb, _conditionality as Qc, AuditEventSourceComponent as Qd, _component as Qe, link as Qf, _hasStage as Qg, _contentReference as Qh, program as Qi, OtherElement as Qj, scoringUnit as Qk, _maxCount as Ql, ExplanationOfBenefitEventComponent as Qm, _ArtifactAssessment as Qn, scope as Qo, inventoryListing as Qp, concentration as Qq, _device as Qr, hierarchyMeaning as Qs, CapabilityStatementRestComponentOperation as Qt, otherMap as Qu, answerConstraint as Qv, normalCodedValueSet as Qw, global as Qx, excludingRecurrenceId as Qy, _SubstanceSourceMaterial as Qz, RequestOrchestration as R, _comorbidity as R$, max as R0, _conformance as R1, _unitPriceComponent as R2, _availabilityStatus as R3, _exitCriteria as R4, Schedule as R5, BiologicallyDerivedProductCollectionComponent as R6, DomainResource as R7, _AdverseEvent as R8, focalDevice as R9, _activity as RA, prediction as RB, _mimeType as RC, exception as RD, ImplementationGuideDefinitionTemplateComponent as RE, _edit as RF, _usage as RG, proposedNewTime as RH, security as RI, _parameter as RJ, InventoryItemDescriptionComponent as RK, ConditionDefinitionPreconditionComponent as RL, LocationPositionComponent as RM, sequenceRange as RN, policyBasis as RO, _inputParameters as RP, _dateRange as RQ, _cost as RR, Timing as RS, _team as RT, _paternalOrganismId as RU, _statusChanged as RV, ActivityDefinitionDynamicValueComponent as RW, processor as RX, _constraint as RY, _sampleSize as RZ, ClinicalUseDefinitionContraindicationComponent as R_, _authorType as Ra, mode as Rb, observation as Rc, _issuer as Rd, ClaimEventComponent as Re, FamilyMemberHistoryParticipantComponent as Rf, _validationStatus as Rg, string as Rh, productCode as Ri, receiver as Rj, CitationCitedArtifactTitleComponent as Rk, totalGross as Rl, _outputProfile as Rm, conditionalDelete as Rn, baseDefinition as Ro, NutritionProductInstanceComponent as Rp, ClinicalUseDefinitionIndicationComponent as Rq, relevantHistory as Rr, referenceInformation as Rs, valueSet as Rt, library as Ru, InventoryReportInventoryListingItemComponent as Rv, performedActivity as Rw, Coverage as Rx, probability as Ry, TerminologyCapabilitiesSoftwareComponent as Rz, StructureMapGroupRuleComponent as S, practiceSetting as S$, _knownDataCount as S0, template as S1, codeFilter as S2, dateAccessed as S3, _organization as S4, _ifModifiedSince as S5, _lastRevisionDate as S6, _strength as S7, numerator as S8, _altitude as S9, variableDefinition as SA, manifestation as SB, searchType as SC, PaymentReconciliation as SD, _modelNumber as SE, groupingId as SF, _VisionPrescription as SG, performerLinkId as SH, procedure as SI, implicitRules as SJ, query as SK, Items as SL, _slot as SM, _conditionalCreate as SN, PatientCommunicationComponent as SO, ConditionDefinitionMedicationComponent as SP, documentation as SQ, maxDosePerTreatmentPeriod as SR, example as SS, _sessionKey as ST, lastPage as SU, hybridType as SV, field as SW, maxDosePerPeriod as SX, _excludedStructure as SY, _script as SZ, acceptLanguage as S_, _countingDateTime as Sa, MedicationDispense as Sb, _maxDuration as Sc, requirement as Sd, SubstanceProteinSubunitComponent as Se, _abatement as Sf, reportingPeriod as Sg, dosage as Sh, _supplement as Si, _treatmentIntent as Sj, performingOrganization as Sk, _what as Sl, intervalUnit as Sm, preAuthPeriod as Sn, fhirPathCriteria as So, administeredBy as Sp, factor as Sq, ContactPoint as Sr, appointmentType as Ss, _collector as St, answerValueSet as Su, _achievementStatus as Sv, carrierHRF as Sw, _evaluatedResource as Sx, signer as Sy, _usageReason as Sz, timing as T, latitude as T$, brand as T0, _attributeEstimate as T1, _end as T2, diagnosisSequence as T3, _specification as T4, _test as T5, _durationMax as T6, impurity as T7, _Practitioner as T8, SubstanceIngredientComponent as T9, _disclaimer as TA, _definitionByCombination as TB, step as TC, fractionDescription as TD, valueCategory as TE, requestMethod as TF, BodySite as TG, etag as TH, specimenQuantity as TI, comprisedOf as TJ, _pediatricUseIndicator as TK, _destination as TL, _evaluationMessage as TM, ResearchStudyComparisonGroupComponent as TN, _DomainResource as TO, CitationCitedArtifactWebLocationComponent as TP, beneficiary as TQ, prefix as TR, effectiveTime as TS, RegulatedAuthorizationCaseComponent as TT, AccountProcedureComponent as TU, doseStatusReason as TV, ResearchStudyAssociatedPartyComponent as TW, reason as TX, _precondition as TY, criteria as TZ, MedicationAdministrationDosageComponent as T_, control as Ta, _enterer as Tb, TransportOutputComponent as Tc, _retentionTime as Td, _encodeRequestUrl as Te, countMax as Tf, _netContent as Tg, AccountBalanceComponent as Th, _sequenceAttachment as Ti, requestedLocation as Tj, DeviceDefinitionRegulatoryIdentifierComponent as Tk, _target as Tl, _implicated as Tm, _administration as Tn, _flag as To, _party as Tp, _version as Tq, provision as Tr, patientPaid as Ts, referenceNumber as Tt, manifest as Tu, Account as Tv, _goal as Tw, _basis as Tx, MessageSource as Ty, _formCode as Tz, appliesToAll as U, country as U$, IngredientSubstanceStrengthReferenceStrengthComponent as U0, _thursday as U1, securityContext as U2, _baseDefinition as U3, _publicationStatus as U4, relatedArtifact as U5, safety as U6, stereochemistry as U7, _timeout as U8, primarySource as U9, MedicationStatementAdherenceComponent as UA, _onAdmission as UB, output as UC, _indication as UD, DeviceDefinitionChargeItemComponent as UE, location as UF, generalCost as UG, _plannedActivityReference as UH, rules as UI, reported as UJ, maxDosePerDay as UK, NutritionOrderOralDietTextureComponent as UL, _definitionByTypeAndValue as UM, GroupMemberComponent as UN, _verificationType as UO, _supportingInformation as UP, kingdom as UQ, sourceMaterialClass as UR, _polymer as US, insurance as UT, _handling as UU, supportingInfo as UV, lifecycleStatus as UW, _symptomConditionEffect as UX, _fraction as UY, language as UZ, combining as U_, NutritionOrderOralDietNutrientComponent as Ua, responseCode as Ub, eventHistory as Uc, _doseForm as Ud, _allowedResponse as Ue, _storageGuideline as Uf, timezone as Ug, copolymerConnectivity as Uh, GenomicStudyAnalysisOutputComponent as Ui, _molecularWeight as Uj, ObservationDefinition as Uk, ifNoneMatch as Ul, _notConsumed as Um, grade as Un, OralDietSchedule as Uo, _diagnosis as Up, _channelType as Uq, _encounter as Ur, SubstancePolymerMonomerSetStartingMaterialComponent as Us, statisticType as Ut, _webLocation as Uu, SubstanceSourceMaterialOrganismOrganismGeneralComponent as Uv, textConcentration as Uw, _multipleAnd as Ux, _freeToShare as Uy, _contributionInstance as Uz, VisionPrescriptionLensSpecificationComponent as V, InvoiceParticipantComponent as V$, isExample as V0, _readHistory as V1, BundleLinkComponent as V2, currentLocation as V3, official as V4, _EncounterHistory as V5, EvidenceVariableCategoryComponent as V6, _administeredBy as V7, _ProductShelfLife as V8, SubstanceDefinitionMolecularWeightComponent as V9, contentDefinition as VA, due as VB, structureProfile as VC, _acceptLanguage as VD, _RegulatedAuthorization as VE, authorType as VF, paymentIssuer as VG, clinicalTrial as VH, _parentSubstanceName as VI, _high as VJ, actorId as VK, _document as VL, _marketPeriod as VM, _denominator as VN, accessionIdentifier as VO, VerificationResultPrimarySourceComponent as VP, authored as VQ, serialNumber as VR, Consent as VS, _resourceType as VT, outcomeMeasure as VU, purpose as VV, DiagnosticReportSupportingInfoComponent as VW, Citation as VX, _serviced as VY, performer as VZ, _stratifier as V_, affectsState as Va, notificationShape as Vb, descriptionSummary as Vc, _answerValueSet as Vd, PractitionerRole as Ve, _rationale as Vf, _ChargeItem as Vg, _offer as Vh, OperationDefinitionParameterReferencedFromComponent as Vi, singleUse as Vj, _exclude as Vk, fhirVersion as Vl, _nucleicAcid as Vm, CodeableConcept as Vn, _Claim as Vo, _site as Vp, targetScope as Vq, _monthInterval as Vr, _monitoringProgram as Vs, mustHaveValue as Vt, _interpreter as Vu, SubscriptionStatus as Vv, _productOrServiceEnd as Vw, doseQuantity as Vx, _prism as Vy, highNumerator as Vz, _appointmentRequired as W, _estimate as W$, requiredBehavior as W0, _oralDiet as W1, monday as W2, MedicationRequestDispenseRequestComponent as W3, _subJurisdiction as W4, _interactant as W5, _admitSource as W6, TargetElement as W7, _given as W8, _recorder as W9, _identityCertificate as WA, _additional as WB, _assurance as WC, _careManager as WD, ImageRegion2D as WE, forecastReason as WF, supplement as WG, _nutrient as WH, _sugar as WI, entryReference as WJ, _citedMedium as WK, MeasureSupplementalDataComponent as WL, input as WM, ManufacturedItemDefinition as WN, Prism as WO, GroupCharacteristicComponent as WP, _qualifier as WQ, GraphDefinition as WR, _BiologicallyDerivedProduct as WS, _Procedure as WT, _receivedTime as WU, quantity as WV, _linkId as WW, ManufacturedItemDefinitionComponentComponentComponentComponent as WX, _prescriber as WY, EvidenceReportSubjectCharacteristicComponent as WZ, hasSeverity as W_, hasPart as Wa, _cancellationDate as Wb, supplements as Wc, constraint as Wd, total as We, outcome as Wf, sampleSize as Wg, ContributorshipSummary as Wh, PrimitiveType as Wi, caloricDensity as Wj, MedicationKnowledgeStorageGuidelineEnvironmentalSettingComponent as Wk, _clinicalUseIssue as Wl, LinkageItemComponent as Wm, AdministrableProductDefinitionRouteOfAdministrationComponent as Wn, _conditionalUpdate as Wo, _publisher as Wp, MolecularSequenceRelativeStartingSequenceComponent as Wq, _validator as Wr, _inactive as Ws, AppointmentResponse as Wt, _molecularFormula as Wu, payload as Wv, subSite as Ww, _sort as Wx, TestScriptOriginComponent as Wy, _allergyIntolerance as Wz, _canFilterBy as X, binding as X$, certainty as X0, _billingStatus as X1, ContactDetail as X2, sessionKey as X3, calibration as X4, _literal as X5, ConditionDefinitionQuestionnaireComponent as X6, _dateTime as X7, CoverageEligibilityRequest as X8, _repeatUnitAmountType as X9, implicated as XA, _actualGroup as XB, _SubstanceProtein as XC, _capabilities as XD, _associatedParty as XE, _supplementalData as XF, _program as XG, offeredIn as XH, TerminologyCapabilitiesCodeSystemComponent as XI, multipleBirth as XJ, _replacedSequence as XK, disclaimer as XL, InsurancePlan as XM, _installDate as XN, _extends as XO, fundsReserve as XP, assigner as XQ, SpecimenProcessingComponent as XR, occurred as XS, _lockedDate as XT, GenomicStudyAnalysisPerformerComponent as XU, _lowNumerator as XV, _classifier as XW, resultsInterpreter as XX, _limit as XY, _serviceProvider as XZ, patientInstruction as X_, pediatricUseIndicator as Xa, SampledData as Xb, attester as Xc, originatingAppointment as Xd, progress as Xe, _frequencyMax as Xf, measureScore as Xg, InsurancePlanCoverageComponent as Xh, Evidence as Xi, _operationalStatus as Xj, ImagingSelectionPerformerComponent as Xk, restriction as Xl, _issues as Xm, dose as Xn, _updateCreate as Xo, _supportingInfo as Xp, warningOnly as Xq, _coverage as Xr, informationSequence as Xs, netContent as Xt, representation as Xu, _typeMode as Xv, subProperty as Xw, _subscription as Xx, Library as Xy, DeviceMetricCalibrationComponent as Xz, filter as Y, DetectedIssueMitigationComponent as Y$, recurrenceType as Y0, during as Y1, capability as Y2, Substance as Y3, suspectEntity as Y4, QuestionnaireItemInitialComponent as Y5, occurrenceDate as Y6, monthlyTemplate as Y7, supportingInformation as Y8, authorizationRequired as Y9, _accident as YA, endRelationship as YB, structure as YC, _library as YD, _descriptionSummary as YE, baseCitation as YF, definitionId as YG, _coordinateSystem as YH, characteristicType as YI, _entry as YJ, imageRegion2D as YK, _DeviceDefinition as YL, conclusionCode as YM, BiologicallyDerivedProductDispensePerformerComponent as YN, _caloricDensity as YO, ManufacturedItemDefinitionComponentComponent as YP, _focal as YQ, indication as YR, _AllergyIntolerance as YS, _publishedIn as YT, partOf as YU, _initialSelected as YV, _key as YW, backCurve as YX, _path as YY, definitionUri as YZ, ExplanationOfBenefitItemReviewOutcomeComponent as Y_, _versionReference as Ya, ImmunizationRecommendationRecommendationComponent as Yb, _measurementPoint as Yc, batch as Yd, _include as Ye, ValueSetComposeIncludeFilterComponent as Yf, subcomponent as Yg, _DetectedIssue as Yh, _GuidanceResponse as Yi, _participantType as Yj, _division as Yk, _section as Yl, _MedicationAdministration as Ym, _outcomeMeasure as Yn, PackagingDistributor as Yo, _serviceType as Yp, _subjectReport as Yq, _initialFill as Yr, _administrableDoseForm as Ys, areaOfHybridisation as Yt, subjectType as Yu, device as Yv, AddedItem as Yw, _region as Yx, MedicationKnowledgeRegulatorySubstitutionComponent as Yy, MeasureReportGroupComponent as Yz, _targetNumber as Z, _artifact as Z$, _lastOccurrenceDate as Z0, _enableWhen as Z1, time as Z2, MedicinalProductDefinitionNameUsageComponent as Z3, ChargeItemDefinitionApplicabilityComponent as Z4, InventoryItemCharacteristicComponent as Z5, _dischargeDisposition as Z6, isModifierReason as Z7, StructureDefinitionContextComponent as Z8, _forecastReason as Z9, _intendedRoute as ZA, score as ZB, DeviceRequestParameterComponent as ZC, _diseaseSymptomProcedure as ZD, _validationProcess as ZE, ExampleScenarioProcessComponent as ZF, _timestamp as ZG, supportedProfile as ZH, TestReportSetupActionAssertComponent as ZI, _label as ZJ, _preparationInstruction as ZK, InventoryItemResponsibleOrganizationComponent as ZL, informationType as ZM, BodyStructureIncludedStructure as ZN, _requesterLinkId as ZO, PlanDefinition as ZP, postConditions as ZQ, EvidenceVariableDefinitionComponent as ZR, _meaningWhenMissing as ZS, DeviceDispense as ZT, _modelCharacteristic as ZU, SetupAction as ZV, _studyDesign as ZW, _analysis as ZX, insurancePlan as ZY, communicationRequest as ZZ, specialty as Z_, SubstanceDefinitionMoietyComponent as Za, _step as Zb, rest as Zc, issuer as Zd, _nutritionProduct as Ze, SubstancePolymer as Zf, ValueSetComposeComponent as Zg, _doseNumber as Zh, SubstanceDefinitionNameComponent as Zi, derivedFromUri as Zj, _startParam as Zk, _attribute as Zl, _extraDetails as Zm, _accessionIdentifier as Zn, _entryReference as Zo, Parameters as Zp, ChargeItem as Zq, _uid as Zr, chain as Zs, _bodySite as Zt, qualification as Zu, yearInterval as Zv, _developmentStage as Zw, riskAdjustment as Zx, _estimatedAge as Zy, RequirementsStatementComponent as Zz, _careTeam as _, inputPopulationId as _$, chargeItemCode as _0, actuality as _1, _maxParticipants as _2, _Basic as _3, _example as _4, _representation as _5, telecom as _6, EvidenceCertaintyComponentCertaintyCertainty as _7, _lastPerformed as _8, _legalState as _9, association as _A, _intendedJurisdiction as _B, _recurrenceType as _C, when as _D, form as _E, _complete as _F, _shortDoco as _G, differential as _H, _occurrenceDate as _I, additional as _J, canonical as _K, _actualComparisonGroup as _L, _requestor as _M, CommunicationPayloadComponent as _N, AccountDiagnosisComponent as _O, _doseStatus as _P, TestScriptTestComponent as _Q, TaskOutputComponent as _R, MeasureReport as _S, producedFrom as _T, tuesday as _U, _sourceReference as _V, crossReference as _W, _Composition as _X, subdetailSequence as _Y, _definitionReference as _Z, supplier as __, _preAuthPeriod as _a, GraphDefinitionLinkComponent as _b, workflow as _c, _incomplete as _d, _sphere as _e, _substanceDefinition as _f, informationSource as _g, _periodUnit as _h, paymentIdentifier as _i, stratifier as _j, pause as _k, _isActive as _l, _synonym as _m, _manifestation as _n, _control as _o, RegulatedAuthorizationCaseComponentCase as _p, dosageInstruction as _q, _implicitRules as _r, AvailabilityAvailableTimeComponent as _s, SpecimenCollectionComponent as _t, regulatoryAuthority as _u, _EnrollmentRequest as _v, hash as _w, marketDistribution as _x, countType as _y, _documentation as _z, _answerOption as a, _performingOrganization as a$, _management as a0, _organismId as a0$, Distance as a00, _primarySource as a01, _opticalActivity as a02, _multipleOr as a03, _specialMeasures as a04, usageReason as a05, GoalTargetComponent as a06, measure as a07, contributionType as a08, modelNumber as a09, insurer as a0A, DeviceDefinitionLinkComponent as a0B, container as a0C, _params as a0D, Goal as a0E, lockedDate as a0F, symptomConditionEffect as a0G, referenceStrength as a0H, interval as a0I, _compartment as a0J, classifier as a0K, PackagedProductDefinitionPackagingPropertyComponent as a0L, setup as a0M, _areaOfHybridisation as a0N, maxLength as a0O, publisherLocation as a0P, RelatedPerson as a0Q, _storageTempRequirements as a0R, _Organization as a0S, _postConditions as a0T, _DeviceDispense as a0U, state as a0V, SubstanceDefinitionSourceMaterialComponent as a0W, _aggregate as a0X, fluidConsistencyType as a0Y, MoneyQuantity as a0Z, _specificCost as a0_, _derivedFromUri as a0a, _method as a0b, effectiveDate as a0c, _servicePeriod as a0d, asNeededFor as a0e, ExplanationOfBenefit as a0f, _add as a0g, _cancelledReason as a0h, orderMeaning as a0i, testCase as a0j, net as a0k, VerificationResultAttestationComponent as a0l, _class as a0m, claim as a0n, Flag as a0o, _riskAdjustment as a0p, _compareToSourceExpression as a0q, _notificationEvent as a0r, guideline as a0s, amount as a0t, _dateFilter as a0u, _statisticType as a0v, genus as a0w, _MessageHeader as a0x, _administrationTreatment as a0y, _country as a0z, _phylum as a1, _hoursOfOperation as a1$, StructureMapGroupInputComponent as a10, _check as a11, _chargeItemCode as a12, ownedBy as a13, _participantStatus as a14, _baseFormulaType as a15, shelfLifeStorage as a16, authorizingPrescription as a17, protein as a18, connectivity as a19, _import as a1A, TaskPerformerComponent as a1B, grantor as a1C, _purpose as a1D, benefit as a1E, contributorship as a1F, PlanDefinitionActionDynamicValueComponent as a1G, ImagingStudySeriesComponent as a1H, programStatus as a1I, _evidence as a1J, ClinicalUseDefinitionInteractionInteractantComponent as a1K, _highNumerator as a1L, ChargeItemDefinitionPropertyGroupComponent as a1M, boolean as a1N, PackagedProductDefinitionProperty as a1O, _Group as a1P, _media as a1Q, hasStage as a1R, TestReportSetupActionAssertRequirementComponent as a1S, _onBehalfOf as a1T, SubstanceReferenceInformationGeneElementComponent as a1U, maxCount as a1V, enableWhen as a1W, regulator as a1X, _medicineClassification as a1Y, imageRegion3D as a1Z, _source as a1_, information as a1a, DeviceDefinitionVersionComponent as a1b, AdverseEvent as a1c, _originRelationshipType as a1d, definitionExpression as a1e, ServiceRequestOrderDetailParameterComponent as a1f, TestPlan as a1g, requestProvider as a1h, _formatted as a1i, NutritionProduct as a1j, ActorDefinition as a1k, RegulatedAuthorization as a1l, _facility as a1m, sourceDocument as a1n, _morphology as a1o, _kind as a1p, color as a1q, _bounds as a1r, snapshot as a1s, SpecimenContainerComponent as a1t, unsignedInt as a1u, MedicationKnowledgeMedicineClassificationComponent as a1v, ImmunizationProgramEligibilityComponent as a1w, _dose as a1x, useBy as a1y, _start as a1z, _distributor as a2, license as a2$, admission as a20, extension as a21, _reAdmission as a22, integer64 as a23, _Task as a24, HealthcareService as a25, _Appointment as a26, _crossReference as a27, _hasPart as a28, _executionPeriod as a29, photo as a2A, multipleAnd as a2B, _gender as a2C, _coding as a2D, _system as a2E, _Slot as a2F, freeToShare as a2G, ElementDefinitionMappingComponent as a2H, copackagedIndicator as a2I, precheckBehavior as a2J, map as a2K, additionalInfo as a2L, preConditions as a2M, numberOfSubunits as a2N, numberOfEvents as a2O, _sender as a2P, _validCodedValueSet as a2Q, _referenceInformation as a2R, longitude as a2S, _contentDerivative as a2T, _reportedDateTime as a2U, Primitive as a2V, _processingMode as a2W, _composition as a2X, _width as a2Y, _valueAlternatives as a2Z, hint as a2_, Expression as a2a, Class as a2b, _operation as a2c, _adjustmentReason as a2d, notConsumed as a2e, relativePath as a2f, ImplementationGuideDefinitionComponent as a2g, geneSequenceOrigin as a2h, level as a2i, TestReportTestComponent as a2j, doseNumber as a2k, ParametersParameterComponentParameterParameter as a2l, age as a2m, _payload as a2n, entityRelatedness as a2o, startParam as a2p, _intraspecificDescription as a2q, _clinicalStatus as a2r, _compositeScoring as a2s, jurisdiction as a2t, Exemption as a2u, _requestHeader as a2v, _certainty as a2w, connectionType as a2x, _groupingBehavior as a2y, _translations as a2z, _clinicalRecommendationStatement as a3, _numberOfRepeatsAllowed as a3$, created as a30, expectedInResearchStudy as a31, originalPrescription as a32, scoring as a33, ClinicalUseDefinitionInteractionComponent as a34, PlanDefinitionActorComponent as a35, subjectStatus as a36, _qualitativeRisk as a37, _header as a38, recurrenceId as a39, CapabilityStatementRestResourceComponent as a3A, _lineItem as a3B, _InventoryReport as a3C, _copyright as a3D, _Substance as a3E, _timing as a3F, wasSubstituted as a3G, aggregation as a3H, _authorDescription as a3I, _filter as a3J, MedicinalProductDefinitionOperationComponent as a3K, _defaultValue as a3L, StructureMapStructureComponent as a3M, recipient as a3N, _lotNumber as a3O, QuestionnaireItemAnswerOptionComponent as a3P, applies as a3Q, caseSensitive as a3R, subtype as a3S, _field as a3T, _hasIngredient as a3U, strength as a3V, linkId as a3W, StructureMapGroupRuleTargetComponent as a3X, _resultingEffect as a3Y, altitude as a3Z, phase as a3_, _author as a3a, responsibleOrganization as a3b, TriggerDefinition as a3c, _BackboneElement as a3d, _offeredIn as a3e, _accessionNumber as a3f, legalState as a3g, incomplete as a3h, CodeableReference as a3i, activity as a3j, availableEndTime as a3k, mimeType as a3l, NutritionOrderEnteralFormulaAdministrationComponent as a3m, periodUnit as a3n, EvidenceReportRelatesToComponent as a3o, SubstanceDefinition as a3p, _useContext as a3q, _instantiatesUri as a3r, authorizationUrl as a3s, contributedToDeath as a3t, confidentialityIndicator as a3u, _diagnosisSequence as a3v, selectionBehavior as a3w, _time as a3x, addresses as a3y, _dataRequirement as a3z, _manifest as a4, _careTeamSequence as a4$, groupSize as a40, _oligoNucleotideType as a41, doseStatus as a42, directnessMatch as a43, AppointmentParticipantComponent as a44, _continuous as a45, _dispenseInterval as a46, stage as a47, associatedMedication as a48, dateOfDiagnosis as a49, _InsurancePlan as a4A, repeatUnit as a4B, StructureDefinition as a4C, _node as a4D, TestPlanTestCaseAssertionComponent as a4E, relatedData as a4F, _content as a4G, _associationType as a4H, _regulatoryBasis as a4I, attachment as a4J, ActionSubject as a4K, _packagedMedicinalProduct as a4L, _packagedProduct as a4M, _onset as a4N, _basedOn as a4O, CitationCitedArtifactRelatesToComponent as a4P, _backCurve as a4Q, AuditEventOutcomeComponent as a4R, payee as a4S, _reporter as a4T, SubstanceDefinitionStructureComponentMolecularWeight as a4U, biologicalSourceEvent as a4V, RequestOrchestrationActionComponent as a4W, period as a4X, SearchParameterComponentComponent as a4Y, protocolPerformed as a4Z, ResearchStudyLabelComponent as a4_, _actualPeriod as a4a, ValueSet as a4b, lastOccurrence as a4c, disulfideLinkage as a4d, participatingOrganization as a4e, ResearchSubject as a4f, heartbeatPeriod as a4g, OrganizationAffiliation as a4h, _binding as a4i, SubstanceNucleicAcidSubunitLinkageComponent as a4j, ImplementationGuideDefinitionPageComponent as a4k, FamilyMemberHistoryProcedureComponent as a4l, subscriptionTopic as a4m, _resource as a4n, correspondingContact as a4o, graph as a4p, _QuestionnaireResponse as a4q, RequestOrchestrationActionComponentAction as a4r, issues as a4s, instances as a4t, _isDefining as a4u, primaryPurposeType as a4v, _specimenRequirement as a4w, _sourceDocument as a4x, SubstanceReferenceInformation as a4y, _multipleBirth as a4z, cancellationDate as a5, ElementDefinitionConstraintComponent as a5$, instantiates as a50, _patientCharacteristic as a51, _allowedType as a52, Element as a53, DeviceMetric as a54, _maxTreatmentPeriod as a55, _InventoryItem as a56, AppointmentRecurrenceTemplateComponent as a57, targetDisease as a58, PlanDefinitionActionComponentAction as a59, MessageDestination as a5A, _additionalInfo as a5B, _numberOfEvents as a5C, _includedStructure as a5D, _imageRegion2D as a5E, _tax as a5F, _appointment as a5G, treatmentIntent as a5H, SubstanceDefinitionCodeComponent as a5I, _study as a5J, _ratioType as a5K, policyHolder as a5L, region as a5M, operationType as a5N, _actuality as a5O, _definitionUri as a5P, organismId as a5Q, ManufacturedItemDefinitionComponentComponentComponentProperty as a5R, _consumedItem as a5S, thursday as a5T, _rules as a5U, dependent as a5V, deliverFrom as a5W, ImmunizationProtocolAppliedComponent as a5X, actualGroup as a5Y, Age as a5Z, subsumption as a5_, file as a5a, const__workaround as a5b, citedMedium as a5c, _frames as a5d, multipleOr as a5e, inputParameters as a5f, causality as a5g, SupplyDelivery as a5h, minimumId as a5i, _processNote as a5j, Money as a5k, _BackboneType as a5l, _Endpoint as a5m, udiDeviceIdentifier as a5n, EnteralFormulaSchedule as a5o, diseaseStatus as a5p, _expectedSupplyDuration as a5q, ifModifiedSince as a5r, formCode as a5s, _connectionType as a5t, ImplementationGuideDefinitionResourceComponent as a5u, _fundsReserveRequested as a5v, dateFilter as a5w, matchStatus as a5x, usePeriod as a5y, _participant as a5z, _doseQuantity as a6, Patient as a6$, subjectResults as a60, OperationDefinitionOverloadComponent as a61, recurrenceTemplate as a62, doseForm as a63, adherence as a64, ServiceRequest as a65, deviceIdentifier as a66, _reasonLinkId as a67, versionId as a68, componentPart as a69, MessageHeaderResponseComponent as a6A, Linkage as a6B, permittedUnit as a6C, _sex as a6D, genomeBuild as a6E, changePattern as a6F, MedicationRequestSubstitutionComponent as a6G, _authority as a6H, onBehalfOf as a6I, _rateAggregation as a6J, managingOrganization as a6K, handling as a6L, notConsumedReason as a6M, axis as a6N, _udiCarrier as a6O, paymentBy as a6P, _insurancePlan as a6Q, subDetailSequence as a6R, DataRequirementValueFilterComponent as a6S, problem as a6T, initialFill as a6U, _ManufacturedItemDefinition as a6V, _improvementNotation as a6W, ClinicalUseDefinitionIndicationComponentOtherTherapy as a6X, fraction as a6Y, _lastOccurrence as a6Z, _assessment as a6_, _value as a6a, TestReportParticipantComponent as a6b, morphology as a6c, date as a6d, _isModifier as a6e, _allDay as a6f, contentReference as a6g, _sunday as a6h, DeviceUsageAdherenceComponent as a6i, maxSingleDose as a6j, referenceRange as a6k, _pages as a6l, DeviceDefinitionGuidelineComponent as a6m, _temperatureRange as a6n, _sequenceType as a6o, _partNumber as a6p, _term as a6q, StructureDefinitionDifferentialComponent as a6r, _udi as a6s, _telecom as a6t, CitationCitedArtifactPublicationFormPublishedInComponent as a6u, _wasSubstituted as a6v, initial as a6w, doNotPerform as a6x, diameter as a6y, _property as a6z, DeviceDefinitionPackagingComponentUdiDeviceIdentifier as a7, serviced as a7$, _identified as a70, ExplanationOfBenefitAdjudication as a71, _Subscription as a72, tag as a73, _performed as a74, _formOf as a75, DeviceDefinitionPackagingComponentPackagingPackaging as a76, _subrogation as a77, _deceased as a78, relatedAccount as a79, allowedResponse as a7A, _ElementDefinition as a7B, CitationCitedArtifactContributorshipComponent as a7C, _contentType as a7D, _DeviceUsage as a7E, DeviceDefinitionUdiDeviceIdentifierComponent as a7F, document as a7G, event as a7H, Guarantor as a7I, molecularWeight as a7J, substitution as a7K, NutritionOrderSupplementComponent as a7L, _relativeRisk as a7M, _volume as a7N, _manager as a7O, _presentation as a7P, _linkage as a7Q, isDefault as a7R, BodyStructure as a7S, _relationship as a7T, _maxDispense as a7U, ChargeItemDefinition as a7V, _SupplyDelivery as a7W, _specialArrangement as a7X, DosageDoseAndRateComponent as a7Y, _guideline as a7Z, _grantee as a7_, Transport as a7a, Measure as a7b, RiskAssessment as a7c, _teardown as a7d, degreeOfPolymerisation as a7e, _CoverageEligibilityRequest as a7f, _Medication as a7g, manufacturedDoseForm as a7h, sliceName as a7i, dateAsserted as a7j, ContractParty as a7k, validationStatus as a7l, TestScriptMetadataComponent as a7m, _headerField as a7n, geographicalLocation as a7o, versionNeeded as a7p, ConceptDefinition as a7q, _sigFormat as a7r, publishedIn as a7s, sphere as a7t, _SubstanceDefinition as a7u, SubstanceDefinitionNameOfficialComponent as a7v, _listRuleId as a7w, started as a7x, EvidenceVariable as a7y, ResearchStudyOutcomeMeasureComponent as a7z, VerificationResult as a8, _currentLocation as a8$, _active as a80, _preference as a81, useContext as a82, _container as a83, justification as a84, oralDiet as a85, _testingDestination as a86, lastRevisionDate as a87, NutritionIntakeIngredientLabelComponent as a88, QuestionnaireResponseItemComponentItem as a89, compareToSourceExpression as a8A, nutrient as a8B, _subjectResults as a8C, DocumentReferenceRelatesToComponent as a8D, ImagingStudy as a8E, AppointmentRecurrenceTemplateYearlyTemplateComponent as a8F, SpecimenFeatureComponent as a8G, _ServiceRequest as a8H, tester as a8I, seriousness as a8J, isDefining as a8K, contributingFactor as a8L, CapabilityStatement as a8M, _ImagingSelection as a8N, _unmapped as a8O, compositional as a8P, fundsReserveRequested as a8Q, Total as a8R, _citeAs as a8S, _protein as a8T, _referenceRange as a8U, complication as a8V, SubscriptionTopicResourceTriggerComponent as a8W, estimate as a8X, _material as a8Y, Item as a8Z, encodeRequestUrl as a8_, PermissionJustificationComponent as a8a, recorder as a8b, ImmunizationRecommendationRecommendationDateCriterionComponent as a8c, _focus as a8d, countingDateTime as a8e, MedicationKnowledge as a8f, ConditionDefinition as a8g, noMap as a8h, _userSelected as a8i, appointmentRequired as a8j, _numberOfStudies as a8k, capabilities as a8l, Benefit as a8m, _uri as a8n, _max as a8o, inactive as a8p, other as a8q, dependsOn as a8r, citedArtifact as a8s, fixture as a8t, _insurer as a8u, _endParam as a8v, continuous as a8w, SubstancePolymerRepeatRepeatUnitStructuralRepresentationComponent as a8x, _responsibleOrganization as a8y, url as a8z, preference as a9, _releaseDate as a9$, style as a90, method as a91, _MarketingStatus as a92, group as a93, achievementStatus as a94, evaluatedResource as a95, _udiDeviceIdentifier as a96, _RelatedPerson as a97, dateTime as a98, _intervalUnit as a99, typeMode as a9A, ValueSetScopeComponent as a9B, SupplyRequestParameterComponent as a9C, attributeEstimate as a9D, immutable as a9E, _relatedAccount as a9F, _RiskAssessment as a9G, BiologicallyDerivedProductPropertyComponent as a9H, _totalVolume as a9I, _adjudication as a9J, history as a9K, _isSubpotent as a9L, _longitude as a9M, _sliceIsConstraining as a9N, collected as a9O, medicineClassification as a9P, Signature as a9Q, ConceptReference as a9R, TransportRestrictionComponent as a9S, _rank as a9T, _inResponseTo as a9U, CitationCitedArtifactAbstractComponent as a9V, _error as a9W, origin as a9X, treeRoot as a9Y, _sourceMaterialType as a9Z, bodyStructure as a9_, text as a9a, _contact as a9b, searchInclude as a9c, _fivePrime as a9d, timeOfDay as a9e, originRelationshipType as a9f, CitationClassificationComponent as a9g, _plannedStartDate as a9h, documentType as a9i, CoverageEligibilityRequestEventComponent as a9j, _milestone as a9k, page as a9l, params as a9m, regionsCalled as a9n, conditionalCreate as a9o, lensSpecification as a9p, _grantor as a9q, coverage as a9r, authorizationSupporting as a9s, ElementDefinitionBindingAdditionalComponent as a9t, _benefit as a9u, _testData as a9v, _OrganizationAffiliation as a9w, excludedStructure as a9x, _searchRevInclude as a9y, serviceProvisionCode as a9z, _due as aA, _replaces as aB, EvidenceStatisticModelCharacteristicComponent as aC, _friday as aD, orderedBy as aE, _modality as aF, expirationType as aG, party as aH, _objective as aI, _totalNet as aJ, _adherence as aK, _cardinalityBehavior as aL, startDate as aM, basis as aN, _minutesDuration as aO, instruction as aP, _targetDisease as aQ, eventTrigger as aR, closure as aS, numberOfParticipants as aT, businessArrangement as aU, requesterLinkId as aV, _programEligibility as aW, _average as aX, proxySignature as aY, _assessmentMethod as aZ, _series as a_, _asserter as aa, coding as aa$, normalValue as aa0, PractitionerCommunicationComponent as aa1, targetProfile as aa2, bounds as aa3, _op as aa4, OperationDefinitionParameterComponentParameterParameter as aa5, plannedActivityReference as aa6, _preAuthRef as aa7, _imageRegion3D as aa8, _object as aa9, _topic as aaA, _lastUpdated as aaB, preparedDate as aaC, accident as aaD, code as aaE, _designation as aaF, _creation as aaG, verificationType as aaH, DeviceDefinitionPackagingComponentPackagingUdiDeviceIdentifier as aaI, _containedInstance as aaJ, PackagedProductDefinitionLegalStatusOfSupplyComponent as aaK, _recipient as aaL, ifMatch as aaM, partNumber as aaN, _severity as aaO, _filterBy as aaP, _NutritionIntake as aaQ, BundleEntrySearchComponent as aaR, _responseCode as aaS, _eventHistory as aaT, _rejectionCriterion as aaU, notPerformedReason as aaV, _entryType as aaW, EncounterHistory as aaX, _specialPrecautionsForStorage as aaY, SearchParameter as aaZ, gender as aa_, DocumentReferenceAttesterComponent as aaa, _recall as aab, fastingStatus as aac, seriesUid as aad, SubstanceSourceMaterialPartDescriptionComponent as aae, _geneElement as aaf, publicationDateText as aag, EpisodeOfCareStatusHistoryComponent as aah, evaluationMessage as aai, division as aaj, windowEnd as aak, _foodType as aal, _repeats as aam, _Observation as aan, validateCode as aao, parameterName as aap, source as aaq, currentState as aar, publicationStatus as aas, _license as aat, _created as aau, ClinicalUseDefinitionContraindicationOtherTherapyComponent as aav, isModifier as aaw, _needsMap as aax, performerType as aay, unitPrice as aaz, _regulatoryIdentifier as ab, ProductShelfLife as ab0, system as ab1, _tissue as ab2, associatedParty as ab3, statistic as ab4, DataRequirement as ab5, MedicationKnowledgeRegulatoryMaxDispenseComponent as ab6, udiCarrier as ab7, Availability as ab8, sender as ab9, _strand as aba, IngredientSubstanceStrengthComponent as abb, MedicationKnowledgeMonitoringProgramComponent as abc, _derivation as abd, Condition as abe, AdministrableProductDefinitionRouteOfAdministrationTargetSpeciesWithdrawalPeriodComponent as abf, diagnostics as abg, assessment as abh, _clockFacePosition as abi, attestation as abj, identified as abk, fhirImport as abl, molecularFormula as ac, isActive as ad, dispenserInstruction as ae, MedicationKnowledgeRelatedMedicationKnowledgeComponent as af, CapabilityStatementRestSecurityComponent as ag, initialSelected as ah, _preventiveAction as ai, DeviceDefinitionConformsToComponent as aj, _MedicationStatement as ak, _availableStartTime as al, validationType as am, _axis as an, _serialNumber as ao, Narrative as ap, _dependency as aq, endDate as ar, _prognosisReference as as, _recruitment as at, searchParam as au, _usageInstruction as av, _generation as aw, artifactAssessment as ax, complete as ay, _dependent as az, _applies as b, measurementPoint as b$, frames as b0, _paternalOrganismName as b1, inputProfile as b2, _guarantor as b3, _human as b4, NutritionProductCharacteristicComponent as b5, _orderDetail as b6, maxParticipants as b7, ClinicalUseDefinitionUndesirableEffectComponent as b8, _observed as b9, priceComponent as bA, _Linkage as bB, _indicationGuideline as bC, SubstanceSourceMaterial as bD, _conditionalRead as bE, managingEntity as bF, EvidenceVariableCharacteristicDefinitionByTypeAndValueComponent as bG, operationalStatus as bH, _module as bI, MedicationAdministration as bJ, UdiDeviceIdentifierMarketDistribution as bK, _probability as bL, clinicalRecommendationStatement as bM, _image as bN, SubscriptionTopicNotificationShapeComponent as bO, _componentPart as bP, op as bQ, _processingFacility as bR, unit as bS, _problem as bT, SubstanceDefinitionPropertyComponent as bU, _fluidConsistencyType as bV, _SubstancePolymer as bW, ValueSetComposeIncludeConceptDesignationComponent as bX, versionReference as bY, _maxSingleDose as bZ, meaning as b_, validityPeriod as ba, ComputableLanguage as bb, surfaceOrientation as bc, _Provenance as bd, testRun as be, SubstanceProtein as bf, _focalDevice as bg, _operationType as bh, context as bi, occurrenceDateTime as bj, DetectedIssueEvidenceComponent as bk, _ExplanationOfBenefit as bl, validated as bm, _subunit as bn, EvidenceStatisticAttributeEstimateComponent as bo, replacedSequence as bp, specimen as bq, rater as br, relatedMedicationKnowledge as bs, lastModified as bt, RequestOrchestrationActionParticipantComponent as bu, _informationType as bv, citation as bw, paymentStatus as bx, treatment as by, _initial as bz, constituent as c, PermissionRuleDataComponent as c$, diagnosisRelatedGroup as c0, _relative as c1, _publicationForm as c2, _Patient as c3, GuidanceResponse as c4, entity as c5, sourceReference as c6, valueFilter as c7, _useBy as c8, bodyLandmarkOrientation as c9, _replacementSequence as cA, serviceCategory as cB, _next as cC, paymentTerms as cD, _started as cE, offer as cF, coordinateSystem as cG, DeviceDefinition as cH, _intent as cI, _text as cJ, _level as cK, facility as cL, qualifiedValue as cM, ManifestResource as cN, prism as cO, MedicationBatchComponent as cP, resultForDelete as cQ, _accept as cR, overbooked as cS, _plan as cT, ReviewOutcome as cU, CitationCitedArtifactContributorshipEntryComponent as cV, discriminator as cW, ordered as cX, LegalLanguage as cY, frequencyOfOccurrence as cZ, _validationType as c_, SubstanceDefinitionNameComponentName as ca, _policyText as cb, _changePattern as cc, subDetail as cd, allDay as ce, _modification as cf, _nodeId as cg, AdverseEventContributingFactorComponent as ch, TestPlanTestCaseComponent as ci, sunday as cj, cancellationReason as ck, _title as cl, _sourceId as cm, _entityRelatedness as cn, line as co, _effectivePeriod as cp, preAuthRef as cq, requestId as cr, _autodelete as cs, _fundsReserve as ct, BundleEntryComponentLink as cu, DocumentReferenceContentComponent as cv, _holder as cw, _qualifiers as cx, _Specimen as cy, CodeSystemFilterComponent as cz, decimal as d, size as d$, _versionNeeded as d0, PackagedProductDefinitionPackagingContainedItemComponent as d1, predecessor as d2, ArtifactAssessment as d3, _dependsOn as d4, evidence as d5, MeasureGroupPopulationComponent as d6, opticalActivity as d7, nutritionProduct as d8, specialMeasures as d9, given as dA, account as dB, _organism as dC, _need as dD, environmentalSetting as dE, volume as dF, weeklyTemplate as dG, lowerLimit as dH, _justification as dI, _fixture as dJ, unitPriceComponent as dK, availabilityStatus as dL, _proxySignature as dM, statusChanged as dN, _about as dO, occurence as dP, actualPeriod as dQ, _originalPrescription as dR, _dosage as dS, returnedAmount as dT, _cTerminalModification as dU, name as dV, masterFile as dW, baseFormulaType as dX, threshold as dY, active as dZ, IngredientSubstanceComponent as d_, packageId as da, TerminologyCapabilitiesCodeSystemVersionFilterComponent as db, SubDetail as dc, _received as dd, CapabilityStatementDocumentComponent as de, observationResultRequirement as df, FriendlyLanguage as dg, _observedGroup as dh, cancelledReason as di, _expirationType as dj, _actualNumber as dk, derivation as dl, AdverseEventSuspectEntityComponent as dm, ImmunizationRecommendation as dn, _BiologicallyDerivedProductDispense as dp, _definitionId as dq, _authoredOn as dr, keyword as ds, characteristic as dt, _note as du, ImagingStudySeriesInstanceComponent as dv, _signature as dw, slicing as dx, _population as dy, cap as dz, _lowerLimit as e, legalStatusOfSupply as e$, _validityPeriod as e0, who as e1, ExampleScenarioProcessStepAlternativeComponent as e2, InsurancePlanPlanSpecificCostComponent as e3, interaction as e4, _beneficiary as e5, requestURL as e6, transform as e7, sugar as e8, _subscriptionTopic as e9, _frameOfReferenceUid as eA, MedicinalProductDefinition as eB, paternalOrganismId as eC, averageMolecularFormula as eD, EvidenceStatisticSampleSizeComponent as eE, _occurred as eF, definitionByCombination as eG, _compositional as eH, financial as eI, _bodysite as eJ, sourceScope as eK, parameter as eL, lineItem as eM, _businessArrangement as eN, _ordinalPosition as eO, dependency as eP, DeviceUsage as eQ, sent as eR, _associatedMedication as eS, ParametersParameterComponentParameter as eT, executionPeriod as eU, _custodian as eV, specification as eW, HumanName as eX, ObservationDefinitionComponentComponentQualifiedValue as eY, _searchInclude as eZ, _technique as e_, _usageStatus as ea, _recurring as eb, chargeItem as ec, DiagnosticReportMediaComponent as ed, validationProcess as ee, _DiagnosticReport as ef, moiety as eg, _marketingStatus as eh, _citedArtifact as ei, CitationCitedArtifactPartComponent as ej, TerminologyCapabilitiesImplementationComponent as ek, _immutable as el, _requester as em, regionsStudied as en, _code as eo, sourceMaterial as ep, subrogation as eq, _structureVersion as er, _priceComponent as es, management as et, _additionalInstruction as eu, _managingEntity as ev, patchFormat as ew, proxyIdentityCertificate as ex, DeviceVersionComponent as ey, TaskRestrictionComponent as ez, _productType as f, _assignedComparisonGroup as f$, short as f0, generation as f1, doseAndRate as f2, _condition as f3, _followUp as f4, manufacturer as f5, BiologicallyDerivedProductDispense as f6, _seriesUid as f7, relatesTo as f8, temperatureQualifier as f9, contraindicatedVaccineCode as fA, collector as fB, enterer as fC, _supportedInteraction as fD, _differential as fE, _qualifiedValue as fF, ManufacturedItemDefinitionComponentConstituentComponent as fG, _additionalMonitoringIndicator as fH, _position as fI, limit as fJ, _reason as fK, _planningHorizon as fL, _safety as fM, Identifier as fN, _mitigation as fO, _specialCourtesy as fP, ExampleScenarioInstanceContainedInstanceComponent as fQ, edit as fR, qualitativeRisk as fS, immunizationEvent as fT, reference as fU, reporter as fV, BackboneElement as fW, _hasMember as fX, Provenance as fY, reasonLinkId as fZ, owner as f_, _PackagedProductDefinition as fa, _correspondingContact as fb, citeAs as fc, _DeviceAssociation as fd, requireBoth as fe, provisionData as ff, _characterization as fg, criticality as fh, ConditionDefinitionPlanComponent as fi, canPushUpdates as fj, _nTerminalModificationId as fk, _regionsCalled as fl, TestPlanTestCaseTestRunComponent as fm, _productOrService as fn, reviewOutcome as fo, maxDispense as fp, filterDefinition as fq, sourceAttachment as fr, provisionActor as fs, NamingSystem as ft, dateOfService as fu, VisionPrescription as fv, _unitPrice as fw, resource as fx, _response as fy, _agent as fz, _relatedItem as g, regulatoryBasis as g$, _Condition as g0, ConsentPolicyBasisComponent as g1, communicationMethod as g2, _param as g3, _power as g4, _issue as g5, concept as g6, decisionMode as g7, instantiatesUri as g8, _ifMatch as g9, _availability as gA, resultingEffect as gB, timeout as gC, CapabilityStatementMessagingSupportedMessageComponent as gD, _revenue as gE, _returnedAmount as gF, MedicationKnowledgeDefinitionalIngredientComponent as gG, candidate as gH, Subscription as gI, relatedAction as gJ, textPresentation as gK, _supplements as gL, result as gM, policyText as gN, _regionType as gO, StratifierGroup as gP, _contract as gQ, _timeFromEvent as gR, notificationEvent as gS, _inclusionCriteria as gT, _orderMeaning as gU, autodelete as gV, qualifiers as gW, _regionsStudied as gX, _application as gY, frequency as gZ, _sourceMaterial as g_, sequenceType as ga, _fastingStatus as gb, preferredReportName as gc, _numberOfSeries as gd, rankingOrder as ge, _currency as gf, testTools as gg, _warning as gh, CoverageEligibilityResponseEventComponent as gi, _characteristic as gj, dataRequirement as gk, _domain as gl, InventoryReport as gm, _parameterName as gn, progressStatus as go, _narrative as gp, Endpoint as gq, subjectState as gr, entry as gs, _weeklyTemplate as gt, what as gu, whenPrepared as gv, Action as gw, _observationRequirement as gx, focal as gy, verification as gz, header as h, _canPushUpdates as h$, associationType as h0, _software as h1, _copolymerConnectivity as h2, _approvalDate as h3, totalVolume as h4, AppointmentRecurrenceTemplateWeeklyTemplateComponent as h5, _requestedPerformer as h6, packagedProduct as h7, tissue as h8, isSubpotent as h9, derivedFromCanonical as hA, _hasSeverity as hB, cTerminalModification as hC, ContentDefinition as hD, _bodyLandmarkOrientation as hE, relationship as hF, goal as hG, _connectivity as hH, _listMode as hI, _availableTime as hJ, property as hK, _calibration as hL, TerminologyCapabilitiesExpansionParameterComponent as hM, adjustmentReason as hN, AdministrableProductDefinitionRouteOfAdministrationTargetSpeciesComponent as hO, Basic as hP, _isDerived as hQ, hierarchical as hR, _resultForCreate as hS, _deviceName as hT, _startDate as hU, Attachment as hV, _patientPreparation as hW, CitationCitedArtifactPublicationFormComponent as hX, windowStart as hY, _propertyGroup as hZ, languageCode as h_, _supportingInfoSequence as ha, _rating as hb, maternalOrganismName as hc, CommunicationRequest as hd, polymer as he, initiatorActive as hf, _productStatus as hg, strand as hh, _outputParameters as hi, participantStatus as hj, label as hk, manipulated as hl, _geometry as hm, Coding as hn, requisition as ho, InventoryReportInventoryListingComponent as hp, _parent as hq, _net as hr, presentation as hs, flag as ht, hoursOfOperation as hu, encounter as hv, applicability as hw, releaseDate as hx, _relationshipType as hy, _managingOrganization as hz, author as i, _role as i$, groupingBehavior as i0, for__workaround as i1, _studyUid as i2, _event as i3, informationProvider as i4, network as i5, _manufacturedDoseForm as i6, assert as i7, _warningOnly as i8, isSummary as i9, productOrServiceEnd as iA, teardown as iB, securityLabelNumber as iC, _manufactureDate as iD, _textFilter as iE, _route as iF, parentSubstanceName as iG, _docStatus as iH, ArtifactAssessmentContentComponentContentContent as iI, _subscriber as iJ, workflowStatus as iK, phylum as iL, _mustSupport as iM, forecastStatus as iN, _closure as iO, _abstract as iP, relatedClinicalInformation as iQ, PersonCommunicationComponent as iR, _relativePath as iS, CitationCitedArtifactVersionComponent as iT, _paging as iU, _uniqueId as iV, _readOnly as iW, _jurisdiction as iX, _treatment as iY, _responsibleParty as iZ, RequestOrchestrationActionComponentActionAction as i_, attachedDocument as ia, _unit as ib, _endDate as ic, authoredOn as id, _geographicalLocation as ie, CitationCitedArtifactClassificationComponent as ig, userSelected as ih, _prognosisCodeableConcept as ii, dateCriterion as ij, additionalInstruction as ik, specialPrecautionsForStorage as il, population as im, _member as io, securityLabel as ip, _renderedDosageInstruction as iq, Notes as ir, _dynamicValue as is, _confidentialityIndicator as it, _intendedUse as iu, lastUpdated as iv, deceased as iw, NutritionOrderEnteralFormulaAdditiveComponent as ix, designation as iy, reportedDateTime as iz, _direction as j, _intendedExposure as j$, TestPlanDependencyComponent as j0, Binary as j1, contentDerivative as j2, inforce as j3, RiskAssessmentPredictionComponent as j4, _enteredDate as j5, _legalStatusOfSupply as j6, valueAlternatives as j7, subject as j8, _publicationDate as j9, dispenseInterval as jA, _map as jB, _lensSpecification as jC, allergyIntolerance as jD, asset as jE, CoverageEligibilityResponse as jF, OperationDefinitionParameterComponentParameter as jG, packagedMedicinalProduct as jH, _count as jI, SubstancePolymerRepeatRepeatUnitDegreeOfPolymerisationComponent as jJ, adjudication as jK, RequestOrchestrationActionConditionComponent as jL, validator as jM, _gene as jN, _length as jO, series as jP, maxDosePerAdministration as jQ, _performerRole as jR, _balance as jS, _correctiveAction as jT, dispenser as jU, NutritionOrderOralDietComponent as jV, _meaning as jW, endParam as jX, _provider as jY, inResponseTo as jZ, authorDescription as j_, occurrenceChanged as ja, _referralRequest as jb, friday as jc, productType as jd, _payeeType as je, _fixed as jf, _nTerminalModification as jg, _progressStatus as jh, _age as ji, _verificationDate as jj, CompartmentDefinitionResourceComponent as jk, _questionnaire as jl, TestScript as jm, billingStatus as jn, _resourceTrigger as jo, compose as jp, _submitter as jq, _productReference as jr, payment as js, rateAggregation as jt, OrganizationQualificationComponent as ju, identityCertificate as jv, _subDetail as jw, contextInvariant as jx, _suffix as jy, _recurrenceId as jz, _frequencyOfOccurrence as k, benefitBalance as k$, _cycle as k0, ProvenanceEntityComponentAgent as k1, high as k2, _paymentStatus as k3, TestScriptVariableComponent as k4, _comparator as k5, _instantiatesCanonical as k6, class__workaround as k7, _countryOfOrigin as k8, structuralRepresentation as k9, DeviceDefinitionPackagingComponentPackaging as kA, extends__workaround as kB, AdverseEventSupportingInfoComponent as kC, _MedicationRequest as kD, startingSequence as kE, MedicationKnowledgeMonographComponent as kF, DetectedIssue as kG, targetLocation as kH, MedicinalProductDefinitionCrossReferenceComponent as kI, _alternateMaterial as kJ, _ordered as kK, _List as kL, _gateway as kM, _effect as kN, _coordinate as kO, case__workaround as kP, QuestionnaireItemComponentItem as kQ, DeviceConformsToComponent as kR, PatientLinkComponent as kS, testData as kT, ProcedureFocalDeviceComponent as kU, _typeCanonical as kV, nodeId as kW, CapabilityStatementSoftwareComponent as kX, _preparation as kY, _subType as kZ, _definitionCodeableConcept as k_, _communicationMethod as ka, _size as kb, _averageMolecularFormula as kc, _ingredientLabel as kd, _landmarkDescription as ke, _criticalCodedValueSet as kf, unmapped as kg, _productCategory as kh, SubstanceReferenceInformationTargetComponent as ki, _preferredReportName as kj, _maternalOrganismId as kk, _order as kl, qualifier as km, recruitment as kn, mitigation as ko, Procedure as kp, material as kq, _packageId as kr, address as ks, module as kt, SubstanceNucleicAcidSubunitComponent as ku, _healthcareService as kv, check as kw, _serviceProvisionCode as kx, DeviceDefinitionHasPartComponent as ky, hybrid as kz, _communicationRequest as l, _informationProvider as l$, exclusionCriteria as l0, numberOfStudies as l1, start as l2, AccountRelatedAccountComponent as l3, _OperationOutcome as l4, orientation as l5, holder as l6, _mitigatingAction as l7, include as l8, _conditionalPatch as l9, regionType as lA, _association as lB, _messaging as lC, organismType as lD, accept as lE, _methodType as lF, _authorizationRequired as lG, includedStructure as lH, sourceIdentityCertificate as lI, foodType as lJ, temperatureRange as lK, ManifestPage as lL, DeviceRequest as lM, _contextLinkId as lN, ExampleScenarioProcessStepOperationComponent as lO, SubstanceDefinitionStructureComponent as lP, calculatedAt as lQ, MarketingStatus as lR, _emptyReason as lS, _offsets as lT, _financial as lU, _exposureRoute as lV, _policyHolder as lW, SupplyDeliverySuppliedItemComponent as lX, intendedRoute as lY, _paymentDate as lZ, GenomicStudyAnalysisDeviceComponent as l_, NamingSystemUniqueIdComponent as la, _threshold as lb, Count as lc, _instantiates as ld, media as le, appliesTo as lf, _implementationGuide as lg, RequestOrchestrationActionInputComponent as lh, _discriminator as li, ClaimResponse as lj, section as lk, _workflowStatus as ll, _DeviceMetric as lm, diseaseSymptomProcedure as ln, _keyword as lo, _forecastStatus as lp, Bundle as lq, _excluded as lr, _transform as ls, intent as lt, _slicing as lu, generalPractitioner as lv, gestationalAge as lw, _account as lx, _administeredProduct as ly, answerOption as lz, DocumentReferenceContentProfileComponent as m, meaningWhenMissing as m$, _outsideFoodAllowed as m0, feature as m1, needsMap as m2, _dataAbsentReason as m3, _definition as m4, creation as m5, _minValue as m6, width as m7, _Permission as m8, AllergyIntolerance as m9, nthWeekOfMonth as mA, targetSpecies as mB, authorization as mC, _RequestOrchestration as mD, _endpoint as mE, triggeredBy as mF, _Dosage as mG, _doNotPerform as mH, careTeam as mI, _meta as mJ, TerminologyCapabilitiesCodeSystemVersionComponent as mK, entryQuantity as mL, CapabilityStatementMessagingEndpointComponent as mM, nTerminalModification as mN, _asNeededFor as mO, _link as mP, attribute as mQ, Note as mR, textFilter as mS, disposition as mT, PackagedProductDefinition as mU, Accident as mV, _reference as mW, StructureMapGroupRuleTargetParameterComponent as mX, subscriber as mY, structureType as mZ, _detail as m_, _Encounter as ma, targetNumber as mb, severity as mc, ObservationDefinitionQualifiedValueComponent as md, filterBy as me, packaging as mf, endorser as mg, _relatesTo as mh, _sourceSignature as mi, abnormalCodedValueSet as mj, lastOccurrenceDate as mk, _securityLabelNumber as ml, _queryCriteria as mm, _multipleResultsAllowed as mn, _allowed as mo, _TestReport as mp, _Location as mq, deviceName as mr, ImmunizationReactionComponent as ms, ConceptMap as mt, _daysOfWeek as mu, ParameterDefinition as mv, _packageCode as mw, Insurance as mx, lastPerformed as my, IngredientManufacturerComponent as mz, numberOfRepeatsAllowed as n, _schedule as n$, modelCharacteristic as n0, mapping as n1, _Person as n2, _eligibility as n3, SubstanceSourceMaterialFractionDescriptionComponent as n4, typeCollected as n5, timestamp as n6, _subpotentReason as n7, _relatedMedicationKnowledge as n8, _inventoryStatus as n9, instantiatesCanonical as nA, family as nB, NutritionIntake as nC, EvidenceReport as nD, billablePeriod as nE, _otherTherapy as nF, _dateOfService as nG, _benefitBalance as nH, _information as nI, _CareTeam as nJ, _aggregateMethod as nK, generatedBy as nL, _tag as nM, asserter as nN, _revInclude as nO, onset as nP, criticalCodedValueSet as nQ, _mode as nR, anchor as nS, _substitution as nT, _consent as nU, _candidate as nV, _concept as nW, MeasureReportGroupStratifierStratumComponentComponent as nX, ifNoneExist as nY, GraphDefinitionNodeComponent as nZ, _answer as n_, synonym as na, _category as nb, _regulatory as nc, birthDate as nd, _priorPrescription as ne, Base as nf, _testTools as ng, _targetLocation as nh, substanceDefinition as ni, _medication as nj, _vaccineCode as nk, _dateAsserted as nl, DeviceDefinitionMaterialComponent as nm, _codeSearch as nn, range as no, NutritionOrder as np, _dispenserInstruction as nq, _summary as nr, _synthesisType as ns, productName as nt, _reviewOutcome as nu, claimResponse as nv, path as nw, additive as nx, ElementDefinition as ny, fundingSource as nz, _masterFile as o, format as o$, administrationTreatment as o0, _baseFormulaProductName as o1, PermissionRuleDataResourceComponent as o2, _gestationalAge as o3, carrierAIDC as o4, _capability as o5, usageStatus as o6, _knownAllergen as o7, storageTempRequirements as o8, definitionReference as o9, _normalCodedValueSet as oA, TestCaseDependency as oB, _costToBeneficiary as oC, MessageHeader as oD, ResearchStudyRecruitmentComponent as oE, _forenameInitials as oF, plannedStartDate as oG, study as oH, groupIdentifier as oI, _participatingOrganization as oJ, MeasureGroupStratifierComponent as oK, wednesday as oL, _diameter as oM, enteralFormula as oN, _stabilityDuration as oO, integer as oP, domain as oQ, _periodType as oR, _ImagingStudy as oS, searchRevInclude as oT, _relatedAction as oU, observed as oV, born as oW, _ImmunizationRecommendation as oX, service as oY, _requestIdentifier as oZ, maxDosePerLifetime as o_, experimental as oa, _numberOfParticipants as ob, _repeat as oc, displayName as od, replaces as oe, _distanceFromLandmark as of, _frequency as og, shortDoco as oh, ImagingSelection as oi, modality as oj, _targetId as ok, _amount as ol, species as om, totalNet as on, observationRequirement as oo, InsurancePlanPlanGeneralCostComponent as op, InvoiceLineItemComponent as oq, requestor as or, dietPreference as os, comparator as ot, _combinedPharmaceuticalDoseForm as ou, servicePeriod as ov, _rater as ow, receiverActive as ox, modification as oy, practitioner as oz, productStatus as p, ImplementationGuideDefinitionParameterComponent as p$, _isSummary as p0, supportingInfoSequence as p1, EvidenceStatisticModelCharacteristicVariableComponent as p2, ManufacturedItemDefinitionPropertyComponent as p3, _concentration as p4, coordinate as p5, AddedItemDetailSubDetail as p6, TerminologyCapabilitiesTranslationComponent as p7, _generalPractitioner as p8, _protocol as p9, _applicability as pA, min as pB, DeviceNameComponent as pC, Payment as pD, organismName as pE, relative as pF, Ratio as pG, item as pH, rating as pI, _numerator as pJ, TestScriptScopeComponent as pK, _aggregation as pL, minutesDuration as pM, AuditEventEntityComponent as pN, rate as pO, CompartmentDefinition as pP, renderedDosageInstruction as pQ, methodType as pR, parent as pS, sourceId as pT, _requestedPeriod as pU, _chromosome as pV, isSubPotent as pW, presentedForm as pX, repetitions as pY, aggregate as pZ, EvidenceStatisticComponent as p_, _exception as pa, _complication as pb, value as pc, _nthWeekOfMonth as pd, _url as pe, SubstanceSourceMaterialOrganismHybridComponent as pf, SubscriptionTopicEventTriggerComponent as pg, MedicinalProductDefinitionNameComponent as ph, SubstanceSourceMaterialOrganismComponent as pi, overrideReason as pj, pages as pk, _conclusion as pl, _combined as pm, _contains as pn, _documentType as po, MeasureGroupStratifierComponentComponent as pp, _numberOfInstances as pq, PlanDefinitionActionComponent as pr, _processor as ps, actualNumber as pt, _network as pu, effective as pv, textEquivalent as pw, preferred as px, ImplementationGuide as py, EvidenceReportRelatesToTargetComponent as pz, comment as q, received as q$, CompositionEventComponent as q0, _NutritionOrder as q1, TaskInputComponent as q2, rule as q3, Specimen as q4, _MedicinalProductDefinition as q5, OperationDefinition as q6, process as q7, CitationCitedArtifactContributorshipEntryContributionInstanceComponent as q8, EncounterAdmissionComponent as q9, ratioHighLimitAmount as qA, _relatedData as qB, _inforce as qC, _reportingVendor as qD, _sequenceRange as qE, member as qF, _versionAlgorithm as qG, _subject as qH, _case as qI, _ClinicalUseDefinition as qJ, _cylinder as qK, _saturday as qL, ConceptMapGroupUnmappedComponent as qM, Address as qN, _validateCode as qO, _dispenser as qP, _issued as qQ, TestReport as qR, conditionalRead as qS, fullUrl as qT, parameterFocus as qU, _currentState as qV, ActivityDefinition as qW, daysOfWeek as qX, containedInstance as qY, StructureMapGroupRuleSourceComponent as qZ, application as q_, _MedicationDispense as qa, translation as qb, ObservationTriggeredByComponent as qc, _etag as qd, _dateCriterion as qe, _administrationInstruction as qf, part as qg, _billablePeriod as qh, requestHeader as qi, _shortTitle as qj, _securityLabel as qk, _procedure as ql, periodMax as qm, monograph as qn, _eventsSinceSubscriptionStart as qo, QuestionnaireResponseItemAnswerComponent as qp, formatted as qq, restoreDate as qr, _grouping as qs, definition as qt, BodyStructureIncludedStructureBodyLandmarkOrientationDistanceFromLandmarkComponent as qu, dayOfWeek as qv, _variableDefinition as qw, nodeRole as qx, Permission as qy, dateWritten as qz, availableTime as r, MedicationDispenseSubstitutionComponent as r$, AuditEventEntityComponentAgent as r0, element as r1, _compose as r2, _environmentalSetting as r3, _payment as r4, _preparedDate as r5, ImagingSelectionInstanceComponent as r6, _responseRequired as r7, _contraindication as r8, _operator as r9, effectivePeriod as rA, _matchStatus as rB, virtualService as rC, Communication as rD, _enteralFormula as rE, whenHandedOver as rF, EvidenceReportSubjectComponent as rG, substance as rH, Section as rI, _valueRange as rJ, regulatoryIdentifier as rK, kind as rL, hasIngredient as rM, detailSequence as rN, NutritionProductNutrientComponent as rO, _fractionDescription as rP, _degreeOfPolymerisation as rQ, _Account as rR, rangeCategory as rS, _index as rT, ValueSetComposeComponentInclude as rU, regulatory as rV, _modifier as rW, _short as rX, medication as rY, codeSearch as rZ, suffix as r_, ActivityDefinitionParticipantComponent as ra, _contraindicatedVaccineCode as rb, _membership as rc, _recordedDate as rd, _provision as re, _dietPreference as rf, _laterality as rg, _parentSubstanceId as rh, _report as ri, MedicationDispensePerformerComponent as rj, FamilyMemberHistoryConditionComponent as rk, _editor as rl, instant as rm, paging as rn, _receiverActive as ro, publicationForm as rp, operation as rq, organism as rr, focus as rs, _reviewer as rt, validCodedValueSet as ru, Signatory as rv, clockFacePosition as rw, _instanceReference as rx, withdrawalPeriod as ry, conformance as rz, serviceProvider as s, ManufacturedItemDefinitionComponentComponentComponent as s$, foodPreferenceModifier as s0, Immunization as s1, AppointmentRecurrenceTemplateMonthlyTemplateComponent as s2, preventiveAction as s3, _AdministrableProductDefinition as s4, _deliverFrom as s5, _address as s6, intendedUse as s7, ElementDefinitionSlicingDiscriminatorComponent as s8, SubscriptionTopic as s9, _appliesToAll as sA, comorbidity as sB, TestScriptFixtureComponent as sC, oligoNucleotideType as sD, intendedEffect as sE, _conformsTo as sF, copyright as sG, _insurance as sH, _partDescription as sI, _genomeBuild as sJ, Slot as sK, _medium as sL, followUp as sM, maxDuration as sN, lotNumber as sO, EncounterHistoryLocationComponent as sP, _owner as sQ, InventoryItem as sR, content as sS, DeviceDefinitionPropertyComponent as sT, enteredDate as sU, _district as sV, QuestionnaireItemComponentItemItem as sW, eye as sX, facilityType as sY, markdown as sZ, _friendly as s_, GenomicStudy as sa, _partLocation as sb, _subsumption as sc, BenefitBalance as sd, script as se, _resourceReference as sf, lastReviewDate as sg, SubstanceDefinitionNameComponentNameName as sh, length as si, _overrideReason as sj, _period as sk, TerminologyCapabilities as sl, _supportingPatientInformation as sm, OperationDefinitionParameterBindingComponent as sn, Task as so, MeasureReportGroupPopulationComponent as sp, revInclude as sq, _appliesTo as sr, MedicationKnowledgeDefinitionalComponent as ss, usageInstruction as st, trigger as su, mustSupport as sv, TimingRepeatComponent as sw, effectiveDosePeriod as sx, _textEquivalent as sy, bodysite as sz, _assert as t, _undesirableEffect as t$, basedOn as t0, assessmentMethod as t1, _sourceMaterialClass as t2, CarePlanActivityComponent as t3, response as t4, _singleUse as t5, ProvenanceAgentComponent as t6, _kingdom as t7, error as t8, effect as t9, maxTreatmentPeriod as tA, _relatedIdentifier as tB, _feature as tC, ValueSetExpansionComponent as tD, _parameterFocus as tE, _maxDosePerDay as tF, CapabilityStatementMessagingComponent as tG, ResearchStudyObjectiveComponent as tH, MedicationIngredientComponent as tI, SourceElement as tJ, _sequence as tK, _validateProfileId as tL, responsibility as tM, containedItem as tN, completionTime as tO, _identifier as tP, _scope as tQ, currency as tR, _inputProfile as tS, TestAction as tT, _performer as tU, QuestionnaireResponseItemComponentItemItem as tV, _pushTypeAvailable as tW, communication as tX, interpretation as tY, _capacity as tZ, topic as t_, verifiedWith as ta, _packaging as tb, position as tc, EvidenceCertaintyComponentCertainty as td, low as te, _Device as tf, AddedItemSubDetail as tg, _responsible as th, excludingDate as ti, _verified as tj, TestScriptMetadataCapabilityComponent as tk, marketingStatus as tl, _ClaimResponse as tm, request as tn, MolecularSequenceRelativeEditComponent as to, periodType as tp, approvalDate as tq, _monomerSet as tr, _eventTrigger as ts, _ingredient as tt, _biologicalSourceEvent as tu, durationMax as tv, _MolecularSequence as tw, _permittedDataType as tx, subtitle as ty, _SubscriptionStatus as tz, listRuleId as u, _policy as u$, _noteNumber as u0, _DeviceRequest as u1, courseOfTherapyType as u2, ordinalPosition as u3, ObservationComponentComponentReferenceRange as u4, _actorId as u5, conclusion as u6, Resource as u7, accountNumber as u8, deliverTo as u9, dynamicValue as uA, _detailSequence as uB, SupportingInformation as uC, CitationStatusDateComponent as uD, subscriberId as uE, node as uF, details as uG, GenomicStudyAnalysisInputComponent as uH, contract as uI, _paymentIssuer as uJ, _clinicalTrial as uK, Adjudication as uL, AdverseEventMitigatingActionComponent as uM, ratioType as uN, authoritative as uO, chromosome as uP, referralMethod as uQ, MedicationKnowledgeDefinitionalDrugCharacteristicComponent as uR, _filterParameter as uS, _costCenter as uT, _maternalOrganismName as uU, _CommunicationRequest as uV, _mapping as uW, _spatialReference as uX, _AppointmentResponse as uY, preparation as uZ, _outcome as u_, multipleResultsAllowed as ua, _asNeeded as ub, _onHold as uc, genomeAssembly as ud, _preAuthRefPeriod as ue, itemSequence as uf, _relatedClinicalInformation as ug, ResearchStudy as uh, _action as ui, _DocumentReference as uj, _coverageArea as uk, DataType as ul, Duration as um, _Consent as un, _referencePolicy as uo, _virtualService as up, _lastModified as uq, destination as ur, _whenHandedOver as us, _typeTested as ut, product as uu, _referrer as uv, plannedEndDate as uw, _birthDate as ux, _mustHaveValue as uy, ClinicalUseDefinition as uz, preAdmissionIdentifier as v, emptyReason as v$, planningHorizon as v0, _targetSpecies as v1, EvidenceVariableCharacteristicComponent as v2, _authorization as v3, software as v4, _lastReviewDate as v5, _derivedFromCanonical as v6, specialCourtesy as v7, intraspecificType as v8, shortTitle as v9, improvementNotation as vA, ValuedItem as vB, ElementDefinitionBaseComponent as vC, Errors as vD, pattern as vE, TestScriptDestinationComponent as vF, CoveragePaymentByComponent as vG, _AuditEvent as vH, requirements as vI, authority as vJ, _compareToSourceId as vK, _Contract as vL, _occurrenceChanged as vM, typeReference as vN, detail as vO, _alternative as vP, ClaimResponseAdjudication as vQ, Person as vR, readHistory as vS, _subjects as vT, membership as vU, studyUid as vV, GraphDefinitionLinkCompartmentComponent as vW, _occurrence as vX, _dayOfMonth as vY, Extension as vZ, _proxyIdentityCertificate as v_, channelType as va, _subSite as vb, use as vc, webLocation as vd, PlanDefinitionGoalTargetComponent as ve, _entryQuantity as vf, _seriousness as vg, _born as vh, initiator as vi, geometry as vj, _organismGeneral as vk, TestReportSetupComponent as vl, message as vm, PlanDefinitionActionInputComponent as vn, Dosage as vo, _structureType as vp, onAdmission as vq, EncounterLocationComponent as vr, statusHistory as vs, CitationCitedArtifactComponent as vt, _paymentTerms as vu, _intendedEffect as vv, SubstanceSourceMaterialOrganismAuthorComponent as vw, listMode as vx, _typeCollected as vy, definitional as vz, participantType as w, interactant as w$, ConceptMapGroupComponent as w0, laterality as w1, _previous as w2, _claimResponse as w3, dataUpdateType as w4, paymentDate as w5, baseFormulaProductName as w6, performed as w7, ServiceRequestOrderDetailComponent as w8, _informationSequence as w9, _contributor as wA, _normalValue as wB, _resultsInterpreter as wC, _tester as wD, denominator as wE, uniqueId as wF, readOnly as wG, _effectiveDosePeriod as wH, _patientInstruction as wI, focusReference as wJ, _sopClass as wK, _brand as wL, SubscriptionStatusNotificationEventComponent as wM, specialArrangement as wN, _autocreate as wO, _responsibility as wP, any as wQ, protocolApplied as wR, PaymentNotice as wS, _completionTime as wT, _preAdmissionIdentifier as wU, _interpretation as wV, testingDestination as wW, ExtendedContactDetail as wX, administrableDoseForm as wY, repeat as wZ, CapabilityStatementRestResourceSearchParamComponent as w_, _wednesday as wa, _id as wb, nucleicAcid as wc, implementation as wd, _species as we, _goalId as wf, manager as wg, Meta as wh, interpreter as wi, situation as wj, _recorded as wk, DiagnosticReport as wl, drugCharacteristic as wm, SubstanceDefinitionStructureRepresentationComponent as wn, RequestOrchestrationActionRelatedActionComponent as wo, variableRole as wp, failureAction as wq, suppliedItem as wr, abstract as ws, valueRange as wt, _query as wu, sigFormat as wv, VirtualServiceDetail as ww, _rest as wx, packageCode as wy, _reaction as wz, _related as x, PackagedProductDefinitionPackagingComponentPackaging as x$, _groupDefinition as x0, _effective as x1, _service as x2, admitSource as x3, _cap as x4, _structure as x5, _preferred as x6, human as x7, _genomeAssembly as x8, _dimensions as x9, PermissionRuleActivityComponent as xA, careManager as xB, CodeSystem as xC, MedicinalProductDefinitionNamePartComponent as xD, _requestingOrganization as xE, _referralMethod as xF, _suspectEntity as xG, _exclusionCriteria as xH, ObservationComponentComponent as xI, _testScript as xJ, manufactureDate as xK, _textPresentation as xL, TestReportSetupActionOperationComponent as xM, legal as xN, provider as xO, exitCriteria as xP, image as xQ, SupplyRequest as xR, _periodMax as xS, _monograph as xT, _decision as xU, _diagnostics as xV, _origin as xW, _durationUnit as xX, contact as xY, _disabledDisplay as xZ, _attestation as x_, Reason as xa, eligibility as xb, resultForCreate as xc, PersonLinkComponent as xd, EvidenceCertaintyComponent as xe, texture as xf, characterization as xg, TerminologyCapabilitiesExpansionComponent as xh, DataRequirementCodeFilterComponent as xi, _derivedFrom as xj, _doseAdministrationAid as xk, productOrService as xl, _plannedEndDate as xm, conformsTo as xn, _detected as xo, _threePrime as xp, referencedFrom as xq, targetFormat as xr, _characteristicType as xs, StructureDefinitionMappingComponent as xt, _initiatorActive as xu, supportedInteraction as xv, vaccineCode as xw, seriesNumber as xx, pageCount as xy, _who as xz, SupplementSchedule as y, codeMap as y$, OperationOutcomeIssueComponent as y0, _hash as y1, _pageString as y2, _constituent as y3, DeviceAssociation as y4, _dayOfWeek as y5, _inventoryListing as y6, _hierarchyMeaning as y7, _dispenseRequest as y8, legallyBinding as y9, publicationDate as yA, administrationInstruction as yB, fivePrime as yC, _points as yD, TestScriptSetupActionAssertComponent as yE, referralRequest as yF, _timeAspect as yG, _presentedForm as yH, _seriesDoses as yI, milestone as yJ, MedicationAdministrationPerformerComponent as yK, Invoice as yL, additionalContext as yM, _satisfiedBy as yN, identifier as yO, SubstanceNucleicAcid as yP, resourceTrigger as yQ, _overload as yR, organization as yS, PlanDefinitionActionConditionComponent as yT, RegulatedAuthorizationCaseComponentCaseCase as yU, sliceIsConstraining as yV, _dataUpdateType as yW, noteNumber as yX, installDate as yY, cardBrand as yZ, _fullUrl as y_, _manufacturer as ya, _answerConstraint as yb, _when as yc, _form as yd, businessStatus as ye, comparisonGroup as yf, _instance as yg, _itemStatus as yh, _conditionalDelete as yi, _grade as yj, _process as yk, _articleDate as yl, additionalMonitoringIndicator as ym, title as yn, _courseOfTherapyType as yo, _identity as yp, CapabilityStatementRestComponent as yq, additionalAttribute as yr, monomerSet as ys, ingredient as yt, _subPotentReason as yu, _supportedMessage as yv, DataRequirementDateFilterComponent as yw, _performedActivity as yx, _specialty as yy, _weekInterval as yz, reAdmission as z, cors as z$, ConditionDefinitionObservationComponent as z0, FamilyMemberHistory as z1, operationTypeReason as z2, SpecimenDefinitionTypeTestedContainerAdditiveComponent as z3, _element as z4, _attachedDocument as z5, _implementation as z6, sourceMaterialType as z7, _substance as z8, _qualification as z9, ingredientLabel as zA, _whenPrepared as zB, costCenter as zC, outputParameters as zD, DevicePropertyComponent as zE, productCategory as zF, serviceType as zG, _verification as zH, reliableCache as zI, _Flag as zJ, numberAffected as zK, StructureMapGroupRuleDependentComponent as zL, relationshipType as zM, _statement as zN, _Goal as zO, issued as zP, _instruction as zQ, inclusionCriteria as zR, about as zS, Practitioner as zT, prognosisCodeableConcept as zU, AdverseEventParticipantComponent as zV, _maxValue as zW, ItemDetail as zX, _hasBodySite as zY, _metadata as zZ, rejectionCriterion as z_, _countType as za, sourceMaterialState as zb, _observationResultRequirement as zc, attestationSignature as zd, PackagedProductDefinitionPackagingComponentPackagingPackaging as ze, _marketingAuthorizationHolder as zf, _decisionMode as zg, repeats as zh, typeTested as zi, _rankingOrder as zj, end as zk, GenomicStudyAnalysisComponent as zl, excluded as zm, BundleEntryRequestComponent as zn, DeviceDefinitionDeviceNameComponent as zo, _eventNumber as zp, FormularyItem as zq, _marketDistribution as zr, _searchParam as zs, countryOfOrigin as zt, AuditEventAgentComponent as zu, _regulatoryAuthority as zv, _subjectState as zw, actualComparisonGroup as zx, _focusReference as zy, _statusReason as zz };
