/**
 * constituent
 *
 * ManufacturedItemDefinition.component.component.constituent: A reference to a constituent of the manufactured item as a whole, linked here so that its component location within the item can be indicated. This not where the item's ingredient are primarily stated (for which see Ingredient.for or ManufacturedItemDefinition.ingredient).
 *
 * http://hl7.org/fhir/constituent
 */
export declare const constituent = "http://hl7.org/fhir/constituent";
/**
 * _careTeam
 *
 * (Modified) ExplanationOfBenefit.careTeam
 *
 * http://hl7.org/fhir/_careTeam
 */
export declare const _careTeam = "http://hl7.org/fhir/_careTeam";
/**
 * ClinicalUseDefinitionWarningComponent
 *
 * ClinicalUseDefinitionWarningComponent: A critical piece of information about environmental, health or physical risks or hazards that serve as caution to the user. For example 'Do not operate heavy machinery', 'May cause drowsiness', or 'Get medical advice/attention if you feel unwell'.
 *
 * http://hl7.org/fhir/ClinicalUseDefinitionWarningComponent
 */
export declare const ClinicalUseDefinitionWarningComponent = "http://hl7.org/fhir/ClinicalUseDefinitionWarningComponent";
/**
 * PlanDefinitionActionParticipantComponent
 *
 * PlanDefinitionActionComponentAction.PlanDefinitionActionParticipantComponent: Indicates who should participate in performing the action described.
 *
 * http://hl7.org/fhir/PlanDefinitionActionParticipantComponent
 */
export declare const PlanDefinitionActionParticipantComponent = "http://hl7.org/fhir/PlanDefinitionActionParticipantComponent";
/**
 * VisionPrescriptionLensSpecificationComponent
 *
 * VisionPrescriptionLensSpecificationComponent: Contain the details of  the individual lens specifications and serves as the authorization for the fullfillment by certified professionals.
 *
 * http://hl7.org/fhir/VisionPrescriptionLensSpecificationComponent
 */
export declare const VisionPrescriptionLensSpecificationComponent = "http://hl7.org/fhir/VisionPrescriptionLensSpecificationComponent";
/**
 * _answerOption
 *
 * (Modified) Questionnaire.item.item.answerOption
 *
 * http://hl7.org/fhir/_answerOption
 */
export declare const _answerOption = "http://hl7.org/fhir/_answerOption";
/**
 * decimal
 *
 * A rational number with implicit precision
 *
 * http://hl7.org/fhir/decimal
 */
export declare const decimal = "http://hl7.org/fhir/decimal";
/**
 * _applies
 *
 * (Modified) Contract.term.group.applies
 *
 * http://hl7.org/fhir/_applies
 */
export declare const _applies = "http://hl7.org/fhir/_applies";
/**
 * serviceProvider
 *
 * Encounter.serviceProvider: The organization that is primarily responsible for this Encounter's services. This MAY be the same as the organization on the Patient record, however it could be different, such as if the actor performing the services was from an external organization (which may be billed seperately) for an external consultation.  Refer to the colonoscopy example on the Encounter examples tab.
 *
 * http://hl7.org/fhir/serviceProvider
 */
export declare const serviceProvider = "http://hl7.org/fhir/serviceProvider";
/**
 * NutritionProductIngredientComponent
 *
 * NutritionProductIngredientComponent: Ingredients contained in this product.
 *
 * http://hl7.org/fhir/NutritionProductIngredientComponent
 */
export declare const NutritionProductIngredientComponent = "http://hl7.org/fhir/NutritionProductIngredientComponent";
/**
 * Error
 *
 * ClaimResponse.Error: Errors encountered during the processing of the adjudication.
 * Note that `Error` is a reserved Javascript keyword, and is therefore suffixed by `__workaround`.
 * For a list of reserved keywords, see https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Lexical_grammar#Keywords.
 *
 * http://hl7.org/fhir/Error
 */
export declare const Error__workaround = "http://hl7.org/fhir/Error";
/**
 * productStatus
 *
 * BiologicallyDerivedProduct.productStatus: Whether the product is currently available.
 *
 * http://hl7.org/fhir/productStatus
 */
export declare const productStatus = "http://hl7.org/fhir/productStatus";
/**
 * ImagingStudySeriesPerformerComponent
 *
 * ImagingStudySeriesComponent.ImagingStudySeriesPerformerComponent: Indicates who or what performed the series and how they were involved.
 *
 * http://hl7.org/fhir/ImagingStudySeriesPerformerComponent
 */
export declare const ImagingStudySeriesPerformerComponent = "http://hl7.org/fhir/ImagingStudySeriesPerformerComponent";
/**
 * _lowerLimit
 *
 * (Modified) SampledData.lowerLimit
 *
 * http://hl7.org/fhir/_lowerLimit
 */
export declare const _lowerLimit = "http://hl7.org/fhir/_lowerLimit";
/**
 * Medication
 *
 * This resource is primarily used for the identification and definition of a medication, including ingredients, for the purposes of prescribing, dispensing, and administering a medication as well as for making statements about medication use.
 *
 * http://hl7.org/fhir/Medication
 */
export declare const Medication = "http://hl7.org/fhir/Medication";
/**
 * header
 *
 * Endpoint.header: Additional headers / information to send as part of the notification.
 *
 * http://hl7.org/fhir/header
 */
export declare const header = "http://hl7.org/fhir/header";
/**
 * StructureMapGroupRuleComponent
 *
 * StructureMapGroupComponent.StructureMapGroupRuleComponent: Transform Rule from source to target.
 *
 * http://hl7.org/fhir/StructureMapGroupRuleComponent
 */
export declare const StructureMapGroupRuleComponent = "http://hl7.org/fhir/StructureMapGroupRuleComponent";
/**
 * _productType
 *
 * (Modified) MedicationKnowledge.productType
 *
 * http://hl7.org/fhir/_productType
 */
export declare const _productType = "http://hl7.org/fhir/_productType";
/**
 * _relatedItem
 *
 * (Modified) InventoryItem.association.relatedItem
 *
 * http://hl7.org/fhir/_relatedItem
 */
export declare const _relatedItem = "http://hl7.org/fhir/_relatedItem";
/**
 * author
 *
 * Basic.author: Indicates who was responsible for creating the resource instance.
 *
 * http://hl7.org/fhir/author
 */
export declare const author = "http://hl7.org/fhir/author";
/**
 * _direction
 *
 * (Modified) TestScript.test.action.assert.direction
 *
 * http://hl7.org/fhir/_direction
 */
export declare const _direction = "http://hl7.org/fhir/_direction";
/**
 * _frequencyOfOccurrence
 *
 * (Modified) ClinicalUseDefinition.undesirableEffect.frequencyOfOccurrence
 *
 * http://hl7.org/fhir/_frequencyOfOccurrence
 */
export declare const _frequencyOfOccurrence = "http://hl7.org/fhir/_frequencyOfOccurrence";
/**
 * RequestOrchestration
 *
 * A set of related requests that can be used to capture intended activities that have inter-dependencies such as "give this medication after that one".
 *
 * http://hl7.org/fhir/RequestOrchestration
 */
export declare const RequestOrchestration = "http://hl7.org/fhir/RequestOrchestration";
/**
 * Detail
 *
 * Claim.Item.Detail: A claim detail line. Either a simple (a product or service) or a 'group' of sub-details which are simple items.
 *
 * http://hl7.org/fhir/Detail
 */
export declare const Detail = "http://hl7.org/fhir/Detail";
/**
 * numberOfRepeatsAllowed
 *
 * MedicationRequest.dispenseRequest.numberOfRepeatsAllowed: An integer indicating the number of times, in addition to the original dispense, (aka refills or repeats) that the patient can receive the prescribed medication. Usage Notes: This integer does not include the original order dispense. This means that if an order indicates dispense 30 tablets plus "3 repeats", then the order can be dispensed a total of 4 times and the patient can receive a total of 120 tablets.  A prescriber may explicitly say that zero refills are permitted after the initial dispense.
 *
 * http://hl7.org/fhir/numberOfRepeatsAllowed
 */
export declare const numberOfRepeatsAllowed = "http://hl7.org/fhir/numberOfRepeatsAllowed";
/**
 * _communicationRequest
 *
 * (Modified) ClaimResponse.communicationRequest
 *
 * http://hl7.org/fhir/_communicationRequest
 */
export declare const _communicationRequest = "http://hl7.org/fhir/_communicationRequest";
/**
 * DocumentReferenceContentProfileComponent
 *
 * DocumentReferenceContentComponent.DocumentReferenceContentProfileComponent: An identifier of the document constraints, encoding, structure, and template that the document conforms to beyond the base format indicated in the mimeType.
 *
 * http://hl7.org/fhir/DocumentReferenceContentProfileComponent
 */
export declare const DocumentReferenceContentProfileComponent = "http://hl7.org/fhir/DocumentReferenceContentProfileComponent";
/**
 * _masterFile
 *
 * (Modified) MedicinalProductDefinition.masterFile
 *
 * http://hl7.org/fhir/_masterFile
 */
export declare const _masterFile = "http://hl7.org/fhir/_masterFile";
/**
 * comment
 *
 * Schedule.comment: Comments on the availability to describe any extended information. Such as custom constraints on the slots that may be associated.
 *
 * http://hl7.org/fhir/comment
 */
export declare const comment = "http://hl7.org/fhir/comment";
/**
 * availableTime
 *
 * Availability.availableTime: Times the {item} is available.
 *
 * http://hl7.org/fhir/availableTime
 */
export declare const availableTime = "http://hl7.org/fhir/availableTime";
/**
 * _assert
 *
 * (Modified) TestScript.test.action.assert
 *
 * http://hl7.org/fhir/_assert
 */
export declare const _assert = "http://hl7.org/fhir/_assert";
/**
 * listRuleId
 *
 * StructureMap.group.rule.rule.target.listRuleId: Internal rule reference for shared list items.
 *
 * http://hl7.org/fhir/listRuleId
 */
export declare const listRuleId = "http://hl7.org/fhir/listRuleId";
/**
 * preAdmissionIdentifier
 *
 * Encounter.admission.preAdmissionIdentifier: Pre-admission identifier.
 *
 * http://hl7.org/fhir/preAdmissionIdentifier
 */
export declare const preAdmissionIdentifier = "http://hl7.org/fhir/preAdmissionIdentifier";
/**
 * participantType
 *
 * AppointmentResponse.participantType: Role of participant in the appointment.
 *
 * http://hl7.org/fhir/participantType
 */
export declare const participantType = "http://hl7.org/fhir/participantType";
/**
 * _related
 *
 * (Modified) ExplanationOfBenefit.related
 *
 * http://hl7.org/fhir/_related
 */
export declare const _related = "http://hl7.org/fhir/_related";
/**
 * SupplementSchedule
 *
 * NutritionOrderSupplementComponent.SupplementSchedule: Schedule information for a supplement.
 *
 * http://hl7.org/fhir/SupplementSchedule
 */
export declare const SupplementSchedule = "http://hl7.org/fhir/SupplementSchedule";
/**
 * reAdmission
 *
 * Encounter.admission.reAdmission: Indicates that this encounter is directly related to a prior admission, often because the conditions addressed in the prior admission were not fully addressed.
 *
 * http://hl7.org/fhir/reAdmission
 */
export declare const reAdmission = "http://hl7.org/fhir/reAdmission";
/**
 * _requestURL
 *
 * (Modified) TestScript.test.action.assert.requestURL
 *
 * http://hl7.org/fhir/_requestURL
 */
export declare const _requestURL = "http://hl7.org/fhir/_requestURL";
/**
 * _caseSensitive
 *
 * (Modified) CodeSystem.caseSensitive
 *
 * http://hl7.org/fhir/_caseSensitive
 */
export declare const _caseSensitive = "http://hl7.org/fhir/_caseSensitive";
/**
 * _chargeItem
 *
 * (Modified) Invoice.lineItem.chargeItem
 *
 * http://hl7.org/fhir/_chargeItem
 */
export declare const _chargeItem = "http://hl7.org/fhir/_chargeItem";
/**
 * _withdrawalPeriod
 *
 * (Modified) AdministrableProductDefinition.routeOfAdministration.targetSpecies.withdrawalPeriod
 *
 * http://hl7.org/fhir/_withdrawalPeriod
 */
export declare const _withdrawalPeriod = "http://hl7.org/fhir/_withdrawalPeriod";
/**
 * CapabilityStatementImplementationComponent
 *
 * CapabilityStatementImplementationComponent: Identifies a specific implementation instance that is described by the capability statement - i.e. a particular installation, rather than the capabilities of a software program.
 *
 * http://hl7.org/fhir/CapabilityStatementImplementationComponent
 */
export declare const CapabilityStatementImplementationComponent = "http://hl7.org/fhir/CapabilityStatementImplementationComponent";
/**
 * analysis
 *
 * GenomicStudy.analysis: The details about a specific analysis that was performed in this GenomicStudy.
 *
 * http://hl7.org/fhir/analysis
 */
export declare const analysis = "http://hl7.org/fhir/analysis";
/**
 * monitoringProgram
 *
 * MedicationKnowledge.monitoringProgram: The program under which the medication is reviewed.
 *
 * http://hl7.org/fhir/monitoringProgram
 */
export declare const monitoringProgram = "http://hl7.org/fhir/monitoringProgram";
/**
 * _date
 *
 * (Modified) ResearchStudy.date
 *
 * http://hl7.org/fhir/_date
 */
export declare const _date = "http://hl7.org/fhir/_date";
/**
 * satisfiedBy
 *
 * Requirements.statement.satisfiedBy: A reference to another artifact that satisfies this requirement. This could be a Profile, extension, or an element in one of those, or a CapabilityStatement, OperationDefinition, SearchParameter, CodeSystem(/code), ValueSet, Libary etc.
 *
 * http://hl7.org/fhir/satisfiedBy
 */
export declare const satisfiedBy = "http://hl7.org/fhir/satisfiedBy";
/**
 * artifact
 *
 * TestScript.scope.artifact: The specific conformance artifact being tested. The canonical reference can be version-specific.
 *
 * http://hl7.org/fhir/artifact
 */
export declare const artifact = "http://hl7.org/fhir/artifact";
/**
 * timing
 *
 * RequestOrchestration.action.timing
 *
 * http://hl7.org/fhir/timing
 */
export declare const timing = "http://hl7.org/fhir/timing";
/**
 * appliesToAll
 *
 * CoverageEligibilityRequest.supportingInfo.appliesToAll: The supporting materials are applicable for all detail items, product/servce categories and specific billing codes.
 *
 * http://hl7.org/fhir/appliesToAll
 */
export declare const appliesToAll = "http://hl7.org/fhir/appliesToAll";
/**
 * _appointmentRequired
 *
 * (Modified) HealthcareService.appointmentRequired
 *
 * http://hl7.org/fhir/_appointmentRequired
 */
export declare const _appointmentRequired = "http://hl7.org/fhir/_appointmentRequired";
/**
 * _canFilterBy
 *
 * (Modified) SubscriptionTopic.canFilterBy
 *
 * http://hl7.org/fhir/_canFilterBy
 */
export declare const _canFilterBy = "http://hl7.org/fhir/_canFilterBy";
/**
 * filter
 *
 * ValueSet.compose.exclude.filter: Select concepts by specifying a matching criterion based on the properties (including relationships) defined by the system, or on filters defined by the system. If multiple filters are specified within the include, they SHALL all be true.
 *
 * http://hl7.org/fhir/filter
 */
export declare const filter = "http://hl7.org/fhir/filter";
/**
 * _targetNumber
 *
 * (Modified) ResearchStudy.recruitment.targetNumber
 *
 * http://hl7.org/fhir/_targetNumber
 */
export declare const _targetNumber = "http://hl7.org/fhir/_targetNumber";
/**
 * _additive
 *
 * (Modified) SpecimenDefinition.typeTested.container.additive.additive
 *
 * http://hl7.org/fhir/_additive
 */
export declare const _additive = "http://hl7.org/fhir/_additive";
/**
 * _management
 *
 * (Modified) ClinicalUseDefinition.interaction.management
 *
 * http://hl7.org/fhir/_management
 */
export declare const _management = "http://hl7.org/fhir/_management";
/**
 * _phylum
 *
 * (Modified) SubstanceSourceMaterial.organism.organismGeneral.phylum
 *
 * http://hl7.org/fhir/_phylum
 */
export declare const _phylum = "http://hl7.org/fhir/_phylum";
/**
 * _distributor
 *
 * (Modified) DeviceDefinition.packaging.packaging.distributor
 *
 * http://hl7.org/fhir/_distributor
 */
export declare const _distributor = "http://hl7.org/fhir/_distributor";
/**
 * _clinicalRecommendationStatement
 *
 * (Modified) Measure.clinicalRecommendationStatement
 *
 * http://hl7.org/fhir/_clinicalRecommendationStatement
 */
export declare const _clinicalRecommendationStatement = "http://hl7.org/fhir/_clinicalRecommendationStatement";
/**
 * _manifest
 *
 * (Modified) ImplementationGuide.manifest
 *
 * http://hl7.org/fhir/_manifest
 */
export declare const _manifest = "http://hl7.org/fhir/_manifest";
/**
 * cancellationDate
 *
 * Appointment.cancellationDate: The date/time describing when the appointment was cancelled.
 *
 * http://hl7.org/fhir/cancellationDate
 */
export declare const cancellationDate = "http://hl7.org/fhir/cancellationDate";
/**
 * _doseQuantity
 *
 * (Modified) Immunization.doseQuantity
 *
 * http://hl7.org/fhir/_doseQuantity
 */
export declare const _doseQuantity = "http://hl7.org/fhir/_doseQuantity";
/**
 * DeviceDefinitionPackagingComponentUdiDeviceIdentifier
 *
 * Unique Device Identifier (UDI) Barcode string on the packaging.
 *
 * http://hl7.org/fhir/DeviceDefinitionPackagingComponentUdiDeviceIdentifier
 */
export declare const DeviceDefinitionPackagingComponentUdiDeviceIdentifier = "http://hl7.org/fhir/DeviceDefinitionPackagingComponentUdiDeviceIdentifier";
/**
 * VerificationResult
 *
 * Describes validation requirements, source(s), status and dates for one or more elements.
 *
 * http://hl7.org/fhir/VerificationResult
 */
export declare const VerificationResult = "http://hl7.org/fhir/VerificationResult";
/**
 * preference
 *
 * SpecimenDefinition.typeTested.preference: The preference for this type of conditioned specimen.
 *
 * http://hl7.org/fhir/preference
 */
export declare const preference = "http://hl7.org/fhir/preference";
/**
 * _asserter
 *
 * (Modified) Permission.asserter
 *
 * http://hl7.org/fhir/_asserter
 */
export declare const _asserter = "http://hl7.org/fhir/_asserter";
/**
 * _regulatoryIdentifier
 *
 * (Modified) DeviceDefinition.regulatoryIdentifier
 *
 * http://hl7.org/fhir/_regulatoryIdentifier
 */
export declare const _regulatoryIdentifier = "http://hl7.org/fhir/_regulatoryIdentifier";
/**
 * molecularFormula
 *
 * SubstanceDefinition.structure.molecularFormula: An expression which states the number and type of atoms present in a molecule of a substance.
 *
 * http://hl7.org/fhir/molecularFormula
 */
export declare const molecularFormula = "http://hl7.org/fhir/molecularFormula";
/**
 * isActive
 *
 * Medication.ingredient.isActive: Indication of whether this ingredient affects the therapeutic action of the drug.
 *
 * http://hl7.org/fhir/isActive
 */
export declare const isActive = "http://hl7.org/fhir/isActive";
/**
 * dispenserInstruction
 *
 * MedicationRequest.dispenseRequest.dispenserInstruction: Provides additional information to the dispenser, for example, counselling to be provided to the patient.
 *
 * http://hl7.org/fhir/dispenserInstruction
 */
export declare const dispenserInstruction = "http://hl7.org/fhir/dispenserInstruction";
/**
 * MedicationKnowledgeRelatedMedicationKnowledgeComponent
 *
 * MedicationKnowledgeRelatedMedicationKnowledgeComponent: Associated or related medications. For example, if the medication is a branded product (e.g. Crestor), this is the Therapeutic Moeity (e.g. Rosuvastatin) or if this is a generic medication (e.g. Rosuvastatin), this would link to a branded product (e.g. Crestor.
 *
 * http://hl7.org/fhir/MedicationKnowledgeRelatedMedicationKnowledgeComponent
 */
export declare const MedicationKnowledgeRelatedMedicationKnowledgeComponent = "http://hl7.org/fhir/MedicationKnowledgeRelatedMedicationKnowledgeComponent";
/**
 * CapabilityStatementRestSecurityComponent
 *
 * CapabilityStatementRestComponent.CapabilityStatementRestSecurityComponent: Information about security implementation from an interface perspective - what a client needs to know.
 *
 * http://hl7.org/fhir/CapabilityStatementRestSecurityComponent
 */
export declare const CapabilityStatementRestSecurityComponent = "http://hl7.org/fhir/CapabilityStatementRestSecurityComponent";
/**
 * initialSelected
 *
 * Questionnaire.item.item.answerOption.initialSelected: Indicates whether the answer value is selected when the list of possible answers is initially shown.
 *
 * http://hl7.org/fhir/initialSelected
 */
export declare const initialSelected = "http://hl7.org/fhir/initialSelected";
/**
 * _preventiveAction
 *
 * (Modified) AdverseEvent.preventiveAction
 *
 * http://hl7.org/fhir/_preventiveAction
 */
export declare const _preventiveAction = "http://hl7.org/fhir/_preventiveAction";
/**
 * DeviceDefinitionConformsToComponent
 *
 * DeviceDefinitionConformsToComponent: Identifies the standards, specifications, or formal guidances for the capabilities supported by the device. The device may be certified as conformant to these specifications e.g., communication, performance, process, measurement, or specialization standards.
 *
 * http://hl7.org/fhir/DeviceDefinitionConformsToComponent
 */
export declare const DeviceDefinitionConformsToComponent = "http://hl7.org/fhir/DeviceDefinitionConformsToComponent";
/**
 * _MedicationStatement
 *
 * (Modified) MedicationStatement
 *
 * http://hl7.org/fhir/_MedicationStatement
 */
export declare const _MedicationStatement = "http://hl7.org/fhir/_MedicationStatement";
/**
 * _availableStartTime
 *
 * (Modified) Availability.availableTime.availableStartTime
 *
 * http://hl7.org/fhir/_availableStartTime
 */
export declare const _availableStartTime = "http://hl7.org/fhir/_availableStartTime";
/**
 * validationType
 *
 * VerificationResult.validationType: What the target is validated against (nothing; primary source; multiple sources).
 *
 * http://hl7.org/fhir/validationType
 */
export declare const validationType = "http://hl7.org/fhir/validationType";
/**
 * _axis
 *
 * (Modified) VisionPrescription.lensSpecification.axis
 *
 * http://hl7.org/fhir/_axis
 */
export declare const _axis = "http://hl7.org/fhir/_axis";
/**
 * _serialNumber
 *
 * (Modified) Device.serialNumber
 *
 * http://hl7.org/fhir/_serialNumber
 */
export declare const _serialNumber = "http://hl7.org/fhir/_serialNumber";
/**
 * Narrative
 *
 * A human-readable summary of the resource conveying the essential clinical and business information for the resource.
 *
 * http://hl7.org/fhir/Narrative
 */
export declare const Narrative = "http://hl7.org/fhir/Narrative";
/**
 * _dependency
 *
 * (Modified) TestPlan.testCase.dependency
 *
 * http://hl7.org/fhir/_dependency
 */
export declare const _dependency = "http://hl7.org/fhir/_dependency";
/**
 * endDate
 *
 * ResearchSubject.progress.endDate: The date when the state ended.
 *
 * http://hl7.org/fhir/endDate
 */
export declare const endDate = "http://hl7.org/fhir/endDate";
/**
 * _prognosisReference
 *
 * (Modified) ClinicalImpression.prognosisReference
 *
 * http://hl7.org/fhir/_prognosisReference
 */
export declare const _prognosisReference = "http://hl7.org/fhir/_prognosisReference";
/**
 * _recruitment
 *
 * (Modified) ResearchStudy.recruitment
 *
 * http://hl7.org/fhir/_recruitment
 */
export declare const _recruitment = "http://hl7.org/fhir/_recruitment";
/**
 * searchParam
 *
 * DataRequirement.valueFilter.searchParam: A search parameter defined on the specified type of the DataRequirement, and which searches on elements of a type compatible with the type of the valueFilter.value[x] for the filter.
 *
 * http://hl7.org/fhir/searchParam
 */
export declare const searchParam = "http://hl7.org/fhir/searchParam";
/**
 * _usageInstruction
 *
 * (Modified) DeviceDispense.usageInstruction
 *
 * http://hl7.org/fhir/_usageInstruction
 */
export declare const _usageInstruction = "http://hl7.org/fhir/_usageInstruction";
/**
 * _generation
 *
 * (Modified) ImplementationGuide.definition.page.page.generation
 *
 * http://hl7.org/fhir/_generation
 */
export declare const _generation = "http://hl7.org/fhir/_generation";
/**
 * artifactAssessment
 *
 * Citation.citedArtifact.classification.artifactAssessment: Complex or externally created classification.
 *
 * http://hl7.org/fhir/artifactAssessment
 */
export declare const artifactAssessment = "http://hl7.org/fhir/artifactAssessment";
/**
 * complete
 *
 * Citation.citedArtifact.contributorship.complete: Indicates if the list includes all authors and/or contributors.
 *
 * http://hl7.org/fhir/complete
 */
export declare const complete = "http://hl7.org/fhir/complete";
/**
 * _dependent
 *
 * (Modified) StructureMap.group.rule.dependent
 *
 * http://hl7.org/fhir/_dependent
 */
export declare const _dependent = "http://hl7.org/fhir/_dependent";
/**
 * _due
 *
 * (Modified) PlanDefinition.goal.target.due
 *
 * http://hl7.org/fhir/_due
 */
export declare const _due = "http://hl7.org/fhir/_due";
/**
 * _replaces
 *
 * (Modified) DeviceRequest.replaces
 *
 * http://hl7.org/fhir/_replaces
 */
export declare const _replaces = "http://hl7.org/fhir/_replaces";
/**
 * EvidenceStatisticModelCharacteristicComponent
 *
 * EvidenceStatisticComponent.EvidenceStatisticModelCharacteristicComponent: A component of the method to generate the statistic.
 *
 * http://hl7.org/fhir/EvidenceStatisticModelCharacteristicComponent
 */
export declare const EvidenceStatisticModelCharacteristicComponent = "http://hl7.org/fhir/EvidenceStatisticModelCharacteristicComponent";
/**
 * _friday
 *
 * (Modified) Appointment.recurrenceTemplate.weeklyTemplate.friday
 *
 * http://hl7.org/fhir/_friday
 */
export declare const _friday = "http://hl7.org/fhir/_friday";
/**
 * orderedBy
 *
 * EvidenceReport.section.orderedBy: Specifies the order applied to the items in the section entries.
 *
 * http://hl7.org/fhir/orderedBy
 */
export declare const orderedBy = "http://hl7.org/fhir/orderedBy";
/**
 * _modality
 *
 * (Modified) ImagingStudy.series.modality
 *
 * http://hl7.org/fhir/_modality
 */
export declare const _modality = "http://hl7.org/fhir/_modality";
/**
 * expirationType
 *
 * Contract.expirationType: Event resulting in discontinuation or termination of this Contract instance by one or more parties to the contract.
 *
 * http://hl7.org/fhir/expirationType
 */
export declare const expirationType = "http://hl7.org/fhir/expirationType";
/**
 * party
 *
 * Contract.signer.party: Party which is a signator to this Contract.
 *
 * http://hl7.org/fhir/party
 */
export declare const party = "http://hl7.org/fhir/party";
/**
 * _objective
 *
 * (Modified) ResearchStudy.objective
 *
 * http://hl7.org/fhir/_objective
 */
export declare const _objective = "http://hl7.org/fhir/_objective";
/**
 * _totalNet
 *
 * (Modified) Invoice.totalNet
 *
 * http://hl7.org/fhir/_totalNet
 */
export declare const _totalNet = "http://hl7.org/fhir/_totalNet";
/**
 * _adherence
 *
 * (Modified) MedicationStatement.adherence
 *
 * http://hl7.org/fhir/_adherence
 */
export declare const _adherence = "http://hl7.org/fhir/_adherence";
/**
 * _cardinalityBehavior
 *
 * (Modified) RequestOrchestration.action.action.cardinalityBehavior
 *
 * http://hl7.org/fhir/_cardinalityBehavior
 */
export declare const _cardinalityBehavior = "http://hl7.org/fhir/_cardinalityBehavior";
/**
 * startDate
 *
 * ResearchSubject.progress.startDate: The date when the new status started.
 *
 * http://hl7.org/fhir/startDate
 */
export declare const startDate = "http://hl7.org/fhir/startDate";
/**
 * basis
 *
 * RegulatedAuthorization.basis: The legal or regulatory framework against which this authorization is granted, or other reasons for it.
 *
 * http://hl7.org/fhir/basis
 */
export declare const basis = "http://hl7.org/fhir/basis";
/**
 * _minutesDuration
 *
 * (Modified) Appointment.minutesDuration
 *
 * http://hl7.org/fhir/_minutesDuration
 */
export declare const _minutesDuration = "http://hl7.org/fhir/_minutesDuration";
/**
 * instruction
 *
 * SpecimenDefinition.typeTested.handling.instruction: Additional textual instructions for the preservation or transport of the specimen. For instance, 'Protect from light exposure'.
 *
 * http://hl7.org/fhir/instruction
 */
export declare const instruction = "http://hl7.org/fhir/instruction";
/**
 * _targetDisease
 *
 * (Modified) ImmunizationRecommendation.recommendation.targetDisease
 *
 * http://hl7.org/fhir/_targetDisease
 */
export declare const _targetDisease = "http://hl7.org/fhir/_targetDisease";
/**
 * eventTrigger
 *
 * SubscriptionTopic.eventTrigger: Event definition which can be used to trigger the SubscriptionTopic.
 *
 * http://hl7.org/fhir/eventTrigger
 */
export declare const eventTrigger = "http://hl7.org/fhir/eventTrigger";
/**
 * closure
 *
 * TerminologyCapabilities.closure: Whether the $closure operation is supported.
 *
 * http://hl7.org/fhir/closure
 */
export declare const closure = "http://hl7.org/fhir/closure";
/**
 * numberOfParticipants
 *
 * Evidence.statistic.sampleSize.numberOfParticipants: A human-readable string to clarify or explain concepts about the sample size.
 *
 * http://hl7.org/fhir/numberOfParticipants
 */
export declare const numberOfParticipants = "http://hl7.org/fhir/numberOfParticipants";
/**
 * businessArrangement
 *
 * CoverageEligibilityRequest.insurance.businessArrangement: A business agreement number established between the provider and the insurer for special business processing purposes.
 *
 * http://hl7.org/fhir/businessArrangement
 */
export declare const businessArrangement = "http://hl7.org/fhir/businessArrangement";
/**
 * requesterLinkId
 *
 * Contract.term.group.action.requesterLinkId: Id [identifier??] of the clause or question text related to the requester of this action in the referenced form or QuestionnaireResponse.
 *
 * http://hl7.org/fhir/requesterLinkId
 */
export declare const requesterLinkId = "http://hl7.org/fhir/requesterLinkId";
/**
 * _programEligibility
 *
 * (Modified) Immunization.programEligibility
 *
 * http://hl7.org/fhir/_programEligibility
 */
export declare const _programEligibility = "http://hl7.org/fhir/_programEligibility";
/**
 * _average
 *
 * (Modified) SubstancePolymer.repeat.repeatUnit.degreeOfPolymerisation.average
 *
 * http://hl7.org/fhir/_average
 */
export declare const _average = "http://hl7.org/fhir/_average";
/**
 * proxySignature
 *
 * VerificationResult.attestation.proxySignature: Signed assertion by the proxy entity indicating that they have the right to submit attested information on behalf of the attestation source.
 *
 * http://hl7.org/fhir/proxySignature
 */
export declare const proxySignature = "http://hl7.org/fhir/proxySignature";
/**
 * _assessmentMethod
 *
 * (Modified) AdverseEvent.suspectEntity.causality.assessmentMethod
 *
 * http://hl7.org/fhir/_assessmentMethod
 */
export declare const _assessmentMethod = "http://hl7.org/fhir/_assessmentMethod";
/**
 * _series
 *
 * (Modified) ImmunizationRecommendation.recommendation.series
 *
 * http://hl7.org/fhir/_series
 */
export declare const _series = "http://hl7.org/fhir/_series";
/**
 * _performingOrganization
 *
 * (Modified) ChargeItem.performingOrganization
 *
 * http://hl7.org/fhir/_performingOrganization
 */
export declare const _performingOrganization = "http://hl7.org/fhir/_performingOrganization";
/**
 * frames
 *
 * Attachment.frames: The number of frames in a photo. This is used with a multi-page fax, or an imaging acquisition context that takes multiple slices in a single image, or an animated gif. If there is more than one frame, this SHALL have a value in order to alert interface software that a multi-frame capable rendering widget is required.
 *
 * http://hl7.org/fhir/frames
 */
export declare const frames = "http://hl7.org/fhir/frames";
/**
 * _paternalOrganismName
 *
 * (Modified) SubstanceSourceMaterial.organism.hybrid.paternalOrganismName
 *
 * http://hl7.org/fhir/_paternalOrganismName
 */
export declare const _paternalOrganismName = "http://hl7.org/fhir/_paternalOrganismName";
/**
 * inputProfile
 *
 * OperationDefinition.inputProfile: Additional validation information for the in parameters - a single profile that covers all the parameters. The profile is a constraint on the parameters resource as a whole.
 *
 * http://hl7.org/fhir/inputProfile
 */
export declare const inputProfile = "http://hl7.org/fhir/inputProfile";
/**
 * _guarantor
 *
 * (Modified) Account.guarantor
 *
 * http://hl7.org/fhir/_guarantor
 */
export declare const _guarantor = "http://hl7.org/fhir/_guarantor";
/**
 * _human
 *
 * (Modified) ElementDefinition.constraint.human
 *
 * http://hl7.org/fhir/_human
 */
export declare const _human = "http://hl7.org/fhir/_human";
/**
 * NutritionProductCharacteristicComponent
 *
 * NutritionProductCharacteristicComponent: Specifies descriptive properties of the nutrition product.
 *
 * http://hl7.org/fhir/NutritionProductCharacteristicComponent
 */
export declare const NutritionProductCharacteristicComponent = "http://hl7.org/fhir/NutritionProductCharacteristicComponent";
/**
 * _orderDetail
 *
 * (Modified) ServiceRequest.orderDetail
 *
 * http://hl7.org/fhir/_orderDetail
 */
export declare const _orderDetail = "http://hl7.org/fhir/_orderDetail";
/**
 * maxParticipants
 *
 * VirtualServiceDetail.maxParticipants: Maximum number of participants supported by the virtual service.
 *
 * http://hl7.org/fhir/maxParticipants
 */
export declare const maxParticipants = "http://hl7.org/fhir/maxParticipants";
/**
 * ClinicalUseDefinitionUndesirableEffectComponent
 *
 * ClinicalUseDefinitionUndesirableEffectComponent: Describe the possible undesirable effects (negative outcomes) from the use of the medicinal product as treatment.
 *
 * http://hl7.org/fhir/ClinicalUseDefinitionUndesirableEffectComponent
 */
export declare const ClinicalUseDefinitionUndesirableEffectComponent = "http://hl7.org/fhir/ClinicalUseDefinitionUndesirableEffectComponent";
/**
 * _observed
 *
 * (Modified) Evidence.variableDefinition.observed
 *
 * http://hl7.org/fhir/_observed
 */
export declare const _observed = "http://hl7.org/fhir/_observed";
/**
 * validityPeriod
 *
 * RegulatedAuthorization.validityPeriod: The time period in which the regulatory approval, clearance or licencing is in effect. As an example, a Marketing Authorization includes the date of authorization and/or an expiration date.
 *
 * http://hl7.org/fhir/validityPeriod
 */
export declare const validityPeriod = "http://hl7.org/fhir/validityPeriod";
/**
 * ComputableLanguage
 *
 * Contract.ComputableLanguage: List of Computable Policy Rule Language Representations of this Contract.
 *
 * http://hl7.org/fhir/ComputableLanguage
 */
export declare const ComputableLanguage = "http://hl7.org/fhir/ComputableLanguage";
/**
 * surfaceOrientation
 *
 * BodyStructure.excludedStructure.bodyLandmarkOrientation.surfaceOrientation: The surface area a body location is in relation to a landmark.
 *
 * http://hl7.org/fhir/surfaceOrientation
 */
export declare const surfaceOrientation = "http://hl7.org/fhir/surfaceOrientation";
/**
 * _Provenance
 *
 * (Modified) Provenance
 *
 * http://hl7.org/fhir/_Provenance
 */
export declare const _Provenance = "http://hl7.org/fhir/_Provenance";
/**
 * testRun
 *
 * TestPlan.testCase.testRun: The actual test to be executed.
 *
 * http://hl7.org/fhir/testRun
 */
export declare const testRun = "http://hl7.org/fhir/testRun";
/**
 * SubstanceProtein
 *
 * A SubstanceProtein is defined as a single unit of a linear amino acid sequence, or a combination of subunits that are either covalently linked or have a defined invariant stoichiometric relationship. This includes all synthetic, recombinant and purified SubstanceProteins of defined sequence, whether the use is therapeutic or prophylactic. This set of elements will be used to describe albumins, coagulation factors, cytokines, growth factors, peptide/SubstanceProtein hormones, enzymes, toxins, toxoids, recombinant vaccines, and immunomodulators.
 *
 * http://hl7.org/fhir/SubstanceProtein
 */
export declare const SubstanceProtein = "http://hl7.org/fhir/SubstanceProtein";
/**
 * _focalDevice
 *
 * (Modified) Procedure.focalDevice
 *
 * http://hl7.org/fhir/_focalDevice
 */
export declare const _focalDevice = "http://hl7.org/fhir/_focalDevice";
/**
 * _operationType
 *
 * (Modified) InventoryReport.operationType
 *
 * http://hl7.org/fhir/_operationType
 */
export declare const _operationType = "http://hl7.org/fhir/_operationType";
/**
 * context
 *
 * Contract.term.group.asset.context: Circumstance of the asset.
 *
 * http://hl7.org/fhir/context
 */
export declare const context = "http://hl7.org/fhir/context";
/**
 * occurrenceDateTime
 *
 * GuidanceResponse.occurrenceDateTime: Indicates when the guidance response was processed.
 *
 * http://hl7.org/fhir/occurrenceDateTime
 */
export declare const occurrenceDateTime = "http://hl7.org/fhir/occurrenceDateTime";
/**
 * DetectedIssueEvidenceComponent
 *
 * DetectedIssueEvidenceComponent: Supporting evidence or manifestations that provide the basis for identifying the detected issue such as a GuidanceResponse or MeasureReport.
 *
 * http://hl7.org/fhir/DetectedIssueEvidenceComponent
 */
export declare const DetectedIssueEvidenceComponent = "http://hl7.org/fhir/DetectedIssueEvidenceComponent";
/**
 * _ExplanationOfBenefit
 *
 * (Modified) ExplanationOfBenefit
 *
 * http://hl7.org/fhir/_ExplanationOfBenefit
 */
export declare const _ExplanationOfBenefit = "http://hl7.org/fhir/_ExplanationOfBenefit";
/**
 * validated
 *
 * TestScript.metadata.capability.validated: Whether or not the test execution will validate the given capabilities of the server in order for this test script to execute.
 *
 * http://hl7.org/fhir/validated
 */
export declare const validated = "http://hl7.org/fhir/validated";
/**
 * _subunit
 *
 * (Modified) SubstanceProtein.subunit.subunit
 *
 * http://hl7.org/fhir/_subunit
 */
export declare const _subunit = "http://hl7.org/fhir/_subunit";
/**
 * EvidenceStatisticAttributeEstimateComponent
 *
 * EvidenceStatisticComponent.EvidenceStatisticAttributeEstimateComponent: A statistical attribute of the statistic such as a measure of heterogeneity.
 *
 * http://hl7.org/fhir/EvidenceStatisticAttributeEstimateComponent
 */
export declare const EvidenceStatisticAttributeEstimateComponent = "http://hl7.org/fhir/EvidenceStatisticAttributeEstimateComponent";
/**
 * replacedSequence
 *
 * MolecularSequence.relative.edit.replacedSequence: Allele in the starting sequence. Nucleotide(s)/amino acids from start position of sequence to stop position of sequence on the positive (+) strand of the starting sequence. When the sequence  type is DNA, it should be the sequence on the positive (+) strand. This will lay in the range between variant.start and variant.end.
 *
 * http://hl7.org/fhir/replacedSequence
 */
export declare const replacedSequence = "http://hl7.org/fhir/replacedSequence";
/**
 * specimen
 *
 * ObservationDefinition.specimen: The kind of specimen that this type of observation is produced on.
 *
 * http://hl7.org/fhir/specimen
 */
export declare const specimen = "http://hl7.org/fhir/specimen";
/**
 * rater
 *
 * Evidence.certainty.subcomponent.rater: Individual or group who did the rating.
 *
 * http://hl7.org/fhir/rater
 */
export declare const rater = "http://hl7.org/fhir/rater";
/**
 * relatedMedicationKnowledge
 *
 * MedicationKnowledge.relatedMedicationKnowledge: Associated or related medications. For example, if the medication is a branded product (e.g. Crestor), this is the Therapeutic Moeity (e.g. Rosuvastatin) or if this is a generic medication (e.g. Rosuvastatin), this would link to a branded product (e.g. Crestor.
 *
 * http://hl7.org/fhir/relatedMedicationKnowledge
 */
export declare const relatedMedicationKnowledge = "http://hl7.org/fhir/relatedMedicationKnowledge";
/**
 * lastModified
 *
 * Transport.lastModified: The date and time of last modification to this transport.
 *
 * http://hl7.org/fhir/lastModified
 */
export declare const lastModified = "http://hl7.org/fhir/lastModified";
/**
 * RequestOrchestrationActionParticipantComponent
 *
 * RequestOrchestrationActionComponent.RequestOrchestrationActionParticipantComponent: The participant that should perform or be responsible for this action.
 *
 * http://hl7.org/fhir/RequestOrchestrationActionParticipantComponent
 */
export declare const RequestOrchestrationActionParticipantComponent = "http://hl7.org/fhir/RequestOrchestrationActionParticipantComponent";
/**
 * _informationType
 *
 * (Modified) ArtifactAssessment.content.component.informationType
 *
 * http://hl7.org/fhir/_informationType
 */
export declare const _informationType = "http://hl7.org/fhir/_informationType";
/**
 * citation
 *
 * Citation.citedArtifact.relatesTo.citation: A bibliographic citation for the related artifact. This text SHOULD be formatted according to an accepted citation format.
 *
 * http://hl7.org/fhir/citation
 */
export declare const citation = "http://hl7.org/fhir/citation";
/**
 * paymentStatus
 *
 * PaymentNotice.paymentStatus: A code indicating whether payment has been sent or cleared.
 *
 * http://hl7.org/fhir/paymentStatus
 */
export declare const paymentStatus = "http://hl7.org/fhir/paymentStatus";
/**
 * treatment
 *
 * ClinicalUseDefinition.indication.otherTherapy.treatment: Reference to a specific medication (active substance, medicinal product or class of products, biological, food etc.) as part of an indication or contraindication.
 *
 * http://hl7.org/fhir/treatment
 */
export declare const treatment = "http://hl7.org/fhir/treatment";
/**
 * _initial
 *
 * (Modified) Questionnaire.item.item.initial
 *
 * http://hl7.org/fhir/_initial
 */
export declare const _initial = "http://hl7.org/fhir/_initial";
/**
 * priceComponent
 *
 * Invoice.lineItem.priceComponent: The price for a ChargeItem may be calculated as a base price with surcharges/deductions that apply in certain conditions. A ChargeItemDefinition resource that defines the prices, factors and conditions that apply to a billing code is currently under development. The priceComponent element can be used to offer transparency to the recipient of the Invoice as to how the prices have been calculated.
 *
 * http://hl7.org/fhir/priceComponent
 */
export declare const priceComponent = "http://hl7.org/fhir/priceComponent";
/**
 * _Linkage
 *
 * (Modified) Linkage
 *
 * http://hl7.org/fhir/_Linkage
 */
export declare const _Linkage = "http://hl7.org/fhir/_Linkage";
/**
 * _indicationGuideline
 *
 * (Modified) MedicationKnowledge.indicationGuideline
 *
 * http://hl7.org/fhir/_indicationGuideline
 */
export declare const _indicationGuideline = "http://hl7.org/fhir/_indicationGuideline";
/**
 * SubstanceSourceMaterial
 *
 * Source material shall capture information on the taxonomic and anatomical origins as well as the fraction of a material that can result in or can be modified to form a substance. This set of data elements shall be used to define polymer substances isolated from biological matrices. Taxonomic and anatomical origins shall be described using a controlled vocabulary as required. This information is captured for naturally derived polymers ( . starch) and structurally diverse substances. For Organisms belonging to the Kingdom Plantae the Substance level defines the fresh material of a single species or infraspecies, the Herbal Drug and the Herbal preparation. For Herbal preparations, the fraction information will be captured at the Substance information level and additional information for herbal extracts will be captured at the Specified Substance Group 1 information level. See for further explanation the Substance Class: Structurally Diverse and the herbal annex.
 *
 * http://hl7.org/fhir/SubstanceSourceMaterial
 */
export declare const SubstanceSourceMaterial = "http://hl7.org/fhir/SubstanceSourceMaterial";
/**
 * _conditionalRead
 *
 * (Modified) CapabilityStatement.rest.resource.conditionalRead
 *
 * http://hl7.org/fhir/_conditionalRead
 */
export declare const _conditionalRead = "http://hl7.org/fhir/_conditionalRead";
/**
 * managingEntity
 *
 * Subscription.managingEntity: Entity with authorization to make subsequent revisions to the Subscription and also determines what data the subscription is authorized to disclose.
 *
 * http://hl7.org/fhir/managingEntity
 */
export declare const managingEntity = "http://hl7.org/fhir/managingEntity";
/**
 * EvidenceVariableCharacteristicDefinitionByTypeAndValueComponent
 *
 * EvidenceVariableCharacteristicComponent.EvidenceVariableCharacteristicDefinitionByCombinationComponentCharacteristic.EvidenceVariableCharacteristicDefinitionByTypeAndValueComponent: Defines the characteristic using both a type and value[x] elements.
 *
 * http://hl7.org/fhir/EvidenceVariableCharacteristicDefinitionByTypeAndValueComponent
 */
export declare const EvidenceVariableCharacteristicDefinitionByTypeAndValueComponent = "http://hl7.org/fhir/EvidenceVariableCharacteristicDefinitionByTypeAndValueComponent";
/**
 * operationalStatus
 *
 * Location.operationalStatus: The operational status covers operation values most relevant to beds (but can also apply to rooms/units/chairs/etc. such as an isolation unit/dialysis chair). This typically covers concepts such as contamination, housekeeping, and other activities like maintenance.
 *
 * http://hl7.org/fhir/operationalStatus
 */
export declare const operationalStatus = "http://hl7.org/fhir/operationalStatus";
/**
 * _module
 *
 * (Modified) GuidanceResponse.module
 *
 * http://hl7.org/fhir/_module
 */
export declare const _module = "http://hl7.org/fhir/_module";
/**
 * MedicationAdministration
 *
 * Describes the event of a patient consuming or otherwise being administered a medication.  This may be as simple as swallowing a tablet or it may be a long running infusion. Related resources tie this event to the authorizing prescription, and the specific encounter between patient and health care practitioner. This event can also be used to record waste using a status of not-done and the appropriate statusReason.
 *
 * http://hl7.org/fhir/MedicationAdministration
 */
export declare const MedicationAdministration = "http://hl7.org/fhir/MedicationAdministration";
/**
 * UdiDeviceIdentifierMarketDistribution
 *
 * DeviceDefinitionPackagingComponentPackagingUdiDeviceIdentifier.UdiDeviceIdentifierMarketDistribution: Indicates where and when the device is available on the market.
 *
 * http://hl7.org/fhir/UdiDeviceIdentifierMarketDistribution
 */
export declare const UdiDeviceIdentifierMarketDistribution = "http://hl7.org/fhir/UdiDeviceIdentifierMarketDistribution";
/**
 * _probability
 *
 * (Modified) RiskAssessment.prediction.probability
 *
 * http://hl7.org/fhir/_probability
 */
export declare const _probability = "http://hl7.org/fhir/_probability";
/**
 * clinicalRecommendationStatement
 *
 * Measure.clinicalRecommendationStatement: Provides a summary of relevant clinical guidelines or other clinical recommendations supporting the measure.
 *
 * http://hl7.org/fhir/clinicalRecommendationStatement
 */
export declare const clinicalRecommendationStatement = "http://hl7.org/fhir/clinicalRecommendationStatement";
/**
 * _image
 *
 * (Modified) ImplementationGuide.manifest.image
 *
 * http://hl7.org/fhir/_image
 */
export declare const _image = "http://hl7.org/fhir/_image";
/**
 * SubscriptionTopicNotificationShapeComponent
 *
 * SubscriptionTopicNotificationShapeComponent: List of properties to describe the shape (e.g., resources) included in notifications from this Subscription Topic.
 *
 * http://hl7.org/fhir/SubscriptionTopicNotificationShapeComponent
 */
export declare const SubscriptionTopicNotificationShapeComponent = "http://hl7.org/fhir/SubscriptionTopicNotificationShapeComponent";
/**
 * _componentPart
 *
 * (Modified) PackagedProductDefinition.packaging.packaging.componentPart
 *
 * http://hl7.org/fhir/_componentPart
 */
export declare const _componentPart = "http://hl7.org/fhir/_componentPart";
/**
 * op
 *
 * ValueSet.compose.exclude.filter.op: The kind of operation to perform as a part of the filter criteria.
 *
 * http://hl7.org/fhir/op
 */
export declare const op = "http://hl7.org/fhir/op";
/**
 * _processingFacility
 *
 * (Modified) BiologicallyDerivedProduct.processingFacility
 *
 * http://hl7.org/fhir/_processingFacility
 */
export declare const _processingFacility = "http://hl7.org/fhir/_processingFacility";
/**
 * unit
 *
 * Quantity.unit: A human-readable form of the unit.
 *
 * http://hl7.org/fhir/unit
 */
export declare const unit = "http://hl7.org/fhir/unit";
/**
 * _problem
 *
 * (Modified) ClinicalImpression.problem
 *
 * http://hl7.org/fhir/_problem
 */
export declare const _problem = "http://hl7.org/fhir/_problem";
/**
 * SubstanceDefinitionPropertyComponent
 *
 * SubstanceDefinitionPropertyComponent: General specifications for this substance.
 *
 * http://hl7.org/fhir/SubstanceDefinitionPropertyComponent
 */
export declare const SubstanceDefinitionPropertyComponent = "http://hl7.org/fhir/SubstanceDefinitionPropertyComponent";
/**
 * _fluidConsistencyType
 *
 * (Modified) NutritionOrder.oralDiet.fluidConsistencyType
 *
 * http://hl7.org/fhir/_fluidConsistencyType
 */
export declare const _fluidConsistencyType = "http://hl7.org/fhir/_fluidConsistencyType";
/**
 * _SubstancePolymer
 *
 * (Modified) SubstancePolymer
 *
 * http://hl7.org/fhir/_SubstancePolymer
 */
export declare const _SubstancePolymer = "http://hl7.org/fhir/_SubstancePolymer";
/**
 * ValueSetComposeIncludeConceptDesignationComponent
 *
 * ValueSetComposeComponent.ConceptSet.ConceptReference.ValueSetComposeIncludeConceptDesignationComponent: Additional representations for this concept when used in this value set - other languages, aliases, specialized purposes, used for particular purposes, etc.
 *
 * http://hl7.org/fhir/ValueSetComposeIncludeConceptDesignationComponent
 */
export declare const ValueSetComposeIncludeConceptDesignationComponent = "http://hl7.org/fhir/ValueSetComposeIncludeConceptDesignationComponent";
/**
 * versionReference
 *
 * ExampleScenario.process.step.alternative.step.process.step.operation.request.versionReference: A reference to the key of a specific version of an instance in this instance.
 *
 * http://hl7.org/fhir/versionReference
 */
export declare const versionReference = "http://hl7.org/fhir/versionReference";
/**
 * _maxSingleDose
 *
 * (Modified) AdministrableProductDefinition.routeOfAdministration.maxSingleDose
 *
 * http://hl7.org/fhir/_maxSingleDose
 */
export declare const _maxSingleDose = "http://hl7.org/fhir/_maxSingleDose";
/**
 * meaning
 *
 * Permission.rule.data.resource.meaning: How the resource reference is interpreted when testing consent restrictions.
 *
 * http://hl7.org/fhir/meaning
 */
export declare const meaning = "http://hl7.org/fhir/meaning";
/**
 * measurementPoint
 *
 * Ingredient.substance.strength.referenceStrength.measurementPoint: For when strength is measured at a particular point or distance.
 *
 * http://hl7.org/fhir/measurementPoint
 */
export declare const measurementPoint = "http://hl7.org/fhir/measurementPoint";
/**
 * diagnosisRelatedGroup
 *
 * ExplanationOfBenefit.diagnosisRelatedGroup: A package billing code or bundle code used to group products and services to a particular health condition (such as heart attack) which is based on a predetermined grouping code system.
 *
 * http://hl7.org/fhir/diagnosisRelatedGroup
 */
export declare const diagnosisRelatedGroup = "http://hl7.org/fhir/diagnosisRelatedGroup";
/**
 * _relative
 *
 * (Modified) MolecularSequence.relative
 *
 * http://hl7.org/fhir/_relative
 */
export declare const _relative = "http://hl7.org/fhir/_relative";
/**
 * _publicationForm
 *
 * (Modified) Citation.citedArtifact.publicationForm
 *
 * http://hl7.org/fhir/_publicationForm
 */
export declare const _publicationForm = "http://hl7.org/fhir/_publicationForm";
/**
 * _Patient
 *
 * (Modified) Patient
 *
 * http://hl7.org/fhir/_Patient
 */
export declare const _Patient = "http://hl7.org/fhir/_Patient";
/**
 * GuidanceResponse
 *
 * A guidance response is the formal response to a guidance request, including any output parameters returned by the evaluation, as well as the description of any proposed actions to be taken.
 *
 * http://hl7.org/fhir/GuidanceResponse
 */
export declare const GuidanceResponse = "http://hl7.org/fhir/GuidanceResponse";
/**
 * entity
 *
 * Contract.term.asset.valuedItem.entity
 *
 * http://hl7.org/fhir/entity
 */
export declare const entity = "http://hl7.org/fhir/entity";
/**
 * sourceReference
 *
 * Consent.sourceReference: A reference to a consent that links back to such a source, a reference to a document repository (e.g. XDS) that stores the original consent document.
 *
 * http://hl7.org/fhir/sourceReference
 */
export declare const sourceReference = "http://hl7.org/fhir/sourceReference";
/**
 * valueFilter
 *
 * DataRequirement.valueFilter: Value filters specify additional constraints on the data for elements other than code-valued or date-valued. Each value filter specifies an additional constraint on the data (i.e. valueFilters are AND'ed, not OR'ed).
 *
 * http://hl7.org/fhir/valueFilter
 */
export declare const valueFilter = "http://hl7.org/fhir/valueFilter";
/**
 * _useBy
 *
 * (Modified) NutritionProduct.instance.useBy
 *
 * http://hl7.org/fhir/_useBy
 */
export declare const _useBy = "http://hl7.org/fhir/_useBy";
/**
 * bodyLandmarkOrientation
 *
 * BodyStructure.excludedStructure.bodyLandmarkOrientation: Body locations in relation to a specific body landmark (tatoo, scar, other body structure).
 *
 * http://hl7.org/fhir/bodyLandmarkOrientation
 */
export declare const bodyLandmarkOrientation = "http://hl7.org/fhir/bodyLandmarkOrientation";
/**
 * SubstanceDefinitionNameComponentName
 *
 * A synonym of this particular name, by which the substance is also known.
 *
 * http://hl7.org/fhir/SubstanceDefinitionNameComponentName
 */
export declare const SubstanceDefinitionNameComponentName = "http://hl7.org/fhir/SubstanceDefinitionNameComponentName";
/**
 * _policyText
 *
 * (Modified) Consent.policyText
 *
 * http://hl7.org/fhir/_policyText
 */
export declare const _policyText = "http://hl7.org/fhir/_policyText";
/**
 * _changePattern
 *
 * (Modified) ClinicalImpression.changePattern
 *
 * http://hl7.org/fhir/_changePattern
 */
export declare const _changePattern = "http://hl7.org/fhir/_changePattern";
/**
 * subDetail
 *
 * ExplanationOfBenefit.item.detail.subDetail: Third-tier of goods and services.
 *
 * http://hl7.org/fhir/subDetail
 */
export declare const subDetail = "http://hl7.org/fhir/subDetail";
/**
 * allDay
 *
 * Availability.availableTime.allDay: Always available? i.e. 24 hour service.
 *
 * http://hl7.org/fhir/allDay
 */
export declare const allDay = "http://hl7.org/fhir/allDay";
/**
 * _modification
 *
 * (Modified) SubstancePolymer.modification
 *
 * http://hl7.org/fhir/_modification
 */
export declare const _modification = "http://hl7.org/fhir/_modification";
/**
 * _nodeId
 *
 * (Modified) GraphDefinition.node.nodeId
 *
 * http://hl7.org/fhir/_nodeId
 */
export declare const _nodeId = "http://hl7.org/fhir/_nodeId";
/**
 * AdverseEventContributingFactorComponent
 *
 * AdverseEventContributingFactorComponent: The contributing factors suspected to have increased the probability or severity of the adverse event.
 *
 * http://hl7.org/fhir/AdverseEventContributingFactorComponent
 */
export declare const AdverseEventContributingFactorComponent = "http://hl7.org/fhir/AdverseEventContributingFactorComponent";
/**
 * TestPlanTestCaseComponent
 *
 * TestPlanTestCaseComponent: The individual test cases that are part of this plan, when they they are made explicit.
 *
 * http://hl7.org/fhir/TestPlanTestCaseComponent
 */
export declare const TestPlanTestCaseComponent = "http://hl7.org/fhir/TestPlanTestCaseComponent";
/**
 * sunday
 *
 * Appointment.recurrenceTemplate.weeklyTemplate.sunday: Indicates that recurring appointments should occur on Sundays.
 *
 * http://hl7.org/fhir/sunday
 */
export declare const sunday = "http://hl7.org/fhir/sunday";
/**
 * cancellationReason
 *
 * Appointment.cancellationReason: The coded reason for the appointment being cancelled. This is often used in reporting/billing/futher processing to determine if further actions are required, or specific fees apply.
 *
 * http://hl7.org/fhir/cancellationReason
 */
export declare const cancellationReason = "http://hl7.org/fhir/cancellationReason";
/**
 * _title
 *
 * (Modified) ExampleScenario.process.step.process.step.alternative.step.operation.title
 *
 * http://hl7.org/fhir/_title
 */
export declare const _title = "http://hl7.org/fhir/_title";
/**
 * _sourceId
 *
 * (Modified) OperationDefinition.parameter.referencedFrom.sourceId
 *
 * http://hl7.org/fhir/_sourceId
 */
export declare const _sourceId = "http://hl7.org/fhir/_sourceId";
/**
 * _entityRelatedness
 *
 * (Modified) AdverseEvent.suspectEntity.causality.entityRelatedness
 *
 * http://hl7.org/fhir/_entityRelatedness
 */
export declare const _entityRelatedness = "http://hl7.org/fhir/_entityRelatedness";
/**
 * line
 *
 * Address.line: This component contains the house number, apartment number, street name, street direction,  P.O. Box number, delivery hints, and similar address information.
 *
 * http://hl7.org/fhir/line
 */
export declare const line = "http://hl7.org/fhir/line";
/**
 * _effectivePeriod
 *
 * (Modified) PlanDefinition.effectivePeriod
 *
 * http://hl7.org/fhir/_effectivePeriod
 */
export declare const _effectivePeriod = "http://hl7.org/fhir/_effectivePeriod";
/**
 * preAuthRef
 *
 * ClaimResponse.preAuthRef: Reference from the Insurer which is used in later communications which refers to this adjudication.
 *
 * http://hl7.org/fhir/preAuthRef
 */
export declare const preAuthRef = "http://hl7.org/fhir/preAuthRef";
/**
 * requestId
 *
 * TestScript.teardown.action.operation.requestId: The fixture id (maybe new) to map to the request.
 *
 * http://hl7.org/fhir/requestId
 */
export declare const requestId = "http://hl7.org/fhir/requestId";
/**
 * _autodelete
 *
 * (Modified) TestScript.fixture.autodelete
 *
 * http://hl7.org/fhir/_autodelete
 */
export declare const _autodelete = "http://hl7.org/fhir/_autodelete";
/**
 * _fundsReserve
 *
 * (Modified) ExplanationOfBenefit.fundsReserve
 *
 * http://hl7.org/fhir/_fundsReserve
 */
export declare const _fundsReserve = "http://hl7.org/fhir/_fundsReserve";
/**
 * BundleEntryComponentLink
 *
 * A series of links that provide context to this entry.
 *
 * http://hl7.org/fhir/BundleEntryComponentLink
 */
export declare const BundleEntryComponentLink = "http://hl7.org/fhir/BundleEntryComponentLink";
/**
 * DocumentReferenceContentComponent
 *
 * DocumentReferenceContentComponent: The document and format referenced.  If there are multiple content element repetitions, these must all represent the same document in different format, or attachment metadata.
 *
 * http://hl7.org/fhir/DocumentReferenceContentComponent
 */
export declare const DocumentReferenceContentComponent = "http://hl7.org/fhir/DocumentReferenceContentComponent";
/**
 * _holder
 *
 * (Modified) RegulatedAuthorization.holder
 *
 * http://hl7.org/fhir/_holder
 */
export declare const _holder = "http://hl7.org/fhir/_holder";
/**
 * _qualifiers
 *
 * (Modified) InsurancePlan.plan.specificCost.benefit.cost.qualifiers
 *
 * http://hl7.org/fhir/_qualifiers
 */
export declare const _qualifiers = "http://hl7.org/fhir/_qualifiers";
/**
 * _Specimen
 *
 * (Modified) Specimen
 *
 * http://hl7.org/fhir/_Specimen
 */
export declare const _Specimen = "http://hl7.org/fhir/_Specimen";
/**
 * CodeSystemFilterComponent
 *
 * CodeSystemFilterComponent: A filter that can be used in a value set compose statement when selecting concepts using a filter.
 *
 * http://hl7.org/fhir/CodeSystemFilterComponent
 */
export declare const CodeSystemFilterComponent = "http://hl7.org/fhir/CodeSystemFilterComponent";
/**
 * _replacementSequence
 *
 * (Modified) MolecularSequence.relative.edit.replacementSequence
 *
 * http://hl7.org/fhir/_replacementSequence
 */
export declare const _replacementSequence = "http://hl7.org/fhir/_replacementSequence";
/**
 * serviceCategory
 *
 * Slot.serviceCategory: A broad categorization of the service that is to be performed during this appointment.
 *
 * http://hl7.org/fhir/serviceCategory
 */
export declare const serviceCategory = "http://hl7.org/fhir/serviceCategory";
/**
 * _next
 *
 * (Modified) ValueSet.expansion.next
 *
 * http://hl7.org/fhir/_next
 */
export declare const _next = "http://hl7.org/fhir/_next";
/**
 * paymentTerms
 *
 * Invoice.paymentTerms: Payment details such as banking details, period of payment, deductibles, methods of payment.
 *
 * http://hl7.org/fhir/paymentTerms
 */
export declare const paymentTerms = "http://hl7.org/fhir/paymentTerms";
/**
 * _started
 *
 * (Modified) ImagingStudy.series.started
 *
 * http://hl7.org/fhir/_started
 */
export declare const _started = "http://hl7.org/fhir/_started";
/**
 * offer
 *
 * Contract.term.group.offer: The matter of concern in the context of this provision of the agrement.
 *
 * http://hl7.org/fhir/offer
 */
export declare const offer = "http://hl7.org/fhir/offer";
/**
 * coordinateSystem
 *
 * MolecularSequence.relative.coordinateSystem: These are different ways of identifying nucleotides or amino acids within a sequence. Different databases and file types may use different systems. For detail definitions, see https://loinc.org/92822-6/ for more detail.
 *
 * http://hl7.org/fhir/coordinateSystem
 */
export declare const coordinateSystem = "http://hl7.org/fhir/coordinateSystem";
/**
 * DeviceDefinition
 *
 * This is a specialized resource that defines the characteristics and capabilities of a device.
 *
 * http://hl7.org/fhir/DeviceDefinition
 */
export declare const DeviceDefinition = "http://hl7.org/fhir/DeviceDefinition";
/**
 * _intent
 *
 * (Modified) RequestOrchestration.intent
 *
 * http://hl7.org/fhir/_intent
 */
export declare const _intent = "http://hl7.org/fhir/_intent";
/**
 * _text
 *
 * (Modified) QuestionnaireResponse.item.item.text
 *
 * http://hl7.org/fhir/_text
 */
export declare const _text = "http://hl7.org/fhir/_text";
/**
 * _level
 *
 * (Modified) Evidence.statistic.modelCharacteristic.attributeEstimate.level
 *
 * http://hl7.org/fhir/_level
 */
export declare const _level = "http://hl7.org/fhir/_level";
/**
 * facility
 *
 * CoverageEligibilityRequest.item.facility: Facility where the services will be provided.
 *
 * http://hl7.org/fhir/facility
 */
export declare const facility = "http://hl7.org/fhir/facility";
/**
 * qualifiedValue
 *
 * ObservationDefinition.component.qualifiedValue: A set of qualified values associated with a context and a set of conditions -  provides a range for quantitative and ordinal observations and a collection of value sets for qualitative observations.
 *
 * http://hl7.org/fhir/qualifiedValue
 */
export declare const qualifiedValue = "http://hl7.org/fhir/qualifiedValue";
/**
 * ManifestResource
 *
 * ImplementationGuideManifestComponent.ManifestResource: A resource that is part of the implementation guide. Conformance resources (value set, structure definition, capability statements etc.) are obvious candidates for inclusion, but any kind of resource can be included as an example resource.
 *
 * http://hl7.org/fhir/ManifestResource
 */
export declare const ManifestResource = "http://hl7.org/fhir/ManifestResource";
/**
 * prism
 *
 * VisionPrescription.lensSpecification.prism: Allows for adjustment on two axis.
 *
 * http://hl7.org/fhir/prism
 */
export declare const prism = "http://hl7.org/fhir/prism";
/**
 * MedicationBatchComponent
 *
 * MedicationBatchComponent: Information that only applies to packages (not products).
 *
 * http://hl7.org/fhir/MedicationBatchComponent
 */
export declare const MedicationBatchComponent = "http://hl7.org/fhir/MedicationBatchComponent";
/**
 * resultForDelete
 *
 * SubscriptionTopic.resourceTrigger.queryCriteria.resultForDelete: For 'delete' interactions, should the 'current' query criteria count as an automatic pass or an automatic fail. If not present, the testing behavior during `delete` interactions is unspecified (server discretion).
 *
 * http://hl7.org/fhir/resultForDelete
 */
export declare const resultForDelete = "http://hl7.org/fhir/resultForDelete";
/**
 * _accept
 *
 * (Modified) TestScript.teardown.action.operation.accept
 *
 * http://hl7.org/fhir/_accept
 */
export declare const _accept = "http://hl7.org/fhir/_accept";
/**
 * overbooked
 *
 * Slot.overbooked: This slot has already been overbooked, appointments are unlikely to be accepted for this time.
 *
 * http://hl7.org/fhir/overbooked
 */
export declare const overbooked = "http://hl7.org/fhir/overbooked";
/**
 * _plan
 *
 * (Modified) InsurancePlan.plan
 *
 * http://hl7.org/fhir/_plan
 */
export declare const _plan = "http://hl7.org/fhir/_plan";
/**
 * ReviewOutcome
 *
 * ClaimResponse.Item.ReviewOutcome: The high-level results of the adjudication if adjudication has been performed.
 *
 * http://hl7.org/fhir/ReviewOutcome
 */
export declare const ReviewOutcome = "http://hl7.org/fhir/ReviewOutcome";
/**
 * CitationCitedArtifactContributorshipEntryComponent
 *
 * CitationCitedArtifactComponent.CitationCitedArtifactContributorshipComponent.CitationCitedArtifactContributorshipEntryComponent: An individual entity named as a contributor, for example in the author list or contributor list.
 *
 * http://hl7.org/fhir/CitationCitedArtifactContributorshipEntryComponent
 */
export declare const CitationCitedArtifactContributorshipEntryComponent = "http://hl7.org/fhir/CitationCitedArtifactContributorshipEntryComponent";
/**
 * discriminator
 *
 * ElementDefinition.slicing.discriminator: Designates which child elements are used to discriminate between the slices when processing an instance. If one or more discriminators are provided, the value of the child elements in the instance data SHALL completely distinguish which slice the element in the resource matches based on the allowed values for those elements in each of the slices.
 *
 * http://hl7.org/fhir/discriminator
 */
export declare const discriminator = "http://hl7.org/fhir/discriminator";
/**
 * ordered
 *
 * ElementDefinition.slicing.ordered: If the matching elements have to occur in the same order as defined in the profile.
 *
 * http://hl7.org/fhir/ordered
 */
export declare const ordered = "http://hl7.org/fhir/ordered";
/**
 * LegalLanguage
 *
 * Contract.LegalLanguage: List of Legal expressions or representations of this Contract.
 *
 * http://hl7.org/fhir/LegalLanguage
 */
export declare const LegalLanguage = "http://hl7.org/fhir/LegalLanguage";
/**
 * frequencyOfOccurrence
 *
 * ClinicalUseDefinition.undesirableEffect.frequencyOfOccurrence: How often the effect is seen.
 *
 * http://hl7.org/fhir/frequencyOfOccurrence
 */
export declare const frequencyOfOccurrence = "http://hl7.org/fhir/frequencyOfOccurrence";
/**
 * _validationType
 *
 * (Modified) VerificationResult.validationType
 *
 * http://hl7.org/fhir/_validationType
 */
export declare const _validationType = "http://hl7.org/fhir/_validationType";
/**
 * PermissionRuleDataComponent
 *
 * Permission.Rule.PermissionRuleDataComponent: A description or definition of which activities are allowed to be done on the data.
 *
 * http://hl7.org/fhir/PermissionRuleDataComponent
 */
export declare const PermissionRuleDataComponent = "http://hl7.org/fhir/PermissionRuleDataComponent";
/**
 * _versionNeeded
 *
 * (Modified) CodeSystem.versionNeeded
 *
 * http://hl7.org/fhir/_versionNeeded
 */
export declare const _versionNeeded = "http://hl7.org/fhir/_versionNeeded";
/**
 * PackagedProductDefinitionPackagingContainedItemComponent
 *
 * PackagedProductDefinitionPackagingComponent.PackagedProductDefinitionPackagingContainedItemComponent: The item(s) within the packaging.
 *
 * http://hl7.org/fhir/PackagedProductDefinitionPackagingContainedItemComponent
 */
export declare const PackagedProductDefinitionPackagingContainedItemComponent = "http://hl7.org/fhir/PackagedProductDefinitionPackagingContainedItemComponent";
/**
 * predecessor
 *
 * TestPlan.testCase.dependency.predecessor: Link to predecessor test plans.
 *
 * http://hl7.org/fhir/predecessor
 */
export declare const predecessor = "http://hl7.org/fhir/predecessor";
/**
 * ArtifactAssessment
 *
 * This Resource provides one or more comments, classifiers or ratings about a Resource and supports attribution and rights management metadata for the added content.
 *
 * http://hl7.org/fhir/ArtifactAssessment
 */
export declare const ArtifactAssessment = "http://hl7.org/fhir/ArtifactAssessment";
/**
 * _dependsOn
 *
 * (Modified) ImplementationGuide.dependsOn
 *
 * http://hl7.org/fhir/_dependsOn
 */
export declare const _dependsOn = "http://hl7.org/fhir/_dependsOn";
/**
 * evidence
 *
 * Condition.evidence: Supporting evidence / manifestations that are the basis of the Condition's verification status, such as evidence that confirmed or refuted the condition.
 *
 * http://hl7.org/fhir/evidence
 */
export declare const evidence = "http://hl7.org/fhir/evidence";
/**
 * MeasureGroupPopulationComponent
 *
 * MeasureGroupComponent.MeasureGroupPopulationComponent: A population criteria for the measure.
 *
 * http://hl7.org/fhir/MeasureGroupPopulationComponent
 */
export declare const MeasureGroupPopulationComponent = "http://hl7.org/fhir/MeasureGroupPopulationComponent";
/**
 * opticalActivity
 *
 * SubstanceDefinition.structure.opticalActivity: Optical activity type.
 *
 * http://hl7.org/fhir/opticalActivity
 */
export declare const opticalActivity = "http://hl7.org/fhir/opticalActivity";
/**
 * nutritionProduct
 *
 * NutritionIntake.consumedItem.nutritionProduct: Identifies the food or fluid product that was consumed. This is potentially a link to a resource representing the details of the food product (TBD) or a simple attribute carrying a code that identifies the food from a known list of foods.
 *
 * http://hl7.org/fhir/nutritionProduct
 */
export declare const nutritionProduct = "http://hl7.org/fhir/nutritionProduct";
/**
 * specialMeasures
 *
 * MedicinalProductDefinition.specialMeasures: Whether the Medicinal Product is subject to special measures for regulatory reasons, such as a requirement to conduct post-authorization studies.
 *
 * http://hl7.org/fhir/specialMeasures
 */
export declare const specialMeasures = "http://hl7.org/fhir/specialMeasures";
/**
 * packageId
 *
 * ImplementationGuide.dependsOn.packageId: The NPM package name for the Implementation Guide that this IG depends on.
 *
 * http://hl7.org/fhir/packageId
 */
export declare const packageId = "http://hl7.org/fhir/packageId";
/**
 * TerminologyCapabilitiesCodeSystemVersionFilterComponent
 *
 * TerminologyCapabilitiesCodeSystemComponent.TerminologyCapabilitiesCodeSystemVersionComponent.TerminologyCapabilitiesCodeSystemVersionFilterComponent: Filter Properties supported.
 *
 * http://hl7.org/fhir/TerminologyCapabilitiesCodeSystemVersionFilterComponent
 */
export declare const TerminologyCapabilitiesCodeSystemVersionFilterComponent = "http://hl7.org/fhir/TerminologyCapabilitiesCodeSystemVersionFilterComponent";
/**
 * SubDetail
 *
 * ExplanationOfBenefit.Item.Detail.SubDetail: Third-tier of goods and services.
 *
 * http://hl7.org/fhir/SubDetail
 */
export declare const SubDetail = "http://hl7.org/fhir/SubDetail";
/**
 * _received
 *
 * (Modified) Communication.received
 *
 * http://hl7.org/fhir/_received
 */
export declare const _received = "http://hl7.org/fhir/_received";
/**
 * CapabilityStatementDocumentComponent
 *
 * CapabilityStatementDocumentComponent: A document definition.
 *
 * http://hl7.org/fhir/CapabilityStatementDocumentComponent
 */
export declare const CapabilityStatementDocumentComponent = "http://hl7.org/fhir/CapabilityStatementDocumentComponent";
/**
 * observationResultRequirement
 *
 * ActivityDefinition.observationResultRequirement: Defines the observations that are expected to be produced by the action.
 *
 * http://hl7.org/fhir/observationResultRequirement
 */
export declare const observationResultRequirement = "http://hl7.org/fhir/observationResultRequirement";
/**
 * FriendlyLanguage
 *
 * Contract.FriendlyLanguage: The "patient friendly language" versionof the Contract in whole or in parts. "Patient friendly language" means the representation of the Contract and Contract Provisions in a manner that is readily accessible and understandable by a layperson in accordance with best practices for communication styles that ensure that those agreeing to or signing the Contract understand the roles, actions, obligations, responsibilities, and implication of the agreement.
 *
 * http://hl7.org/fhir/FriendlyLanguage
 */
export declare const FriendlyLanguage = "http://hl7.org/fhir/FriendlyLanguage";
/**
 * _observedGroup
 *
 * (Modified) ResearchStudy.comparisonGroup.observedGroup
 *
 * http://hl7.org/fhir/_observedGroup
 */
export declare const _observedGroup = "http://hl7.org/fhir/_observedGroup";
/**
 * cancelledReason
 *
 * Invoice.cancelledReason: In case of Invoice cancellation a reason must be given (entered in error, superseded by corrected invoice etc.).
 *
 * http://hl7.org/fhir/cancelledReason
 */
export declare const cancelledReason = "http://hl7.org/fhir/cancelledReason";
/**
 * _expirationType
 *
 * (Modified) Contract.expirationType
 *
 * http://hl7.org/fhir/_expirationType
 */
export declare const _expirationType = "http://hl7.org/fhir/_expirationType";
/**
 * _actualNumber
 *
 * (Modified) ResearchStudy.recruitment.actualNumber
 *
 * http://hl7.org/fhir/_actualNumber
 */
export declare const _actualNumber = "http://hl7.org/fhir/_actualNumber";
/**
 * derivation
 *
 * StructureDefinition.derivation: How the type relates to the baseDefinition.
 *
 * http://hl7.org/fhir/derivation
 */
export declare const derivation = "http://hl7.org/fhir/derivation";
/**
 * AdverseEventSuspectEntityComponent
 *
 * AdverseEventSuspectEntityComponent: Describes the entity that is suspected to have caused the adverse event.
 *
 * http://hl7.org/fhir/AdverseEventSuspectEntityComponent
 */
export declare const AdverseEventSuspectEntityComponent = "http://hl7.org/fhir/AdverseEventSuspectEntityComponent";
/**
 * ImmunizationRecommendation
 *
 * A patient's point-in-time set of recommendations (i.e. forecasting) according to a published schedule with optional supporting justification.
 *
 * http://hl7.org/fhir/ImmunizationRecommendation
 */
export declare const ImmunizationRecommendation = "http://hl7.org/fhir/ImmunizationRecommendation";
/**
 * _BiologicallyDerivedProductDispense
 *
 * (Modified) BiologicallyDerivedProductDispense
 *
 * http://hl7.org/fhir/_BiologicallyDerivedProductDispense
 */
export declare const _BiologicallyDerivedProductDispense = "http://hl7.org/fhir/_BiologicallyDerivedProductDispense";
/**
 * _definitionId
 *
 * (Modified) EvidenceVariable.characteristic.definitionByCombination.characteristic.definitionId
 *
 * http://hl7.org/fhir/_definitionId
 */
export declare const _definitionId = "http://hl7.org/fhir/_definitionId";
/**
 * _authoredOn
 *
 * (Modified) ServiceRequest.authoredOn
 *
 * http://hl7.org/fhir/_authoredOn
 */
export declare const _authoredOn = "http://hl7.org/fhir/_authoredOn";
/**
 * keyword
 *
 * StructureDefinition.keyword: (DEPRECATED) A set of key words or terms from external terminologies that may be used to assist with indexing and searching of templates nby describing the use of this structure definition, or the content it describes.
 *
 * http://hl7.org/fhir/keyword
 */
export declare const keyword = "http://hl7.org/fhir/keyword";
/**
 * characteristic
 *
 * PackagedProductDefinition.characteristic: Allows the key features to be recorded, such as "hospital pack", "nurse prescribable", "calendar pack".
 *
 * http://hl7.org/fhir/characteristic
 */
export declare const characteristic = "http://hl7.org/fhir/characteristic";
/**
 * _note
 *
 * (Modified) List.note
 *
 * http://hl7.org/fhir/_note
 */
export declare const _note = "http://hl7.org/fhir/_note";
/**
 * ImagingStudySeriesInstanceComponent
 *
 * ImagingStudySeriesComponent.ImagingStudySeriesInstanceComponent: A single SOP instance within the series, e.g. an image, or presentation state.
 *
 * http://hl7.org/fhir/ImagingStudySeriesInstanceComponent
 */
export declare const ImagingStudySeriesInstanceComponent = "http://hl7.org/fhir/ImagingStudySeriesInstanceComponent";
/**
 * _signature
 *
 * (Modified) Provenance.signature
 *
 * http://hl7.org/fhir/_signature
 */
export declare const _signature = "http://hl7.org/fhir/_signature";
/**
 * slicing
 *
 * ElementDefinition.slicing: Indicates that the element is sliced into a set of alternative definitions (i.e. in a structure definition, there are multiple different constraints on a single element in the base resource). Slicing can be used in any resource that has cardinality ..* on the base resource, or any resource with a choice of types. The set of slices is any elements that come after this in the element sequence that have the same path, until a shorter path occurs (the shorter path terminates the set).
 *
 * http://hl7.org/fhir/slicing
 */
export declare const slicing = "http://hl7.org/fhir/slicing";
/**
 * _population
 *
 * (Modified) MeasureReport.group.stratifier.stratum.population
 *
 * http://hl7.org/fhir/_population
 */
export declare const _population = "http://hl7.org/fhir/_population";
/**
 * cap
 *
 * SpecimenDefinition.typeTested.container.cap: Color of container cap.
 *
 * http://hl7.org/fhir/cap
 */
export declare const cap = "http://hl7.org/fhir/cap";
/**
 * given
 *
 * HumanName.given: Given name.
 *
 * http://hl7.org/fhir/given
 */
export declare const given = "http://hl7.org/fhir/given";
/**
 * account
 *
 * Account.relatedAccount.account: Reference to an associated Account.
 *
 * http://hl7.org/fhir/account
 */
export declare const account = "http://hl7.org/fhir/account";
/**
 * _organism
 *
 * (Modified) SubstanceSourceMaterial.organism
 *
 * http://hl7.org/fhir/_organism
 */
export declare const _organism = "http://hl7.org/fhir/_organism";
/**
 * _need
 *
 * (Modified) VerificationResult.need
 *
 * http://hl7.org/fhir/_need
 */
export declare const _need = "http://hl7.org/fhir/_need";
/**
 * environmentalSetting
 *
 * MedicationKnowledge.storageGuideline.environmentalSetting: Describes a setting/value on the environment for the adequate storage of the medication and other substances.  Environment settings may involve temperature, humidity, or exposure to light.
 *
 * http://hl7.org/fhir/environmentalSetting
 */
export declare const environmentalSetting = "http://hl7.org/fhir/environmentalSetting";
/**
 * volume
 *
 * Citation.citedArtifact.publicationForm.volume: Volume number of journal or other collection in which the article is published.
 *
 * http://hl7.org/fhir/volume
 */
export declare const volume = "http://hl7.org/fhir/volume";
/**
 * weeklyTemplate
 *
 * Appointment.recurrenceTemplate.weeklyTemplate: Information about weekly recurring appointments.
 *
 * http://hl7.org/fhir/weeklyTemplate
 */
export declare const weeklyTemplate = "http://hl7.org/fhir/weeklyTemplate";
/**
 * lowerLimit
 *
 * SampledData.lowerLimit: The lower limit of detection of the measured points. This is needed if any of the data points have the value "L" (lower than detection limit).
 *
 * http://hl7.org/fhir/lowerLimit
 */
export declare const lowerLimit = "http://hl7.org/fhir/lowerLimit";
/**
 * _justification
 *
 * (Modified) Permission.justification
 *
 * http://hl7.org/fhir/_justification
 */
export declare const _justification = "http://hl7.org/fhir/_justification";
/**
 * _fixture
 *
 * (Modified) TestScript.fixture
 *
 * http://hl7.org/fhir/_fixture
 */
export declare const _fixture = "http://hl7.org/fhir/_fixture";
/**
 * unitPriceComponent
 *
 * ChargeItem.unitPriceComponent: The unit price of the chargable item.
 *
 * http://hl7.org/fhir/unitPriceComponent
 */
export declare const unitPriceComponent = "http://hl7.org/fhir/unitPriceComponent";
/**
 * availabilityStatus
 *
 * Device.availabilityStatus: The availability of the device.
 *
 * http://hl7.org/fhir/availabilityStatus
 */
export declare const availabilityStatus = "http://hl7.org/fhir/availabilityStatus";
/**
 * _proxySignature
 *
 * (Modified) VerificationResult.attestation.proxySignature
 *
 * http://hl7.org/fhir/_proxySignature
 */
export declare const _proxySignature = "http://hl7.org/fhir/_proxySignature";
/**
 * statusChanged
 *
 * MedicationRequest.statusChanged: The date (and perhaps time) when the status was changed.
 *
 * http://hl7.org/fhir/statusChanged
 */
export declare const statusChanged = "http://hl7.org/fhir/statusChanged";
/**
 * _about
 *
 * (Modified) CommunicationRequest.about
 *
 * http://hl7.org/fhir/_about
 */
export declare const _about = "http://hl7.org/fhir/_about";
/**
 * occurence
 *
 * MedicationAdministration.occurence
 *
 * http://hl7.org/fhir/occurence
 */
export declare const occurence = "http://hl7.org/fhir/occurence";
/**
 * actualPeriod
 *
 * EncounterHistory.actualPeriod: The start and end time associated with this set of values associated with the encounter, may be different to the planned times for various reasons.
 *
 * http://hl7.org/fhir/actualPeriod
 */
export declare const actualPeriod = "http://hl7.org/fhir/actualPeriod";
/**
 * _originalPrescription
 *
 * (Modified) ExplanationOfBenefit.originalPrescription
 *
 * http://hl7.org/fhir/_originalPrescription
 */
export declare const _originalPrescription = "http://hl7.org/fhir/_originalPrescription";
/**
 * _dosage
 *
 * (Modified) MedicationStatement.dosage
 *
 * http://hl7.org/fhir/_dosage
 */
export declare const _dosage = "http://hl7.org/fhir/_dosage";
/**
 * returnedAmount
 *
 * PaymentReconciliation.returnedAmount: The amount returned by the receiver which is excess to the amount payable, often referred to as 'change'.
 *
 * http://hl7.org/fhir/returnedAmount
 */
export declare const returnedAmount = "http://hl7.org/fhir/returnedAmount";
/**
 * _cTerminalModification
 *
 * (Modified) SubstanceProtein.subunit.cTerminalModification
 *
 * http://hl7.org/fhir/_cTerminalModification
 */
export declare const _cTerminalModification = "http://hl7.org/fhir/_cTerminalModification";
/**
 * name
 *
 * ObservationDefinition.name: A natural language name identifying the ObservationDefinition. This name should be usable as an identifier for the module by machine processing applications such as code generation.
 *
 * http://hl7.org/fhir/name
 */
export declare const name = "http://hl7.org/fhir/name";
/**
 * masterFile
 *
 * MedicinalProductDefinition.masterFile: A master file for the medicinal product (e.g. Pharmacovigilance System Master File). Drug master files (DMFs) are documents submitted to regulatory agencies to provide confidential detailed information about facilities, processes or articles used in the manufacturing, processing, packaging and storing of drug products.
 *
 * http://hl7.org/fhir/masterFile
 */
export declare const masterFile = "http://hl7.org/fhir/masterFile";
/**
 * baseFormulaType
 *
 * NutritionOrder.enteralFormula.baseFormulaType: The type of enteral or infant formula such as an adult standard formula with fiber or a soy-based infant formula.
 *
 * http://hl7.org/fhir/baseFormulaType
 */
export declare const baseFormulaType = "http://hl7.org/fhir/baseFormulaType";
/**
 * threshold
 *
 * EvidenceVariable.characteristic.definitionByCombination.characteristic.definitionByCombination.threshold: Provides the value of "n" when "at-least" or "at-most" codes are used.
 *
 * http://hl7.org/fhir/threshold
 */
export declare const threshold = "http://hl7.org/fhir/threshold";
/**
 * active
 *
 * Organization.active: Whether the organization's record is still in active use.
 *
 * http://hl7.org/fhir/active
 */
export declare const active = "http://hl7.org/fhir/active";
/**
 * IngredientSubstanceComponent
 *
 * IngredientSubstanceComponent: The substance that comprises this ingredient.
 *
 * http://hl7.org/fhir/IngredientSubstanceComponent
 */
export declare const IngredientSubstanceComponent = "http://hl7.org/fhir/IngredientSubstanceComponent";
/**
 * size
 *
 * Attachment.size: The number of bytes of data that make up this attachment (before base64 encoding, if that is done).
 *
 * http://hl7.org/fhir/size
 */
export declare const size = "http://hl7.org/fhir/size";
/**
 * _validityPeriod
 *
 * (Modified) RegulatedAuthorization.validityPeriod
 *
 * http://hl7.org/fhir/_validityPeriod
 */
export declare const _validityPeriod = "http://hl7.org/fhir/_validityPeriod";
/**
 * who
 *
 * Provenance.entity.agent.who: Indicates who or what performed in the event.
 *
 * http://hl7.org/fhir/who
 */
export declare const who = "http://hl7.org/fhir/who";
/**
 * ExampleScenarioProcessStepAlternativeComponent
 *
 * ExampleScenarioProcessComponent.ExampleScenarioProcessStepComponent.ExampleScenarioProcessStepAlternativeComponentStepProcess.ExampleScenarioProcessStepComponent.ExampleScenarioProcessStepAlternativeComponent: Indicates an alternative step that can be taken instead of the sub-process, scenario or operation.  E.g. to represent non-happy-path/exceptional/atypical circumstances.
 *
 * http://hl7.org/fhir/ExampleScenarioProcessStepAlternativeComponent
 */
export declare const ExampleScenarioProcessStepAlternativeComponent = "http://hl7.org/fhir/ExampleScenarioProcessStepAlternativeComponent";
/**
 * InsurancePlanPlanSpecificCostComponent
 *
 * InsurancePlanPlanComponent.InsurancePlanPlanSpecificCostComponent: Costs associated with the coverage provided by the product.
 *
 * http://hl7.org/fhir/InsurancePlanPlanSpecificCostComponent
 */
export declare const InsurancePlanPlanSpecificCostComponent = "http://hl7.org/fhir/InsurancePlanPlanSpecificCostComponent";
/**
 * interaction
 *
 * CapabilityStatement.rest.interaction: A specification of restful operations supported by the system.
 *
 * http://hl7.org/fhir/interaction
 */
export declare const interaction = "http://hl7.org/fhir/interaction";
/**
 * _beneficiary
 *
 * (Modified) Coverage.beneficiary
 *
 * http://hl7.org/fhir/_beneficiary
 */
export declare const _beneficiary = "http://hl7.org/fhir/_beneficiary";
/**
 * requestURL
 *
 * TestScript.test.action.assert.requestURL: The value to use in a comparison against the request URL path string.
 *
 * http://hl7.org/fhir/requestURL
 */
export declare const requestURL = "http://hl7.org/fhir/requestURL";
/**
 * transform
 *
 * StructureMap.group.rule.rule.target.transform: How the data is copied / created.
 *
 * http://hl7.org/fhir/transform
 */
export declare const transform = "http://hl7.org/fhir/transform";
/**
 * sugar
 *
 * SubstanceNucleicAcid.subunit.sugar: 5.3.6.8.1 Sugar ID (Mandatory).
 *
 * http://hl7.org/fhir/sugar
 */
export declare const sugar = "http://hl7.org/fhir/sugar";
/**
 * _subscriptionTopic
 *
 * (Modified) TriggerDefinition.subscriptionTopic
 *
 * http://hl7.org/fhir/_subscriptionTopic
 */
export declare const _subscriptionTopic = "http://hl7.org/fhir/_subscriptionTopic";
/**
 * _usageStatus
 *
 * (Modified) DeviceUsage.usageStatus
 *
 * http://hl7.org/fhir/_usageStatus
 */
export declare const _usageStatus = "http://hl7.org/fhir/_usageStatus";
/**
 * _recurring
 *
 * (Modified) AppointmentResponse.recurring
 *
 * http://hl7.org/fhir/_recurring
 */
export declare const _recurring = "http://hl7.org/fhir/_recurring";
/**
 * chargeItem
 *
 * Invoice.lineItem.chargeItem
 *
 * http://hl7.org/fhir/chargeItem
 */
export declare const chargeItem = "http://hl7.org/fhir/chargeItem";
/**
 * DiagnosticReportMediaComponent
 *
 * DiagnosticReportMediaComponent: A list of key images or data associated with this report. The images or data are generally created during the diagnostic process, and may be directly of the patient, or of treated specimens (i.e. slides of interest).
 *
 * http://hl7.org/fhir/DiagnosticReportMediaComponent
 */
export declare const DiagnosticReportMediaComponent = "http://hl7.org/fhir/DiagnosticReportMediaComponent";
/**
 * validationProcess
 *
 * VerificationResult.validationProcess: The primary process by which the target is validated (edit check; value set; primary source; multiple sources; standalone; in context).
 *
 * http://hl7.org/fhir/validationProcess
 */
export declare const validationProcess = "http://hl7.org/fhir/validationProcess";
/**
 * _DiagnosticReport
 *
 * (Modified) DiagnosticReport
 *
 * http://hl7.org/fhir/_DiagnosticReport
 */
export declare const _DiagnosticReport = "http://hl7.org/fhir/_DiagnosticReport";
/**
 * moiety
 *
 * SubstanceDefinition.moiety: Moiety, for structural modifications.
 *
 * http://hl7.org/fhir/moiety
 */
export declare const moiety = "http://hl7.org/fhir/moiety";
/**
 * _marketingStatus
 *
 * (Modified) PackagedProductDefinition.marketingStatus
 *
 * http://hl7.org/fhir/_marketingStatus
 */
export declare const _marketingStatus = "http://hl7.org/fhir/_marketingStatus";
/**
 * _citedArtifact
 *
 * (Modified) Citation.citedArtifact
 *
 * http://hl7.org/fhir/_citedArtifact
 */
export declare const _citedArtifact = "http://hl7.org/fhir/_citedArtifact";
/**
 * CitationCitedArtifactPartComponent
 *
 * CitationCitedArtifactComponent.CitationCitedArtifactPartComponent: The component of the article or artifact.
 *
 * http://hl7.org/fhir/CitationCitedArtifactPartComponent
 */
export declare const CitationCitedArtifactPartComponent = "http://hl7.org/fhir/CitationCitedArtifactPartComponent";
/**
 * TerminologyCapabilitiesImplementationComponent
 *
 * TerminologyCapabilitiesImplementationComponent: Identifies a specific implementation instance that is described by the terminology capability statement - i.e. a particular installation, rather than the capabilities of a software program.
 *
 * http://hl7.org/fhir/TerminologyCapabilitiesImplementationComponent
 */
export declare const TerminologyCapabilitiesImplementationComponent = "http://hl7.org/fhir/TerminologyCapabilitiesImplementationComponent";
/**
 * _immutable
 *
 * (Modified) ValueSet.immutable
 *
 * http://hl7.org/fhir/_immutable
 */
export declare const _immutable = "http://hl7.org/fhir/_immutable";
/**
 * _requester
 *
 * (Modified) Contract.term.action.requester
 *
 * http://hl7.org/fhir/_requester
 */
export declare const _requester = "http://hl7.org/fhir/_requester";
/**
 * regionsStudied
 *
 * GenomicStudy.analysis.regionsStudied: The genomic regions to be studied in the analysis (BED file).
 *
 * http://hl7.org/fhir/regionsStudied
 */
export declare const regionsStudied = "http://hl7.org/fhir/regionsStudied";
/**
 * _code
 *
 * (Modified) ClinicalUseDefinition.warning.code
 *
 * http://hl7.org/fhir/_code
 */
export declare const _code = "http://hl7.org/fhir/_code";
/**
 * sourceMaterial
 *
 * SubstanceDefinition.sourceMaterial: Material or taxonomic/anatomical source for the substance.
 *
 * http://hl7.org/fhir/sourceMaterial
 */
export declare const sourceMaterial = "http://hl7.org/fhir/sourceMaterial";
/**
 * subrogation
 *
 * Coverage.subrogation: When 'subrogation=true' this insurance instance has been included not for adjudication but to provide insurers with the details to recover costs.
 *
 * http://hl7.org/fhir/subrogation
 */
export declare const subrogation = "http://hl7.org/fhir/subrogation";
/**
 * _structureVersion
 *
 * (Modified) ExampleScenario.instance.structureVersion
 *
 * http://hl7.org/fhir/_structureVersion
 */
export declare const _structureVersion = "http://hl7.org/fhir/_structureVersion";
/**
 * _priceComponent
 *
 * (Modified) Invoice.lineItem.priceComponent
 *
 * http://hl7.org/fhir/_priceComponent
 */
export declare const _priceComponent = "http://hl7.org/fhir/_priceComponent";
/**
 * management
 *
 * ClinicalUseDefinition.interaction.management: Actions for managing the interaction.
 *
 * http://hl7.org/fhir/management
 */
export declare const management = "http://hl7.org/fhir/management";
/**
 * _additionalInstruction
 *
 * (Modified) Dosage.additionalInstruction
 *
 * http://hl7.org/fhir/_additionalInstruction
 */
export declare const _additionalInstruction = "http://hl7.org/fhir/_additionalInstruction";
/**
 * _managingEntity
 *
 * (Modified) Subscription.managingEntity
 *
 * http://hl7.org/fhir/_managingEntity
 */
export declare const _managingEntity = "http://hl7.org/fhir/_managingEntity";
/**
 * patchFormat
 *
 * CapabilityStatement.patchFormat: A list of the patch formats supported by this implementation using their content types.
 *
 * http://hl7.org/fhir/patchFormat
 */
export declare const patchFormat = "http://hl7.org/fhir/patchFormat";
/**
 * proxyIdentityCertificate
 *
 * VerificationResult.attestation.proxyIdentityCertificate: A digital identity certificate associated with the proxy entity submitting attested information on behalf of the attestation source.
 *
 * http://hl7.org/fhir/proxyIdentityCertificate
 */
export declare const proxyIdentityCertificate = "http://hl7.org/fhir/proxyIdentityCertificate";
/**
 * DeviceVersionComponent
 *
 * DeviceVersionComponent: The actual design of the device or software version running on the device.
 *
 * http://hl7.org/fhir/DeviceVersionComponent
 */
export declare const DeviceVersionComponent = "http://hl7.org/fhir/DeviceVersionComponent";
/**
 * TaskRestrictionComponent
 *
 * TaskRestrictionComponent: If the Task.focus is a request resource and the task is seeking fulfillment (i.e. is asking for the request to be actioned), this element identifies any limitations on what parts of the referenced request should be actioned.
 *
 * http://hl7.org/fhir/TaskRestrictionComponent
 */
export declare const TaskRestrictionComponent = "http://hl7.org/fhir/TaskRestrictionComponent";
/**
 * _frameOfReferenceUid
 *
 * (Modified) ImagingSelection.frameOfReferenceUid
 *
 * http://hl7.org/fhir/_frameOfReferenceUid
 */
export declare const _frameOfReferenceUid = "http://hl7.org/fhir/_frameOfReferenceUid";
/**
 * MedicinalProductDefinition
 *
 * Detailed definition of a medicinal product, typically for uses other than direct patient care (e.g. regulatory use, drug catalogs, to support prescribing, adverse events management etc.).
 *
 * http://hl7.org/fhir/MedicinalProductDefinition
 */
export declare const MedicinalProductDefinition = "http://hl7.org/fhir/MedicinalProductDefinition";
/**
 * paternalOrganismId
 *
 * SubstanceSourceMaterial.organism.hybrid.paternalOrganismId: The identifier of the paternal species constituting the hybrid organism shall be specified based on a controlled vocabulary.
 *
 * http://hl7.org/fhir/paternalOrganismId
 */
export declare const paternalOrganismId = "http://hl7.org/fhir/paternalOrganismId";
/**
 * averageMolecularFormula
 *
 * SubstancePolymer.repeat.averageMolecularFormula: A representation of an (average) molecular formula from a polymer.
 *
 * http://hl7.org/fhir/averageMolecularFormula
 */
export declare const averageMolecularFormula = "http://hl7.org/fhir/averageMolecularFormula";
/**
 * EvidenceStatisticSampleSizeComponent
 *
 * EvidenceStatisticComponent.EvidenceStatisticSampleSizeComponent: Number of samples in the statistic.
 *
 * http://hl7.org/fhir/EvidenceStatisticSampleSizeComponent
 */
export declare const EvidenceStatisticSampleSizeComponent = "http://hl7.org/fhir/EvidenceStatisticSampleSizeComponent";
/**
 * _occurred
 *
 * (Modified) Provenance.occurred
 *
 * http://hl7.org/fhir/_occurred
 */
export declare const _occurred = "http://hl7.org/fhir/_occurred";
/**
 * definitionByCombination
 *
 * EvidenceVariable.characteristic.definitionByCombination: Defines the characteristic as a combination of two or more characteristics.
 *
 * http://hl7.org/fhir/definitionByCombination
 */
export declare const definitionByCombination = "http://hl7.org/fhir/definitionByCombination";
/**
 * _compositional
 *
 * (Modified) TerminologyCapabilities.codeSystem.version.compositional
 *
 * http://hl7.org/fhir/_compositional
 */
export declare const _compositional = "http://hl7.org/fhir/_compositional";
/**
 * financial
 *
 * ExplanationOfBenefit.benefitBalance.financial: Benefits Used to date.
 *
 * http://hl7.org/fhir/financial
 */
export declare const financial = "http://hl7.org/fhir/financial";
/**
 * _bodysite
 *
 * (Modified) ChargeItem.bodysite
 *
 * http://hl7.org/fhir/_bodysite
 */
export declare const _bodysite = "http://hl7.org/fhir/_bodysite";
/**
 * sourceScope
 *
 * ConceptMap.sourceScope
 *
 * http://hl7.org/fhir/sourceScope
 */
export declare const sourceScope = "http://hl7.org/fhir/sourceScope";
/**
 * parameter
 *
 * ServiceRequest.orderDetail.parameter: The parameter details for the service being requested.
 *
 * http://hl7.org/fhir/parameter
 */
export declare const parameter = "http://hl7.org/fhir/parameter";
/**
 * lineItem
 *
 * Invoice.lineItem: Each line item represents one charge for goods and services rendered. Details such.ofType(date), code and amount are found in the referenced ChargeItem resource.
 *
 * http://hl7.org/fhir/lineItem
 */
export declare const lineItem = "http://hl7.org/fhir/lineItem";
/**
 * _businessArrangement
 *
 * (Modified) CoverageEligibilityRequest.insurance.businessArrangement
 *
 * http://hl7.org/fhir/_businessArrangement
 */
export declare const _businessArrangement = "http://hl7.org/fhir/_businessArrangement";
/**
 * _ordinalPosition
 *
 * (Modified) MolecularSequence.relative.ordinalPosition
 *
 * http://hl7.org/fhir/_ordinalPosition
 */
export declare const _ordinalPosition = "http://hl7.org/fhir/_ordinalPosition";
/**
 * dependency
 *
 * TestPlan.testCase.dependency: The required criteria to execute the test case - e.g. preconditions, previous tests.
 *
 * http://hl7.org/fhir/dependency
 */
export declare const dependency = "http://hl7.org/fhir/dependency";
/**
 * DeviceUsage
 *
 * A record of a device being used by a patient where the record is the result of a report from the patient or a clinician.
 *
 * http://hl7.org/fhir/DeviceUsage
 */
export declare const DeviceUsage = "http://hl7.org/fhir/DeviceUsage";
/**
 * sent
 *
 * Communication.sent: The time when this communication was sent.
 *
 * http://hl7.org/fhir/sent
 */
export declare const sent = "http://hl7.org/fhir/sent";
/**
 * _associatedMedication
 *
 * (Modified) MedicationKnowledge.associatedMedication
 *
 * http://hl7.org/fhir/_associatedMedication
 */
export declare const _associatedMedication = "http://hl7.org/fhir/_associatedMedication";
/**
 * ParametersParameterComponentParameter
 *
 * A named part of a multi-part parameter.
 *
 * http://hl7.org/fhir/ParametersParameterComponentParameter
 */
export declare const ParametersParameterComponentParameter = "http://hl7.org/fhir/ParametersParameterComponentParameter";
/**
 * executionPeriod
 *
 * Task.executionPeriod: Identifies the time action was first taken against the task (start) and/or the time final action was taken against the task prior to marking it as completed (end).
 *
 * http://hl7.org/fhir/executionPeriod
 */
export declare const executionPeriod = "http://hl7.org/fhir/executionPeriod";
/**
 * _custodian
 *
 * (Modified) DocumentReference.custodian
 *
 * http://hl7.org/fhir/_custodian
 */
export declare const _custodian = "http://hl7.org/fhir/_custodian";
/**
 * specification
 *
 * DeviceDefinition.conformsTo.specification: Code that identifies the specific standard, specification, protocol, formal guidance, regulation, legislation, or certification scheme to which the device adheres.
 *
 * http://hl7.org/fhir/specification
 */
export declare const specification = "http://hl7.org/fhir/specification";
/**
 * HumanName
 *
 * A name, normally of a human, that can be used for other living entities (e.g. animals but not organizations) that have been assigned names by a human and may need the use of name parts or the need for usage information.
 *
 * http://hl7.org/fhir/HumanName
 */
export declare const HumanName = "http://hl7.org/fhir/HumanName";
/**
 * ObservationDefinitionComponentComponentQualifiedValue
 *
 * A set of qualified values associated with a context and a set of conditions -  provides a range for quantitative and ordinal observations and a collection of value sets for qualitative observations.
 *
 * http://hl7.org/fhir/ObservationDefinitionComponentComponentQualifiedValue
 */
export declare const ObservationDefinitionComponentComponentQualifiedValue = "http://hl7.org/fhir/ObservationDefinitionComponentComponentQualifiedValue";
/**
 * _searchInclude
 *
 * (Modified) CapabilityStatement.rest.resource.searchInclude
 *
 * http://hl7.org/fhir/_searchInclude
 */
export declare const _searchInclude = "http://hl7.org/fhir/_searchInclude";
/**
 * _technique
 *
 * (Modified) SubstanceDefinition.structure.technique
 *
 * http://hl7.org/fhir/_technique
 */
export declare const _technique = "http://hl7.org/fhir/_technique";
/**
 * legalStatusOfSupply
 *
 * PackagedProductDefinition.legalStatusOfSupply: The legal status of supply of the packaged item as classified by the regulator.
 *
 * http://hl7.org/fhir/legalStatusOfSupply
 */
export declare const legalStatusOfSupply = "http://hl7.org/fhir/legalStatusOfSupply";
/**
 * short
 *
 * ElementDefinition.short: A concise description of what this element means (e.g. for use in autogenerated summaries).
 *
 * http://hl7.org/fhir/short
 */
export declare const short = "http://hl7.org/fhir/short";
/**
 * generation
 *
 * ImplementationGuide.definition.page.page.generation: A code that indicates how the page is generated.
 *
 * http://hl7.org/fhir/generation
 */
export declare const generation = "http://hl7.org/fhir/generation";
/**
 * doseAndRate
 *
 * Dosage.doseAndRate: Depending on the resource,this is the amount of medication administered, to  be administered or typical amount to be administered.
 *
 * http://hl7.org/fhir/doseAndRate
 */
export declare const doseAndRate = "http://hl7.org/fhir/doseAndRate";
/**
 * _condition
 *
 * (Modified) Account.diagnosis.condition
 *
 * http://hl7.org/fhir/_condition
 */
export declare const _condition = "http://hl7.org/fhir/_condition";
/**
 * _followUp
 *
 * (Modified) Procedure.followUp
 *
 * http://hl7.org/fhir/_followUp
 */
export declare const _followUp = "http://hl7.org/fhir/_followUp";
/**
 * manufacturer
 *
 * PackagedProductDefinition.manufacturer: Manufacturer of this package type. When there are multiple it means these are all possible manufacturers.
 *
 * http://hl7.org/fhir/manufacturer
 */
export declare const manufacturer = "http://hl7.org/fhir/manufacturer";
/**
 * BiologicallyDerivedProductDispense
 *
 * A record of dispensation of a biologically derived product.
 *
 * http://hl7.org/fhir/BiologicallyDerivedProductDispense
 */
export declare const BiologicallyDerivedProductDispense = "http://hl7.org/fhir/BiologicallyDerivedProductDispense";
/**
 * _seriesUid
 *
 * (Modified) ImagingSelection.seriesUid
 *
 * http://hl7.org/fhir/_seriesUid
 */
export declare const _seriesUid = "http://hl7.org/fhir/_seriesUid";
/**
 * relatesTo
 *
 * Citation.citedArtifact.relatesTo: The artifact related to the cited artifact.
 *
 * http://hl7.org/fhir/relatesTo
 */
export declare const relatesTo = "http://hl7.org/fhir/relatesTo";
/**
 * temperatureQualifier
 *
 * SpecimenDefinition.typeTested.handling.temperatureQualifier: It qualifies the interval of temperature, which characterizes an occurrence of handling. Conditions that are not related to temperature may be handled in the instruction element.
 *
 * http://hl7.org/fhir/temperatureQualifier
 */
export declare const temperatureQualifier = "http://hl7.org/fhir/temperatureQualifier";
/**
 * _PackagedProductDefinition
 *
 * (Modified) PackagedProductDefinition
 *
 * http://hl7.org/fhir/_PackagedProductDefinition
 */
export declare const _PackagedProductDefinition = "http://hl7.org/fhir/_PackagedProductDefinition";
/**
 * _correspondingContact
 *
 * (Modified) Citation.citedArtifact.contributorship.entry.correspondingContact
 *
 * http://hl7.org/fhir/_correspondingContact
 */
export declare const _correspondingContact = "http://hl7.org/fhir/_correspondingContact";
/**
 * citeAs
 *
 * EvidenceReport.citeAs
 *
 * http://hl7.org/fhir/citeAs
 */
export declare const citeAs = "http://hl7.org/fhir/citeAs";
/**
 * _DeviceAssociation
 *
 * (Modified) DeviceAssociation
 *
 * http://hl7.org/fhir/_DeviceAssociation
 */
export declare const _DeviceAssociation = "http://hl7.org/fhir/_DeviceAssociation";
/**
 * requireBoth
 *
 * SubscriptionTopic.resourceTrigger.queryCriteria.requireBoth: If set to `true`, both the `current` and `previous` query criteria must evaluate `true` to trigger a notification for this topic.  If set to `false` or not present, a notification for this topic will be triggered if either the `current` or `previous` tests evaluate to `true`.
 *
 * http://hl7.org/fhir/requireBoth
 */
export declare const requireBoth = "http://hl7.org/fhir/requireBoth";
/**
 * provisionData
 *
 * Consent.provision.provisionData: The resources controlled by this provision if specific resources are referenced.
 *
 * http://hl7.org/fhir/provisionData
 */
export declare const provisionData = "http://hl7.org/fhir/provisionData";
/**
 * _characterization
 *
 * (Modified) SubstanceDefinition.characterization
 *
 * http://hl7.org/fhir/_characterization
 */
export declare const _characterization = "http://hl7.org/fhir/_characterization";
/**
 * criticality
 *
 * AllergyIntolerance.criticality: Estimate of the potential clinical harm, or seriousness, of the reaction to the identified substance.
 *
 * http://hl7.org/fhir/criticality
 */
export declare const criticality = "http://hl7.org/fhir/criticality";
/**
 * ConditionDefinitionPlanComponent
 *
 * ConditionDefinitionPlanComponent: Plan that is appropriate.
 *
 * http://hl7.org/fhir/ConditionDefinitionPlanComponent
 */
export declare const ConditionDefinitionPlanComponent = "http://hl7.org/fhir/ConditionDefinitionPlanComponent";
/**
 * canPushUpdates
 *
 * VerificationResult.primarySource.canPushUpdates: Ability of the primary source to push updates/alerts (yes; no; undetermined).
 *
 * http://hl7.org/fhir/canPushUpdates
 */
export declare const canPushUpdates = "http://hl7.org/fhir/canPushUpdates";
/**
 * _nTerminalModificationId
 *
 * (Modified) SubstanceProtein.subunit.nTerminalModificationId
 *
 * http://hl7.org/fhir/_nTerminalModificationId
 */
export declare const _nTerminalModificationId = "http://hl7.org/fhir/_nTerminalModificationId";
/**
 * _regionsCalled
 *
 * (Modified) GenomicStudy.analysis.regionsCalled
 *
 * http://hl7.org/fhir/_regionsCalled
 */
export declare const _regionsCalled = "http://hl7.org/fhir/_regionsCalled";
/**
 * TestPlanTestCaseTestRunComponent
 *
 * TestPlanTestCaseComponent.TestPlanTestCaseTestRunComponent: The actual test to be executed.
 *
 * http://hl7.org/fhir/TestPlanTestCaseTestRunComponent
 */
export declare const TestPlanTestCaseTestRunComponent = "http://hl7.org/fhir/TestPlanTestCaseTestRunComponent";
/**
 * _productOrService
 *
 * (Modified) CoverageEligibilityRequest.item.productOrService
 *
 * http://hl7.org/fhir/_productOrService
 */
export declare const _productOrService = "http://hl7.org/fhir/_productOrService";
/**
 * reviewOutcome
 *
 * ClaimResponse.addItem.reviewOutcome: The high-level results of the adjudication if adjudication has been performed.
 *
 * http://hl7.org/fhir/reviewOutcome
 */
export declare const reviewOutcome = "http://hl7.org/fhir/reviewOutcome";
/**
 * maxDispense
 *
 * MedicationKnowledge.regulatory.maxDispense: The maximum number of units of the medication that can be dispensed in a period.
 *
 * http://hl7.org/fhir/maxDispense
 */
export declare const maxDispense = "http://hl7.org/fhir/maxDispense";
/**
 * filterDefinition
 *
 * SubscriptionTopic.canFilterBy.filterDefinition: Either the canonical URL to a search parameter (like "http://hl7.org/fhir/SearchParameter/encounter-patient") or the officially-defined URI for a shared filter concept (like "http://example.org/concepts/shared-common-event").
 *
 * http://hl7.org/fhir/filterDefinition
 */
export declare const filterDefinition = "http://hl7.org/fhir/filterDefinition";
/**
 * sourceAttachment
 *
 * Consent.sourceAttachment: The source on which this consent statement is based. The source might be a scanned original paper form.
 *
 * http://hl7.org/fhir/sourceAttachment
 */
export declare const sourceAttachment = "http://hl7.org/fhir/sourceAttachment";
/**
 * provisionActor
 *
 * Consent.provision.provisionActor: Who or what is controlled by this provision. Use group to identify a set of actors by some property they share (e.g. 'admitting officers').
 *
 * http://hl7.org/fhir/provisionActor
 */
export declare const provisionActor = "http://hl7.org/fhir/provisionActor";
/**
 * NamingSystem
 *
 * A curated namespace that issues unique symbols within that namespace for the identification of concepts, people, devices, etc.  Represents a "System" used within the Identifier and Coding data types.
 *
 * http://hl7.org/fhir/NamingSystem
 */
export declare const NamingSystem = "http://hl7.org/fhir/NamingSystem";
/**
 * dateOfService
 *
 * Account.procedure.dateOfService: Date of the procedure when using a coded procedure. If using a reference to a procedure, then the date on the procedure should be used.
 *
 * http://hl7.org/fhir/dateOfService
 */
export declare const dateOfService = "http://hl7.org/fhir/dateOfService";
/**
 * VisionPrescription
 *
 * An authorization for the provision of glasses and/or contact lenses to a patient.
 *
 * http://hl7.org/fhir/VisionPrescription
 */
export declare const VisionPrescription = "http://hl7.org/fhir/VisionPrescription";
/**
 * _unitPrice
 *
 * (Modified) Claim.item.unitPrice
 *
 * http://hl7.org/fhir/_unitPrice
 */
export declare const _unitPrice = "http://hl7.org/fhir/_unitPrice";
/**
 * resource
 *
 * SubscriptionTopic.notificationShape.resource: URL of the Resource that is the type used in this shape. This is the 'focus' resource of the topic (or one of them if there are more than one) and the root resource for this shape definition. It will be the same, a generality, or a specificity of SubscriptionTopic.resourceTrigger.resource or SubscriptionTopic.eventTrigger.resource when they are present.
 *
 * http://hl7.org/fhir/resource
 */
export declare const resource = "http://hl7.org/fhir/resource";
/**
 * _response
 *
 * (Modified) TestScript.test.action.assert.response
 *
 * http://hl7.org/fhir/_response
 */
export declare const _response = "http://hl7.org/fhir/_response";
/**
 * _agent
 *
 * (Modified) Provenance.entity.agent
 *
 * http://hl7.org/fhir/_agent
 */
export declare const _agent = "http://hl7.org/fhir/_agent";
/**
 * contraindicatedVaccineCode
 *
 * ImmunizationRecommendation.recommendation.contraindicatedVaccineCode: Vaccine(s) which should not be used to fulfill the recommendation.
 *
 * http://hl7.org/fhir/contraindicatedVaccineCode
 */
export declare const contraindicatedVaccineCode = "http://hl7.org/fhir/contraindicatedVaccineCode";
/**
 * collector
 *
 * Specimen.collection.collector: Person who collected the specimen.
 *
 * http://hl7.org/fhir/collector
 */
export declare const collector = "http://hl7.org/fhir/collector";
/**
 * enterer
 *
 * CoverageEligibilityRequest.enterer: Person who created the request.
 *
 * http://hl7.org/fhir/enterer
 */
export declare const enterer = "http://hl7.org/fhir/enterer";
/**
 * _supportedInteraction
 *
 * (Modified) SubscriptionTopic.resourceTrigger.supportedInteraction
 *
 * http://hl7.org/fhir/_supportedInteraction
 */
export declare const _supportedInteraction = "http://hl7.org/fhir/_supportedInteraction";
/**
 * _differential
 *
 * (Modified) StructureDefinition.differential
 *
 * http://hl7.org/fhir/_differential
 */
export declare const _differential = "http://hl7.org/fhir/_differential";
/**
 * _qualifiedValue
 *
 * (Modified) ObservationDefinition.component.qualifiedValue
 *
 * http://hl7.org/fhir/_qualifiedValue
 */
export declare const _qualifiedValue = "http://hl7.org/fhir/_qualifiedValue";
/**
 * ManufacturedItemDefinitionComponentConstituentComponent
 *
 * ManufacturedItemDefinitionComponentComponent.ManufacturedItemDefinitionComponentConstituentComponent: A reference to a constituent of the manufactured item as a whole, linked here so that its component location within the item can be indicated. This not where the item's ingredient are primarily stated (for which see Ingredient.for or ManufacturedItemDefinition.ingredient).
 *
 * http://hl7.org/fhir/ManufacturedItemDefinitionComponentConstituentComponent
 */
export declare const ManufacturedItemDefinitionComponentConstituentComponent = "http://hl7.org/fhir/ManufacturedItemDefinitionComponentConstituentComponent";
/**
 * _additionalMonitoringIndicator
 *
 * (Modified) MedicinalProductDefinition.additionalMonitoringIndicator
 *
 * http://hl7.org/fhir/_additionalMonitoringIndicator
 */
export declare const _additionalMonitoringIndicator = "http://hl7.org/fhir/_additionalMonitoringIndicator";
/**
 * _position
 *
 * (Modified) Location.position
 *
 * http://hl7.org/fhir/_position
 */
export declare const _position = "http://hl7.org/fhir/_position";
/**
 * limit
 *
 * Permission.rule.limit: What limits apply to the use of the data.
 *
 * http://hl7.org/fhir/limit
 */
export declare const limit = "http://hl7.org/fhir/limit";
/**
 * _reason
 *
 * (Modified) Appointment.reason
 *
 * http://hl7.org/fhir/_reason
 */
export declare const _reason = "http://hl7.org/fhir/_reason";
/**
 * _planningHorizon
 *
 * (Modified) Schedule.planningHorizon
 *
 * http://hl7.org/fhir/_planningHorizon
 */
export declare const _planningHorizon = "http://hl7.org/fhir/_planningHorizon";
/**
 * _safety
 *
 * (Modified) DeviceDefinition.safety
 *
 * http://hl7.org/fhir/_safety
 */
export declare const _safety = "http://hl7.org/fhir/_safety";
/**
 * Identifier
 *
 * An identifier - identifies some entity uniquely and unambiguously. Typically this is used for business identifiers.
 *
 * http://hl7.org/fhir/Identifier
 */
export declare const Identifier = "http://hl7.org/fhir/Identifier";
/**
 * _mitigation
 *
 * (Modified) RiskAssessment.mitigation
 *
 * http://hl7.org/fhir/_mitigation
 */
export declare const _mitigation = "http://hl7.org/fhir/_mitigation";
/**
 * _specialCourtesy
 *
 * (Modified) Encounter.specialCourtesy
 *
 * http://hl7.org/fhir/_specialCourtesy
 */
export declare const _specialCourtesy = "http://hl7.org/fhir/_specialCourtesy";
/**
 * ExampleScenarioInstanceContainedInstanceComponent
 *
 * ExampleScenarioInstanceComponent.ExampleScenarioInstanceContainedInstanceComponent: References to other instances that can be found within this instance (e.g. the observations contained in a bundle).
 *
 * http://hl7.org/fhir/ExampleScenarioInstanceContainedInstanceComponent
 */
export declare const ExampleScenarioInstanceContainedInstanceComponent = "http://hl7.org/fhir/ExampleScenarioInstanceContainedInstanceComponent";
/**
 * edit
 *
 * MolecularSequence.relative.edit: Changes in sequence from the starting sequence.
 *
 * http://hl7.org/fhir/edit
 */
export declare const edit = "http://hl7.org/fhir/edit";
/**
 * qualitativeRisk
 *
 * RiskAssessment.prediction.qualitativeRisk: Indicates how likely the outcome is (in the specified timeframe), expressed as a qualitative value (e.g. low, medium, or high).
 *
 * http://hl7.org/fhir/qualitativeRisk
 */
export declare const qualitativeRisk = "http://hl7.org/fhir/qualitativeRisk";
/**
 * immunizationEvent
 *
 * ImmunizationEvaluation.immunizationEvent: The vaccine administration event being evaluated.
 *
 * http://hl7.org/fhir/immunizationEvent
 */
export declare const immunizationEvent = "http://hl7.org/fhir/immunizationEvent";
/**
 * reference
 *
 * Contract.term.offer.party.reference: Participant in the offer.
 *
 * http://hl7.org/fhir/reference
 */
export declare const reference = "http://hl7.org/fhir/reference";
/**
 * reporter
 *
 * MeasureReport.reporter: The individual or organization that is reporting the data.
 *
 * http://hl7.org/fhir/reporter
 */
export declare const reporter = "http://hl7.org/fhir/reporter";
/**
 * BackboneElement
 *
 * Base definition for all elements that are defined inside a resource - but not those in a data type.
 *
 * http://hl7.org/fhir/BackboneElement
 */
export declare const BackboneElement = "http://hl7.org/fhir/BackboneElement";
/**
 * _hasMember
 *
 * (Modified) ObservationDefinition.hasMember
 *
 * http://hl7.org/fhir/_hasMember
 */
export declare const _hasMember = "http://hl7.org/fhir/_hasMember";
/**
 * Provenance
 *
 * Provenance of a resource is a record that describes entities and processes involved in producing and delivering or otherwise influencing that resource. Provenance provides a critical foundation for assessing authenticity, enabling trust, and allowing reproducibility. Provenance assertions are a form of contextual metadata and can themselves become important records with their own provenance. Provenance statement indicates clinical significance in terms of confidence in authenticity, reliability, and trustworthiness, integrity, and stage in lifecycle (e.g. Document Completion - has the artifact been legally authenticated), all of which may impact security, privacy, and trust policies.
 *
 * http://hl7.org/fhir/Provenance
 */
export declare const Provenance = "http://hl7.org/fhir/Provenance";
/**
 * reasonLinkId
 *
 * Contract.term.group.action.reasonLinkId: Id [identifier??] of the clause or question text related to the reason type or reference of this  action in the referenced form or QuestionnaireResponse.
 *
 * http://hl7.org/fhir/reasonLinkId
 */
export declare const reasonLinkId = "http://hl7.org/fhir/reasonLinkId";
/**
 * owner
 *
 * DeviceDefinition.owner: An organization that is responsible for the provision and ongoing maintenance of the device.
 *
 * http://hl7.org/fhir/owner
 */
export declare const owner = "http://hl7.org/fhir/owner";
/**
 * _assignedComparisonGroup
 *
 * (Modified) ResearchSubject.assignedComparisonGroup
 *
 * http://hl7.org/fhir/_assignedComparisonGroup
 */
export declare const _assignedComparisonGroup = "http://hl7.org/fhir/_assignedComparisonGroup";
/**
 * _Condition
 *
 * (Modified) Condition
 *
 * http://hl7.org/fhir/_Condition
 */
export declare const _Condition = "http://hl7.org/fhir/_Condition";
/**
 * ConsentPolicyBasisComponent
 *
 * ConsentPolicyBasisComponent: A Reference or URL used to uniquely identify the policy the organization will enforce for this Consent. This Reference or URL should be specific to the version of the policy and should be dereferencable to a computable policy of some form.
 *
 * http://hl7.org/fhir/ConsentPolicyBasisComponent
 */
export declare const ConsentPolicyBasisComponent = "http://hl7.org/fhir/ConsentPolicyBasisComponent";
/**
 * communicationMethod
 *
 * VerificationResult.attestation.communicationMethod: The method by which attested information was submitted/retrieved (manual; API; Push).
 *
 * http://hl7.org/fhir/communicationMethod
 */
export declare const communicationMethod = "http://hl7.org/fhir/communicationMethod";
/**
 * _param
 *
 * (Modified) CompartmentDefinition.resource.param
 *
 * http://hl7.org/fhir/_param
 */
export declare const _param = "http://hl7.org/fhir/_param";
/**
 * _power
 *
 * (Modified) VisionPrescription.lensSpecification.power
 *
 * http://hl7.org/fhir/_power
 */
export declare const _power = "http://hl7.org/fhir/_power";
/**
 * _issue
 *
 * (Modified) OperationOutcome.issue
 *
 * http://hl7.org/fhir/_issue
 */
export declare const _issue = "http://hl7.org/fhir/_issue";
/**
 * concept
 *
 * CodeSystem.concept.concept.concept: Defines children of a concept to produce a hierarchy of concepts. The nature of the relationships is variable (is-a/contains/categorizes) - see hierarchyMeaning.
 *
 * http://hl7.org/fhir/concept
 */
export declare const concept = "http://hl7.org/fhir/concept";
/**
 * decisionMode
 *
 * Contract.term.group.offer.decisionMode: How the decision about a Contract was conveyed.
 *
 * http://hl7.org/fhir/decisionMode
 */
export declare const decisionMode = "http://hl7.org/fhir/decisionMode";
/**
 * instantiatesUri
 *
 * CarePlan.instantiatesUri: The URL pointing to an externally maintained protocol, guideline, questionnaire or other definition that is adhered to in whole or in part by this CarePlan.
 *
 * http://hl7.org/fhir/instantiatesUri
 */
export declare const instantiatesUri = "http://hl7.org/fhir/instantiatesUri";
/**
 * _ifMatch
 *
 * (Modified) Bundle.entry.request.ifMatch
 *
 * http://hl7.org/fhir/_ifMatch
 */
export declare const _ifMatch = "http://hl7.org/fhir/_ifMatch";
/**
 * sequenceType
 *
 * SubstanceProtein.sequenceType: The SubstanceProtein descriptive elements will only be used when a complete or partial amino acid sequence is available or derivable from a nucleic acid sequence.
 *
 * http://hl7.org/fhir/sequenceType
 */
export declare const sequenceType = "http://hl7.org/fhir/sequenceType";
/**
 * _fastingStatus
 *
 * (Modified) Specimen.collection.fastingStatus
 *
 * http://hl7.org/fhir/_fastingStatus
 */
export declare const _fastingStatus = "http://hl7.org/fhir/_fastingStatus";
/**
 * preferredReportName
 *
 * ObservationDefinition.preferredReportName: The preferred name to be used when reporting the results of observations conforming to this ObservationDefinition.
 *
 * http://hl7.org/fhir/preferredReportName
 */
export declare const preferredReportName = "http://hl7.org/fhir/preferredReportName";
/**
 * _numberOfSeries
 *
 * (Modified) ImagingStudy.numberOfSeries
 *
 * http://hl7.org/fhir/_numberOfSeries
 */
export declare const _numberOfSeries = "http://hl7.org/fhir/_numberOfSeries";
/**
 * rankingOrder
 *
 * Citation.citedArtifact.contributorship.entry.rankingOrder: Provides a numerical ranking to represent the degree of contributorship relative to other contributors, such as 1 for first author and 2 for second author.
 *
 * http://hl7.org/fhir/rankingOrder
 */
export declare const rankingOrder = "http://hl7.org/fhir/rankingOrder";
/**
 * _currency
 *
 * (Modified) Account.currency
 *
 * http://hl7.org/fhir/_currency
 */
export declare const _currency = "http://hl7.org/fhir/_currency";
/**
 * testTools
 *
 * TestPlan.testTools: A description of test tools to be used in the test plan.
 *
 * http://hl7.org/fhir/testTools
 */
export declare const testTools = "http://hl7.org/fhir/testTools";
/**
 * _warning
 *
 * (Modified) DeviceDefinition.guideline.warning
 *
 * http://hl7.org/fhir/_warning
 */
export declare const _warning = "http://hl7.org/fhir/_warning";
/**
 * CoverageEligibilityResponseEventComponent
 *
 * CoverageEligibilityResponseEventComponent: Information code for an event with a corresponding date or period.
 *
 * http://hl7.org/fhir/CoverageEligibilityResponseEventComponent
 */
export declare const CoverageEligibilityResponseEventComponent = "http://hl7.org/fhir/CoverageEligibilityResponseEventComponent";
/**
 * _characteristic
 *
 * (Modified) Group.characteristic
 *
 * http://hl7.org/fhir/_characteristic
 */
export declare const _characteristic = "http://hl7.org/fhir/_characteristic";
/**
 * dataRequirement
 *
 * Library.dataRequirement: Describes a set of data that must be provided in order to be able to successfully perform the computations defined by the library.
 *
 * http://hl7.org/fhir/dataRequirement
 */
export declare const dataRequirement = "http://hl7.org/fhir/dataRequirement";
/**
 * _domain
 *
 * (Modified) SubstanceDefinition.name.translation.domain
 *
 * http://hl7.org/fhir/_domain
 */
export declare const _domain = "http://hl7.org/fhir/_domain";
/**
 * InventoryReport
 *
 * A report of inventory or stock items.
 *
 * http://hl7.org/fhir/InventoryReport
 */
export declare const InventoryReport = "http://hl7.org/fhir/InventoryReport";
/**
 * _parameterName
 *
 * (Modified) OperationDefinition.overload.parameterName
 *
 * http://hl7.org/fhir/_parameterName
 */
export declare const _parameterName = "http://hl7.org/fhir/_parameterName";
/**
 * progressStatus
 *
 * ResearchStudy.progressStatus: Status of study with time for that status.
 *
 * http://hl7.org/fhir/progressStatus
 */
export declare const progressStatus = "http://hl7.org/fhir/progressStatus";
/**
 * _narrative
 *
 * (Modified) TestPlan.testCase.testRun.narrative
 *
 * http://hl7.org/fhir/_narrative
 */
export declare const _narrative = "http://hl7.org/fhir/_narrative";
/**
 * Endpoint
 *
 * The technical details of an endpoint that can be used for electronic services, such as for web services providing XDS.b, a REST endpoint for another FHIR server, or a s/Mime email address. This may include any security context information.
 *
 * http://hl7.org/fhir/Endpoint
 */
export declare const Endpoint = "http://hl7.org/fhir/Endpoint";
/**
 * subjectState
 *
 * ResearchSubject.progress.subjectState: The current state of the subject.
 *
 * http://hl7.org/fhir/subjectState
 */
export declare const subjectState = "http://hl7.org/fhir/subjectState";
/**
 * entry
 *
 * Composition.section.entry: A reference to the actual resource from which the narrative in the section is derived.
 *
 * http://hl7.org/fhir/entry
 */
export declare const entry = "http://hl7.org/fhir/entry";
/**
 * _weeklyTemplate
 *
 * (Modified) Appointment.recurrenceTemplate.weeklyTemplate
 *
 * http://hl7.org/fhir/_weeklyTemplate
 */
export declare const _weeklyTemplate = "http://hl7.org/fhir/_weeklyTemplate";
/**
 * what
 *
 * Provenance.entity.what: Identity of the  Entity used. May be a logical or physical uri and maybe absolute or relative.
 *
 * http://hl7.org/fhir/what
 */
export declare const what = "http://hl7.org/fhir/what";
/**
 * whenPrepared
 *
 * MedicationDispense.whenPrepared: The time when the dispensed product was packaged and reviewed.
 *
 * http://hl7.org/fhir/whenPrepared
 */
export declare const whenPrepared = "http://hl7.org/fhir/whenPrepared";
/**
 * Action
 *
 * Contract.TermTerm.Action: An actor taking a role in an activity for which it can be assigned some degree of responsibility for the activity taking place.
 *
 * http://hl7.org/fhir/Action
 */
export declare const Action = "http://hl7.org/fhir/Action";
/**
 * _observationRequirement
 *
 * (Modified) ActivityDefinition.observationRequirement
 *
 * http://hl7.org/fhir/_observationRequirement
 */
export declare const _observationRequirement = "http://hl7.org/fhir/_observationRequirement";
/**
 * focal
 *
 * ExplanationOfBenefit.insurance.focal: A flag to indicate that this Coverage is to be used for adjudication of this claim when set to true.
 *
 * http://hl7.org/fhir/focal
 */
export declare const focal = "http://hl7.org/fhir/focal";
/**
 * verification
 *
 * Consent.verification: Whether a treatment instruction (e.g. artificial respiration: yes or no) was verified with the patient, his/her family or another authorized person.
 *
 * http://hl7.org/fhir/verification
 */
export declare const verification = "http://hl7.org/fhir/verification";
/**
 * _availability
 *
 * (Modified) PractitionerRole.availability
 *
 * http://hl7.org/fhir/_availability
 */
export declare const _availability = "http://hl7.org/fhir/_availability";
/**
 * resultingEffect
 *
 * AdverseEvent.resultingEffect: Information about the condition that occurred as a result of the adverse event, such as hives due to the exposure to a substance (for example, a drug or a chemical) or a broken leg as a result of the fall.
 *
 * http://hl7.org/fhir/resultingEffect
 */
export declare const resultingEffect = "http://hl7.org/fhir/resultingEffect";
/**
 * timeout
 *
 * Subscription.timeout: If present, the maximum amount of time a server will allow before failing a notification attempt.
 *
 * http://hl7.org/fhir/timeout
 */
export declare const timeout = "http://hl7.org/fhir/timeout";
/**
 * CapabilityStatementMessagingSupportedMessageComponent
 *
 * CapabilityStatementMessagingComponent.CapabilityStatementMessagingSupportedMessageComponent: References to message definitions for messages this system can send or receive.
 *
 * http://hl7.org/fhir/CapabilityStatementMessagingSupportedMessageComponent
 */
export declare const CapabilityStatementMessagingSupportedMessageComponent = "http://hl7.org/fhir/CapabilityStatementMessagingSupportedMessageComponent";
/**
 * _revenue
 *
 * (Modified) ExplanationOfBenefit.item.detail.subDetail.revenue
 *
 * http://hl7.org/fhir/_revenue
 */
export declare const _revenue = "http://hl7.org/fhir/_revenue";
/**
 * _returnedAmount
 *
 * (Modified) PaymentReconciliation.returnedAmount
 *
 * http://hl7.org/fhir/_returnedAmount
 */
export declare const _returnedAmount = "http://hl7.org/fhir/_returnedAmount";
/**
 * MedicationKnowledgeDefinitionalIngredientComponent
 *
 * MedicationKnowledgeDefinitionalComponent.MedicationKnowledgeDefinitionalIngredientComponent: Identifies a particular constituent of interest in the product.
 *
 * http://hl7.org/fhir/MedicationKnowledgeDefinitionalIngredientComponent
 */
export declare const MedicationKnowledgeDefinitionalIngredientComponent = "http://hl7.org/fhir/MedicationKnowledgeDefinitionalIngredientComponent";
/**
 * candidate
 *
 * EnrollmentRequest.candidate: Patient Resource.
 *
 * http://hl7.org/fhir/candidate
 */
export declare const candidate = "http://hl7.org/fhir/candidate";
/**
 * Subscription
 *
 * The subscription resource describes a particular client's request to be notified about a SubscriptionTopic.
 *
 * http://hl7.org/fhir/Subscription
 */
export declare const Subscription = "http://hl7.org/fhir/Subscription";
/**
 * relatedAction
 *
 * PlanDefinition.action.action.relatedAction: A relationship to another action such as "before" or "30-60 minutes after start of".
 *
 * http://hl7.org/fhir/relatedAction
 */
export declare const relatedAction = "http://hl7.org/fhir/relatedAction";
/**
 * textPresentation
 *
 * Ingredient.substance.strength.textPresentation: A textual represention of either the whole of the presentation strength or a part of it - with the rest being in Strength.presentation as a ratio.
 *
 * http://hl7.org/fhir/textPresentation
 */
export declare const textPresentation = "http://hl7.org/fhir/textPresentation";
/**
 * _supplements
 *
 * (Modified) CodeSystem.supplements
 *
 * http://hl7.org/fhir/_supplements
 */
export declare const _supplements = "http://hl7.org/fhir/_supplements";
/**
 * result
 *
 * DiagnosticReport.result: [Observations](observation.html)  that are part of this diagnostic report.
 *
 * http://hl7.org/fhir/result
 */
export declare const result = "http://hl7.org/fhir/result";
/**
 * policyText
 *
 * Consent.policyText: A Reference to the human readable policy explaining the basis for the Consent.
 *
 * http://hl7.org/fhir/policyText
 */
export declare const policyText = "http://hl7.org/fhir/policyText";
/**
 * _regionType
 *
 * (Modified) ImagingSelection.instance.imageRegion3D.regionType
 *
 * http://hl7.org/fhir/_regionType
 */
export declare const _regionType = "http://hl7.org/fhir/_regionType";
/**
 * StratifierGroup
 *
 * MeasureReportGroupComponent.MeasureReportGroupStratifierComponent.StratifierGroup: This element contains the results for a single stratum within the stratifier. For example, when stratifying on administrative gender, there will be four strata, one for each possible gender value.
 *
 * http://hl7.org/fhir/StratifierGroup
 */
export declare const StratifierGroup = "http://hl7.org/fhir/StratifierGroup";
/**
 * _contract
 *
 * (Modified) Coverage.contract
 *
 * http://hl7.org/fhir/_contract
 */
export declare const _contract = "http://hl7.org/fhir/_contract";
/**
 * _timeFromEvent
 *
 * (Modified) EvidenceVariable.characteristic.timeFromEvent
 *
 * http://hl7.org/fhir/_timeFromEvent
 */
export declare const _timeFromEvent = "http://hl7.org/fhir/_timeFromEvent";
/**
 * notificationEvent
 *
 * SubscriptionStatus.notificationEvent: Detailed information about events relevant to this subscription notification.
 *
 * http://hl7.org/fhir/notificationEvent
 */
export declare const notificationEvent = "http://hl7.org/fhir/notificationEvent";
/**
 * _inclusionCriteria
 *
 * (Modified) ValueSet.scope.inclusionCriteria
 *
 * http://hl7.org/fhir/_inclusionCriteria
 */
export declare const _inclusionCriteria = "http://hl7.org/fhir/_inclusionCriteria";
/**
 * _orderMeaning
 *
 * (Modified) ElementDefinition.orderMeaning
 *
 * http://hl7.org/fhir/_orderMeaning
 */
export declare const _orderMeaning = "http://hl7.org/fhir/_orderMeaning";
/**
 * autodelete
 *
 * TestScript.fixture.autodelete: Whether or not to implicitly delete the fixture during teardown. If true, the fixture is automatically deleted on each server being tested during teardown, therefore no delete operation is required for this fixture in the TestScript.teardown section.
 *
 * http://hl7.org/fhir/autodelete
 */
export declare const autodelete = "http://hl7.org/fhir/autodelete";
/**
 * qualifiers
 *
 * InsurancePlan.plan.specificCost.benefit.cost.qualifiers: Additional information about the cost, such as information about funding sources (e.g. HSA, HRA, FSA, RRA).
 *
 * http://hl7.org/fhir/qualifiers
 */
export declare const qualifiers = "http://hl7.org/fhir/qualifiers";
/**
 * _regionsStudied
 *
 * (Modified) GenomicStudy.analysis.regionsStudied
 *
 * http://hl7.org/fhir/_regionsStudied
 */
export declare const _regionsStudied = "http://hl7.org/fhir/_regionsStudied";
/**
 * _application
 *
 * (Modified) RegulatedAuthorization.case.application
 *
 * http://hl7.org/fhir/_application
 */
export declare const _application = "http://hl7.org/fhir/_application";
/**
 * frequency
 *
 * VerificationResult.frequency: Frequency of revalidation.
 *
 * http://hl7.org/fhir/frequency
 */
export declare const frequency = "http://hl7.org/fhir/frequency";
/**
 * _sourceMaterial
 *
 * (Modified) SubstanceDefinition.sourceMaterial
 *
 * http://hl7.org/fhir/_sourceMaterial
 */
export declare const _sourceMaterial = "http://hl7.org/fhir/_sourceMaterial";
/**
 * regulatoryBasis
 *
 * Consent.regulatoryBasis: A set of codes that indicate the regulatory basis (if any) that this consent supports.
 *
 * http://hl7.org/fhir/regulatoryBasis
 */
export declare const regulatoryBasis = "http://hl7.org/fhir/regulatoryBasis";
/**
 * associationType
 *
 * InventoryItem.association.associationType: This attribute defined the type of association when establishing associations or relations between items, e.g. 'packaged within' or 'used with' or 'to be mixed with.
 *
 * http://hl7.org/fhir/associationType
 */
export declare const associationType = "http://hl7.org/fhir/associationType";
/**
 * _software
 *
 * (Modified) TerminologyCapabilities.software
 *
 * http://hl7.org/fhir/_software
 */
export declare const _software = "http://hl7.org/fhir/_software";
/**
 * _copolymerConnectivity
 *
 * (Modified) SubstancePolymer.copolymerConnectivity
 *
 * http://hl7.org/fhir/_copolymerConnectivity
 */
export declare const _copolymerConnectivity = "http://hl7.org/fhir/_copolymerConnectivity";
/**
 * _approvalDate
 *
 * (Modified) NamingSystem.approvalDate
 *
 * http://hl7.org/fhir/_approvalDate
 */
export declare const _approvalDate = "http://hl7.org/fhir/_approvalDate";
/**
 * totalVolume
 *
 * Medication.totalVolume: When the specified product code does not infer a package size, this is the specific amount of drug in the product.  For example, when specifying a product that has the same strength (For example, Insulin glargine 100 unit per mL solution for injection), this attribute provides additional clarification of the package amount (For example, 3 mL, 10mL, etc.).
 *
 * http://hl7.org/fhir/totalVolume
 */
export declare const totalVolume = "http://hl7.org/fhir/totalVolume";
/**
 * AppointmentRecurrenceTemplateWeeklyTemplateComponent
 *
 * AppointmentRecurrenceTemplateComponent.AppointmentRecurrenceTemplateWeeklyTemplateComponent: Information about weekly recurring appointments.
 *
 * http://hl7.org/fhir/AppointmentRecurrenceTemplateWeeklyTemplateComponent
 */
export declare const AppointmentRecurrenceTemplateWeeklyTemplateComponent = "http://hl7.org/fhir/AppointmentRecurrenceTemplateWeeklyTemplateComponent";
/**
 * _requestedPerformer
 *
 * (Modified) Task.requestedPerformer
 *
 * http://hl7.org/fhir/_requestedPerformer
 */
export declare const _requestedPerformer = "http://hl7.org/fhir/_requestedPerformer";
/**
 * packagedProduct
 *
 * MedicationKnowledge.packaging.packagedProduct: A reference to a PackagedProductDefinition that provides the details of the product that is in the packaging and is being priced.
 *
 * http://hl7.org/fhir/packagedProduct
 */
export declare const packagedProduct = "http://hl7.org/fhir/packagedProduct";
/**
 * tissue
 *
 * AdministrableProductDefinition.routeOfAdministration.targetSpecies.withdrawalPeriod.tissue: Coded expression for the type of tissue for which the withdrawal period applies, e.g. meat, milk.
 *
 * http://hl7.org/fhir/tissue
 */
export declare const tissue = "http://hl7.org/fhir/tissue";
/**
 * isSubpotent
 *
 * Immunization.isSubpotent: Indication if a dose is considered to be subpotent. By default, a dose should be considered to be potent.
 *
 * http://hl7.org/fhir/isSubpotent
 */
export declare const isSubpotent = "http://hl7.org/fhir/isSubpotent";
/**
 * _supportingInfoSequence
 *
 * (Modified) CoverageEligibilityRequest.item.supportingInfoSequence
 *
 * http://hl7.org/fhir/_supportingInfoSequence
 */
export declare const _supportingInfoSequence = "http://hl7.org/fhir/_supportingInfoSequence";
/**
 * _rating
 *
 * (Modified) Evidence.certainty.subcomponent.rating
 *
 * http://hl7.org/fhir/_rating
 */
export declare const _rating = "http://hl7.org/fhir/_rating";
/**
 * maternalOrganismName
 *
 * SubstanceSourceMaterial.organism.hybrid.maternalOrganismName: The name of the maternal species constituting the hybrid organism shall be specified. For plants, the parents aren’t always known, and it is unlikely that it will be known which is maternal and which is paternal.
 *
 * http://hl7.org/fhir/maternalOrganismName
 */
export declare const maternalOrganismName = "http://hl7.org/fhir/maternalOrganismName";
/**
 * CommunicationRequest
 *
 * A request to convey information; e.g. the CDS system proposes that an alert be sent to a responsible provider, the CDS system proposes that the public health agency be notified about a reportable condition.
 *
 * http://hl7.org/fhir/CommunicationRequest
 */
export declare const CommunicationRequest = "http://hl7.org/fhir/CommunicationRequest";
/**
 * polymer
 *
 * SubstanceDefinition.polymer: Data items specific to polymers.
 *
 * http://hl7.org/fhir/polymer
 */
export declare const polymer = "http://hl7.org/fhir/polymer";
/**
 * initiatorActive
 *
 * ExampleScenario.process.step.process.step.alternative.step.operation.initiatorActive: If false, the initiator is deactivated right after the operation.
 *
 * http://hl7.org/fhir/initiatorActive
 */
export declare const initiatorActive = "http://hl7.org/fhir/initiatorActive";
/**
 * _productStatus
 *
 * (Modified) BiologicallyDerivedProduct.productStatus
 *
 * http://hl7.org/fhir/_productStatus
 */
export declare const _productStatus = "http://hl7.org/fhir/_productStatus";
/**
 * strand
 *
 * MolecularSequence.relative.startingSequence.strand: An absolute reference to a strand. The Watson strand is the strand whose 5'-end is on the short arm of the chromosome, and the Crick strand as the one whose 5'-end is on the long arm.
 *
 * http://hl7.org/fhir/strand
 */
export declare const strand = "http://hl7.org/fhir/strand";
/**
 * _outputParameters
 *
 * (Modified) GuidanceResponse.outputParameters
 *
 * http://hl7.org/fhir/_outputParameters
 */
export declare const _outputParameters = "http://hl7.org/fhir/_outputParameters";
/**
 * participantStatus
 *
 * AppointmentResponse.participantStatus: Participation status of the participant. When the status is declined or tentative if the start/end times are different to the appointment, then these times should be interpreted as a requested time change. When the status is accepted, the times can either be the time of the appointment (as a confirmation of the time) or can be empty.
 *
 * http://hl7.org/fhir/participantStatus
 */
export declare const participantStatus = "http://hl7.org/fhir/participantStatus";
/**
 * label
 *
 * RelatedArtifact.label: A short label that can be used to reference the citation from elsewhere in the containing artifact, such as a footnote index.
 *
 * http://hl7.org/fhir/label
 */
export declare const label = "http://hl7.org/fhir/label";
/**
 * manipulated
 *
 * Procedure.focalDevice.manipulated: The device that was manipulated (changed) during the procedure.
 *
 * http://hl7.org/fhir/manipulated
 */
export declare const manipulated = "http://hl7.org/fhir/manipulated";
/**
 * _geometry
 *
 * (Modified) SubstancePolymer.geometry
 *
 * http://hl7.org/fhir/_geometry
 */
export declare const _geometry = "http://hl7.org/fhir/_geometry";
/**
 * Coding
 *
 * A reference to a code defined by a terminology system.
 *
 * http://hl7.org/fhir/Coding
 */
export declare const Coding = "http://hl7.org/fhir/Coding";
/**
 * requisition
 *
 * ServiceRequest.requisition: A shared identifier common to all service requests that were authorized more or less simultaneously by a single author, representing the composite or group identifier.
 *
 * http://hl7.org/fhir/requisition
 */
export declare const requisition = "http://hl7.org/fhir/requisition";
/**
 * InventoryReportInventoryListingComponent
 *
 * InventoryReportInventoryListingComponent: An inventory listing section (grouped by any of the attributes).
 *
 * http://hl7.org/fhir/InventoryReportInventoryListingComponent
 */
export declare const InventoryReportInventoryListingComponent = "http://hl7.org/fhir/InventoryReportInventoryListingComponent";
/**
 * _parent
 *
 * (Modified) Specimen.parent
 *
 * http://hl7.org/fhir/_parent
 */
export declare const _parent = "http://hl7.org/fhir/_parent";
/**
 * _net
 *
 * (Modified) Claim.item.net
 *
 * http://hl7.org/fhir/_net
 */
export declare const _net = "http://hl7.org/fhir/_net";
/**
 * presentation
 *
 * Ingredient.substance.strength.presentation
 *
 * http://hl7.org/fhir/presentation
 */
export declare const presentation = "http://hl7.org/fhir/presentation";
/**
 * flag
 *
 * List.entry.flag: The flag allows the system constructing the list to indicate the role and significance of the item in the list.
 *
 * http://hl7.org/fhir/flag
 */
export declare const flag = "http://hl7.org/fhir/flag";
/**
 * hoursOfOperation
 *
 * Location.hoursOfOperation: What days/times during a week is this location usually open, and any exceptions where the location is not available.
 *
 * http://hl7.org/fhir/hoursOfOperation
 */
export declare const hoursOfOperation = "http://hl7.org/fhir/hoursOfOperation";
/**
 * encounter
 *
 * AdverseEvent.encounter: The Encounter associated with the start of the AdverseEvent.
 *
 * http://hl7.org/fhir/encounter
 */
export declare const encounter = "http://hl7.org/fhir/encounter";
/**
 * applicability
 *
 * ChargeItemDefinition.propertyGroup.applicability: Expressions that describe applicability criteria for the priceComponent.
 *
 * http://hl7.org/fhir/applicability
 */
export declare const applicability = "http://hl7.org/fhir/applicability";
/**
 * releaseDate
 *
 * CapabilityStatement.software.releaseDate: Date this version of the software was released.
 *
 * http://hl7.org/fhir/releaseDate
 */
export declare const releaseDate = "http://hl7.org/fhir/releaseDate";
/**
 * _relationshipType
 *
 * (Modified) ClinicalUseDefinition.indication.otherTherapy.relationshipType
 *
 * http://hl7.org/fhir/_relationshipType
 */
export declare const _relationshipType = "http://hl7.org/fhir/_relationshipType";
/**
 * _managingOrganization
 *
 * (Modified) Person.managingOrganization
 *
 * http://hl7.org/fhir/_managingOrganization
 */
export declare const _managingOrganization = "http://hl7.org/fhir/_managingOrganization";
/**
 * derivedFromCanonical
 *
 * SpecimenDefinition.derivedFromCanonical: The canonical URL pointing to another FHIR-defined SpecimenDefinition that is adhered to in whole or in part by this definition.
 *
 * http://hl7.org/fhir/derivedFromCanonical
 */
export declare const derivedFromCanonical = "http://hl7.org/fhir/derivedFromCanonical";
/**
 * _hasSeverity
 *
 * (Modified) ConditionDefinition.hasSeverity
 *
 * http://hl7.org/fhir/_hasSeverity
 */
export declare const _hasSeverity = "http://hl7.org/fhir/_hasSeverity";
/**
 * cTerminalModification
 *
 * SubstanceProtein.subunit.cTerminalModification: The modification at the C-terminal shall be specified.
 *
 * http://hl7.org/fhir/cTerminalModification
 */
export declare const cTerminalModification = "http://hl7.org/fhir/cTerminalModification";
/**
 * ContentDefinition
 *
 * Contract.ContentDefinition: Precusory content developed with a focus and intent of supporting the formation a Contract instance, which may be associated with and transformable into a Contract.
 *
 * http://hl7.org/fhir/ContentDefinition
 */
export declare const ContentDefinition = "http://hl7.org/fhir/ContentDefinition";
/**
 * _bodyLandmarkOrientation
 *
 * (Modified) BodyStructure.excludedStructure.bodyLandmarkOrientation
 *
 * http://hl7.org/fhir/_bodyLandmarkOrientation
 */
export declare const _bodyLandmarkOrientation = "http://hl7.org/fhir/_bodyLandmarkOrientation";
/**
 * relationship
 *
 * PlanDefinition.action.action.relatedAction.relationship: The relationship of the start of this action to the related action.
 *
 * http://hl7.org/fhir/relationship
 */
export declare const relationship = "http://hl7.org/fhir/relationship";
/**
 * goal
 *
 * PlanDefinition.goal: A goal describes an expected outcome that activities within the plan are intended to achieve. For example, weight loss, restoring an activity of daily living, obtaining herd immunity via immunization, meeting a process improvement objective, meeting the acceptance criteria for a test as specified by a quality specification, etc.
 *
 * http://hl7.org/fhir/goal
 */
export declare const goal = "http://hl7.org/fhir/goal";
/**
 * _connectivity
 *
 * (Modified) SubstanceNucleicAcid.subunit.linkage.connectivity
 *
 * http://hl7.org/fhir/_connectivity
 */
export declare const _connectivity = "http://hl7.org/fhir/_connectivity";
/**
 * _listMode
 *
 * (Modified) StructureMap.group.rule.rule.target.listMode
 *
 * http://hl7.org/fhir/_listMode
 */
export declare const _listMode = "http://hl7.org/fhir/_listMode";
/**
 * _availableTime
 *
 * (Modified) Availability.availableTime
 *
 * http://hl7.org/fhir/_availableTime
 */
export declare const _availableTime = "http://hl7.org/fhir/_availableTime";
/**
 * property
 *
 * DeviceDefinition.property: Static or essentially fixed characteristics or features of this kind of device that are otherwise not captured in more specific attributes, e.g., time or timing attributes, resolution, accuracy, and physical attributes.
 *
 * http://hl7.org/fhir/property
 */
export declare const property = "http://hl7.org/fhir/property";
/**
 * _calibration
 *
 * (Modified) DeviceMetric.calibration
 *
 * http://hl7.org/fhir/_calibration
 */
export declare const _calibration = "http://hl7.org/fhir/_calibration";
/**
 * TerminologyCapabilitiesExpansionParameterComponent
 *
 * TerminologyCapabilitiesExpansionComponent.TerminologyCapabilitiesExpansionParameterComponent: Supported expansion parameter.
 *
 * http://hl7.org/fhir/TerminologyCapabilitiesExpansionParameterComponent
 */
export declare const TerminologyCapabilitiesExpansionParameterComponent = "http://hl7.org/fhir/TerminologyCapabilitiesExpansionParameterComponent";
/**
 * adjustmentReason
 *
 * ExplanationOfBenefit.payment.adjustmentReason: Reason for the payment adjustment.
 *
 * http://hl7.org/fhir/adjustmentReason
 */
export declare const adjustmentReason = "http://hl7.org/fhir/adjustmentReason";
/**
 * AdministrableProductDefinitionRouteOfAdministrationTargetSpeciesComponent
 *
 * AdministrableProductDefinitionRouteOfAdministrationComponent.AdministrableProductDefinitionRouteOfAdministrationTargetSpeciesComponent: A species for which this route applies.
 *
 * http://hl7.org/fhir/AdministrableProductDefinitionRouteOfAdministrationTargetSpeciesComponent
 */
export declare const AdministrableProductDefinitionRouteOfAdministrationTargetSpeciesComponent = "http://hl7.org/fhir/AdministrableProductDefinitionRouteOfAdministrationTargetSpeciesComponent";
/**
 * Basic
 *
 * Basic is used for handling concepts not yet defined in FHIR, narrative-only resources that don't map to an existing resource, and custom resources not appropriate for inclusion in the FHIR specification.
 *
 * http://hl7.org/fhir/Basic
 */
export declare const Basic = "http://hl7.org/fhir/Basic";
/**
 * _isDerived
 *
 * (Modified) SpecimenDefinition.typeTested.isDerived
 *
 * http://hl7.org/fhir/_isDerived
 */
export declare const _isDerived = "http://hl7.org/fhir/_isDerived";
/**
 * hierarchical
 *
 * TerminologyCapabilities.expansion.hierarchical: Whether the server can return nested value sets.
 *
 * http://hl7.org/fhir/hierarchical
 */
export declare const hierarchical = "http://hl7.org/fhir/hierarchical";
/**
 * _resultForCreate
 *
 * (Modified) SubscriptionTopic.resourceTrigger.queryCriteria.resultForCreate
 *
 * http://hl7.org/fhir/_resultForCreate
 */
export declare const _resultForCreate = "http://hl7.org/fhir/_resultForCreate";
/**
 * _deviceName
 *
 * (Modified) DeviceDefinition.deviceName
 *
 * http://hl7.org/fhir/_deviceName
 */
export declare const _deviceName = "http://hl7.org/fhir/_deviceName";
/**
 * _startDate
 *
 * (Modified) ResearchSubject.progress.startDate
 *
 * http://hl7.org/fhir/_startDate
 */
export declare const _startDate = "http://hl7.org/fhir/_startDate";
/**
 * Attachment
 *
 * For referring to data content defined in other formats.
 *
 * http://hl7.org/fhir/Attachment
 */
export declare const Attachment = "http://hl7.org/fhir/Attachment";
/**
 * _patientPreparation
 *
 * (Modified) SpecimenDefinition.patientPreparation
 *
 * http://hl7.org/fhir/_patientPreparation
 */
export declare const _patientPreparation = "http://hl7.org/fhir/_patientPreparation";
/**
 * CitationCitedArtifactPublicationFormComponent
 *
 * CitationCitedArtifactComponent.CitationCitedArtifactPublicationFormComponent: If multiple, used to represent alternative forms of the article that are not separate citations.
 *
 * http://hl7.org/fhir/CitationCitedArtifactPublicationFormComponent
 */
export declare const CitationCitedArtifactPublicationFormComponent = "http://hl7.org/fhir/CitationCitedArtifactPublicationFormComponent";
/**
 * windowStart
 *
 * MolecularSequence.relative.startingSequence.windowStart: Start position of the window on the starting sequence. This value should honor the rules of the coordinateSystem.
 *
 * http://hl7.org/fhir/windowStart
 */
export declare const windowStart = "http://hl7.org/fhir/windowStart";
/**
 * _propertyGroup
 *
 * (Modified) ChargeItemDefinition.propertyGroup
 *
 * http://hl7.org/fhir/_propertyGroup
 */
export declare const _propertyGroup = "http://hl7.org/fhir/_propertyGroup";
/**
 * languageCode
 *
 * DeviceDefinition.languageCode: Language code for the human-readable text strings produced by the device (all supported).
 *
 * http://hl7.org/fhir/languageCode
 */
export declare const languageCode = "http://hl7.org/fhir/languageCode";
/**
 * _canPushUpdates
 *
 * (Modified) VerificationResult.primarySource.canPushUpdates
 *
 * http://hl7.org/fhir/_canPushUpdates
 */
export declare const _canPushUpdates = "http://hl7.org/fhir/_canPushUpdates";
/**
 * groupingBehavior
 *
 * PlanDefinition.action.action.groupingBehavior: Defines the grouping behavior for the action and its children.
 *
 * http://hl7.org/fhir/groupingBehavior
 */
export declare const groupingBehavior = "http://hl7.org/fhir/groupingBehavior";
/**
 * for
 *
 * Ingredient.for: The product which this ingredient is a constituent part of.
 * Note that `for` is a reserved Javascript keyword, and is therefore suffixed by `__workaround`.
 * For a list of reserved keywords, see https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Lexical_grammar#Keywords.
 *
 * http://hl7.org/fhir/for
 */
export declare const for__workaround = "http://hl7.org/fhir/for";
/**
 * _studyUid
 *
 * (Modified) ImagingSelection.studyUid
 *
 * http://hl7.org/fhir/_studyUid
 */
export declare const _studyUid = "http://hl7.org/fhir/_studyUid";
/**
 * _event
 *
 * (Modified) MessageHeader.event
 *
 * http://hl7.org/fhir/_event
 */
export declare const _event = "http://hl7.org/fhir/_event";
/**
 * informationProvider
 *
 * CommunicationRequest.informationProvider: The entity (e.g. person, organization, clinical information system, or device) which is to be the source of the communication.
 *
 * http://hl7.org/fhir/informationProvider
 */
export declare const informationProvider = "http://hl7.org/fhir/informationProvider";
/**
 * network
 *
 * InsurancePlan.coverage.network: Reference to the network that providing the type of coverage.
 *
 * http://hl7.org/fhir/network
 */
export declare const network = "http://hl7.org/fhir/network";
/**
 * _manufacturedDoseForm
 *
 * (Modified) ManufacturedItemDefinition.manufacturedDoseForm
 *
 * http://hl7.org/fhir/_manufacturedDoseForm
 */
export declare const _manufacturedDoseForm = "http://hl7.org/fhir/_manufacturedDoseForm";
/**
 * assert
 *
 * TestScript.setup.action.assert: Evaluates the results of previous operations to determine if the server under test behaves appropriately.
 *
 * http://hl7.org/fhir/assert
 */
export declare const assert = "http://hl7.org/fhir/assert";
/**
 * _warningOnly
 *
 * (Modified) TestScript.test.action.assert.warningOnly
 *
 * http://hl7.org/fhir/_warningOnly
 */
export declare const _warningOnly = "http://hl7.org/fhir/_warningOnly";
/**
 * isSummary
 *
 * ElementDefinition.isSummary: Whether the element should be included if a client requests a search with the parameter _summary=true.
 *
 * http://hl7.org/fhir/isSummary
 */
export declare const isSummary = "http://hl7.org/fhir/isSummary";
/**
 * attachedDocument
 *
 * RegulatedAuthorization.attachedDocument: Additional information or supporting documentation about the authorization.
 *
 * http://hl7.org/fhir/attachedDocument
 */
export declare const attachedDocument = "http://hl7.org/fhir/attachedDocument";
/**
 * _unit
 *
 * (Modified) SubstancePolymer.repeat.repeatUnit.unit
 *
 * http://hl7.org/fhir/_unit
 */
export declare const _unit = "http://hl7.org/fhir/_unit";
/**
 * _endDate
 *
 * (Modified) ResearchSubject.progress.endDate
 *
 * http://hl7.org/fhir/_endDate
 */
export declare const _endDate = "http://hl7.org/fhir/_endDate";
/**
 * authoredOn
 *
 * RequestOrchestration.authoredOn: Indicates when the request orchestration was created.
 *
 * http://hl7.org/fhir/authoredOn
 */
export declare const authoredOn = "http://hl7.org/fhir/authoredOn";
/**
 * _geographicalLocation
 *
 * (Modified) SubstanceSourceMaterial.geographicalLocation
 *
 * http://hl7.org/fhir/_geographicalLocation
 */
export declare const _geographicalLocation = "http://hl7.org/fhir/_geographicalLocation";
/**
 * CitationCitedArtifactClassificationComponent
 *
 * CitationCitedArtifactComponent.CitationCitedArtifactClassificationComponent: The assignment to an organizing scheme.
 *
 * http://hl7.org/fhir/CitationCitedArtifactClassificationComponent
 */
export declare const CitationCitedArtifactClassificationComponent = "http://hl7.org/fhir/CitationCitedArtifactClassificationComponent";
/**
 * userSelected
 *
 * Coding.userSelected: Indicates that this coding was chosen by a user directly - e.g. off a pick list of available items (codes or displays).
 *
 * http://hl7.org/fhir/userSelected
 */
export declare const userSelected = "http://hl7.org/fhir/userSelected";
/**
 * _prognosisCodeableConcept
 *
 * (Modified) ClinicalImpression.prognosisCodeableConcept
 *
 * http://hl7.org/fhir/_prognosisCodeableConcept
 */
export declare const _prognosisCodeableConcept = "http://hl7.org/fhir/_prognosisCodeableConcept";
/**
 * dateCriterion
 *
 * ImmunizationRecommendation.recommendation.dateCriterion: Vaccine date recommendations.  For example, earliest date to administer, latest date to administer, etc.
 *
 * http://hl7.org/fhir/dateCriterion
 */
export declare const dateCriterion = "http://hl7.org/fhir/dateCriterion";
/**
 * additionalInstruction
 *
 * Dosage.additionalInstruction: Supplemental instructions to the patient on how to take the medication  (e.g. "with meals" or"take half to one hour before food") or warnings for the patient about the medication (e.g. "may cause drowsiness" or "avoid exposure of skin to direct sunlight or sunlamps").
 *
 * http://hl7.org/fhir/additionalInstruction
 */
export declare const additionalInstruction = "http://hl7.org/fhir/additionalInstruction";
/**
 * specialPrecautionsForStorage
 *
 * ProductShelfLife.specialPrecautionsForStorage: Special precautions for storage, if any, can be specified using an appropriate controlled vocabulary The controlled term and the controlled term identifier shall be specified.
 *
 * http://hl7.org/fhir/specialPrecautionsForStorage
 */
export declare const specialPrecautionsForStorage = "http://hl7.org/fhir/specialPrecautionsForStorage";
/**
 * population
 *
 * ClinicalUseDefinition.population: The population group to which this applies.
 *
 * http://hl7.org/fhir/population
 */
export declare const population = "http://hl7.org/fhir/population";
/**
 * _member
 *
 * (Modified) Group.member
 *
 * http://hl7.org/fhir/_member
 */
export declare const _member = "http://hl7.org/fhir/_member";
/**
 * securityLabel
 *
 * AuditEvent.entity.securityLabel: Security labels for the identified entity.
 *
 * http://hl7.org/fhir/securityLabel
 */
export declare const securityLabel = "http://hl7.org/fhir/securityLabel";
/**
 * _renderedDosageInstruction
 *
 * (Modified) MedicationStatement.renderedDosageInstruction
 *
 * http://hl7.org/fhir/_renderedDosageInstruction
 */
export declare const _renderedDosageInstruction = "http://hl7.org/fhir/_renderedDosageInstruction";
/**
 * Notes
 *
 * PaymentReconciliation.Notes: A note that describes or explains the processing in a human readable form.
 *
 * http://hl7.org/fhir/Notes
 */
export declare const Notes = "http://hl7.org/fhir/Notes";
/**
 * _dynamicValue
 *
 * (Modified) RequestOrchestration.action.action.dynamicValue
 *
 * http://hl7.org/fhir/_dynamicValue
 */
export declare const _dynamicValue = "http://hl7.org/fhir/_dynamicValue";
/**
 * _confidentialityIndicator
 *
 * (Modified) MedicinalProductDefinition.operation.confidentialityIndicator
 *
 * http://hl7.org/fhir/_confidentialityIndicator
 */
export declare const _confidentialityIndicator = "http://hl7.org/fhir/_confidentialityIndicator";
/**
 * _intendedUse
 *
 * (Modified) RegulatedAuthorization.intendedUse
 *
 * http://hl7.org/fhir/_intendedUse
 */
export declare const _intendedUse = "http://hl7.org/fhir/_intendedUse";
/**
 * lastUpdated
 *
 * Meta.lastUpdated: When the resource last changed - e.g. when the version changed.
 *
 * http://hl7.org/fhir/lastUpdated
 */
export declare const lastUpdated = "http://hl7.org/fhir/lastUpdated";
/**
 * deceased
 *
 * Practitioner.deceased
 *
 * http://hl7.org/fhir/deceased
 */
export declare const deceased = "http://hl7.org/fhir/deceased";
/**
 * NutritionOrderEnteralFormulaAdditiveComponent
 *
 * NutritionOrderEnteralFormulaComponent.NutritionOrderEnteralFormulaAdditiveComponent: Indicates modular components to be provided in addition or mixed with the base formula.
 *
 * http://hl7.org/fhir/NutritionOrderEnteralFormulaAdditiveComponent
 */
export declare const NutritionOrderEnteralFormulaAdditiveComponent = "http://hl7.org/fhir/NutritionOrderEnteralFormulaAdditiveComponent";
/**
 * designation
 *
 * ValueSet.expansion.contains.designation: Additional representations for this item - other languages, aliases, specialized purposes, used for particular purposes, etc. These are relevant when the conditions of the expansion do not fix to a single correct representation.
 *
 * http://hl7.org/fhir/designation
 */
export declare const designation = "http://hl7.org/fhir/designation";
/**
 * reportedDateTime
 *
 * InventoryReport.reportedDateTime: When the report has been submitted.
 *
 * http://hl7.org/fhir/reportedDateTime
 */
export declare const reportedDateTime = "http://hl7.org/fhir/reportedDateTime";
/**
 * productOrServiceEnd
 *
 * ExplanationOfBenefit.addItem.productOrServiceEnd: This contains the end of a range of product, service, drug or other billing codes for the item. This element is not used when the .productOrService is a group code. This value may only be present when a .productOfService code has been provided to convey the start of the range. Typically this value may be used only with preauthorizations and not with claims.
 *
 * http://hl7.org/fhir/productOrServiceEnd
 */
export declare const productOrServiceEnd = "http://hl7.org/fhir/productOrServiceEnd";
/**
 * teardown
 *
 * TestScript.teardown: A series of operations required to clean up after all the tests are executed (successfully or otherwise).
 *
 * http://hl7.org/fhir/teardown
 */
export declare const teardown = "http://hl7.org/fhir/teardown";
/**
 * securityLabelNumber
 *
 * Contract.term.action.securityLabelNumber: Security labels that protects the action.
 *
 * http://hl7.org/fhir/securityLabelNumber
 */
export declare const securityLabelNumber = "http://hl7.org/fhir/securityLabelNumber";
/**
 * _manufactureDate
 *
 * (Modified) Device.manufactureDate
 *
 * http://hl7.org/fhir/_manufactureDate
 */
export declare const _manufactureDate = "http://hl7.org/fhir/_manufactureDate";
/**
 * _textFilter
 *
 * (Modified) TerminologyCapabilities.expansion.textFilter
 *
 * http://hl7.org/fhir/_textFilter
 */
export declare const _textFilter = "http://hl7.org/fhir/_textFilter";
/**
 * _route
 *
 * (Modified) MedicinalProductDefinition.route
 *
 * http://hl7.org/fhir/_route
 */
export declare const _route = "http://hl7.org/fhir/_route";
/**
 * parentSubstanceName
 *
 * SubstanceSourceMaterial.parentSubstanceName: The parent substance of the Herbal Drug, or Herbal preparation.
 *
 * http://hl7.org/fhir/parentSubstanceName
 */
export declare const parentSubstanceName = "http://hl7.org/fhir/parentSubstanceName";
/**
 * _docStatus
 *
 * (Modified) DocumentReference.docStatus
 *
 * http://hl7.org/fhir/_docStatus
 */
export declare const _docStatus = "http://hl7.org/fhir/_docStatus";
/**
 * ArtifactAssessmentContentComponentContentContent
 *
 * If the informationType is container, the components of the content.
 *
 * http://hl7.org/fhir/ArtifactAssessmentContentComponentContentContent
 */
export declare const ArtifactAssessmentContentComponentContentContent = "http://hl7.org/fhir/ArtifactAssessmentContentComponentContentContent";
/**
 * _subscriber
 *
 * (Modified) Coverage.subscriber
 *
 * http://hl7.org/fhir/_subscriber
 */
export declare const _subscriber = "http://hl7.org/fhir/_subscriber";
/**
 * workflowStatus
 *
 * ArtifactAssessment.workflowStatus: Indicates the workflow status of the comment or change request.
 *
 * http://hl7.org/fhir/workflowStatus
 */
export declare const workflowStatus = "http://hl7.org/fhir/workflowStatus";
/**
 * phylum
 *
 * SubstanceSourceMaterial.organism.organismGeneral.phylum: The phylum of an organism shall be specified.
 *
 * http://hl7.org/fhir/phylum
 */
export declare const phylum = "http://hl7.org/fhir/phylum";
/**
 * _mustSupport
 *
 * (Modified) ElementDefinition.mustSupport
 *
 * http://hl7.org/fhir/_mustSupport
 */
export declare const _mustSupport = "http://hl7.org/fhir/_mustSupport";
/**
 * forecastStatus
 *
 * ImmunizationRecommendation.recommendation.forecastStatus: Indicates the patient status with respect to the path to immunity for the target disease.
 *
 * http://hl7.org/fhir/forecastStatus
 */
export declare const forecastStatus = "http://hl7.org/fhir/forecastStatus";
/**
 * _closure
 *
 * (Modified) TerminologyCapabilities.closure
 *
 * http://hl7.org/fhir/_closure
 */
export declare const _closure = "http://hl7.org/fhir/_closure";
/**
 * _abstract
 *
 * (Modified) ValueSet.expansion.contains.contains.abstract
 *
 * http://hl7.org/fhir/_abstract
 */
export declare const _abstract = "http://hl7.org/fhir/_abstract";
/**
 * relatedClinicalInformation
 *
 * MedicationStatement.relatedClinicalInformation: Link to information that is relevant to a medication statement, for example, illicit drug use, gestational age, etc.
 *
 * http://hl7.org/fhir/relatedClinicalInformation
 */
export declare const relatedClinicalInformation = "http://hl7.org/fhir/relatedClinicalInformation";
/**
 * PersonCommunicationComponent
 *
 * PersonCommunicationComponent: A language which may be used to communicate with the person about his or her health.
 *
 * http://hl7.org/fhir/PersonCommunicationComponent
 */
export declare const PersonCommunicationComponent = "http://hl7.org/fhir/PersonCommunicationComponent";
/**
 * _relativePath
 *
 * (Modified) ImplementationGuide.manifest.resource.relativePath
 *
 * http://hl7.org/fhir/_relativePath
 */
export declare const _relativePath = "http://hl7.org/fhir/_relativePath";
/**
 * CitationCitedArtifactVersionComponent
 *
 * CitationCitedArtifactComponent.CitationCitedArtifactVersionComponent: The defined version of the cited artifact.
 *
 * http://hl7.org/fhir/CitationCitedArtifactVersionComponent
 */
export declare const CitationCitedArtifactVersionComponent = "http://hl7.org/fhir/CitationCitedArtifactVersionComponent";
/**
 * _paging
 *
 * (Modified) TerminologyCapabilities.expansion.paging
 *
 * http://hl7.org/fhir/_paging
 */
export declare const _paging = "http://hl7.org/fhir/_paging";
/**
 * _uniqueId
 *
 * (Modified) NamingSystem.uniqueId
 *
 * http://hl7.org/fhir/_uniqueId
 */
export declare const _uniqueId = "http://hl7.org/fhir/_uniqueId";
/**
 * _readOnly
 *
 * (Modified) Questionnaire.item.item.readOnly
 *
 * http://hl7.org/fhir/_readOnly
 */
export declare const _readOnly = "http://hl7.org/fhir/_readOnly";
/**
 * _jurisdiction
 *
 * (Modified) DeviceDefinition.packaging.packaging.udiDeviceIdentifier.jurisdiction
 *
 * http://hl7.org/fhir/_jurisdiction
 */
export declare const _jurisdiction = "http://hl7.org/fhir/_jurisdiction";
/**
 * _treatment
 *
 * (Modified) ClinicalUseDefinition.indication.otherTherapy.treatment
 *
 * http://hl7.org/fhir/_treatment
 */
export declare const _treatment = "http://hl7.org/fhir/_treatment";
/**
 * _responsibleParty
 *
 * (Modified) MedicationDispense.substitution.responsibleParty
 *
 * http://hl7.org/fhir/_responsibleParty
 */
export declare const _responsibleParty = "http://hl7.org/fhir/_responsibleParty";
/**
 * RequestOrchestrationActionComponentActionAction
 *
 * Sub actions.
 *
 * http://hl7.org/fhir/RequestOrchestrationActionComponentActionAction
 */
export declare const RequestOrchestrationActionComponentActionAction = "http://hl7.org/fhir/RequestOrchestrationActionComponentActionAction";
/**
 * _role
 *
 * (Modified) PlanDefinition.action.action.participant.role
 *
 * http://hl7.org/fhir/_role
 */
export declare const _role = "http://hl7.org/fhir/_role";
/**
 * TestPlanDependencyComponent
 *
 * TestPlanDependencyComponent: The required criteria to execute the test plan - e.g. preconditions, previous tests...
 *
 * http://hl7.org/fhir/TestPlanDependencyComponent
 */
export declare const TestPlanDependencyComponent = "http://hl7.org/fhir/TestPlanDependencyComponent";
/**
 * Binary
 *
 * A resource that represents the data of a single raw artifact as digital content accessible in its native format.  A Binary resource can contain any content, whether text, image, pdf, zip archive, etc.
 *
 * http://hl7.org/fhir/Binary
 */
export declare const Binary = "http://hl7.org/fhir/Binary";
/**
 * contentDerivative
 *
 * Contract.contentDerivative: The minimal content derived from the basal information source at a specific stage in its lifecycle.
 *
 * http://hl7.org/fhir/contentDerivative
 */
export declare const contentDerivative = "http://hl7.org/fhir/contentDerivative";
/**
 * inforce
 *
 * CoverageEligibilityResponse.insurance.inforce: Flag indicating if the coverage provided is inforce currently if no service date(s) specified or for the whole duration of the service dates.
 *
 * http://hl7.org/fhir/inforce
 */
export declare const inforce = "http://hl7.org/fhir/inforce";
/**
 * RiskAssessmentPredictionComponent
 *
 * RiskAssessmentPredictionComponent: Describes the expected outcome for the subject.
 *
 * http://hl7.org/fhir/RiskAssessmentPredictionComponent
 */
export declare const RiskAssessmentPredictionComponent = "http://hl7.org/fhir/RiskAssessmentPredictionComponent";
/**
 * _enteredDate
 *
 * (Modified) ChargeItem.enteredDate
 *
 * http://hl7.org/fhir/_enteredDate
 */
export declare const _enteredDate = "http://hl7.org/fhir/_enteredDate";
/**
 * _legalStatusOfSupply
 *
 * (Modified) PackagedProductDefinition.legalStatusOfSupply
 *
 * http://hl7.org/fhir/_legalStatusOfSupply
 */
export declare const _legalStatusOfSupply = "http://hl7.org/fhir/_legalStatusOfSupply";
/**
 * valueAlternatives
 *
 * ElementDefinition.valueAlternatives: Specifies a list of extensions that can appear in place of a primitive value.
 *
 * http://hl7.org/fhir/valueAlternatives
 */
export declare const valueAlternatives = "http://hl7.org/fhir/valueAlternatives";
/**
 * subject
 *
 * Account.subject: Identifies the entity which incurs the expenses. While the immediate recipients of services or goods might be entities related to the subject, the expenses were ultimately incurred by the subject of the Account.
 *
 * http://hl7.org/fhir/subject
 */
export declare const subject = "http://hl7.org/fhir/subject";
/**
 * _publicationDate
 *
 * (Modified) Contract.contentDefinition.publicationDate
 *
 * http://hl7.org/fhir/_publicationDate
 */
export declare const _publicationDate = "http://hl7.org/fhir/_publicationDate";
/**
 * occurrenceChanged
 *
 * Appointment.occurrenceChanged: This appointment varies from the recurring pattern.
 *
 * http://hl7.org/fhir/occurrenceChanged
 */
export declare const occurrenceChanged = "http://hl7.org/fhir/occurrenceChanged";
/**
 * _referralRequest
 *
 * (Modified) EpisodeOfCare.referralRequest
 *
 * http://hl7.org/fhir/_referralRequest
 */
export declare const _referralRequest = "http://hl7.org/fhir/_referralRequest";
/**
 * friday
 *
 * Appointment.recurrenceTemplate.weeklyTemplate.friday: Indicates that recurring appointments should occur on Fridays.
 *
 * http://hl7.org/fhir/friday
 */
export declare const friday = "http://hl7.org/fhir/friday";
/**
 * productType
 *
 * MedicationKnowledge.productType: Category of the medication or product (e.g. branded product, therapeutic moeity, generic product, innovator product, etc.).
 *
 * http://hl7.org/fhir/productType
 */
export declare const productType = "http://hl7.org/fhir/productType";
/**
 * _payeeType
 *
 * (Modified) ClaimResponse.payeeType
 *
 * http://hl7.org/fhir/_payeeType
 */
export declare const _payeeType = "http://hl7.org/fhir/_payeeType";
/**
 * _fixed
 *
 * (Modified) ElementDefinition.fixed
 *
 * http://hl7.org/fhir/_fixed
 */
export declare const _fixed = "http://hl7.org/fhir/_fixed";
/**
 * _nTerminalModification
 *
 * (Modified) SubstanceProtein.subunit.nTerminalModification
 *
 * http://hl7.org/fhir/_nTerminalModification
 */
export declare const _nTerminalModification = "http://hl7.org/fhir/_nTerminalModification";
/**
 * _progressStatus
 *
 * (Modified) ResearchStudy.progressStatus
 *
 * http://hl7.org/fhir/_progressStatus
 */
export declare const _progressStatus = "http://hl7.org/fhir/_progressStatus";
/**
 * _age
 *
 * (Modified) ObservationDefinition.component.qualifiedValue.age
 *
 * http://hl7.org/fhir/_age
 */
export declare const _age = "http://hl7.org/fhir/_age";
/**
 * _verificationDate
 *
 * (Modified) Consent.verification.verificationDate
 *
 * http://hl7.org/fhir/_verificationDate
 */
export declare const _verificationDate = "http://hl7.org/fhir/_verificationDate";
/**
 * CompartmentDefinitionResourceComponent
 *
 * CompartmentDefinitionResourceComponent: Information about how a resource is related to the compartment.
 *
 * http://hl7.org/fhir/CompartmentDefinitionResourceComponent
 */
export declare const CompartmentDefinitionResourceComponent = "http://hl7.org/fhir/CompartmentDefinitionResourceComponent";
/**
 * _questionnaire
 *
 * (Modified) QuestionnaireResponse.questionnaire
 *
 * http://hl7.org/fhir/_questionnaire
 */
export declare const _questionnaire = "http://hl7.org/fhir/_questionnaire";
/**
 * TestScript
 *
 * A structured set of tests against a FHIR server or client implementation to determine compliance against the FHIR specification.
 *
 * http://hl7.org/fhir/TestScript
 */
export declare const TestScript = "http://hl7.org/fhir/TestScript";
/**
 * billingStatus
 *
 * Account.billingStatus: The BillingStatus tracks the lifecycle of the account through the billing process. It indicates how transactions are treated when they are allocated to the account.
 *
 * http://hl7.org/fhir/billingStatus
 */
export declare const billingStatus = "http://hl7.org/fhir/billingStatus";
/**
 * _resourceTrigger
 *
 * (Modified) SubscriptionTopic.resourceTrigger
 *
 * http://hl7.org/fhir/_resourceTrigger
 */
export declare const _resourceTrigger = "http://hl7.org/fhir/_resourceTrigger";
/**
 * compose
 *
 * ValueSet.compose: A set of criteria that define the contents of the value set by including or excluding codes selected from the specified code system(s) that the value set draws from. This is also known as the Content Logical Definition (CLD).
 *
 * http://hl7.org/fhir/compose
 */
export declare const compose = "http://hl7.org/fhir/compose";
/**
 * _submitter
 *
 * (Modified) PaymentReconciliation.allocation.submitter
 *
 * http://hl7.org/fhir/_submitter
 */
export declare const _submitter = "http://hl7.org/fhir/_submitter";
/**
 * _productReference
 *
 * (Modified) InventoryItem.productReference
 *
 * http://hl7.org/fhir/_productReference
 */
export declare const _productReference = "http://hl7.org/fhir/_productReference";
/**
 * payment
 *
 * ClaimResponse.payment: Payment details for the adjudication of the claim.
 *
 * http://hl7.org/fhir/payment
 */
export declare const payment = "http://hl7.org/fhir/payment";
/**
 * rateAggregation
 *
 * Measure.group.rateAggregation: Describes how to combine the information calculated, based on logic in each of several populations, into one summarized result.
 *
 * http://hl7.org/fhir/rateAggregation
 */
export declare const rateAggregation = "http://hl7.org/fhir/rateAggregation";
/**
 * OrganizationQualificationComponent
 *
 * OrganizationQualificationComponent: The official certifications, accreditations, training, designations and licenses that authorize and/or otherwise endorse the provision of care by the organization.

For example, an approval to provide a type of services issued by a certifying body (such as the US Joint Commission) to an organization.
 *
 * http://hl7.org/fhir/OrganizationQualificationComponent
 */
export declare const OrganizationQualificationComponent = "http://hl7.org/fhir/OrganizationQualificationComponent";
/**
 * identityCertificate
 *
 * VerificationResult.validator.identityCertificate: A digital identity certificate associated with the validator.
 *
 * http://hl7.org/fhir/identityCertificate
 */
export declare const identityCertificate = "http://hl7.org/fhir/identityCertificate";
/**
 * _subDetail
 *
 * (Modified) ExplanationOfBenefit.addItem.detail.subDetail
 *
 * http://hl7.org/fhir/_subDetail
 */
export declare const _subDetail = "http://hl7.org/fhir/_subDetail";
/**
 * contextInvariant
 *
 * StructureDefinition.contextInvariant: A set of rules as FHIRPath Invariants about when the extension can be used (e.g. co-occurrence variants for the extension). All the rules must be true.
 *
 * http://hl7.org/fhir/contextInvariant
 */
export declare const contextInvariant = "http://hl7.org/fhir/contextInvariant";
/**
 * _suffix
 *
 * (Modified) HumanName.suffix
 *
 * http://hl7.org/fhir/_suffix
 */
export declare const _suffix = "http://hl7.org/fhir/_suffix";
/**
 * _recurrenceId
 *
 * (Modified) AppointmentResponse.recurrenceId
 *
 * http://hl7.org/fhir/_recurrenceId
 */
export declare const _recurrenceId = "http://hl7.org/fhir/_recurrenceId";
/**
 * dispenseInterval
 *
 * MedicationRequest.dispenseRequest.dispenseInterval: The minimum period of time that must occur between dispenses of the medication.
 *
 * http://hl7.org/fhir/dispenseInterval
 */
export declare const dispenseInterval = "http://hl7.org/fhir/dispenseInterval";
/**
 * _map
 *
 * (Modified) ElementDefinition.mapping.map
 *
 * http://hl7.org/fhir/_map
 */
export declare const _map = "http://hl7.org/fhir/_map";
/**
 * _lensSpecification
 *
 * (Modified) VisionPrescription.lensSpecification
 *
 * http://hl7.org/fhir/_lensSpecification
 */
export declare const _lensSpecification = "http://hl7.org/fhir/_lensSpecification";
/**
 * allergyIntolerance
 *
 * NutritionOrder.allergyIntolerance: A link to a record of allergies or intolerances  which should be included in the nutrition order.
 *
 * http://hl7.org/fhir/allergyIntolerance
 */
export declare const allergyIntolerance = "http://hl7.org/fhir/allergyIntolerance";
/**
 * asset
 *
 * Contract.term.group.asset: Contract Term Asset List.
 *
 * http://hl7.org/fhir/asset
 */
export declare const asset = "http://hl7.org/fhir/asset";
/**
 * CoverageEligibilityResponse
 *
 * This resource provides eligibility and plan details from the processing of an CoverageEligibilityRequest resource.
 *
 * http://hl7.org/fhir/CoverageEligibilityResponse
 */
export declare const CoverageEligibilityResponse = "http://hl7.org/fhir/CoverageEligibilityResponse";
/**
 * OperationDefinitionParameterComponentParameter
 *
 * The parts of a nested Parameter.
 *
 * http://hl7.org/fhir/OperationDefinitionParameterComponentParameter
 */
export declare const OperationDefinitionParameterComponentParameter = "http://hl7.org/fhir/OperationDefinitionParameterComponentParameter";
/**
 * packagedMedicinalProduct
 *
 * MedicinalProductDefinition.packagedMedicinalProduct: Package type for the product. See also the PackagedProductDefinition resource.
 *
 * http://hl7.org/fhir/packagedMedicinalProduct
 */
export declare const packagedMedicinalProduct = "http://hl7.org/fhir/packagedMedicinalProduct";
/**
 * _count
 *
 * (Modified) DeviceDefinition.packaging.packaging.count
 *
 * http://hl7.org/fhir/_count
 */
export declare const _count = "http://hl7.org/fhir/_count";
/**
 * SubstancePolymerRepeatRepeatUnitDegreeOfPolymerisationComponent
 *
 * SubstancePolymerRepeatComponent.SubstancePolymerRepeatRepeatUnitComponent.SubstancePolymerRepeatRepeatUnitDegreeOfPolymerisationComponent: Applies to homopolymer and block co-polymers where the degree of polymerisation within a block can be described.
 *
 * http://hl7.org/fhir/SubstancePolymerRepeatRepeatUnitDegreeOfPolymerisationComponent
 */
export declare const SubstancePolymerRepeatRepeatUnitDegreeOfPolymerisationComponent = "http://hl7.org/fhir/SubstancePolymerRepeatRepeatUnitDegreeOfPolymerisationComponent";
/**
 * adjudication
 *
 * ExplanationOfBenefit.adjudication: The adjudication results which are presented at the header level rather than at the line-item or add-item levels.
 *
 * http://hl7.org/fhir/adjudication
 */
export declare const adjudication = "http://hl7.org/fhir/adjudication";
/**
 * RequestOrchestrationActionConditionComponent
 *
 * RequestOrchestrationActionComponentAction.RequestOrchestrationActionConditionComponent: An expression that describes applicability criteria, or start/stop conditions for the action.
 *
 * http://hl7.org/fhir/RequestOrchestrationActionConditionComponent
 */
export declare const RequestOrchestrationActionConditionComponent = "http://hl7.org/fhir/RequestOrchestrationActionConditionComponent";
/**
 * validator
 *
 * VerificationResult.validator: Information about the entity validating information.
 *
 * http://hl7.org/fhir/validator
 */
export declare const validator = "http://hl7.org/fhir/validator";
/**
 * _gene
 *
 * (Modified) SubstanceReferenceInformation.gene.gene
 *
 * http://hl7.org/fhir/_gene
 */
export declare const _gene = "http://hl7.org/fhir/_gene";
/**
 * _length
 *
 * (Modified) SubstanceProtein.subunit.length
 *
 * http://hl7.org/fhir/_length
 */
export declare const _length = "http://hl7.org/fhir/_length";
/**
 * series
 *
 * ImmunizationEvaluation.series: One possible path to achieve presumed immunity against a disease - within the context of an authority.
 *
 * http://hl7.org/fhir/series
 */
export declare const series = "http://hl7.org/fhir/series";
/**
 * maxDosePerAdministration
 *
 * Dosage.maxDosePerAdministration: Upper limit on medication per administration.
 *
 * http://hl7.org/fhir/maxDosePerAdministration
 */
export declare const maxDosePerAdministration = "http://hl7.org/fhir/maxDosePerAdministration";
/**
 * _performerRole
 *
 * (Modified) Contract.term.group.action.performerRole
 *
 * http://hl7.org/fhir/_performerRole
 */
export declare const _performerRole = "http://hl7.org/fhir/_performerRole";
/**
 * _balance
 *
 * (Modified) Account.balance
 *
 * http://hl7.org/fhir/_balance
 */
export declare const _balance = "http://hl7.org/fhir/_balance";
/**
 * _correctiveAction
 *
 * (Modified) DeviceDefinition.correctiveAction
 *
 * http://hl7.org/fhir/_correctiveAction
 */
export declare const _correctiveAction = "http://hl7.org/fhir/_correctiveAction";
/**
 * dispenser
 *
 * MedicationRequest.dispenseRequest.dispenser: Indicates the intended performing Organization that will dispense the medication as specified by the prescriber.
 *
 * http://hl7.org/fhir/dispenser
 */
export declare const dispenser = "http://hl7.org/fhir/dispenser";
/**
 * NutritionOrderOralDietComponent
 *
 * NutritionOrderOralDietComponent: Diet given orally in contrast to enteral (tube) feeding.
 *
 * http://hl7.org/fhir/NutritionOrderOralDietComponent
 */
export declare const NutritionOrderOralDietComponent = "http://hl7.org/fhir/NutritionOrderOralDietComponent";
/**
 * _meaning
 *
 * (Modified) Permission.rule.data.resource.meaning
 *
 * http://hl7.org/fhir/_meaning
 */
export declare const _meaning = "http://hl7.org/fhir/_meaning";
/**
 * endParam
 *
 * CompartmentDefinition.resource.endParam: Search Parameter for mapping requests made with $everything.end (e.g. on [Patient.$everything](patient-operation-everything.html)).
 *
 * http://hl7.org/fhir/endParam
 */
export declare const endParam = "http://hl7.org/fhir/endParam";
/**
 * _provider
 *
 * (Modified) CoverageEligibilityRequest.item.provider
 *
 * http://hl7.org/fhir/_provider
 */
export declare const _provider = "http://hl7.org/fhir/_provider";
/**
 * inResponseTo
 *
 * Communication.inResponseTo: Prior communication that this communication is in response to.
 *
 * http://hl7.org/fhir/inResponseTo
 */
export declare const inResponseTo = "http://hl7.org/fhir/inResponseTo";
/**
 * authorDescription
 *
 * SubstanceSourceMaterial.organism.author.authorDescription: The author of an organism species shall be specified. The author year of an organism shall also be specified when applicable; refers to the year in which the first author(s) published the infraspecific plant/animal name (of any rank).
 *
 * http://hl7.org/fhir/authorDescription
 */
export declare const authorDescription = "http://hl7.org/fhir/authorDescription";
/**
 * _intendedExposure
 *
 * (Modified) ResearchStudy.comparisonGroup.intendedExposure
 *
 * http://hl7.org/fhir/_intendedExposure
 */
export declare const _intendedExposure = "http://hl7.org/fhir/_intendedExposure";
/**
 * _cycle
 *
 * (Modified) Device.cycle
 *
 * http://hl7.org/fhir/_cycle
 */
export declare const _cycle = "http://hl7.org/fhir/_cycle";
/**
 * ProvenanceEntityComponentAgent
 *
 * The entity is attributed to an agent to express the agent's responsibility for that entity, possibly along with other agents. This description can be understood as shorthand for saying that the agent was responsible for the activity which used the entity.
 *
 * http://hl7.org/fhir/ProvenanceEntityComponentAgent
 */
export declare const ProvenanceEntityComponentAgent = "http://hl7.org/fhir/ProvenanceEntityComponentAgent";
/**
 * high
 *
 * Range.high: The high limit. The boundary is inclusive.
 *
 * http://hl7.org/fhir/high
 */
export declare const high = "http://hl7.org/fhir/high";
/**
 * _paymentStatus
 *
 * (Modified) PaymentNotice.paymentStatus
 *
 * http://hl7.org/fhir/_paymentStatus
 */
export declare const _paymentStatus = "http://hl7.org/fhir/_paymentStatus";
/**
 * TestScriptVariableComponent
 *
 * TestScriptVariableComponent: Variable is set based either on element value in response body or on header field value in the response headers.
 *
 * http://hl7.org/fhir/TestScriptVariableComponent
 */
export declare const TestScriptVariableComponent = "http://hl7.org/fhir/TestScriptVariableComponent";
/**
 * _comparator
 *
 * (Modified) SubstanceDefinition.relationship.comparator
 *
 * http://hl7.org/fhir/_comparator
 */
export declare const _comparator = "http://hl7.org/fhir/_comparator";
/**
 * _instantiatesCanonical
 *
 * (Modified) Transport.instantiatesCanonical
 *
 * http://hl7.org/fhir/_instantiatesCanonical
 */
export declare const _instantiatesCanonical = "http://hl7.org/fhir/_instantiatesCanonical";
/**
 * class
 *
 * EncounterHistory.class: Concepts representing classification of patient encounter such as ambulatory (outpatient), inpatient, emergency, home health or others due to local variations.
 * Note that `class` is a reserved Javascript keyword, and is therefore suffixed by `__workaround`.
 * For a list of reserved keywords, see https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Lexical_grammar#Keywords.
 *
 * http://hl7.org/fhir/class
 */
export declare const class__workaround = "http://hl7.org/fhir/class";
/**
 * _countryOfOrigin
 *
 * (Modified) SubstanceSourceMaterial.countryOfOrigin
 *
 * http://hl7.org/fhir/_countryOfOrigin
 */
export declare const _countryOfOrigin = "http://hl7.org/fhir/_countryOfOrigin";
/**
 * structuralRepresentation
 *
 * SubstancePolymer.repeat.repeatUnit.structuralRepresentation: A graphical structure for this SRU.
 *
 * http://hl7.org/fhir/structuralRepresentation
 */
export declare const structuralRepresentation = "http://hl7.org/fhir/structuralRepresentation";
/**
 * _communicationMethod
 *
 * (Modified) VerificationResult.attestation.communicationMethod
 *
 * http://hl7.org/fhir/_communicationMethod
 */
export declare const _communicationMethod = "http://hl7.org/fhir/_communicationMethod";
/**
 * _size
 *
 * (Modified) Attachment.size
 *
 * http://hl7.org/fhir/_size
 */
export declare const _size = "http://hl7.org/fhir/_size";
/**
 * _averageMolecularFormula
 *
 * (Modified) SubstancePolymer.repeat.averageMolecularFormula
 *
 * http://hl7.org/fhir/_averageMolecularFormula
 */
export declare const _averageMolecularFormula = "http://hl7.org/fhir/_averageMolecularFormula";
/**
 * _ingredientLabel
 *
 * (Modified) NutritionIntake.ingredientLabel
 *
 * http://hl7.org/fhir/_ingredientLabel
 */
export declare const _ingredientLabel = "http://hl7.org/fhir/_ingredientLabel";
/**
 * _landmarkDescription
 *
 * (Modified) BodyStructure.excludedStructure.bodyLandmarkOrientation.landmarkDescription
 *
 * http://hl7.org/fhir/_landmarkDescription
 */
export declare const _landmarkDescription = "http://hl7.org/fhir/_landmarkDescription";
/**
 * _criticalCodedValueSet
 *
 * (Modified) ObservationDefinition.component.qualifiedValue.criticalCodedValueSet
 *
 * http://hl7.org/fhir/_criticalCodedValueSet
 */
export declare const _criticalCodedValueSet = "http://hl7.org/fhir/_criticalCodedValueSet";
/**
 * unmapped
 *
 * ConceptMap.group.unmapped: What to do when there is no mapping to a target concept from the source concept and ConceptMap.group.element.noMap is not true. This provides the "default" to be applied when there is no target concept mapping specified or the expansion of ConceptMap.group.element.target.valueSet is empty.
 *
 * http://hl7.org/fhir/unmapped
 */
export declare const unmapped = "http://hl7.org/fhir/unmapped";
/**
 * _productCategory
 *
 * (Modified) BiologicallyDerivedProduct.productCategory
 *
 * http://hl7.org/fhir/_productCategory
 */
export declare const _productCategory = "http://hl7.org/fhir/_productCategory";
/**
 * SubstanceReferenceInformationTargetComponent
 *
 * SubstanceReferenceInformationTargetComponent: Todo.
 *
 * http://hl7.org/fhir/SubstanceReferenceInformationTargetComponent
 */
export declare const SubstanceReferenceInformationTargetComponent = "http://hl7.org/fhir/SubstanceReferenceInformationTargetComponent";
/**
 * _preferredReportName
 *
 * (Modified) ObservationDefinition.preferredReportName
 *
 * http://hl7.org/fhir/_preferredReportName
 */
export declare const _preferredReportName = "http://hl7.org/fhir/_preferredReportName";
/**
 * _maternalOrganismId
 *
 * (Modified) SubstanceSourceMaterial.organism.hybrid.maternalOrganismId
 *
 * http://hl7.org/fhir/_maternalOrganismId
 */
export declare const _maternalOrganismId = "http://hl7.org/fhir/_maternalOrganismId";
/**
 * _order
 *
 * (Modified) SubstanceSourceMaterial.organism.organismGeneral.order
 *
 * http://hl7.org/fhir/_order
 */
export declare const _order = "http://hl7.org/fhir/_order";
/**
 * qualifier
 *
 * BodyStructure.excludedStructure.qualifier: Code that represents the included structure qualifier.
 *
 * http://hl7.org/fhir/qualifier
 */
export declare const qualifier = "http://hl7.org/fhir/qualifier";
/**
 * recruitment
 *
 * ResearchStudy.recruitment: Target or actual group of participants enrolled in study.
 *
 * http://hl7.org/fhir/recruitment
 */
export declare const recruitment = "http://hl7.org/fhir/recruitment";
/**
 * mitigation
 *
 * RiskAssessment.mitigation: A description of the steps that might be taken to reduce the identified risk(s).
 *
 * http://hl7.org/fhir/mitigation
 */
export declare const mitigation = "http://hl7.org/fhir/mitigation";
/**
 * Procedure
 *
 * An action that is or was performed on or for a patient, practitioner, device, organization, or location. For example, this can be a physical intervention on a patient like an operation, or less invasive like long term services, counseling, or hypnotherapy.  This can be a quality or safety inspection for a location, organization, or device.  This can be an accreditation procedure on a practitioner for licensing.
 *
 * http://hl7.org/fhir/Procedure
 */
export declare const Procedure = "http://hl7.org/fhir/Procedure";
/**
 * material
 *
 * PackagedProductDefinition.packaging.material: Material type of the package item.
 *
 * http://hl7.org/fhir/material
 */
export declare const material = "http://hl7.org/fhir/material";
/**
 * _packageId
 *
 * (Modified) ImplementationGuide.dependsOn.packageId
 *
 * http://hl7.org/fhir/_packageId
 */
export declare const _packageId = "http://hl7.org/fhir/_packageId";
/**
 * address
 *
 * Practitioner.address: Address(es) of the practitioner that are not role specific (typically home address).
Work addresses are not typically entered in this property as they are usually role dependent.
 *
 * http://hl7.org/fhir/address
 */
export declare const address = "http://hl7.org/fhir/address";
/**
 * module
 *
 * GuidanceResponse.module
 *
 * http://hl7.org/fhir/module
 */
export declare const module = "http://hl7.org/fhir/module";
/**
 * SubstanceNucleicAcidSubunitComponent
 *
 * SubstanceNucleicAcidSubunitComponent: Subunits are listed in order of decreasing length; sequences of the same length will be ordered by molecular weight; subunits that have identical sequences will be repeated multiple times.
 *
 * http://hl7.org/fhir/SubstanceNucleicAcidSubunitComponent
 */
export declare const SubstanceNucleicAcidSubunitComponent = "http://hl7.org/fhir/SubstanceNucleicAcidSubunitComponent";
/**
 * _healthcareService
 *
 * (Modified) PractitionerRole.healthcareService
 *
 * http://hl7.org/fhir/_healthcareService
 */
export declare const _healthcareService = "http://hl7.org/fhir/_healthcareService";
/**
 * check
 *
 * StructureMap.group.rule.rule.source.check: FHIRPath expression  - must be true or the mapping engine throws an error instead of completing.
 *
 * http://hl7.org/fhir/check
 */
export declare const check = "http://hl7.org/fhir/check";
/**
 * _serviceProvisionCode
 *
 * (Modified) HealthcareService.serviceProvisionCode
 *
 * http://hl7.org/fhir/_serviceProvisionCode
 */
export declare const _serviceProvisionCode = "http://hl7.org/fhir/_serviceProvisionCode";
/**
 * DeviceDefinitionHasPartComponent
 *
 * DeviceDefinitionHasPartComponent: A device that is part (for example a component) of the present device.
 *
 * http://hl7.org/fhir/DeviceDefinitionHasPartComponent
 */
export declare const DeviceDefinitionHasPartComponent = "http://hl7.org/fhir/DeviceDefinitionHasPartComponent";
/**
 * hybrid
 *
 * SubstanceSourceMaterial.organism.hybrid: 4.9.13.8.1 Hybrid species maternal organism ID (Optional).
 *
 * http://hl7.org/fhir/hybrid
 */
export declare const hybrid = "http://hl7.org/fhir/hybrid";
/**
 * DeviceDefinitionPackagingComponentPackaging
 *
 * Allows packages within packages.
 *
 * http://hl7.org/fhir/DeviceDefinitionPackagingComponentPackaging
 */
export declare const DeviceDefinitionPackagingComponentPackaging = "http://hl7.org/fhir/DeviceDefinitionPackagingComponentPackaging";
/**
 * extends
 *
 * StructureMap.group.extends: Another group that this group adds rules to.
 * Note that `extends` is a reserved Javascript keyword, and is therefore suffixed by `__workaround`.
 * For a list of reserved keywords, see https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Lexical_grammar#Keywords.
 *
 * http://hl7.org/fhir/extends
 */
export declare const extends__workaround = "http://hl7.org/fhir/extends";
/**
 * AdverseEventSupportingInfoComponent
 *
 * AdverseEventSupportingInfoComponent: Supporting information relevant to the event.
 *
 * http://hl7.org/fhir/AdverseEventSupportingInfoComponent
 */
export declare const AdverseEventSupportingInfoComponent = "http://hl7.org/fhir/AdverseEventSupportingInfoComponent";
/**
 * _MedicationRequest
 *
 * (Modified) MedicationRequest
 *
 * http://hl7.org/fhir/_MedicationRequest
 */
export declare const _MedicationRequest = "http://hl7.org/fhir/_MedicationRequest";
/**
 * startingSequence
 *
 * MolecularSequence.relative.startingSequence: A sequence that is used as a starting sequence to describe variants that are present in a sequence analyzed.
 *
 * http://hl7.org/fhir/startingSequence
 */
export declare const startingSequence = "http://hl7.org/fhir/startingSequence";
/**
 * MedicationKnowledgeMonographComponent
 *
 * MedicationKnowledgeMonographComponent: Associated documentation about the medication.
 *
 * http://hl7.org/fhir/MedicationKnowledgeMonographComponent
 */
export declare const MedicationKnowledgeMonographComponent = "http://hl7.org/fhir/MedicationKnowledgeMonographComponent";
/**
 * DetectedIssue
 *
 * Indicates an actual or potential clinical issue with or between one or more active or proposed clinical actions for a patient; e.g. Drug-drug interaction, Ineffective treatment frequency, Procedure-condition conflict, gaps in care, etc.
 *
 * http://hl7.org/fhir/DetectedIssue
 */
export declare const DetectedIssue = "http://hl7.org/fhir/DetectedIssue";
/**
 * targetLocation
 *
 * VerificationResult.targetLocation: The fhirpath location(s) within the resource that was validated.
 *
 * http://hl7.org/fhir/targetLocation
 */
export declare const targetLocation = "http://hl7.org/fhir/targetLocation";
/**
 * MedicinalProductDefinitionCrossReferenceComponent
 *
 * MedicinalProductDefinitionCrossReferenceComponent: Reference to another product, e.g. for linking authorised to investigational product, or a virtual product.
 *
 * http://hl7.org/fhir/MedicinalProductDefinitionCrossReferenceComponent
 */
export declare const MedicinalProductDefinitionCrossReferenceComponent = "http://hl7.org/fhir/MedicinalProductDefinitionCrossReferenceComponent";
/**
 * _alternateMaterial
 *
 * (Modified) PackagedProductDefinition.packaging.packaging.alternateMaterial
 *
 * http://hl7.org/fhir/_alternateMaterial
 */
export declare const _alternateMaterial = "http://hl7.org/fhir/_alternateMaterial";
/**
 * _ordered
 *
 * (Modified) ElementDefinition.slicing.ordered
 *
 * http://hl7.org/fhir/_ordered
 */
export declare const _ordered = "http://hl7.org/fhir/_ordered";
/**
 * _List
 *
 * (Modified) List
 *
 * http://hl7.org/fhir/_List
 */
export declare const _List = "http://hl7.org/fhir/_List";
/**
 * _gateway
 *
 * (Modified) Device.gateway
 *
 * http://hl7.org/fhir/_gateway
 */
export declare const _gateway = "http://hl7.org/fhir/_gateway";
/**
 * _effect
 *
 * (Modified) ClinicalUseDefinition.interaction.effect
 *
 * http://hl7.org/fhir/_effect
 */
export declare const _effect = "http://hl7.org/fhir/_effect";
/**
 * _coordinate
 *
 * (Modified) ImagingSelection.instance.imageRegion3D.coordinate
 *
 * http://hl7.org/fhir/_coordinate
 */
export declare const _coordinate = "http://hl7.org/fhir/_coordinate";
/**
 * case
 *
 * RegulatedAuthorization.case: The case or regulatory procedure for granting or amending a regulated authorization. An authorization is granted in response to submissions/applications by those seeking authorization. A case is the administrative process that deals with the application(s) that relate to this and assesses them. Note: This area is subject to ongoing review and the workgroup is seeking implementer feedback on its use (see link at bottom of page).
 * Note that `case` is a reserved Javascript keyword, and is therefore suffixed by `__workaround`.
 * For a list of reserved keywords, see https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Lexical_grammar#Keywords.
 *
 * http://hl7.org/fhir/case
 */
export declare const case__workaround = "http://hl7.org/fhir/case";
/**
 * QuestionnaireItemComponentItem
 *
 * Text, questions and other groups to be nested beneath a question or group.
 *
 * http://hl7.org/fhir/QuestionnaireItemComponentItem
 */
export declare const QuestionnaireItemComponentItem = "http://hl7.org/fhir/QuestionnaireItemComponentItem";
/**
 * DeviceConformsToComponent
 *
 * DeviceConformsToComponent: Identifies the standards, specifications, or formal guidances for the capabilities supported by the device. The device may be certified as conformant to these specifications e.g., communication, performance, process, measurement, or specialization standards.
 *
 * http://hl7.org/fhir/DeviceConformsToComponent
 */
export declare const DeviceConformsToComponent = "http://hl7.org/fhir/DeviceConformsToComponent";
/**
 * PatientLinkComponent
 *
 * PatientLinkComponent: Link to a Patient or RelatedPerson resource that concerns the same actual individual.
 *
 * http://hl7.org/fhir/PatientLinkComponent
 */
export declare const PatientLinkComponent = "http://hl7.org/fhir/PatientLinkComponent";
/**
 * testData
 *
 * TestPlan.testCase.testData: The test data used in the test case.
 *
 * http://hl7.org/fhir/testData
 */
export declare const testData = "http://hl7.org/fhir/testData";
/**
 * ProcedureFocalDeviceComponent
 *
 * ProcedureFocalDeviceComponent: A device that is implanted, removed or otherwise manipulated (calibration, battery replacement, fitting a prosthesis, attaching a wound-vac, etc.) as a focal portion of the Procedure.
 *
 * http://hl7.org/fhir/ProcedureFocalDeviceComponent
 */
export declare const ProcedureFocalDeviceComponent = "http://hl7.org/fhir/ProcedureFocalDeviceComponent";
/**
 * _typeCanonical
 *
 * (Modified) RequestOrchestration.action.action.participant.typeCanonical
 *
 * http://hl7.org/fhir/_typeCanonical
 */
export declare const _typeCanonical = "http://hl7.org/fhir/_typeCanonical";
/**
 * nodeId
 *
 * GraphDefinition.node.nodeId: Internal ID of node - target for link references.
 *
 * http://hl7.org/fhir/nodeId
 */
export declare const nodeId = "http://hl7.org/fhir/nodeId";
/**
 * CapabilityStatementSoftwareComponent
 *
 * CapabilityStatementSoftwareComponent: Software that is covered by this capability statement.  It is used when the capability statement describes the capabilities of a particular software version, independent of an installation.
 *
 * http://hl7.org/fhir/CapabilityStatementSoftwareComponent
 */
export declare const CapabilityStatementSoftwareComponent = "http://hl7.org/fhir/CapabilityStatementSoftwareComponent";
/**
 * _preparation
 *
 * (Modified) SpecimenDefinition.typeTested.container.preparation
 *
 * http://hl7.org/fhir/_preparation
 */
export declare const _preparation = "http://hl7.org/fhir/_preparation";
/**
 * _subType
 *
 * (Modified) ExplanationOfBenefit.subType
 *
 * http://hl7.org/fhir/_subType
 */
export declare const _subType = "http://hl7.org/fhir/_subType";
/**
 * _definitionCodeableConcept
 *
 * (Modified) EvidenceVariable.characteristic.definitionByCombination.characteristic.definitionCodeableConcept
 *
 * http://hl7.org/fhir/_definitionCodeableConcept
 */
export declare const _definitionCodeableConcept = "http://hl7.org/fhir/_definitionCodeableConcept";
/**
 * benefitBalance
 *
 * ExplanationOfBenefit.benefitBalance: Balance by Benefit Category.
 *
 * http://hl7.org/fhir/benefitBalance
 */
export declare const benefitBalance = "http://hl7.org/fhir/benefitBalance";
/**
 * exclusionCriteria
 *
 * ValueSet.scope.exclusionCriteria: Criteria describing which concepts or codes should be excluded and why.
 *
 * http://hl7.org/fhir/exclusionCriteria
 */
export declare const exclusionCriteria = "http://hl7.org/fhir/exclusionCriteria";
/**
 * numberOfStudies
 *
 * Evidence.statistic.sampleSize.numberOfStudies: Number of participants in the population.
 *
 * http://hl7.org/fhir/numberOfStudies
 */
export declare const numberOfStudies = "http://hl7.org/fhir/numberOfStudies";
/**
 * start
 *
 * MolecularSequence.relative.edit.start: Start position of the edit on the starting sequence. If the coordinate system is either 0-based or 1-based, then start position is inclusive.
 *
 * http://hl7.org/fhir/start
 */
export declare const start = "http://hl7.org/fhir/start";
/**
 * AccountRelatedAccountComponent
 *
 * AccountRelatedAccountComponent: Other associated accounts related to this account.
 *
 * http://hl7.org/fhir/AccountRelatedAccountComponent
 */
export declare const AccountRelatedAccountComponent = "http://hl7.org/fhir/AccountRelatedAccountComponent";
/**
 * _OperationOutcome
 *
 * (Modified) OperationOutcome
 *
 * http://hl7.org/fhir/_OperationOutcome
 */
export declare const _OperationOutcome = "http://hl7.org/fhir/_OperationOutcome";
/**
 * orientation
 *
 * SubstancePolymer.repeat.repeatUnit.orientation: The orientation of the polymerisation, e.g. head-tail, head-head, random.
 *
 * http://hl7.org/fhir/orientation
 */
export declare const orientation = "http://hl7.org/fhir/orientation";
/**
 * holder
 *
 * RegulatedAuthorization.holder: The organization that has been granted this authorization, by some authoritative body (the 'regulator').
 *
 * http://hl7.org/fhir/holder
 */
export declare const holder = "http://hl7.org/fhir/holder";
/**
 * _mitigatingAction
 *
 * (Modified) AdverseEvent.mitigatingAction
 *
 * http://hl7.org/fhir/_mitigatingAction
 */
export declare const _mitigatingAction = "http://hl7.org/fhir/_mitigatingAction";
/**
 * include
 *
 * ValueSet.compose.include: Include one or more codes from a code system or other value set(s).
 *
 * http://hl7.org/fhir/include
 */
export declare const include = "http://hl7.org/fhir/include";
/**
 * _conditionalPatch
 *
 * (Modified) CapabilityStatement.rest.resource.conditionalPatch
 *
 * http://hl7.org/fhir/_conditionalPatch
 */
export declare const _conditionalPatch = "http://hl7.org/fhir/_conditionalPatch";
/**
 * NamingSystemUniqueIdComponent
 *
 * NamingSystemUniqueIdComponent: Indicates how the system may be identified when referenced in electronic exchange.
 *
 * http://hl7.org/fhir/NamingSystemUniqueIdComponent
 */
export declare const NamingSystemUniqueIdComponent = "http://hl7.org/fhir/NamingSystemUniqueIdComponent";
/**
 * _threshold
 *
 * (Modified) EvidenceVariable.characteristic.definitionByCombination.characteristic.definitionByCombination.threshold
 *
 * http://hl7.org/fhir/_threshold
 */
export declare const _threshold = "http://hl7.org/fhir/_threshold";
/**
 * Count
 *
 * A measured amount (or an amount that can potentially be measured). Note that measured amounts include amounts that are not precisely quantified, including amounts involving arbitrary units and floating currencies.
 *
 * http://hl7.org/fhir/Count
 */
export declare const Count = "http://hl7.org/fhir/Count";
/**
 * _instantiates
 *
 * (Modified) Observation.instantiates
 *
 * http://hl7.org/fhir/_instantiates
 */
export declare const _instantiates = "http://hl7.org/fhir/_instantiates";
/**
 * media
 *
 * DiagnosticReport.media: A list of key images or data associated with this report. The images or data are generally created during the diagnostic process, and may be directly of the patient, or of treated specimens (i.e. slides of interest).
 *
 * http://hl7.org/fhir/media
 */
export declare const media = "http://hl7.org/fhir/media";
/**
 * appliesTo
 *
 * Observation.component.referenceRange.appliesTo: Codes to indicate the target population this reference range applies to.  For example, a reference range may be based on the normal population or a particular sex or race.  Multiple `appliesTo`  are interpreted as an "AND" of the target populations.  For example, to represent a target population of African American females, both a code of female and a code for African American would be used.
 *
 * http://hl7.org/fhir/appliesTo
 */
export declare const appliesTo = "http://hl7.org/fhir/appliesTo";
/**
 * _implementationGuide
 *
 * (Modified) CapabilityStatement.implementationGuide
 *
 * http://hl7.org/fhir/_implementationGuide
 */
export declare const _implementationGuide = "http://hl7.org/fhir/_implementationGuide";
/**
 * RequestOrchestrationActionInputComponent
 *
 * RequestOrchestrationActionComponentAction.RequestOrchestrationActionInputComponent: Defines input data requirements for the action.
 *
 * http://hl7.org/fhir/RequestOrchestrationActionInputComponent
 */
export declare const RequestOrchestrationActionInputComponent = "http://hl7.org/fhir/RequestOrchestrationActionInputComponent";
/**
 * _discriminator
 *
 * (Modified) ElementDefinition.slicing.discriminator
 *
 * http://hl7.org/fhir/_discriminator
 */
export declare const _discriminator = "http://hl7.org/fhir/_discriminator";
/**
 * ClaimResponse
 *
 * This resource provides the adjudication details from the processing of a Claim resource.
 *
 * http://hl7.org/fhir/ClaimResponse
 */
export declare const ClaimResponse = "http://hl7.org/fhir/ClaimResponse";
/**
 * section
 *
 * EvidenceReport.section.section.section: A nested sub-section within this section.
 *
 * http://hl7.org/fhir/section
 */
export declare const section = "http://hl7.org/fhir/section";
/**
 * _workflowStatus
 *
 * (Modified) ArtifactAssessment.workflowStatus
 *
 * http://hl7.org/fhir/_workflowStatus
 */
export declare const _workflowStatus = "http://hl7.org/fhir/_workflowStatus";
/**
 * _DeviceMetric
 *
 * (Modified) DeviceMetric
 *
 * http://hl7.org/fhir/_DeviceMetric
 */
export declare const _DeviceMetric = "http://hl7.org/fhir/_DeviceMetric";
/**
 * diseaseSymptomProcedure
 *
 * ClinicalUseDefinition.indication.diseaseSymptomProcedure: The situation that is being documented as an indicaton for this item.
 *
 * http://hl7.org/fhir/diseaseSymptomProcedure
 */
export declare const diseaseSymptomProcedure = "http://hl7.org/fhir/diseaseSymptomProcedure";
/**
 * _keyword
 *
 * (Modified) StructureDefinition.keyword
 *
 * http://hl7.org/fhir/_keyword
 */
export declare const _keyword = "http://hl7.org/fhir/_keyword";
/**
 * _forecastStatus
 *
 * (Modified) ImmunizationRecommendation.recommendation.forecastStatus
 *
 * http://hl7.org/fhir/_forecastStatus
 */
export declare const _forecastStatus = "http://hl7.org/fhir/_forecastStatus";
/**
 * Bundle
 *
 * A container for a collection of resources.
 *
 * http://hl7.org/fhir/Bundle
 */
export declare const Bundle = "http://hl7.org/fhir/Bundle";
/**
 * _excluded
 *
 * (Modified) ExplanationOfBenefit.benefitBalance.excluded
 *
 * http://hl7.org/fhir/_excluded
 */
export declare const _excluded = "http://hl7.org/fhir/_excluded";
/**
 * _transform
 *
 * (Modified) StructureMap.group.rule.rule.target.transform
 *
 * http://hl7.org/fhir/_transform
 */
export declare const _transform = "http://hl7.org/fhir/_transform";
/**
 * intent
 *
 * CarePlan.intent: Indicates the level of authority/intentionality associated with the care plan and where the care plan fits into the workflow chain.
 *
 * http://hl7.org/fhir/intent
 */
export declare const intent = "http://hl7.org/fhir/intent";
/**
 * _slicing
 *
 * (Modified) ElementDefinition.slicing
 *
 * http://hl7.org/fhir/_slicing
 */
export declare const _slicing = "http://hl7.org/fhir/_slicing";
/**
 * generalPractitioner
 *
 * Patient.generalPractitioner: Patient's nominated care provider.
 *
 * http://hl7.org/fhir/generalPractitioner
 */
export declare const generalPractitioner = "http://hl7.org/fhir/generalPractitioner";
/**
 * gestationalAge
 *
 * ObservationDefinition.component.qualifiedValue.gestationalAge: The gestational age this  set of qualified values applies to.
 *
 * http://hl7.org/fhir/gestationalAge
 */
export declare const gestationalAge = "http://hl7.org/fhir/gestationalAge";
/**
 * _account
 *
 * (Modified) PaymentReconciliation.allocation.account
 *
 * http://hl7.org/fhir/_account
 */
export declare const _account = "http://hl7.org/fhir/_account";
/**
 * _administeredProduct
 *
 * (Modified) Immunization.administeredProduct
 *
 * http://hl7.org/fhir/_administeredProduct
 */
export declare const _administeredProduct = "http://hl7.org/fhir/_administeredProduct";
/**
 * answerOption
 *
 * Questionnaire.item.item.answerOption: One of the permitted answers for the question.
 *
 * http://hl7.org/fhir/answerOption
 */
export declare const answerOption = "http://hl7.org/fhir/answerOption";
/**
 * regionType
 *
 * ImagingSelection.instance.imageRegion3D.regionType: Specifies the type of image region.
 *
 * http://hl7.org/fhir/regionType
 */
export declare const regionType = "http://hl7.org/fhir/regionType";
/**
 * _association
 *
 * (Modified) InventoryItem.association
 *
 * http://hl7.org/fhir/_association
 */
export declare const _association = "http://hl7.org/fhir/_association";
/**
 * _messaging
 *
 * (Modified) CapabilityStatement.messaging
 *
 * http://hl7.org/fhir/_messaging
 */
export declare const _messaging = "http://hl7.org/fhir/_messaging";
/**
 * organismType
 *
 * SubstanceReferenceInformation.target.organismType: Todo.
 *
 * http://hl7.org/fhir/organismType
 */
export declare const organismType = "http://hl7.org/fhir/organismType";
/**
 * accept
 *
 * TestScript.teardown.action.operation.accept: The mime-type to use for RESTful operation in the 'Accept' header.
 *
 * http://hl7.org/fhir/accept
 */
export declare const accept = "http://hl7.org/fhir/accept";
/**
 * _methodType
 *
 * (Modified) GenomicStudy.analysis.methodType
 *
 * http://hl7.org/fhir/_methodType
 */
export declare const _methodType = "http://hl7.org/fhir/_methodType";
/**
 * _authorizationRequired
 *
 * (Modified) CoverageEligibilityResponse.insurance.item.authorizationRequired
 *
 * http://hl7.org/fhir/_authorizationRequired
 */
export declare const _authorizationRequired = "http://hl7.org/fhir/_authorizationRequired";
/**
 * includedStructure
 *
 * BodyStructure.includedStructure: The anatomical location(s) or region(s) of the specimen, lesion, or body structure.
 *
 * http://hl7.org/fhir/includedStructure
 */
export declare const includedStructure = "http://hl7.org/fhir/includedStructure";
/**
 * sourceIdentityCertificate
 *
 * VerificationResult.attestation.sourceIdentityCertificate: A digital identity certificate associated with the attestation source.
 *
 * http://hl7.org/fhir/sourceIdentityCertificate
 */
export declare const sourceIdentityCertificate = "http://hl7.org/fhir/sourceIdentityCertificate";
/**
 * foodType
 *
 * NutritionOrder.oralDiet.texture.foodType: The food type(s) (e.g. meats, all foods)  that the texture modification applies to.  This could be all foods types.
 *
 * http://hl7.org/fhir/foodType
 */
export declare const foodType = "http://hl7.org/fhir/foodType";
/**
 * temperatureRange
 *
 * SpecimenDefinition.typeTested.handling.temperatureRange: The temperature interval for this set of handling instructions.
 *
 * http://hl7.org/fhir/temperatureRange
 */
export declare const temperatureRange = "http://hl7.org/fhir/temperatureRange";
/**
 * ManifestPage
 *
 * ImplementationGuideManifestComponent.ManifestPage: Information about a page within the IG.
 *
 * http://hl7.org/fhir/ManifestPage
 */
export declare const ManifestPage = "http://hl7.org/fhir/ManifestPage";
/**
 * DeviceRequest
 *
 * Represents a request a device to be provided to a specific patient. The device may be an implantable device to be subsequently implanted, or an external assistive device, such as a walker, to be delivered and subsequently be used.
 *
 * http://hl7.org/fhir/DeviceRequest
 */
export declare const DeviceRequest = "http://hl7.org/fhir/DeviceRequest";
/**
 * _contextLinkId
 *
 * (Modified) Contract.term.group.action.contextLinkId
 *
 * http://hl7.org/fhir/_contextLinkId
 */
export declare const _contextLinkId = "http://hl7.org/fhir/_contextLinkId";
/**
 * ExampleScenarioProcessStepOperationComponent
 *
 * ExampleScenarioProcessComponent.ExampleScenarioProcessStepComponent.ExampleScenarioProcessStepOperationComponent: The step represents a single operation invoked on receiver by sender.
 *
 * http://hl7.org/fhir/ExampleScenarioProcessStepOperationComponent
 */
export declare const ExampleScenarioProcessStepOperationComponent = "http://hl7.org/fhir/ExampleScenarioProcessStepOperationComponent";
/**
 * SubstanceDefinitionStructureComponent
 *
 * SubstanceDefinitionStructureComponent: Structural information.
 *
 * http://hl7.org/fhir/SubstanceDefinitionStructureComponent
 */
export declare const SubstanceDefinitionStructureComponent = "http://hl7.org/fhir/SubstanceDefinitionStructureComponent";
/**
 * calculatedAt
 *
 * Account.calculatedAt: Time the balance amount was calculated.
 *
 * http://hl7.org/fhir/calculatedAt
 */
export declare const calculatedAt = "http://hl7.org/fhir/calculatedAt";
/**
 * MarketingStatus
 *
 * The marketing status describes the date when a medicinal product is actually put on the market or the date as of which it is no longer available.
 *
 * http://hl7.org/fhir/MarketingStatus
 */
export declare const MarketingStatus = "http://hl7.org/fhir/MarketingStatus";
/**
 * _emptyReason
 *
 * (Modified) List.emptyReason
 *
 * http://hl7.org/fhir/_emptyReason
 */
export declare const _emptyReason = "http://hl7.org/fhir/_emptyReason";
/**
 * _offsets
 *
 * (Modified) SampledData.offsets
 *
 * http://hl7.org/fhir/_offsets
 */
export declare const _offsets = "http://hl7.org/fhir/_offsets";
/**
 * _financial
 *
 * (Modified) ExplanationOfBenefit.benefitBalance.financial
 *
 * http://hl7.org/fhir/_financial
 */
export declare const _financial = "http://hl7.org/fhir/_financial";
/**
 * _exposureRoute
 *
 * (Modified) AllergyIntolerance.reaction.exposureRoute
 *
 * http://hl7.org/fhir/_exposureRoute
 */
export declare const _exposureRoute = "http://hl7.org/fhir/_exposureRoute";
/**
 * _policyHolder
 *
 * (Modified) Coverage.policyHolder
 *
 * http://hl7.org/fhir/_policyHolder
 */
export declare const _policyHolder = "http://hl7.org/fhir/_policyHolder";
/**
 * SupplyDeliverySuppliedItemComponent
 *
 * SupplyDeliverySuppliedItemComponent: The item that is being delivered or has been supplied.
 *
 * http://hl7.org/fhir/SupplyDeliverySuppliedItemComponent
 */
export declare const SupplyDeliverySuppliedItemComponent = "http://hl7.org/fhir/SupplyDeliverySuppliedItemComponent";
/**
 * intendedRoute
 *
 * MedicationKnowledge.definitional.intendedRoute: The intended or approved route of administration.
 *
 * http://hl7.org/fhir/intendedRoute
 */
export declare const intendedRoute = "http://hl7.org/fhir/intendedRoute";
/**
 * _paymentDate
 *
 * (Modified) PaymentNotice.paymentDate
 *
 * http://hl7.org/fhir/_paymentDate
 */
export declare const _paymentDate = "http://hl7.org/fhir/_paymentDate";
/**
 * GenomicStudyAnalysisDeviceComponent
 *
 * GenomicStudyAnalysisComponent.GenomicStudyAnalysisDeviceComponent: Devices used for the analysis (e.g., instruments, software), with settings and parameters.
 *
 * http://hl7.org/fhir/GenomicStudyAnalysisDeviceComponent
 */
export declare const GenomicStudyAnalysisDeviceComponent = "http://hl7.org/fhir/GenomicStudyAnalysisDeviceComponent";
/**
 * _informationProvider
 *
 * (Modified) CommunicationRequest.informationProvider
 *
 * http://hl7.org/fhir/_informationProvider
 */
export declare const _informationProvider = "http://hl7.org/fhir/_informationProvider";
/**
 * _outsideFoodAllowed
 *
 * (Modified) NutritionOrder.outsideFoodAllowed
 *
 * http://hl7.org/fhir/_outsideFoodAllowed
 */
export declare const _outsideFoodAllowed = "http://hl7.org/fhir/_outsideFoodAllowed";
/**
 * feature
 *
 * Specimen.feature: A physical feature or landmark on a specimen, highlighted for context by the collector of the specimen (e.g. surgeon), that identifies the type of feature as well as its meaning (e.g. the red ink indicating the resection margin of the right lobe of the excised prostate tissue or wire loop at radiologically suspected tumor location).
 *
 * http://hl7.org/fhir/feature
 */
export declare const feature = "http://hl7.org/fhir/feature";
/**
 * needsMap
 *
 * TerminologyCapabilities.translation.needsMap: Whether the client must identify the map.
 *
 * http://hl7.org/fhir/needsMap
 */
export declare const needsMap = "http://hl7.org/fhir/needsMap";
/**
 * _dataAbsentReason
 *
 * (Modified) Observation.component.dataAbsentReason
 *
 * http://hl7.org/fhir/_dataAbsentReason
 */
export declare const _dataAbsentReason = "http://hl7.org/fhir/_dataAbsentReason";
/**
 * _definition
 *
 * (Modified) CapabilityStatement.messaging.supportedMessage.definition
 *
 * http://hl7.org/fhir/_definition
 */
export declare const _definition = "http://hl7.org/fhir/_definition";
/**
 * creation
 *
 * Invoice.creation: Date/time(s) of when this Invoice was posted.
 *
 * http://hl7.org/fhir/creation
 */
export declare const creation = "http://hl7.org/fhir/creation";
/**
 * _minValue
 *
 * (Modified) ElementDefinition.minValue
 *
 * http://hl7.org/fhir/_minValue
 */
export declare const _minValue = "http://hl7.org/fhir/_minValue";
/**
 * width
 *
 * Attachment.width: Width of the image in pixels (photo/video).
 *
 * http://hl7.org/fhir/width
 */
export declare const width = "http://hl7.org/fhir/width";
/**
 * _Permission
 *
 * (Modified) Permission
 *
 * http://hl7.org/fhir/_Permission
 */
export declare const _Permission = "http://hl7.org/fhir/_Permission";
/**
 * AllergyIntolerance
 *
 * Risk of harmful or undesirable, physiological response which is unique to an individual and associated with exposure to a substance.
 *
 * http://hl7.org/fhir/AllergyIntolerance
 */
export declare const AllergyIntolerance = "http://hl7.org/fhir/AllergyIntolerance";
/**
 * _Encounter
 *
 * (Modified) Encounter
 *
 * http://hl7.org/fhir/_Encounter
 */
export declare const _Encounter = "http://hl7.org/fhir/_Encounter";
/**
 * targetNumber
 *
 * ResearchStudy.recruitment.targetNumber: Estimated total number of participants to be enrolled.
 *
 * http://hl7.org/fhir/targetNumber
 */
export declare const targetNumber = "http://hl7.org/fhir/targetNumber";
/**
 * severity
 *
 * AllergyIntolerance.reaction.severity: Clinical assessment of the severity of the reaction event as a whole, potentially considering multiple different manifestations.
 *
 * http://hl7.org/fhir/severity
 */
export declare const severity = "http://hl7.org/fhir/severity";
/**
 * ObservationDefinitionQualifiedValueComponent
 *
 * ObservationDefinitionQualifiedValueComponent: A set of qualified values associated with a context and a set of conditions -  provides a range for quantitative and ordinal observations and a collection of value sets for qualitative observations.
 *
 * http://hl7.org/fhir/ObservationDefinitionQualifiedValueComponent
 */
export declare const ObservationDefinitionQualifiedValueComponent = "http://hl7.org/fhir/ObservationDefinitionQualifiedValueComponent";
/**
 * filterBy
 *
 * Subscription.filterBy: The filter properties to be applied to narrow the subscription topic stream.  When multiple filters are applied, evaluates to true if all the conditions applicable to that resource are met; otherwise it returns false (i.e., logical AND).
 *
 * http://hl7.org/fhir/filterBy
 */
export declare const filterBy = "http://hl7.org/fhir/filterBy";
/**
 * packaging
 *
 * PackagedProductDefinition.packaging.packaging: Allows containers (and parts of containers) within containers, still as a part of a single packaged product. See also PackagedProductDefinition.packaging.containedItem.item(PackagedProductDefinition).
 *
 * http://hl7.org/fhir/packaging
 */
export declare const packaging = "http://hl7.org/fhir/packaging";
/**
 * endorser
 *
 * Citation.endorser: Who endorsed the citation record.
 *
 * http://hl7.org/fhir/endorser
 */
export declare const endorser = "http://hl7.org/fhir/endorser";
/**
 * _relatesTo
 *
 * (Modified) EvidenceReport.relatesTo
 *
 * http://hl7.org/fhir/_relatesTo
 */
export declare const _relatesTo = "http://hl7.org/fhir/_relatesTo";
/**
 * _sourceSignature
 *
 * (Modified) VerificationResult.attestation.sourceSignature
 *
 * http://hl7.org/fhir/_sourceSignature
 */
export declare const _sourceSignature = "http://hl7.org/fhir/_sourceSignature";
/**
 * abnormalCodedValueSet
 *
 * ObservationDefinition.component.qualifiedValue.abnormalCodedValueSet: The set of abnormal coded results for qualitative observations  that match the criteria of this set of qualified values.
 *
 * http://hl7.org/fhir/abnormalCodedValueSet
 */
export declare const abnormalCodedValueSet = "http://hl7.org/fhir/abnormalCodedValueSet";
/**
 * lastOccurrenceDate
 *
 * Appointment.recurrenceTemplate.lastOccurrenceDate: Recurring appointments will not occur after this date.
 *
 * http://hl7.org/fhir/lastOccurrenceDate
 */
export declare const lastOccurrenceDate = "http://hl7.org/fhir/lastOccurrenceDate";
/**
 * _securityLabelNumber
 *
 * (Modified) Contract.term.asset.valuedItem.securityLabelNumber
 *
 * http://hl7.org/fhir/_securityLabelNumber
 */
export declare const _securityLabelNumber = "http://hl7.org/fhir/_securityLabelNumber";
/**
 * _queryCriteria
 *
 * (Modified) SubscriptionTopic.resourceTrigger.queryCriteria
 *
 * http://hl7.org/fhir/_queryCriteria
 */
export declare const _queryCriteria = "http://hl7.org/fhir/_queryCriteria";
/**
 * _multipleResultsAllowed
 *
 * (Modified) ObservationDefinition.multipleResultsAllowed
 *
 * http://hl7.org/fhir/_multipleResultsAllowed
 */
export declare const _multipleResultsAllowed = "http://hl7.org/fhir/_multipleResultsAllowed";
/**
 * _allowed
 *
 * (Modified) MedicationRequest.substitution.allowed
 *
 * http://hl7.org/fhir/_allowed
 */
export declare const _allowed = "http://hl7.org/fhir/_allowed";
/**
 * _TestReport
 *
 * (Modified) TestReport
 *
 * http://hl7.org/fhir/_TestReport
 */
export declare const _TestReport = "http://hl7.org/fhir/_TestReport";
/**
 * _Location
 *
 * (Modified) Location
 *
 * http://hl7.org/fhir/_Location
 */
export declare const _Location = "http://hl7.org/fhir/_Location";
/**
 * deviceName
 *
 * DeviceDefinition.deviceName: The name or names of the device as given by the manufacturer.
 *
 * http://hl7.org/fhir/deviceName
 */
export declare const deviceName = "http://hl7.org/fhir/deviceName";
/**
 * ImmunizationReactionComponent
 *
 * ImmunizationReactionComponent: Categorical data indicating that an adverse event is associated in time to an immunization.
 *
 * http://hl7.org/fhir/ImmunizationReactionComponent
 */
export declare const ImmunizationReactionComponent = "http://hl7.org/fhir/ImmunizationReactionComponent";
/**
 * ConceptMap
 *
 * A statement of relationships from one set of concepts to one or more other concepts - either concepts in code systems, or data element/data element concepts, or classes in class models.
 *
 * http://hl7.org/fhir/ConceptMap
 */
export declare const ConceptMap = "http://hl7.org/fhir/ConceptMap";
/**
 * _daysOfWeek
 *
 * (Modified) Availability.availableTime.daysOfWeek
 *
 * http://hl7.org/fhir/_daysOfWeek
 */
export declare const _daysOfWeek = "http://hl7.org/fhir/_daysOfWeek";
/**
 * ParameterDefinition
 *
 * The parameters to the module. This collection specifies both the input and output parameters. Input parameters are provided by the caller as part of the $evaluate operation. Output parameters are included in the GuidanceResponse.
 *
 * http://hl7.org/fhir/ParameterDefinition
 */
export declare const ParameterDefinition = "http://hl7.org/fhir/ParameterDefinition";
/**
 * _packageCode
 *
 * (Modified) Account.procedure.packageCode
 *
 * http://hl7.org/fhir/_packageCode
 */
export declare const _packageCode = "http://hl7.org/fhir/_packageCode";
/**
 * Insurance
 *
 * ExplanationOfBenefit.Insurance: Financial instruments for reimbursement for the health care products and services specified on the claim.
 *
 * http://hl7.org/fhir/Insurance
 */
export declare const Insurance = "http://hl7.org/fhir/Insurance";
/**
 * lastPerformed
 *
 * VerificationResult.lastPerformed: The date/time validation was last completed (including failed validations).
 *
 * http://hl7.org/fhir/lastPerformed
 */
export declare const lastPerformed = "http://hl7.org/fhir/lastPerformed";
/**
 * IngredientManufacturerComponent
 *
 * IngredientManufacturerComponent: The organization(s) that manufacture this ingredient. Can be used to indicate:         1) Organizations we are aware of that manufacture this ingredient         2) Specific Manufacturer(s) currently being used         3) Set of organisations allowed to manufacture this ingredient for this product         Users must be clear on the application of context relevant to their use case.
 *
 * http://hl7.org/fhir/IngredientManufacturerComponent
 */
export declare const IngredientManufacturerComponent = "http://hl7.org/fhir/IngredientManufacturerComponent";
/**
 * nthWeekOfMonth
 *
 * Appointment.recurrenceTemplate.monthlyTemplate.nthWeekOfMonth: Indicates which week within a month the appointments in the series of recurring appointments should occur on.
 *
 * http://hl7.org/fhir/nthWeekOfMonth
 */
export declare const nthWeekOfMonth = "http://hl7.org/fhir/nthWeekOfMonth";
/**
 * targetSpecies
 *
 * AdministrableProductDefinition.routeOfAdministration.targetSpecies: A species for which this route applies.
 *
 * http://hl7.org/fhir/targetSpecies
 */
export declare const targetSpecies = "http://hl7.org/fhir/targetSpecies";
/**
 * authorization
 *
 * AuditEvent.entity.agent.authorization: The authorization (e.g., PurposeOfUse) that was used during the event being recorded.
 *
 * http://hl7.org/fhir/authorization
 */
export declare const authorization = "http://hl7.org/fhir/authorization";
/**
 * _RequestOrchestration
 *
 * (Modified) RequestOrchestration
 *
 * http://hl7.org/fhir/_RequestOrchestration
 */
export declare const _RequestOrchestration = "http://hl7.org/fhir/_RequestOrchestration";
/**
 * _endpoint
 *
 * (Modified) CapabilityStatement.messaging.endpoint
 *
 * http://hl7.org/fhir/_endpoint
 */
export declare const _endpoint = "http://hl7.org/fhir/_endpoint";
/**
 * triggeredBy
 *
 * Observation.triggeredBy: Identifies the observation(s) that triggered the performance of this observation.
 *
 * http://hl7.org/fhir/triggeredBy
 */
export declare const triggeredBy = "http://hl7.org/fhir/triggeredBy";
/**
 * _Dosage
 *
 * (Modified) Dosage
 *
 * http://hl7.org/fhir/_Dosage
 */
export declare const _Dosage = "http://hl7.org/fhir/_Dosage";
/**
 * _doNotPerform
 *
 * (Modified) Contract.term.group.action.doNotPerform
 *
 * http://hl7.org/fhir/_doNotPerform
 */
export declare const _doNotPerform = "http://hl7.org/fhir/_doNotPerform";
/**
 * careTeam
 *
 * ExplanationOfBenefit.careTeam: The members of the team who provided the products and services.
 *
 * http://hl7.org/fhir/careTeam
 */
export declare const careTeam = "http://hl7.org/fhir/careTeam";
/**
 * _meta
 *
 * (Modified) Resource.meta
 *
 * http://hl7.org/fhir/_meta
 */
export declare const _meta = "http://hl7.org/fhir/_meta";
/**
 * TerminologyCapabilitiesCodeSystemVersionComponent
 *
 * TerminologyCapabilitiesCodeSystemComponent.TerminologyCapabilitiesCodeSystemVersionComponent: For the code system, a list of versions that are supported by the server.
 *
 * http://hl7.org/fhir/TerminologyCapabilitiesCodeSystemVersionComponent
 */
export declare const TerminologyCapabilitiesCodeSystemVersionComponent = "http://hl7.org/fhir/TerminologyCapabilitiesCodeSystemVersionComponent";
/**
 * entryQuantity
 *
 * EvidenceReport.section.section.entryQuantity: Quantity as content.
 *
 * http://hl7.org/fhir/entryQuantity
 */
export declare const entryQuantity = "http://hl7.org/fhir/entryQuantity";
/**
 * CapabilityStatementMessagingEndpointComponent
 *
 * CapabilityStatementMessagingComponent.CapabilityStatementMessagingEndpointComponent: An endpoint (network accessible address) to which messages and/or replies are to be sent.
 *
 * http://hl7.org/fhir/CapabilityStatementMessagingEndpointComponent
 */
export declare const CapabilityStatementMessagingEndpointComponent = "http://hl7.org/fhir/CapabilityStatementMessagingEndpointComponent";
/**
 * nTerminalModification
 *
 * SubstanceProtein.subunit.nTerminalModification: The name of the fragment modified at the N-terminal of the SubstanceProtein shall be specified.
 *
 * http://hl7.org/fhir/nTerminalModification
 */
export declare const nTerminalModification = "http://hl7.org/fhir/nTerminalModification";
/**
 * _asNeededFor
 *
 * (Modified) NutritionOrder.enteralFormula.administration.schedule.asNeededFor
 *
 * http://hl7.org/fhir/_asNeededFor
 */
export declare const _asNeededFor = "http://hl7.org/fhir/_asNeededFor";
/**
 * _link
 *
 * (Modified) Bundle.link
 *
 * http://hl7.org/fhir/_link
 */
export declare const _link = "http://hl7.org/fhir/_link";
/**
 * attribute
 *
 * ConceptMap.group.element.target.product.attribute: A reference to the additional attribute that holds a value the map depends on.
 *
 * http://hl7.org/fhir/attribute
 */
export declare const attribute = "http://hl7.org/fhir/attribute";
/**
 * Note
 *
 * ExplanationOfBenefit.Note: A note that describes or explains adjudication results in a human readable form.
 *
 * http://hl7.org/fhir/Note
 */
export declare const Note = "http://hl7.org/fhir/Note";
/**
 * textFilter
 *
 * TerminologyCapabilities.expansion.textFilter: Documentation about text searching works.
 *
 * http://hl7.org/fhir/textFilter
 */
export declare const textFilter = "http://hl7.org/fhir/textFilter";
/**
 * disposition
 *
 * ExplanationOfBenefit.disposition: A human readable description of the status of the adjudication.
 *
 * http://hl7.org/fhir/disposition
 */
export declare const disposition = "http://hl7.org/fhir/disposition";
/**
 * PackagedProductDefinition
 *
 * A medically related item or items, in a container or package.
 *
 * http://hl7.org/fhir/PackagedProductDefinition
 */
export declare const PackagedProductDefinition = "http://hl7.org/fhir/PackagedProductDefinition";
/**
 * Accident
 *
 * ExplanationOfBenefit.Accident: Details of a accident which resulted in injuries which required the products and services listed in the claim.
 *
 * http://hl7.org/fhir/Accident
 */
export declare const Accident = "http://hl7.org/fhir/Accident";
/**
 * _reference
 *
 * (Modified) Consent.provision.provision.data.reference
 *
 * http://hl7.org/fhir/_reference
 */
export declare const _reference = "http://hl7.org/fhir/_reference";
/**
 * StructureMapGroupRuleTargetParameterComponent
 *
 * StructureMapGroupComponent.StructureMapGroupRuleComponentRule.StructureMapGroupRuleTargetComponent.StructureMapGroupRuleTargetParameterComponent: Parameters to the transform.
 *
 * http://hl7.org/fhir/StructureMapGroupRuleTargetParameterComponent
 */
export declare const StructureMapGroupRuleTargetParameterComponent = "http://hl7.org/fhir/StructureMapGroupRuleTargetParameterComponent";
/**
 * subscriber
 *
 * Coverage.subscriber: The party who has signed-up for or 'owns' the contractual relationship to the policy or to whom the benefit of the policy for services rendered to them or their family is due.
 *
 * http://hl7.org/fhir/subscriber
 */
export declare const subscriber = "http://hl7.org/fhir/subscriber";
/**
 * structureType
 *
 * ExampleScenario.instance.structureType: A code indicating the kind of data structure (FHIR resource or some other standard) this is an instance of.
 *
 * http://hl7.org/fhir/structureType
 */
export declare const structureType = "http://hl7.org/fhir/structureType";
/**
 * _detail
 *
 * (Modified) TestReport.setup.action.operation.detail
 *
 * http://hl7.org/fhir/_detail
 */
export declare const _detail = "http://hl7.org/fhir/_detail";
/**
 * meaningWhenMissing
 *
 * ElementDefinition.meaningWhenMissing: The Implicit meaning that is to be understood when this element is missing (e.g. 'when this element is missing, the period is ongoing').
 *
 * http://hl7.org/fhir/meaningWhenMissing
 */
export declare const meaningWhenMissing = "http://hl7.org/fhir/meaningWhenMissing";
/**
 * modelCharacteristic
 *
 * Evidence.statistic.modelCharacteristic: A component of the method to generate the statistic.
 *
 * http://hl7.org/fhir/modelCharacteristic
 */
export declare const modelCharacteristic = "http://hl7.org/fhir/modelCharacteristic";
/**
 * mapping
 *
 * StructureDefinition.mapping: An external specification that the content is mapped to.
 *
 * http://hl7.org/fhir/mapping
 */
export declare const mapping = "http://hl7.org/fhir/mapping";
/**
 * _Person
 *
 * (Modified) Person
 *
 * http://hl7.org/fhir/_Person
 */
export declare const _Person = "http://hl7.org/fhir/_Person";
/**
 * _eligibility
 *
 * (Modified) ResearchStudy.recruitment.eligibility
 *
 * http://hl7.org/fhir/_eligibility
 */
export declare const _eligibility = "http://hl7.org/fhir/_eligibility";
/**
 * SubstanceSourceMaterialFractionDescriptionComponent
 *
 * SubstanceSourceMaterialFractionDescriptionComponent: Many complex materials are fractions of parts of plants, animals, or minerals. Fraction elements are often necessary to define both Substances and Specified Group 1 Substances. For substances derived from Plants, fraction information will be captured at the Substance information level ( . Oils, Juices and Exudates). Additional information for Extracts, such as extraction solvent composition, will be captured at the Specified Substance Group 1 information level. For plasma-derived products fraction information will be captured at the Substance and the Specified Substance Group 1 levels.
 *
 * http://hl7.org/fhir/SubstanceSourceMaterialFractionDescriptionComponent
 */
export declare const SubstanceSourceMaterialFractionDescriptionComponent = "http://hl7.org/fhir/SubstanceSourceMaterialFractionDescriptionComponent";
/**
 * typeCollected
 *
 * SpecimenDefinition.typeCollected: The kind of material to be collected.
 *
 * http://hl7.org/fhir/typeCollected
 */
export declare const typeCollected = "http://hl7.org/fhir/typeCollected";
/**
 * timestamp
 *
 * ValueSet.expansion.timestamp: The time at which the expansion was produced by the expanding system.
 *
 * http://hl7.org/fhir/timestamp
 */
export declare const timestamp = "http://hl7.org/fhir/timestamp";
/**
 * _subpotentReason
 *
 * (Modified) Immunization.subpotentReason
 *
 * http://hl7.org/fhir/_subpotentReason
 */
export declare const _subpotentReason = "http://hl7.org/fhir/_subpotentReason";
/**
 * _relatedMedicationKnowledge
 *
 * (Modified) MedicationKnowledge.relatedMedicationKnowledge
 *
 * http://hl7.org/fhir/_relatedMedicationKnowledge
 */
export declare const _relatedMedicationKnowledge = "http://hl7.org/fhir/_relatedMedicationKnowledge";
/**
 * _inventoryStatus
 *
 * (Modified) InventoryItem.inventoryStatus
 *
 * http://hl7.org/fhir/_inventoryStatus
 */
export declare const _inventoryStatus = "http://hl7.org/fhir/_inventoryStatus";
/**
 * synonym
 *
 * SubstanceDefinition.name.translation.synonym: A synonym of this particular name, by which the substance is also known.
 *
 * http://hl7.org/fhir/synonym
 */
export declare const synonym = "http://hl7.org/fhir/synonym";
/**
 * _category
 *
 * (Modified) DeviceDefinition.conformsTo.category
 *
 * http://hl7.org/fhir/_category
 */
export declare const _category = "http://hl7.org/fhir/_category";
/**
 * _regulatory
 *
 * (Modified) MedicationKnowledge.regulatory
 *
 * http://hl7.org/fhir/_regulatory
 */
export declare const _regulatory = "http://hl7.org/fhir/_regulatory";
/**
 * birthDate
 *
 * Practitioner.birthDate: The date of birth for the practitioner.
 *
 * http://hl7.org/fhir/birthDate
 */
export declare const birthDate = "http://hl7.org/fhir/birthDate";
/**
 * _priorPrescription
 *
 * (Modified) MedicationRequest.priorPrescription
 *
 * http://hl7.org/fhir/_priorPrescription
 */
export declare const _priorPrescription = "http://hl7.org/fhir/_priorPrescription";
/**
 * Base
 *
 * Base definition for all types defined in FHIR type system.
 *
 * http://hl7.org/fhir/Base
 */
export declare const Base = "http://hl7.org/fhir/Base";
/**
 * _testTools
 *
 * (Modified) TestPlan.testTools
 *
 * http://hl7.org/fhir/_testTools
 */
export declare const _testTools = "http://hl7.org/fhir/_testTools";
/**
 * _targetLocation
 *
 * (Modified) VerificationResult.targetLocation
 *
 * http://hl7.org/fhir/_targetLocation
 */
export declare const _targetLocation = "http://hl7.org/fhir/_targetLocation";
/**
 * substanceDefinition
 *
 * SubstanceDefinition.relationship.substanceDefinition
 *
 * http://hl7.org/fhir/substanceDefinition
 */
export declare const substanceDefinition = "http://hl7.org/fhir/substanceDefinition";
/**
 * _medication
 *
 * (Modified) MedicationStatement.medication
 *
 * http://hl7.org/fhir/_medication
 */
export declare const _medication = "http://hl7.org/fhir/_medication";
/**
 * _vaccineCode
 *
 * (Modified) ImmunizationRecommendation.recommendation.vaccineCode
 *
 * http://hl7.org/fhir/_vaccineCode
 */
export declare const _vaccineCode = "http://hl7.org/fhir/_vaccineCode";
/**
 * _dateAsserted
 *
 * (Modified) MedicationStatement.dateAsserted
 *
 * http://hl7.org/fhir/_dateAsserted
 */
export declare const _dateAsserted = "http://hl7.org/fhir/_dateAsserted";
/**
 * DeviceDefinitionMaterialComponent
 *
 * DeviceDefinitionMaterialComponent: A substance used to create the material(s) of which the device is made.
 *
 * http://hl7.org/fhir/DeviceDefinitionMaterialComponent
 */
export declare const DeviceDefinitionMaterialComponent = "http://hl7.org/fhir/DeviceDefinitionMaterialComponent";
/**
 * _codeSearch
 *
 * (Modified) TerminologyCapabilities.codeSearch
 *
 * http://hl7.org/fhir/_codeSearch
 */
export declare const _codeSearch = "http://hl7.org/fhir/_codeSearch";
/**
 * range
 *
 * ObservationDefinition.qualifiedValue.range: The range of values defined for continuous or ordinal observations that match the criteria of this set of qualified values.
 *
 * http://hl7.org/fhir/range
 */
export declare const range = "http://hl7.org/fhir/range";
/**
 * NutritionOrder
 *
 * A request to supply a diet, formula feeding (enteral) or oral nutritional supplement to a patient/resident.
 *
 * http://hl7.org/fhir/NutritionOrder
 */
export declare const NutritionOrder = "http://hl7.org/fhir/NutritionOrder";
/**
 * _dispenserInstruction
 *
 * (Modified) MedicationRequest.dispenseRequest.dispenserInstruction
 *
 * http://hl7.org/fhir/_dispenserInstruction
 */
export declare const _dispenserInstruction = "http://hl7.org/fhir/_dispenserInstruction";
/**
 * _summary
 *
 * (Modified) Condition.stage.summary
 *
 * http://hl7.org/fhir/_summary
 */
export declare const _summary = "http://hl7.org/fhir/_summary";
/**
 * _synthesisType
 *
 * (Modified) Evidence.synthesisType
 *
 * http://hl7.org/fhir/_synthesisType
 */
export declare const _synthesisType = "http://hl7.org/fhir/_synthesisType";
/**
 * productName
 *
 * NutritionOrder.enteralFormula.additive.productName: The product or brand name of the type of modular component to be added to the formula.
 *
 * http://hl7.org/fhir/productName
 */
export declare const productName = "http://hl7.org/fhir/productName";
/**
 * _reviewOutcome
 *
 * (Modified) ExplanationOfBenefit.addItem.detail.subDetail.reviewOutcome
 *
 * http://hl7.org/fhir/_reviewOutcome
 */
export declare const _reviewOutcome = "http://hl7.org/fhir/_reviewOutcome";
/**
 * claimResponse
 *
 * ExplanationOfBenefit.claimResponse: The business identifier for the instance of the adjudication response: claim, predetermination or preauthorization response.
 *
 * http://hl7.org/fhir/claimResponse
 */
export declare const claimResponse = "http://hl7.org/fhir/claimResponse";
/**
 * path
 *
 * RequestOrchestration.action.dynamicValue.path: The path to the element to be customized. This is the path on the resource that will hold the result of the calculation defined by the expression. The specified path SHALL be a FHIRPath resolvable on the specified target type of the ActivityDefinition, and SHALL consist only of identifiers, constant indexers, and a restricted subset of functions. The path is allowed to contain qualifiers (.) to traverse sub-elements, as well as indexers ([x]) to traverse multiple-cardinality sub-elements (see the [Simple FHIRPath Profile](fhirpath.html#simple) for full details).
 *
 * http://hl7.org/fhir/path
 */
export declare const path = "http://hl7.org/fhir/path";
/**
 * additive
 *
 * Specimen.processing.additive: Material used in the processing step.
 *
 * http://hl7.org/fhir/additive
 */
export declare const additive = "http://hl7.org/fhir/additive";
/**
 * ElementDefinition
 *
 * Captures constraints on each element within the resource, profile, or extension.
 *
 * http://hl7.org/fhir/ElementDefinition
 */
export declare const ElementDefinition = "http://hl7.org/fhir/ElementDefinition";
/**
 * fundingSource
 *
 * Immunization.fundingSource: Indicates the source of the vaccine actually administered. This may be different than the patient eligibility (e.g. the patient may be eligible for a publically purchased vaccine but due to inventory issues, vaccine purchased with private funds was actually administered).
 *
 * http://hl7.org/fhir/fundingSource
 */
export declare const fundingSource = "http://hl7.org/fhir/fundingSource";
/**
 * instantiatesCanonical
 *
 * GenomicStudy.instantiatesCanonical: The defined protocol that describes the study.
 *
 * http://hl7.org/fhir/instantiatesCanonical
 */
export declare const instantiatesCanonical = "http://hl7.org/fhir/instantiatesCanonical";
/**
 * family
 *
 * SubstanceSourceMaterial.organism.family: The family of an organism shall be specified.
 *
 * http://hl7.org/fhir/family
 */
export declare const family = "http://hl7.org/fhir/family";
/**
 * NutritionIntake
 *
 * A record of food or fluid that is being consumed by a patient.  A NutritionIntake may indicate that the patient may be consuming the food or fluid now or has consumed the food or fluid in the past.  The source of this information can be the patient, significant other (such as a family member or spouse), or a clinician.  A common scenario where this information is captured is during the history taking process during a patient visit or stay or through an app that tracks food or fluids consumed.   The consumption information may come from sources such as the patient's memory, from a nutrition label,  or from a clinician documenting observed intake.
 *
 * http://hl7.org/fhir/NutritionIntake
 */
export declare const NutritionIntake = "http://hl7.org/fhir/NutritionIntake";
/**
 * EvidenceReport
 *
 * The EvidenceReport Resource is a specialized container for a collection of resources and codeable concepts, adapted to support compositions of Evidence, EvidenceVariable, and Citation resources and related concepts.
 *
 * http://hl7.org/fhir/EvidenceReport
 */
export declare const EvidenceReport = "http://hl7.org/fhir/EvidenceReport";
/**
 * billablePeriod
 *
 * ExplanationOfBenefit.billablePeriod: The period for which charges are being submitted.
 *
 * http://hl7.org/fhir/billablePeriod
 */
export declare const billablePeriod = "http://hl7.org/fhir/billablePeriod";
/**
 * _otherTherapy
 *
 * (Modified) ClinicalUseDefinition.indication.otherTherapy
 *
 * http://hl7.org/fhir/_otherTherapy
 */
export declare const _otherTherapy = "http://hl7.org/fhir/_otherTherapy";
/**
 * _dateOfService
 *
 * (Modified) Account.procedure.dateOfService
 *
 * http://hl7.org/fhir/_dateOfService
 */
export declare const _dateOfService = "http://hl7.org/fhir/_dateOfService";
/**
 * _benefitBalance
 *
 * (Modified) ExplanationOfBenefit.benefitBalance
 *
 * http://hl7.org/fhir/_benefitBalance
 */
export declare const _benefitBalance = "http://hl7.org/fhir/_benefitBalance";
/**
 * _information
 *
 * (Modified) CoverageEligibilityRequest.supportingInfo.information
 *
 * http://hl7.org/fhir/_information
 */
export declare const _information = "http://hl7.org/fhir/_information";
/**
 * _CareTeam
 *
 * (Modified) CareTeam
 *
 * http://hl7.org/fhir/_CareTeam
 */
export declare const _CareTeam = "http://hl7.org/fhir/_CareTeam";
/**
 * _aggregateMethod
 *
 * (Modified) Measure.group.population.aggregateMethod
 *
 * http://hl7.org/fhir/_aggregateMethod
 */
export declare const _aggregateMethod = "http://hl7.org/fhir/_aggregateMethod";
/**
 * generatedBy
 *
 * GenomicStudy.analysis.input.generatedBy
 *
 * http://hl7.org/fhir/generatedBy
 */
export declare const generatedBy = "http://hl7.org/fhir/generatedBy";
/**
 * _tag
 *
 * (Modified) Meta.tag
 *
 * http://hl7.org/fhir/_tag
 */
export declare const _tag = "http://hl7.org/fhir/_tag";
/**
 * asserter
 *
 * Permission.asserter: The person or entity that asserts the permission.
 *
 * http://hl7.org/fhir/asserter
 */
export declare const asserter = "http://hl7.org/fhir/asserter";
/**
 * _revInclude
 *
 * (Modified) SubscriptionTopic.notificationShape.revInclude
 *
 * http://hl7.org/fhir/_revInclude
 */
export declare const _revInclude = "http://hl7.org/fhir/_revInclude";
/**
 * onset
 *
 * FamilyMemberHistory.condition.onset
 *
 * http://hl7.org/fhir/onset
 */
export declare const onset = "http://hl7.org/fhir/onset";
/**
 * criticalCodedValueSet
 *
 * ObservationDefinition.component.qualifiedValue.criticalCodedValueSet: The set of critical coded results for qualitative observations  that match the criteria of this set of qualified values.
 *
 * http://hl7.org/fhir/criticalCodedValueSet
 */
export declare const criticalCodedValueSet = "http://hl7.org/fhir/criticalCodedValueSet";
/**
 * _mode
 *
 * (Modified) Device.mode
 *
 * http://hl7.org/fhir/_mode
 */
export declare const _mode = "http://hl7.org/fhir/_mode";
/**
 * anchor
 *
 * ImplementationGuide.manifest.page.anchor: The name of an anchor available on the page.
 *
 * http://hl7.org/fhir/anchor
 */
export declare const anchor = "http://hl7.org/fhir/anchor";
/**
 * _substitution
 *
 * (Modified) MedicationRequest.substitution
 *
 * http://hl7.org/fhir/_substitution
 */
export declare const _substitution = "http://hl7.org/fhir/_substitution";
/**
 * _consent
 *
 * (Modified) ResearchSubject.consent
 *
 * http://hl7.org/fhir/_consent
 */
export declare const _consent = "http://hl7.org/fhir/_consent";
/**
 * _candidate
 *
 * (Modified) EnrollmentRequest.candidate
 *
 * http://hl7.org/fhir/_candidate
 */
export declare const _candidate = "http://hl7.org/fhir/_candidate";
/**
 * _concept
 *
 * (Modified) ValueSet.compose.exclude.concept
 *
 * http://hl7.org/fhir/_concept
 */
export declare const _concept = "http://hl7.org/fhir/_concept";
/**
 * MeasureReportGroupStratifierStratumComponentComponent
 *
 * MeasureReportGroupComponent.MeasureReportGroupStratifierComponent.StratifierGroup.MeasureReportGroupStratifierStratumComponentComponent: A stratifier component value.
 *
 * http://hl7.org/fhir/MeasureReportGroupStratifierStratumComponentComponent
 */
export declare const MeasureReportGroupStratifierStratumComponentComponent = "http://hl7.org/fhir/MeasureReportGroupStratifierStratumComponentComponent";
/**
 * ifNoneExist
 *
 * Bundle.entry.request.ifNoneExist: Instruct the server not to perform the create if a specified resource already exists. For further information, see the API documentation for ["Conditional Create"](http.html#ccreate). This is just the query portion of the URL - what follows the "?" (not including the "?").
 *
 * http://hl7.org/fhir/ifNoneExist
 */
export declare const ifNoneExist = "http://hl7.org/fhir/ifNoneExist";
/**
 * GraphDefinitionNodeComponent
 *
 * GraphDefinitionNodeComponent: Potential target for the link.
 *
 * http://hl7.org/fhir/GraphDefinitionNodeComponent
 */
export declare const GraphDefinitionNodeComponent = "http://hl7.org/fhir/GraphDefinitionNodeComponent";
/**
 * _answer
 *
 * (Modified) Contract.term.group.asset.answer
 *
 * http://hl7.org/fhir/_answer
 */
export declare const _answer = "http://hl7.org/fhir/_answer";
/**
 * _schedule
 *
 * (Modified) Slot.schedule
 *
 * http://hl7.org/fhir/_schedule
 */
export declare const _schedule = "http://hl7.org/fhir/_schedule";
/**
 * administrationTreatment
 *
 * MedicationKnowledge.indicationGuideline.dosingGuideline.administrationTreatment: The type of the treatment that the guideline applies to, for example, long term therapy, first line treatment, etc.
 *
 * http://hl7.org/fhir/administrationTreatment
 */
export declare const administrationTreatment = "http://hl7.org/fhir/administrationTreatment";
/**
 * _baseFormulaProductName
 *
 * (Modified) NutritionOrder.enteralFormula.baseFormulaProductName
 *
 * http://hl7.org/fhir/_baseFormulaProductName
 */
export declare const _baseFormulaProductName = "http://hl7.org/fhir/_baseFormulaProductName";
/**
 * PermissionRuleDataResourceComponent
 *
 * Permission.Rule.PermissionRuleDataComponent.PermissionRuleDataResourceComponent: Explicit FHIR Resource references.
 *
 * http://hl7.org/fhir/PermissionRuleDataResourceComponent
 */
export declare const PermissionRuleDataResourceComponent = "http://hl7.org/fhir/PermissionRuleDataResourceComponent";
/**
 * _gestationalAge
 *
 * (Modified) ObservationDefinition.component.qualifiedValue.gestationalAge
 *
 * http://hl7.org/fhir/_gestationalAge
 */
export declare const _gestationalAge = "http://hl7.org/fhir/_gestationalAge";
/**
 * carrierAIDC
 *
 * Device.udiCarrier.carrierAIDC: The full UDI carrier of the Automatic Identification and Data Capture (AIDC) technology representation of the barcode string as printed on the packaging of the device - e.g., a barcode or RFID.   Because of limitations on character sets in XML and the need to round-trip JSON data through XML, AIDC Formats *SHALL* be base64 encoded.
 *
 * http://hl7.org/fhir/carrierAIDC
 */
export declare const carrierAIDC = "http://hl7.org/fhir/carrierAIDC";
/**
 * _capability
 *
 * (Modified) TestScript.metadata.capability
 *
 * http://hl7.org/fhir/_capability
 */
export declare const _capability = "http://hl7.org/fhir/_capability";
/**
 * usageStatus
 *
 * DeviceUsage.usageStatus: The status of the device usage, for example always, sometimes, never. This is not the same as the status of the statement.
 *
 * http://hl7.org/fhir/usageStatus
 */
export declare const usageStatus = "http://hl7.org/fhir/usageStatus";
/**
 * _knownAllergen
 *
 * (Modified) NutritionProduct.knownAllergen
 *
 * http://hl7.org/fhir/_knownAllergen
 */
export declare const _knownAllergen = "http://hl7.org/fhir/_knownAllergen";
/**
 * storageTempRequirements
 *
 * BiologicallyDerivedProduct.storageTempRequirements: The temperature requirements for storage of the biologically-derived product.
 *
 * http://hl7.org/fhir/storageTempRequirements
 */
export declare const storageTempRequirements = "http://hl7.org/fhir/storageTempRequirements";
/**
 * definitionReference
 *
 * EvidenceVariable.characteristic.definitionByCombination.characteristic.definitionReference: Defines the characteristic using a Reference.
 *
 * http://hl7.org/fhir/definitionReference
 */
export declare const definitionReference = "http://hl7.org/fhir/definitionReference";
/**
 * experimental
 *
 * SubscriptionTopic.experimental: A flag to indicate that this TopSubscriptionTopicic is authored for testing purposes (or education/evaluation/marketing), and is not intended to be used for genuine usage.
 *
 * http://hl7.org/fhir/experimental
 */
export declare const experimental = "http://hl7.org/fhir/experimental";
/**
 * _numberOfParticipants
 *
 * (Modified) Evidence.statistic.sampleSize.numberOfParticipants
 *
 * http://hl7.org/fhir/_numberOfParticipants
 */
export declare const _numberOfParticipants = "http://hl7.org/fhir/_numberOfParticipants";
/**
 * _repeat
 *
 * (Modified) SubstancePolymer.repeat
 *
 * http://hl7.org/fhir/_repeat
 */
export declare const _repeat = "http://hl7.org/fhir/_repeat";
/**
 * displayName
 *
 * Device.displayName: The name used to display by default when the device is referenced. Based on intent of use by the resource creator, this may reflect one of the names in Device.name, or may be another simple name.
 *
 * http://hl7.org/fhir/displayName
 */
export declare const displayName = "http://hl7.org/fhir/displayName";
/**
 * replaces
 *
 * ServiceRequest.replaces: The request takes the place of the referenced completed or terminated request(s).
 *
 * http://hl7.org/fhir/replaces
 */
export declare const replaces = "http://hl7.org/fhir/replaces";
/**
 * _distanceFromLandmark
 *
 * (Modified) BodyStructure.excludedStructure.bodyLandmarkOrientation.distanceFromLandmark
 *
 * http://hl7.org/fhir/_distanceFromLandmark
 */
export declare const _distanceFromLandmark = "http://hl7.org/fhir/_distanceFromLandmark";
/**
 * _frequency
 *
 * (Modified) VerificationResult.frequency
 *
 * http://hl7.org/fhir/_frequency
 */
export declare const _frequency = "http://hl7.org/fhir/_frequency";
/**
 * shortDoco
 *
 * ElementDefinition.binding.additional.shortDoco: Concise documentation - for summary tables.
 *
 * http://hl7.org/fhir/shortDoco
 */
export declare const shortDoco = "http://hl7.org/fhir/shortDoco";
/**
 * ImagingSelection
 *
 * A selection of DICOM SOP instances and/or frames within a single Study and Series. This might include additional specifics such as an image region, an Observation UID or a Segmentation Number, allowing linkage to an Observation Resource or transferring this information along with the ImagingStudy Resource.
 *
 * http://hl7.org/fhir/ImagingSelection
 */
export declare const ImagingSelection = "http://hl7.org/fhir/ImagingSelection";
/**
 * modality
 *
 * ImagingStudy.modality: A list of all the distinct values of series.modality. This may include both acquisition and non-acquisition modalities.
 *
 * http://hl7.org/fhir/modality
 */
export declare const modality = "http://hl7.org/fhir/modality";
/**
 * _targetId
 *
 * (Modified) TestScript.test.action.operation.targetId
 *
 * http://hl7.org/fhir/_targetId
 */
export declare const _targetId = "http://hl7.org/fhir/_targetId";
/**
 * _amount
 *
 * (Modified) ExplanationOfBenefit.adjudication.amount
 *
 * http://hl7.org/fhir/_amount
 */
export declare const _amount = "http://hl7.org/fhir/_amount";
/**
 * species
 *
 * SubstanceSourceMaterial.organism.species: The species of an organism shall be specified; refers to the Latin epithet of the species of the plant/animal; it is present in names for species and infraspecies.
 *
 * http://hl7.org/fhir/species
 */
export declare const species = "http://hl7.org/fhir/species";
/**
 * totalNet
 *
 * Invoice.totalNet: Invoice total , taxes excluded.
 *
 * http://hl7.org/fhir/totalNet
 */
export declare const totalNet = "http://hl7.org/fhir/totalNet";
/**
 * observationRequirement
 *
 * ActivityDefinition.observationRequirement: Defines observation requirements for the action to be performed, such as body weight or surface area.
 *
 * http://hl7.org/fhir/observationRequirement
 */
export declare const observationRequirement = "http://hl7.org/fhir/observationRequirement";
/**
 * InsurancePlanPlanGeneralCostComponent
 *
 * InsurancePlanPlanComponent.InsurancePlanPlanGeneralCostComponent: Overall costs associated with the plan.
 *
 * http://hl7.org/fhir/InsurancePlanPlanGeneralCostComponent
 */
export declare const InsurancePlanPlanGeneralCostComponent = "http://hl7.org/fhir/InsurancePlanPlanGeneralCostComponent";
/**
 * InvoiceLineItemComponent
 *
 * InvoiceLineItemComponent: Each line item represents one charge for goods and services rendered. Details such.ofType(date), code and amount are found in the referenced ChargeItem resource.
 *
 * http://hl7.org/fhir/InvoiceLineItemComponent
 */
export declare const InvoiceLineItemComponent = "http://hl7.org/fhir/InvoiceLineItemComponent";
/**
 * requestor
 *
 * ClaimResponse.requestor: The provider which is responsible for the claim, predetermination or preauthorization.
 *
 * http://hl7.org/fhir/requestor
 */
export declare const requestor = "http://hl7.org/fhir/requestor";
/**
 * dietPreference
 *
 * Encounter.dietPreference: Diet preferences reported by the patient.
 *
 * http://hl7.org/fhir/dietPreference
 */
export declare const dietPreference = "http://hl7.org/fhir/dietPreference";
/**
 * comparator
 *
 * SearchParameter.comparator: Comparators supported for the search parameter.
 *
 * http://hl7.org/fhir/comparator
 */
export declare const comparator = "http://hl7.org/fhir/comparator";
/**
 * _combinedPharmaceuticalDoseForm
 *
 * (Modified) MedicinalProductDefinition.combinedPharmaceuticalDoseForm
 *
 * http://hl7.org/fhir/_combinedPharmaceuticalDoseForm
 */
export declare const _combinedPharmaceuticalDoseForm = "http://hl7.org/fhir/_combinedPharmaceuticalDoseForm";
/**
 * servicePeriod
 *
 * Account.servicePeriod: The date range of services associated with this account.
 *
 * http://hl7.org/fhir/servicePeriod
 */
export declare const servicePeriod = "http://hl7.org/fhir/servicePeriod";
/**
 * _rater
 *
 * (Modified) Evidence.certainty.subcomponent.rater
 *
 * http://hl7.org/fhir/_rater
 */
export declare const _rater = "http://hl7.org/fhir/_rater";
/**
 * receiverActive
 *
 * ExampleScenario.process.step.process.step.alternative.step.operation.receiverActive: If false, the receiver is deactivated right after the operation.
 *
 * http://hl7.org/fhir/receiverActive
 */
export declare const receiverActive = "http://hl7.org/fhir/receiverActive";
/**
 * modification
 *
 * SubstancePolymer.modification: Todo - this is intended to connect to a repeating full modification structure, also used by Protein and Nucleic Acid . String is just a placeholder.
 *
 * http://hl7.org/fhir/modification
 */
export declare const modification = "http://hl7.org/fhir/modification";
/**
 * practitioner
 *
 * PractitionerRole.practitioner: Practitioner that is able to provide the defined services for the organization.
 *
 * http://hl7.org/fhir/practitioner
 */
export declare const practitioner = "http://hl7.org/fhir/practitioner";
/**
 * _normalCodedValueSet
 *
 * (Modified) ObservationDefinition.component.qualifiedValue.normalCodedValueSet
 *
 * http://hl7.org/fhir/_normalCodedValueSet
 */
export declare const _normalCodedValueSet = "http://hl7.org/fhir/_normalCodedValueSet";
/**
 * TestCaseDependency
 *
 * TestPlanTestCaseComponent.TestCaseDependency: The required criteria to execute the test case - e.g. preconditions, previous tests.
 *
 * http://hl7.org/fhir/TestCaseDependency
 */
export declare const TestCaseDependency = "http://hl7.org/fhir/TestCaseDependency";
/**
 * _costToBeneficiary
 *
 * (Modified) Coverage.costToBeneficiary
 *
 * http://hl7.org/fhir/_costToBeneficiary
 */
export declare const _costToBeneficiary = "http://hl7.org/fhir/_costToBeneficiary";
/**
 * MessageHeader
 *
 * The header for a message exchange that is either requesting or responding to an action.  The reference(s) that are the subject of the action as well as other information related to the action are typically transmitted in a bundle in which the MessageHeader resource instance is the first resource in the bundle.
 *
 * http://hl7.org/fhir/MessageHeader
 */
export declare const MessageHeader = "http://hl7.org/fhir/MessageHeader";
/**
 * ResearchStudyRecruitmentComponent
 *
 * ResearchStudyRecruitmentComponent: Target or actual group of participants enrolled in study.
 *
 * http://hl7.org/fhir/ResearchStudyRecruitmentComponent
 */
export declare const ResearchStudyRecruitmentComponent = "http://hl7.org/fhir/ResearchStudyRecruitmentComponent";
/**
 * _forenameInitials
 *
 * (Modified) Citation.citedArtifact.contributorship.entry.forenameInitials
 *
 * http://hl7.org/fhir/_forenameInitials
 */
export declare const _forenameInitials = "http://hl7.org/fhir/_forenameInitials";
/**
 * plannedStartDate
 *
 * EncounterHistory.plannedStartDate: The planned start date/time (or admission date) of the encounter.
 *
 * http://hl7.org/fhir/plannedStartDate
 */
export declare const plannedStartDate = "http://hl7.org/fhir/plannedStartDate";
/**
 * study
 *
 * ResearchSubject.study: Reference to the study the subject is participating in.
 *
 * http://hl7.org/fhir/study
 */
export declare const study = "http://hl7.org/fhir/study";
/**
 * groupIdentifier
 *
 * NutritionOrder.groupIdentifier: A shared identifier common to all nutrition orders that were authorized more or less simultaneously by a single author, representing the composite or group identifier.
 *
 * http://hl7.org/fhir/groupIdentifier
 */
export declare const groupIdentifier = "http://hl7.org/fhir/groupIdentifier";
/**
 * _participatingOrganization
 *
 * (Modified) OrganizationAffiliation.participatingOrganization
 *
 * http://hl7.org/fhir/_participatingOrganization
 */
export declare const _participatingOrganization = "http://hl7.org/fhir/_participatingOrganization";
/**
 * MeasureGroupStratifierComponent
 *
 * MeasureGroupComponent.MeasureGroupStratifierComponent: The stratifier criteria for the measure report, specified as either the name of a valid CQL expression defined within a referenced library or a valid FHIR Resource Path.
 *
 * http://hl7.org/fhir/MeasureGroupStratifierComponent
 */
export declare const MeasureGroupStratifierComponent = "http://hl7.org/fhir/MeasureGroupStratifierComponent";
/**
 * wednesday
 *
 * Appointment.recurrenceTemplate.weeklyTemplate.wednesday: Indicates that recurring appointments should occur on Wednesdays.
 *
 * http://hl7.org/fhir/wednesday
 */
export declare const wednesday = "http://hl7.org/fhir/wednesday";
/**
 * _diameter
 *
 * (Modified) VisionPrescription.lensSpecification.diameter
 *
 * http://hl7.org/fhir/_diameter
 */
export declare const _diameter = "http://hl7.org/fhir/_diameter";
/**
 * enteralFormula
 *
 * NutritionOrder.enteralFormula: Feeding provided through the gastrointestinal tract via a tube, catheter, or stoma that delivers nutrition distal to the oral cavity.
 *
 * http://hl7.org/fhir/enteralFormula
 */
export declare const enteralFormula = "http://hl7.org/fhir/enteralFormula";
/**
 * _stabilityDuration
 *
 * (Modified) MedicationKnowledge.storageGuideline.stabilityDuration
 *
 * http://hl7.org/fhir/_stabilityDuration
 */
export declare const _stabilityDuration = "http://hl7.org/fhir/_stabilityDuration";
/**
 * integer
 *
 * A whole number
 *
 * http://hl7.org/fhir/integer
 */
export declare const integer = "http://hl7.org/fhir/integer";
/**
 * domain
 *
 * SubstanceDefinition.name.translation.domain: The use context of this name for example if there is a different name a drug active ingredient as opposed to a food colour additive.
 *
 * http://hl7.org/fhir/domain
 */
export declare const domain = "http://hl7.org/fhir/domain";
/**
 * _periodType
 *
 * (Modified) Contract.term.group.asset.periodType
 *
 * http://hl7.org/fhir/_periodType
 */
export declare const _periodType = "http://hl7.org/fhir/_periodType";
/**
 * _ImagingStudy
 *
 * (Modified) ImagingStudy
 *
 * http://hl7.org/fhir/_ImagingStudy
 */
export declare const _ImagingStudy = "http://hl7.org/fhir/_ImagingStudy";
/**
 * searchRevInclude
 *
 * CapabilityStatement.rest.resource.searchRevInclude: A list of _revinclude (reverse include) values supported by the server.
 *
 * http://hl7.org/fhir/searchRevInclude
 */
export declare const searchRevInclude = "http://hl7.org/fhir/searchRevInclude";
/**
 * _relatedAction
 *
 * (Modified) RequestOrchestration.action.action.relatedAction
 *
 * http://hl7.org/fhir/_relatedAction
 */
export declare const _relatedAction = "http://hl7.org/fhir/_relatedAction";
/**
 * observed
 *
 * Evidence.variableDefinition.observed: Definition of the actual variable related to the statistic(s).
 *
 * http://hl7.org/fhir/observed
 */
export declare const observed = "http://hl7.org/fhir/observed";
/**
 * born
 *
 * FamilyMemberHistory.born
 *
 * http://hl7.org/fhir/born
 */
export declare const born = "http://hl7.org/fhir/born";
/**
 * _ImmunizationRecommendation
 *
 * (Modified) ImmunizationRecommendation
 *
 * http://hl7.org/fhir/_ImmunizationRecommendation
 */
export declare const _ImmunizationRecommendation = "http://hl7.org/fhir/_ImmunizationRecommendation";
/**
 * service
 *
 * ChargeItem.service: Indicated the rendered service that caused this charge.
 *
 * http://hl7.org/fhir/service
 */
export declare const service = "http://hl7.org/fhir/service";
/**
 * _requestIdentifier
 *
 * (Modified) GuidanceResponse.requestIdentifier
 *
 * http://hl7.org/fhir/_requestIdentifier
 */
export declare const _requestIdentifier = "http://hl7.org/fhir/_requestIdentifier";
/**
 * maxDosePerLifetime
 *
 * Dosage.maxDosePerLifetime: Upper limit on medication per lifetime of the patient.
 *
 * http://hl7.org/fhir/maxDosePerLifetime
 */
export declare const maxDosePerLifetime = "http://hl7.org/fhir/maxDosePerLifetime";
/**
 * format
 *
 * SubstancePolymer.repeat.repeatUnit.structuralRepresentation.format: The format of the representation e.g. InChI, SMILES, MOLFILE, CDX, SDF, PDB, mmCIF.
 *
 * http://hl7.org/fhir/format
 */
export declare const format = "http://hl7.org/fhir/format";
/**
 * _isSummary
 *
 * (Modified) ElementDefinition.isSummary
 *
 * http://hl7.org/fhir/_isSummary
 */
export declare const _isSummary = "http://hl7.org/fhir/_isSummary";
/**
 * supportingInfoSequence
 *
 * CoverageEligibilityRequest.item.supportingInfoSequence: Exceptions, special conditions and supporting information applicable for this service or product line.
 *
 * http://hl7.org/fhir/supportingInfoSequence
 */
export declare const supportingInfoSequence = "http://hl7.org/fhir/supportingInfoSequence";
/**
 * EvidenceStatisticModelCharacteristicVariableComponent
 *
 * EvidenceStatisticComponent.EvidenceStatisticModelCharacteristicComponent.EvidenceStatisticModelCharacteristicVariableComponent: A variable adjusted for in the adjusted analysis.
 *
 * http://hl7.org/fhir/EvidenceStatisticModelCharacteristicVariableComponent
 */
export declare const EvidenceStatisticModelCharacteristicVariableComponent = "http://hl7.org/fhir/EvidenceStatisticModelCharacteristicVariableComponent";
/**
 * ManufacturedItemDefinitionPropertyComponent
 *
 * ManufacturedItemDefinitionPropertyComponent: General characteristics of this item.
 *
 * http://hl7.org/fhir/ManufacturedItemDefinitionPropertyComponent
 */
export declare const ManufacturedItemDefinitionPropertyComponent = "http://hl7.org/fhir/ManufacturedItemDefinitionPropertyComponent";
/**
 * _concentration
 *
 * (Modified) Ingredient.substance.strength.concentration
 *
 * http://hl7.org/fhir/_concentration
 */
export declare const _concentration = "http://hl7.org/fhir/_concentration";
/**
 * coordinate
 *
 * ImagingSelection.instance.imageRegion3D.coordinate: The coordinates describing the image region. Encoded as an ordered set of (x,y,z) triplets (in mm and may be negative) that define a region of interest in the patient-relative Reference Coordinate System defined by ImagingSelection.frameOfReferenceUid element.
 *
 * http://hl7.org/fhir/coordinate
 */
export declare const coordinate = "http://hl7.org/fhir/coordinate";
/**
 * AddedItemDetailSubDetail
 *
 * ExplanationOfBenefit.AddedItem.AddedItemDetail.AddedItemDetailSubDetail: The third-tier service adjudications for payor added services.
 *
 * http://hl7.org/fhir/AddedItemDetailSubDetail
 */
export declare const AddedItemDetailSubDetail = "http://hl7.org/fhir/AddedItemDetailSubDetail";
/**
 * TerminologyCapabilitiesTranslationComponent
 *
 * TerminologyCapabilitiesTranslationComponent: Information about the [ConceptMap/$translate](conceptmap-operation-translate.html) operation.
 *
 * http://hl7.org/fhir/TerminologyCapabilitiesTranslationComponent
 */
export declare const TerminologyCapabilitiesTranslationComponent = "http://hl7.org/fhir/TerminologyCapabilitiesTranslationComponent";
/**
 * _generalPractitioner
 *
 * (Modified) Patient.generalPractitioner
 *
 * http://hl7.org/fhir/_generalPractitioner
 */
export declare const _generalPractitioner = "http://hl7.org/fhir/_generalPractitioner";
/**
 * _protocol
 *
 * (Modified) ResearchStudy.protocol
 *
 * http://hl7.org/fhir/_protocol
 */
export declare const _protocol = "http://hl7.org/fhir/_protocol";
/**
 * _exception
 *
 * (Modified) Coverage.costToBeneficiary.exception
 *
 * http://hl7.org/fhir/_exception
 */
export declare const _exception = "http://hl7.org/fhir/_exception";
/**
 * _complication
 *
 * (Modified) Procedure.complication
 *
 * http://hl7.org/fhir/_complication
 */
export declare const _complication = "http://hl7.org/fhir/_complication";
/**
 * value
 *
 * CodeSystem.filter.value: A description of what the value for the filter should be.
 *
 * http://hl7.org/fhir/value
 */
export declare const value = "http://hl7.org/fhir/value";
/**
 * _nthWeekOfMonth
 *
 * (Modified) Appointment.recurrenceTemplate.monthlyTemplate.nthWeekOfMonth
 *
 * http://hl7.org/fhir/_nthWeekOfMonth
 */
export declare const _nthWeekOfMonth = "http://hl7.org/fhir/_nthWeekOfMonth";
/**
 * _url
 *
 * (Modified) ActorDefinition.url
 *
 * http://hl7.org/fhir/_url
 */
export declare const _url = "http://hl7.org/fhir/_url";
/**
 * SubstanceSourceMaterialOrganismHybridComponent
 *
 * SubstanceSourceMaterialOrganismComponent.SubstanceSourceMaterialOrganismHybridComponent: 4.9.13.8.1 Hybrid species maternal organism ID (Optional).
 *
 * http://hl7.org/fhir/SubstanceSourceMaterialOrganismHybridComponent
 */
export declare const SubstanceSourceMaterialOrganismHybridComponent = "http://hl7.org/fhir/SubstanceSourceMaterialOrganismHybridComponent";
/**
 * SubscriptionTopicEventTriggerComponent
 *
 * SubscriptionTopicEventTriggerComponent: Event definition which can be used to trigger the SubscriptionTopic.
 *
 * http://hl7.org/fhir/SubscriptionTopicEventTriggerComponent
 */
export declare const SubscriptionTopicEventTriggerComponent = "http://hl7.org/fhir/SubscriptionTopicEventTriggerComponent";
/**
 * MedicinalProductDefinitionNameComponent
 *
 * MedicinalProductDefinitionNameComponent: The product's name, including full name and possibly coded parts.
 *
 * http://hl7.org/fhir/MedicinalProductDefinitionNameComponent
 */
export declare const MedicinalProductDefinitionNameComponent = "http://hl7.org/fhir/MedicinalProductDefinitionNameComponent";
/**
 * SubstanceSourceMaterialOrganismComponent
 *
 * SubstanceSourceMaterialOrganismComponent: This subclause describes the organism which the substance is derived from. For vaccines, the parent organism shall be specified based on these subclause elements. As an example, full taxonomy will be described for the Substance Name: ., Leaf.
 *
 * http://hl7.org/fhir/SubstanceSourceMaterialOrganismComponent
 */
export declare const SubstanceSourceMaterialOrganismComponent = "http://hl7.org/fhir/SubstanceSourceMaterialOrganismComponent";
/**
 * overrideReason
 *
 * ChargeItem.overrideReason: If the list price or the rule-based factor associated with the code is overridden, this attribute can capture a text to indicate the  reason for this action.
 *
 * http://hl7.org/fhir/overrideReason
 */
export declare const overrideReason = "http://hl7.org/fhir/overrideReason";
/**
 * pages
 *
 * Attachment.pages: The number of pages when printed.
 *
 * http://hl7.org/fhir/pages
 */
export declare const pages = "http://hl7.org/fhir/pages";
/**
 * _conclusion
 *
 * (Modified) DiagnosticReport.conclusion
 *
 * http://hl7.org/fhir/_conclusion
 */
export declare const _conclusion = "http://hl7.org/fhir/_conclusion";
/**
 * _combined
 *
 * (Modified) Specimen.combined
 *
 * http://hl7.org/fhir/_combined
 */
export declare const _combined = "http://hl7.org/fhir/_combined";
/**
 * _contains
 *
 * (Modified) ValueSet.expansion.contains.contains
 *
 * http://hl7.org/fhir/_contains
 */
export declare const _contains = "http://hl7.org/fhir/_contains";
/**
 * _documentType
 *
 * (Modified) Consent.provision.provision.documentType
 *
 * http://hl7.org/fhir/_documentType
 */
export declare const _documentType = "http://hl7.org/fhir/_documentType";
/**
 * MeasureGroupStratifierComponentComponent
 *
 * MeasureGroupComponent.MeasureGroupStratifierComponent.MeasureGroupStratifierComponentComponent: A component of the stratifier criteria for the measure report, specified as either the name of a valid CQL expression defined within a referenced library or a valid FHIR Resource Path.
 *
 * http://hl7.org/fhir/MeasureGroupStratifierComponentComponent
 */
export declare const MeasureGroupStratifierComponentComponent = "http://hl7.org/fhir/MeasureGroupStratifierComponentComponent";
/**
 * _numberOfInstances
 *
 * (Modified) ImagingStudy.series.numberOfInstances
 *
 * http://hl7.org/fhir/_numberOfInstances
 */
export declare const _numberOfInstances = "http://hl7.org/fhir/_numberOfInstances";
/**
 * PlanDefinitionActionComponent
 *
 * PlanDefinitionActionComponent: An action or group of actions to be taken as part of the plan. For example, in clinical care, an action would be to prescribe a particular indicated medication, or perform a particular test as appropriate. In pharmaceutical quality, an action would be the test that needs to be performed on a drug product as defined in the quality specification.
 *
 * http://hl7.org/fhir/PlanDefinitionActionComponent
 */
export declare const PlanDefinitionActionComponent = "http://hl7.org/fhir/PlanDefinitionActionComponent";
/**
 * _processor
 *
 * (Modified) PaymentReconciliation.processor
 *
 * http://hl7.org/fhir/_processor
 */
export declare const _processor = "http://hl7.org/fhir/_processor";
/**
 * actualNumber
 *
 * ResearchStudy.recruitment.actualNumber: Actual total number of participants enrolled in study.
 *
 * http://hl7.org/fhir/actualNumber
 */
export declare const actualNumber = "http://hl7.org/fhir/actualNumber";
/**
 * _network
 *
 * (Modified) AuditEvent.agent.network
 *
 * http://hl7.org/fhir/_network
 */
export declare const _network = "http://hl7.org/fhir/_network";
/**
 * effective
 *
 * Observation.effective
 *
 * http://hl7.org/fhir/effective
 */
export declare const effective = "http://hl7.org/fhir/effective";
/**
 * textEquivalent
 *
 * RequestOrchestration.action.textEquivalent: A text equivalent of the action to be performed. This provides a human-interpretable description of the action when the definition is consumed by a system that might not be capable of interpreting it dynamically.
 *
 * http://hl7.org/fhir/textEquivalent
 */
export declare const textEquivalent = "http://hl7.org/fhir/textEquivalent";
/**
 * preferred
 *
 * RelatedPerson.communication.preferred: Indicates whether or not the related person prefers this language (over other languages he or she masters up a certain level).
 *
 * http://hl7.org/fhir/preferred
 */
export declare const preferred = "http://hl7.org/fhir/preferred";
/**
 * ImplementationGuide
 *
 * A set of rules of how a particular interoperability or standards problem is solved - typically through the use of FHIR resources. This resource is used to gather all the parts of an implementation guide into a logical whole and to publish a computable definition of all the parts.
 *
 * http://hl7.org/fhir/ImplementationGuide
 */
export declare const ImplementationGuide = "http://hl7.org/fhir/ImplementationGuide";
/**
 * EvidenceReportRelatesToTargetComponent
 *
 * EvidenceReportRelatesToComponent.EvidenceReportRelatesToTargetComponent: The target composition/document of this relationship.
 *
 * http://hl7.org/fhir/EvidenceReportRelatesToTargetComponent
 */
export declare const EvidenceReportRelatesToTargetComponent = "http://hl7.org/fhir/EvidenceReportRelatesToTargetComponent";
/**
 * _applicability
 *
 * (Modified) InsurancePlan.plan.specificCost.benefit.cost.applicability
 *
 * http://hl7.org/fhir/_applicability
 */
export declare const _applicability = "http://hl7.org/fhir/_applicability";
/**
 * min
 *
 * GraphDefinition.link.min: Minimum occurrences for this link.
 *
 * http://hl7.org/fhir/min
 */
export declare const min = "http://hl7.org/fhir/min";
/**
 * DeviceNameComponent
 *
 * DeviceNameComponent: This represents the manufacturer's name of the device as provided by the device, from a UDI label, or by a person describing the Device.  This typically would be used when a person provides the name(s) or when the device represents one of the names available from DeviceDefinition.
 *
 * http://hl7.org/fhir/DeviceNameComponent
 */
export declare const DeviceNameComponent = "http://hl7.org/fhir/DeviceNameComponent";
/**
 * Payment
 *
 * ClaimResponse.Payment: Payment details for the adjudication of the claim.
 *
 * http://hl7.org/fhir/Payment
 */
export declare const Payment = "http://hl7.org/fhir/Payment";
/**
 * organismName
 *
 * SubstanceSourceMaterial.organismName: The organism accepted Scientific name shall be provided based on the organism taxonomy.
 *
 * http://hl7.org/fhir/organismName
 */
export declare const organismName = "http://hl7.org/fhir/organismName";
/**
 * relative
 *
 * MolecularSequence.relative: A sequence defined relative to another sequence.
 *
 * http://hl7.org/fhir/relative
 */
export declare const relative = "http://hl7.org/fhir/relative";
/**
 * Ratio
 *
 * A relationship of two Quantity values - expressed as a numerator and a denominator.
 *
 * http://hl7.org/fhir/Ratio
 */
export declare const Ratio = "http://hl7.org/fhir/Ratio";
/**
 * item
 *
 * ExplanationOfBenefit.item: A claim line. Either a simple (a product or service) or a 'group' of details which can also be a simple items or groups of sub-details.
 *
 * http://hl7.org/fhir/item
 */
export declare const item = "http://hl7.org/fhir/item";
/**
 * rating
 *
 * Evidence.certainty.subcomponent.rating: Assessment or judgement of the aspect.
 *
 * http://hl7.org/fhir/rating
 */
export declare const rating = "http://hl7.org/fhir/rating";
/**
 * _numerator
 *
 * (Modified) Ratio.numerator
 *
 * http://hl7.org/fhir/_numerator
 */
export declare const _numerator = "http://hl7.org/fhir/_numerator";
/**
 * TestScriptScopeComponent
 *
 * TestScriptScopeComponent: The scope indicates a conformance artifact that is tested by the test(s) within this test case and the expectation of the test outcome(s) as well as the intended test phase inclusion.
 *
 * http://hl7.org/fhir/TestScriptScopeComponent
 */
export declare const TestScriptScopeComponent = "http://hl7.org/fhir/TestScriptScopeComponent";
/**
 * _aggregation
 *
 * (Modified) ElementDefinition.type.aggregation
 *
 * http://hl7.org/fhir/_aggregation
 */
export declare const _aggregation = "http://hl7.org/fhir/_aggregation";
/**
 * minutesDuration
 *
 * Appointment.minutesDuration: Number of minutes that the appointment is to take. This can be less than the duration between the start and end times.  For example, where the actual time of appointment is only an estimate or if a 30 minute appointment is being requested, but any time would work.  Also, if there is, for example, a planned 15 minute break in the middle of a long appointment, the duration may be 15 minutes less than the difference between the start and end.
 *
 * http://hl7.org/fhir/minutesDuration
 */
export declare const minutesDuration = "http://hl7.org/fhir/minutesDuration";
/**
 * AuditEventEntityComponent
 *
 * AuditEventEntityComponent: Specific instances of data or objects that have been accessed.
 *
 * http://hl7.org/fhir/AuditEventEntityComponent
 */
export declare const AuditEventEntityComponent = "http://hl7.org/fhir/AuditEventEntityComponent";
/**
 * rate
 *
 * NutritionOrder.enteralFormula.administration.rate
 *
 * http://hl7.org/fhir/rate
 */
export declare const rate = "http://hl7.org/fhir/rate";
/**
 * CompartmentDefinition
 *
 * A compartment definition that defines how resources are accessed on a server.
 *
 * http://hl7.org/fhir/CompartmentDefinition
 */
export declare const CompartmentDefinition = "http://hl7.org/fhir/CompartmentDefinition";
/**
 * renderedDosageInstruction
 *
 * MedicationStatement.renderedDosageInstruction: The full representation of the dose of the medication included in all dosage instructions.  To be used when multiple dosage instructions are included to represent complex dosing such as increasing or tapering doses.
 *
 * http://hl7.org/fhir/renderedDosageInstruction
 */
export declare const renderedDosageInstruction = "http://hl7.org/fhir/renderedDosageInstruction";
/**
 * methodType
 *
 * GenomicStudy.analysis.methodType: Type of the methods used in the analysis, e.g., Fluorescence in situ hybridization (FISH), Karyotyping, or Microsatellite instability testing (MSI).
 *
 * http://hl7.org/fhir/methodType
 */
export declare const methodType = "http://hl7.org/fhir/methodType";
/**
 * parent
 *
 * MessageDefinition.parent: Identifies a protocol or workflow that this MessageDefinition represents a step in.
 *
 * http://hl7.org/fhir/parent
 */
export declare const parent = "http://hl7.org/fhir/parent";
/**
 * sourceId
 *
 * OperationDefinition.parameter.referencedFrom.sourceId: The id of the element in the referencing resource that is expected to resolve to this resource.
 *
 * http://hl7.org/fhir/sourceId
 */
export declare const sourceId = "http://hl7.org/fhir/sourceId";
/**
 * _requestedPeriod
 *
 * (Modified) Task.requestedPeriod
 *
 * http://hl7.org/fhir/_requestedPeriod
 */
export declare const _requestedPeriod = "http://hl7.org/fhir/_requestedPeriod";
/**
 * _chromosome
 *
 * (Modified) MolecularSequence.relative.startingSequence.chromosome
 *
 * http://hl7.org/fhir/_chromosome
 */
export declare const _chromosome = "http://hl7.org/fhir/_chromosome";
/**
 * isSubPotent
 *
 * MedicationAdministration.isSubPotent: An indication that the full dose was not administered.
 *
 * http://hl7.org/fhir/isSubPotent
 */
export declare const isSubPotent = "http://hl7.org/fhir/isSubPotent";
/**
 * presentedForm
 *
 * DiagnosticReport.presentedForm: Rich text representation of the entire result as issued by the diagnostic service. Multiple formats are allowed but they SHALL be semantically equivalent.
 *
 * http://hl7.org/fhir/presentedForm
 */
export declare const presentedForm = "http://hl7.org/fhir/presentedForm";
/**
 * repetitions
 *
 * Transport.restriction.repetitions: Indicates the number of times the requested action should occur.
 *
 * http://hl7.org/fhir/repetitions
 */
export declare const repetitions = "http://hl7.org/fhir/repetitions";
/**
 * aggregate
 *
 * Account.balance.aggregate: Who is expected to pay this part of the balance.
 *
 * http://hl7.org/fhir/aggregate
 */
export declare const aggregate = "http://hl7.org/fhir/aggregate";
/**
 * EvidenceStatisticComponent
 *
 * EvidenceStatisticComponent: Values and parameters for a single statistic.
 *
 * http://hl7.org/fhir/EvidenceStatisticComponent
 */
export declare const EvidenceStatisticComponent = "http://hl7.org/fhir/EvidenceStatisticComponent";
/**
 * ImplementationGuideDefinitionParameterComponent
 *
 * ImplementationGuideDefinitionComponent.ImplementationGuideDefinitionParameterComponent: A set of parameters that defines how the implementation guide is built. The parameters are defined by the relevant tools that build the implementation guides.
 *
 * http://hl7.org/fhir/ImplementationGuideDefinitionParameterComponent
 */
export declare const ImplementationGuideDefinitionParameterComponent = "http://hl7.org/fhir/ImplementationGuideDefinitionParameterComponent";
/**
 * CompositionEventComponent
 *
 * CompositionEventComponent: The clinical service, such as a colonoscopy or an appendectomy, being documented.
 *
 * http://hl7.org/fhir/CompositionEventComponent
 */
export declare const CompositionEventComponent = "http://hl7.org/fhir/CompositionEventComponent";
/**
 * _NutritionOrder
 *
 * (Modified) NutritionOrder
 *
 * http://hl7.org/fhir/_NutritionOrder
 */
export declare const _NutritionOrder = "http://hl7.org/fhir/_NutritionOrder";
/**
 * TaskInputComponent
 *
 * TaskInputComponent: Additional information that may be needed in the execution of the task.
 *
 * http://hl7.org/fhir/TaskInputComponent
 */
export declare const TaskInputComponent = "http://hl7.org/fhir/TaskInputComponent";
/**
 * rule
 *
 * StructureMap.group.rule.rule: Rules contained in this rule.
 *
 * http://hl7.org/fhir/rule
 */
export declare const rule = "http://hl7.org/fhir/rule";
/**
 * Specimen
 *
 * A sample to be used for analysis.
 *
 * http://hl7.org/fhir/Specimen
 */
export declare const Specimen = "http://hl7.org/fhir/Specimen";
/**
 * _MedicinalProductDefinition
 *
 * (Modified) MedicinalProductDefinition
 *
 * http://hl7.org/fhir/_MedicinalProductDefinition
 */
export declare const _MedicinalProductDefinition = "http://hl7.org/fhir/_MedicinalProductDefinition";
/**
 * OperationDefinition
 *
 * A formal computable definition of an operation (on the RESTful interface) or a named query (using the search interaction).
 *
 * http://hl7.org/fhir/OperationDefinition
 */
export declare const OperationDefinition = "http://hl7.org/fhir/OperationDefinition";
/**
 * process
 *
 * ExampleScenario.process: A group of operations that represents a significant step within a scenario.
 *
 * http://hl7.org/fhir/process
 */
export declare const process = "http://hl7.org/fhir/process";
/**
 * CitationCitedArtifactContributorshipEntryContributionInstanceComponent
 *
 * CitationCitedArtifactComponent.CitationCitedArtifactContributorshipComponent.CitationCitedArtifactContributorshipEntryComponent.CitationCitedArtifactContributorshipEntryContributionInstanceComponent: Contributions with accounting for time or number.
 *
 * http://hl7.org/fhir/CitationCitedArtifactContributorshipEntryContributionInstanceComponent
 */
export declare const CitationCitedArtifactContributorshipEntryContributionInstanceComponent = "http://hl7.org/fhir/CitationCitedArtifactContributorshipEntryContributionInstanceComponent";
/**
 * EncounterAdmissionComponent
 *
 * EncounterAdmissionComponent: Details about the stay during which a healthcare service is provided.

This does not describe the event of admitting the patient, but rather any information that is relevant from the time of admittance until the time of discharge.
 *
 * http://hl7.org/fhir/EncounterAdmissionComponent
 */
export declare const EncounterAdmissionComponent = "http://hl7.org/fhir/EncounterAdmissionComponent";
/**
 * _MedicationDispense
 *
 * (Modified) MedicationDispense
 *
 * http://hl7.org/fhir/_MedicationDispense
 */
export declare const _MedicationDispense = "http://hl7.org/fhir/_MedicationDispense";
/**
 * translation
 *
 * SubstanceDefinition.name.synonym.translation: A translation for this name into another human language.
 *
 * http://hl7.org/fhir/translation
 */
export declare const translation = "http://hl7.org/fhir/translation";
/**
 * ObservationTriggeredByComponent
 *
 * ObservationTriggeredByComponent: Identifies the observation(s) that triggered the performance of this observation.
 *
 * http://hl7.org/fhir/ObservationTriggeredByComponent
 */
export declare const ObservationTriggeredByComponent = "http://hl7.org/fhir/ObservationTriggeredByComponent";
/**
 * _etag
 *
 * (Modified) Bundle.entry.response.etag
 *
 * http://hl7.org/fhir/_etag
 */
export declare const _etag = "http://hl7.org/fhir/_etag";
/**
 * _dateCriterion
 *
 * (Modified) ImmunizationRecommendation.recommendation.dateCriterion
 *
 * http://hl7.org/fhir/_dateCriterion
 */
export declare const _dateCriterion = "http://hl7.org/fhir/_dateCriterion";
/**
 * _administrationInstruction
 *
 * (Modified) NutritionOrder.enteralFormula.administrationInstruction
 *
 * http://hl7.org/fhir/_administrationInstruction
 */
export declare const _administrationInstruction = "http://hl7.org/fhir/_administrationInstruction";
/**
 * part
 *
 * OperationDefinition.parameter.part.part: The parts of a nested Parameter.
 *
 * http://hl7.org/fhir/part
 */
export declare const part = "http://hl7.org/fhir/part";
/**
 * _billablePeriod
 *
 * (Modified) ExplanationOfBenefit.billablePeriod
 *
 * http://hl7.org/fhir/_billablePeriod
 */
export declare const _billablePeriod = "http://hl7.org/fhir/_billablePeriod";
/**
 * requestHeader
 *
 * TestScript.teardown.action.operation.requestHeader: Header elements would be used to set HTTP headers.
 *
 * http://hl7.org/fhir/requestHeader
 */
export declare const requestHeader = "http://hl7.org/fhir/requestHeader";
/**
 * _shortTitle
 *
 * (Modified) EvidenceVariable.shortTitle
 *
 * http://hl7.org/fhir/_shortTitle
 */
export declare const _shortTitle = "http://hl7.org/fhir/_shortTitle";
/**
 * _securityLabel
 *
 * (Modified) DocumentReference.securityLabel
 *
 * http://hl7.org/fhir/_securityLabel
 */
export declare const _securityLabel = "http://hl7.org/fhir/_securityLabel";
/**
 * _procedure
 *
 * (Modified) ExplanationOfBenefit.procedure.procedure
 *
 * http://hl7.org/fhir/_procedure
 */
export declare const _procedure = "http://hl7.org/fhir/_procedure";
/**
 * periodMax
 *
 * Timing.repeat.periodMax: If present, indicates that the period is a range from [period] to [periodMax], allowing expressing concepts such as "do this once every 3-5 days.
 *
 * http://hl7.org/fhir/periodMax
 */
export declare const periodMax = "http://hl7.org/fhir/periodMax";
/**
 * monograph
 *
 * MedicationKnowledge.monograph: Associated documentation about the medication.
 *
 * http://hl7.org/fhir/monograph
 */
export declare const monograph = "http://hl7.org/fhir/monograph";
/**
 * _eventsSinceSubscriptionStart
 *
 * (Modified) SubscriptionStatus.eventsSinceSubscriptionStart
 *
 * http://hl7.org/fhir/_eventsSinceSubscriptionStart
 */
export declare const _eventsSinceSubscriptionStart = "http://hl7.org/fhir/_eventsSinceSubscriptionStart";
/**
 * QuestionnaireResponseItemAnswerComponent
 *
 * QuestionnaireResponseItemComponent.QuestionnaireResponseItemAnswerComponent: The respondent's answer(s) to the question.
 *
 * http://hl7.org/fhir/QuestionnaireResponseItemAnswerComponent
 */
export declare const QuestionnaireResponseItemAnswerComponent = "http://hl7.org/fhir/QuestionnaireResponseItemAnswerComponent";
/**
 * formatted
 *
 * MolecularSequence.formatted: Sequence that was observed as file content. Can be an actual file contents, or referenced by a URL to an external system.
 *
 * http://hl7.org/fhir/formatted
 */
export declare const formatted = "http://hl7.org/fhir/formatted";
/**
 * restoreDate
 *
 * MarketingStatus.restoreDate: The date when the Medicinal Product is placed on the market by the Marketing Authorization Holder (or where applicable, the manufacturer/distributor) in a country and/or jurisdiction shall be provided A complete date consisting of day, month and year shall be specified using the ISO 8601 date format NOTE “Placed on the market” refers to the release of the Medicinal Product into the distribution chain.
 *
 * http://hl7.org/fhir/restoreDate
 */
export declare const restoreDate = "http://hl7.org/fhir/restoreDate";
/**
 * _grouping
 *
 * (Modified) ImplementationGuide.definition.grouping
 *
 * http://hl7.org/fhir/_grouping
 */
export declare const _grouping = "http://hl7.org/fhir/_grouping";
/**
 * definition
 *
 * QuestionnaireResponse.item.definition: A reference to an [ElementDefinition](elementdefinition.html) that provides the details for the item.
 *
 * http://hl7.org/fhir/definition
 */
export declare const definition = "http://hl7.org/fhir/definition";
/**
 * BodyStructureIncludedStructureBodyLandmarkOrientationDistanceFromLandmarkComponent
 *
 * BodyStructureIncludedStructureBodyLandmarkOrientationComponent.BodyStructureIncludedStructureBodyLandmarkOrientationDistanceFromLandmarkComponent: The distance in centimeters a certain observation is made from a body landmark.
 *
 * http://hl7.org/fhir/BodyStructureIncludedStructureBodyLandmarkOrientationDistanceFromLandmarkComponent
 */
export declare const BodyStructureIncludedStructureBodyLandmarkOrientationDistanceFromLandmarkComponent = "http://hl7.org/fhir/BodyStructureIncludedStructureBodyLandmarkOrientationDistanceFromLandmarkComponent";
/**
 * dayOfWeek
 *
 * Appointment.recurrenceTemplate.monthlyTemplate.dayOfWeek: Indicates which day of the week the recurring appointments should occur each nth week.
 *
 * http://hl7.org/fhir/dayOfWeek
 */
export declare const dayOfWeek = "http://hl7.org/fhir/dayOfWeek";
/**
 * _variableDefinition
 *
 * (Modified) Evidence.statistic.modelCharacteristic.variable.variableDefinition
 *
 * http://hl7.org/fhir/_variableDefinition
 */
export declare const _variableDefinition = "http://hl7.org/fhir/_variableDefinition";
/**
 * nodeRole
 *
 * http://hl7.org/fhir/nodeRole
 */
export declare const nodeRole = "http://hl7.org/fhir/nodeRole";
/**
 * Permission
 *
 * Permission resource holds access rules for a given data and context.
 *
 * http://hl7.org/fhir/Permission
 */
export declare const Permission = "http://hl7.org/fhir/Permission";
/**
 * dateWritten
 *
 * VisionPrescription.dateWritten: The date (and perhaps time) when the prescription was written.
 *
 * http://hl7.org/fhir/dateWritten
 */
export declare const dateWritten = "http://hl7.org/fhir/dateWritten";
/**
 * ratioHighLimitAmount
 *
 * SubstanceDefinition.relationship.ratioHighLimitAmount: For use when the numeric has an uncertain range.
 *
 * http://hl7.org/fhir/ratioHighLimitAmount
 */
export declare const ratioHighLimitAmount = "http://hl7.org/fhir/ratioHighLimitAmount";
/**
 * _relatedData
 *
 * (Modified) PlanDefinition.action.output.relatedData
 *
 * http://hl7.org/fhir/_relatedData
 */
export declare const _relatedData = "http://hl7.org/fhir/_relatedData";
/**
 * _inforce
 *
 * (Modified) CoverageEligibilityResponse.insurance.inforce
 *
 * http://hl7.org/fhir/_inforce
 */
export declare const _inforce = "http://hl7.org/fhir/_inforce";
/**
 * _reportingVendor
 *
 * (Modified) MeasureReport.reportingVendor
 *
 * http://hl7.org/fhir/_reportingVendor
 */
export declare const _reportingVendor = "http://hl7.org/fhir/_reportingVendor";
/**
 * _sequenceRange
 *
 * (Modified) MolecularSequence.relative.sequenceRange
 *
 * http://hl7.org/fhir/_sequenceRange
 */
export declare const _sequenceRange = "http://hl7.org/fhir/_sequenceRange";
/**
 * member
 *
 * Group.member: Identifies the resource instances that are members of the group.
 *
 * http://hl7.org/fhir/member
 */
export declare const member = "http://hl7.org/fhir/member";
/**
 * _versionAlgorithm
 *
 * (Modified) Library.versionAlgorithm
 *
 * http://hl7.org/fhir/_versionAlgorithm
 */
export declare const _versionAlgorithm = "http://hl7.org/fhir/_versionAlgorithm";
/**
 * _subject
 *
 * (Modified) Condition.subject
 *
 * http://hl7.org/fhir/_subject
 */
export declare const _subject = "http://hl7.org/fhir/_subject";
/**
 * _case
 *
 * (Modified) RegulatedAuthorization.case
 *
 * http://hl7.org/fhir/_case
 */
export declare const _case = "http://hl7.org/fhir/_case";
/**
 * _ClinicalUseDefinition
 *
 * (Modified) ClinicalUseDefinition
 *
 * http://hl7.org/fhir/_ClinicalUseDefinition
 */
export declare const _ClinicalUseDefinition = "http://hl7.org/fhir/_ClinicalUseDefinition";
/**
 * _cylinder
 *
 * (Modified) VisionPrescription.lensSpecification.cylinder
 *
 * http://hl7.org/fhir/_cylinder
 */
export declare const _cylinder = "http://hl7.org/fhir/_cylinder";
/**
 * _saturday
 *
 * (Modified) Appointment.recurrenceTemplate.weeklyTemplate.saturday
 *
 * http://hl7.org/fhir/_saturday
 */
export declare const _saturday = "http://hl7.org/fhir/_saturday";
/**
 * ConceptMapGroupUnmappedComponent
 *
 * ConceptMapGroupComponent.ConceptMapGroupUnmappedComponent: What to do when there is no mapping to a target concept from the source concept and ConceptMap.group.element.noMap is not true. This provides the "default" to be applied when there is no target concept mapping specified or the expansion of ConceptMap.group.element.target.valueSet is empty.
 *
 * http://hl7.org/fhir/ConceptMapGroupUnmappedComponent
 */
export declare const ConceptMapGroupUnmappedComponent = "http://hl7.org/fhir/ConceptMapGroupUnmappedComponent";
/**
 * Address
 *
 * An address expressed using postal conventions (as opposed to GPS or other location definition formats).  This data type may be used to convey addresses for use in delivering mail as well as for visiting locations which might not be valid for mail delivery.  There are a variety of postal address formats defined around the world.
 * The ISO21090-codedString may be used to provide a coded representation of the contents of strings in an Address.
 *
 * http://hl7.org/fhir/Address
 */
export declare const Address = "http://hl7.org/fhir/Address";
/**
 * _validateCode
 *
 * (Modified) TerminologyCapabilities.validateCode
 *
 * http://hl7.org/fhir/_validateCode
 */
export declare const _validateCode = "http://hl7.org/fhir/_validateCode";
/**
 * _dispenser
 *
 * (Modified) MedicationRequest.dispenseRequest.dispenser
 *
 * http://hl7.org/fhir/_dispenser
 */
export declare const _dispenser = "http://hl7.org/fhir/_dispenser";
/**
 * _issued
 *
 * (Modified) TestReport.issued
 *
 * http://hl7.org/fhir/_issued
 */
export declare const _issued = "http://hl7.org/fhir/_issued";
/**
 * TestReport
 *
 * A summary of information based on the results of executing a TestScript.
 *
 * http://hl7.org/fhir/TestReport
 */
export declare const TestReport = "http://hl7.org/fhir/TestReport";
/**
 * conditionalRead
 *
 * CapabilityStatement.rest.resource.conditionalRead: A code that indicates how the server supports conditional read.
 *
 * http://hl7.org/fhir/conditionalRead
 */
export declare const conditionalRead = "http://hl7.org/fhir/conditionalRead";
/**
 * fullUrl
 *
 * Bundle.entry.fullUrl: The Absolute URL for the resource. Except for transactions and batches, each entry in a Bundle must have a fullUrl. The fullUrl SHALL NOT disagree with the id in the resource - i.e. if the fullUrl is not a urn:uuid, the URL shall be version-independent URL consistent with the Resource.id. The fullUrl is a version independent reference to the resource. Even when not required, fullUrl MAY be set to a urn:uuid to allow referencing entries in a transaction. The fullUrl can be an arbitrary URI and is not limited to urn:uuid, urn:oid, http, and https. The fullUrl element SHALL have a value except when:
 * * invoking a create
 * * invoking or responding to an operation where the body is not a single identified resource
 * * invoking or returning the results of a search or history operation.
 *
 * http://hl7.org/fhir/fullUrl
 */
export declare const fullUrl = "http://hl7.org/fhir/fullUrl";
/**
 * parameterFocus
 *
 * ServiceRequest.orderDetail.parameterFocus: Indicates the context of the order details by reference.
 *
 * http://hl7.org/fhir/parameterFocus
 */
export declare const parameterFocus = "http://hl7.org/fhir/parameterFocus";
/**
 * _currentState
 *
 * (Modified) Citation.citedArtifact.currentState
 *
 * http://hl7.org/fhir/_currentState
 */
export declare const _currentState = "http://hl7.org/fhir/_currentState";
/**
 * ActivityDefinition
 *
 * This resource allows for the definition of some activity to be performed, independent of a particular patient, practitioner, or other performance context.
 *
 * http://hl7.org/fhir/ActivityDefinition
 */
export declare const ActivityDefinition = "http://hl7.org/fhir/ActivityDefinition";
/**
 * daysOfWeek
 *
 * Availability.availableTime.daysOfWeek: mon | tue | wed | thu | fri | sat | sun.
 *
 * http://hl7.org/fhir/daysOfWeek
 */
export declare const daysOfWeek = "http://hl7.org/fhir/daysOfWeek";
/**
 * containedInstance
 *
 * ExampleScenario.instance.containedInstance: References to other instances that can be found within this instance (e.g. the observations contained in a bundle).
 *
 * http://hl7.org/fhir/containedInstance
 */
export declare const containedInstance = "http://hl7.org/fhir/containedInstance";
/**
 * StructureMapGroupRuleSourceComponent
 *
 * StructureMapGroupComponent.StructureMapGroupRuleComponentRule.StructureMapGroupRuleSourceComponent: Source inputs to the mapping.
 *
 * http://hl7.org/fhir/StructureMapGroupRuleSourceComponent
 */
export declare const StructureMapGroupRuleSourceComponent = "http://hl7.org/fhir/StructureMapGroupRuleSourceComponent";
/**
 * application
 *
 * RegulatedAuthorization.case.application: A regulatory submission from an organization to a regulator, as part of an assessing case. Multiple applications may occur over time, with more or different information to support or modify the submission or the authorization. The applications can be considered as steps within the longer running case or procedure for this authorization process.
 *
 * http://hl7.org/fhir/application
 */
export declare const application = "http://hl7.org/fhir/application";
/**
 * received
 *
 * Communication.received: The time when this communication arrived at the destination.
 *
 * http://hl7.org/fhir/received
 */
export declare const received = "http://hl7.org/fhir/received";
/**
 * AuditEventEntityComponentAgent
 *
 * The entity is attributed to an agent to express the agent's responsibility for that entity in the activity. This is most used to indicate when persistence media (the entity) are used by an agent. For example when importing data from a device, the device would be described in an entity, and the user importing data from that media would be indicated as the entity.agent.
 *
 * http://hl7.org/fhir/AuditEventEntityComponentAgent
 */
export declare const AuditEventEntityComponentAgent = "http://hl7.org/fhir/AuditEventEntityComponentAgent";
/**
 * element
 *
 * StructureDefinition.differential.element: Captures constraints on each element within the resource.
 *
 * http://hl7.org/fhir/element
 */
export declare const element = "http://hl7.org/fhir/element";
/**
 * _compose
 *
 * (Modified) ValueSet.compose
 *
 * http://hl7.org/fhir/_compose
 */
export declare const _compose = "http://hl7.org/fhir/_compose";
/**
 * _environmentalSetting
 *
 * (Modified) MedicationKnowledge.storageGuideline.environmentalSetting
 *
 * http://hl7.org/fhir/_environmentalSetting
 */
export declare const _environmentalSetting = "http://hl7.org/fhir/_environmentalSetting";
/**
 * _payment
 *
 * (Modified) PaymentNotice.payment
 *
 * http://hl7.org/fhir/_payment
 */
export declare const _payment = "http://hl7.org/fhir/_payment";
/**
 * _preparedDate
 *
 * (Modified) DeviceDispense.preparedDate
 *
 * http://hl7.org/fhir/_preparedDate
 */
export declare const _preparedDate = "http://hl7.org/fhir/_preparedDate";
/**
 * ImagingSelectionInstanceComponent
 *
 * ImagingSelectionInstanceComponent: Each imaging selection includes one or more selected DICOM SOP instances.
 *
 * http://hl7.org/fhir/ImagingSelectionInstanceComponent
 */
export declare const ImagingSelectionInstanceComponent = "http://hl7.org/fhir/ImagingSelectionInstanceComponent";
/**
 * _responseRequired
 *
 * (Modified) MessageDefinition.responseRequired
 *
 * http://hl7.org/fhir/_responseRequired
 */
export declare const _responseRequired = "http://hl7.org/fhir/_responseRequired";
/**
 * _contraindication
 *
 * (Modified) DeviceDefinition.guideline.contraindication
 *
 * http://hl7.org/fhir/_contraindication
 */
export declare const _contraindication = "http://hl7.org/fhir/_contraindication";
/**
 * _operator
 *
 * (Modified) TestScript.test.action.assert.operator
 *
 * http://hl7.org/fhir/_operator
 */
export declare const _operator = "http://hl7.org/fhir/_operator";
/**
 * ActivityDefinitionParticipantComponent
 *
 * ActivityDefinitionParticipantComponent: Indicates who should participate in performing the action described.
 *
 * http://hl7.org/fhir/ActivityDefinitionParticipantComponent
 */
export declare const ActivityDefinitionParticipantComponent = "http://hl7.org/fhir/ActivityDefinitionParticipantComponent";
/**
 * _contraindicatedVaccineCode
 *
 * (Modified) ImmunizationRecommendation.recommendation.contraindicatedVaccineCode
 *
 * http://hl7.org/fhir/_contraindicatedVaccineCode
 */
export declare const _contraindicatedVaccineCode = "http://hl7.org/fhir/_contraindicatedVaccineCode";
/**
 * _membership
 *
 * (Modified) Group.membership
 *
 * http://hl7.org/fhir/_membership
 */
export declare const _membership = "http://hl7.org/fhir/_membership";
/**
 * _recordedDate
 *
 * (Modified) Condition.recordedDate
 *
 * http://hl7.org/fhir/_recordedDate
 */
export declare const _recordedDate = "http://hl7.org/fhir/_recordedDate";
/**
 * _provision
 *
 * (Modified) Consent.provision.provision
 *
 * http://hl7.org/fhir/_provision
 */
export declare const _provision = "http://hl7.org/fhir/_provision";
/**
 * _dietPreference
 *
 * (Modified) Encounter.dietPreference
 *
 * http://hl7.org/fhir/_dietPreference
 */
export declare const _dietPreference = "http://hl7.org/fhir/_dietPreference";
/**
 * _laterality
 *
 * (Modified) ImagingStudy.series.laterality
 *
 * http://hl7.org/fhir/_laterality
 */
export declare const _laterality = "http://hl7.org/fhir/_laterality";
/**
 * _parentSubstanceId
 *
 * (Modified) SubstanceSourceMaterial.parentSubstanceId
 *
 * http://hl7.org/fhir/_parentSubstanceId
 */
export declare const _parentSubstanceId = "http://hl7.org/fhir/_parentSubstanceId";
/**
 * _report
 *
 * (Modified) Procedure.report
 *
 * http://hl7.org/fhir/_report
 */
export declare const _report = "http://hl7.org/fhir/_report";
/**
 * MedicationDispensePerformerComponent
 *
 * MedicationDispensePerformerComponent: Indicates who or what performed the event.
 *
 * http://hl7.org/fhir/MedicationDispensePerformerComponent
 */
export declare const MedicationDispensePerformerComponent = "http://hl7.org/fhir/MedicationDispensePerformerComponent";
/**
 * FamilyMemberHistoryConditionComponent
 *
 * FamilyMemberHistoryConditionComponent: The significant Conditions (or condition) that the family member had. This is a repeating section to allow a system to represent more than one condition per resource, though there is nothing stopping multiple resources - one per condition.
 *
 * http://hl7.org/fhir/FamilyMemberHistoryConditionComponent
 */
export declare const FamilyMemberHistoryConditionComponent = "http://hl7.org/fhir/FamilyMemberHistoryConditionComponent";
/**
 * _editor
 *
 * (Modified) EvidenceVariable.editor
 *
 * http://hl7.org/fhir/_editor
 */
export declare const _editor = "http://hl7.org/fhir/_editor";
/**
 * instant
 *
 * An instant in time - known at least to the second
 *
 * http://hl7.org/fhir/instant
 */
export declare const instant = "http://hl7.org/fhir/instant";
/**
 * paging
 *
 * TerminologyCapabilities.expansion.paging: Whether the server supports paging on expansion.
 *
 * http://hl7.org/fhir/paging
 */
export declare const paging = "http://hl7.org/fhir/paging";
/**
 * _receiverActive
 *
 * (Modified) ExampleScenario.process.step.alternative.step.operation.receiverActive
 *
 * http://hl7.org/fhir/_receiverActive
 */
export declare const _receiverActive = "http://hl7.org/fhir/_receiverActive";
/**
 * publicationForm
 *
 * Citation.citedArtifact.publicationForm: If multiple, used to represent alternative forms of the article that are not separate citations.
 *
 * http://hl7.org/fhir/publicationForm
 */
export declare const publicationForm = "http://hl7.org/fhir/publicationForm";
/**
 * operation
 *
 * TestScript.teardown.action.operation: An operation would involve a REST request to a server.
 *
 * http://hl7.org/fhir/operation
 */
export declare const operation = "http://hl7.org/fhir/operation";
/**
 * organism
 *
 * SubstanceSourceMaterial.organism: This subclause describes the organism which the substance is derived from. For vaccines, the parent organism shall be specified based on these subclause elements. As an example, full taxonomy will be described for the Substance Name: ., Leaf.
 *
 * http://hl7.org/fhir/organism
 */
export declare const organism = "http://hl7.org/fhir/organism";
/**
 * focus
 *
 * Composition.section.focus: The actual focus of the section when it is not the subject of the composition, but instead represents something or someone associated with the subject such as (for a patient subject) a spouse, parent, fetus, or donor. If not focus is specified, the focus is assumed to be focus of the parent section, or, for a section in the Composition itself, the subject of the composition. Sections with a focus SHALL only include resources where the logical subject (patient, subject, focus, etc.) matches the section focus, or the resources have no logical subject (few resources).
 *
 * http://hl7.org/fhir/focus
 */
export declare const focus = "http://hl7.org/fhir/focus";
/**
 * _reviewer
 *
 * (Modified) EvidenceVariable.reviewer
 *
 * http://hl7.org/fhir/_reviewer
 */
export declare const _reviewer = "http://hl7.org/fhir/_reviewer";
/**
 * validCodedValueSet
 *
 * ObservationDefinition.component.qualifiedValue.validCodedValueSet: The set of valid coded results for qualitative observations  that match the criteria of this set of qualified values.
 *
 * http://hl7.org/fhir/validCodedValueSet
 */
export declare const validCodedValueSet = "http://hl7.org/fhir/validCodedValueSet";
/**
 * Signatory
 *
 * Contract.Signatory: Parties with legal standing in the Contract, including the principal parties, the grantor(s) and grantee(s), which are any person or organization bound by the contract, and any ancillary parties, which facilitate the execution of the contract such as a notary or witness.
 *
 * http://hl7.org/fhir/Signatory
 */
export declare const Signatory = "http://hl7.org/fhir/Signatory";
/**
 * clockFacePosition
 *
 * BodyStructure.excludedStructure.bodyLandmarkOrientation.clockFacePosition: An description of the direction away from a landmark something is located based on a radial clock dial.
 *
 * http://hl7.org/fhir/clockFacePosition
 */
export declare const clockFacePosition = "http://hl7.org/fhir/clockFacePosition";
/**
 * _instanceReference
 *
 * (Modified) ExampleScenario.process.step.operation.request.instanceReference
 *
 * http://hl7.org/fhir/_instanceReference
 */
export declare const _instanceReference = "http://hl7.org/fhir/_instanceReference";
/**
 * withdrawalPeriod
 *
 * AdministrableProductDefinition.routeOfAdministration.targetSpecies.withdrawalPeriod: A species specific time during which consumption of animal product is not appropriate.
 *
 * http://hl7.org/fhir/withdrawalPeriod
 */
export declare const withdrawalPeriod = "http://hl7.org/fhir/withdrawalPeriod";
/**
 * conformance
 *
 * TestScript.scope.conformance: The expectation of whether the test must pass for the system to be considered conformant with the artifact: required - all tests are expected to pass, optional - all test are expected to pass but non-pass status may be allowed, strict - all tests are expected to pass and warnings are treated as a failure.
 *
 * http://hl7.org/fhir/conformance
 */
export declare const conformance = "http://hl7.org/fhir/conformance";
/**
 * effectivePeriod
 *
 * EvidenceVariable.effectivePeriod: The period during which the resource content was or is planned to be in active use.
 *
 * http://hl7.org/fhir/effectivePeriod
 */
export declare const effectivePeriod = "http://hl7.org/fhir/effectivePeriod";
/**
 * _matchStatus
 *
 * (Modified) BiologicallyDerivedProductDispense.matchStatus
 *
 * http://hl7.org/fhir/_matchStatus
 */
export declare const _matchStatus = "http://hl7.org/fhir/_matchStatus";
/**
 * virtualService
 *
 * Location.virtualService: Connection details of a virtual service (e.g. shared conference call facility with dedicated number/details).
 *
 * http://hl7.org/fhir/virtualService
 */
export declare const virtualService = "http://hl7.org/fhir/virtualService";
/**
 * Communication
 *
 * A clinical or business level record of information being transmitted or shared; e.g. an alert that was sent to a responsible provider, a public health agency communication to a provider/reporter in response to a case report for a reportable condition.
 *
 * http://hl7.org/fhir/Communication
 */
export declare const Communication = "http://hl7.org/fhir/Communication";
/**
 * _enteralFormula
 *
 * (Modified) NutritionOrder.enteralFormula
 *
 * http://hl7.org/fhir/_enteralFormula
 */
export declare const _enteralFormula = "http://hl7.org/fhir/_enteralFormula";
/**
 * whenHandedOver
 *
 * MedicationDispense.whenHandedOver: The time the dispensed product was provided to the patient or their representative.
 *
 * http://hl7.org/fhir/whenHandedOver
 */
export declare const whenHandedOver = "http://hl7.org/fhir/whenHandedOver";
/**
 * EvidenceReportSubjectComponent
 *
 * EvidenceReportSubjectComponent: Specifies the subject or focus of the report. Answers "What is this report about?".
 *
 * http://hl7.org/fhir/EvidenceReportSubjectComponent
 */
export declare const EvidenceReportSubjectComponent = "http://hl7.org/fhir/EvidenceReportSubjectComponent";
/**
 * substance
 *
 * Ingredient.substance: The substance that comprises this ingredient.
 *
 * http://hl7.org/fhir/substance
 */
export declare const substance = "http://hl7.org/fhir/substance";
/**
 * Section
 *
 * EvidenceReport.Section: The root of the sections that make up the composition.
 *
 * http://hl7.org/fhir/Section
 */
export declare const Section = "http://hl7.org/fhir/Section";
/**
 * _valueRange
 *
 * (Modified) Evidence.statistic.modelCharacteristic.variable.valueRange
 *
 * http://hl7.org/fhir/_valueRange
 */
export declare const _valueRange = "http://hl7.org/fhir/_valueRange";
/**
 * regulatoryIdentifier
 *
 * DeviceDefinition.regulatoryIdentifier: Identifier associated with the regulatory documentation (certificates, technical documentation, post-market surveillance documentation and reports) of a set of device models sharing the same intended purpose, risk class and essential design and manufacturing characteristics. One example is the Basic UDI-DI in Europe.
 *
 * http://hl7.org/fhir/regulatoryIdentifier
 */
export declare const regulatoryIdentifier = "http://hl7.org/fhir/regulatoryIdentifier";
/**
 * kind
 *
 * NamingSystem.kind: Indicates the purpose for the naming system - what kinds of things does it make unique?
 *
 * http://hl7.org/fhir/kind
 */
export declare const kind = "http://hl7.org/fhir/kind";
/**
 * hasIngredient
 *
 * ManufacturedItemDefinition.component.component.constituent.hasIngredient: The ingredient that is the constituent of the given component.
 *
 * http://hl7.org/fhir/hasIngredient
 */
export declare const hasIngredient = "http://hl7.org/fhir/hasIngredient";
/**
 * detailSequence
 *
 * ClaimResponse.addItem.detailSequence: The sequence number of the details within the claim item which this line is intended to replace.
 *
 * http://hl7.org/fhir/detailSequence
 */
export declare const detailSequence = "http://hl7.org/fhir/detailSequence";
/**
 * NutritionProductNutrientComponent
 *
 * NutritionProductNutrientComponent: The product's nutritional information expressed by the nutrients.
 *
 * http://hl7.org/fhir/NutritionProductNutrientComponent
 */
export declare const NutritionProductNutrientComponent = "http://hl7.org/fhir/NutritionProductNutrientComponent";
/**
 * _fractionDescription
 *
 * (Modified) SubstanceSourceMaterial.fractionDescription
 *
 * http://hl7.org/fhir/_fractionDescription
 */
export declare const _fractionDescription = "http://hl7.org/fhir/_fractionDescription";
/**
 * _degreeOfPolymerisation
 *
 * (Modified) SubstancePolymer.repeat.repeatUnit.degreeOfPolymerisation
 *
 * http://hl7.org/fhir/_degreeOfPolymerisation
 */
export declare const _degreeOfPolymerisation = "http://hl7.org/fhir/_degreeOfPolymerisation";
/**
 * _Account
 *
 * (Modified) Account
 *
 * http://hl7.org/fhir/_Account
 */
export declare const _Account = "http://hl7.org/fhir/_Account";
/**
 * rangeCategory
 *
 * ObservationDefinition.component.qualifiedValue.rangeCategory: The category of range of values for continuous or ordinal observations that match the criteria of this set of qualified values.
 *
 * http://hl7.org/fhir/rangeCategory
 */
export declare const rangeCategory = "http://hl7.org/fhir/rangeCategory";
/**
 * _index
 *
 * (Modified) TestScript.destination.index
 *
 * http://hl7.org/fhir/_index
 */
export declare const _index = "http://hl7.org/fhir/_index";
/**
 * ValueSetComposeComponentInclude
 *
 * Exclude one or more codes from the value set based on code system filters and/or other value sets.
 *
 * http://hl7.org/fhir/ValueSetComposeComponentInclude
 */
export declare const ValueSetComposeComponentInclude = "http://hl7.org/fhir/ValueSetComposeComponentInclude";
/**
 * regulatory
 *
 * MedicationKnowledge.regulatory: Regulatory information about a medication.
 *
 * http://hl7.org/fhir/regulatory
 */
export declare const regulatory = "http://hl7.org/fhir/regulatory";
/**
 * _modifier
 *
 * (Modified) ExplanationOfBenefit.addItem.modifier
 *
 * http://hl7.org/fhir/_modifier
 */
export declare const _modifier = "http://hl7.org/fhir/_modifier";
/**
 * _short
 *
 * (Modified) ElementDefinition.short
 *
 * http://hl7.org/fhir/_short
 */
export declare const _short = "http://hl7.org/fhir/_short";
/**
 * medication
 *
 * MedicationRequest.medication: Identifies the medication being requested. This is a link to a resource that represents the medication which may be the details of the medication or simply an attribute carrying a code that identifies the medication from a known list of medications.
 *
 * http://hl7.org/fhir/medication
 */
export declare const medication = "http://hl7.org/fhir/medication";
/**
 * codeSearch
 *
 * TerminologyCapabilities.codeSearch: The degree to which the server supports the code search parameter on ValueSet, if it is supported.
 *
 * http://hl7.org/fhir/codeSearch
 */
export declare const codeSearch = "http://hl7.org/fhir/codeSearch";
/**
 * suffix
 *
 * HumanName.suffix: Part of the name that is acquired as a title due to academic, legal, employment or nobility status, etc. and that appears at the end of the name.
 *
 * http://hl7.org/fhir/suffix
 */
export declare const suffix = "http://hl7.org/fhir/suffix";
/**
 * MedicationDispenseSubstitutionComponent
 *
 * MedicationDispenseSubstitutionComponent: Indicates whether or not substitution was made as part of the dispense.  In some cases, substitution will be expected but does not happen, in other cases substitution is not expected but does happen.  This block explains what substitution did or did not happen and why.  If nothing is specified, substitution was not done.
 *
 * http://hl7.org/fhir/MedicationDispenseSubstitutionComponent
 */
export declare const MedicationDispenseSubstitutionComponent = "http://hl7.org/fhir/MedicationDispenseSubstitutionComponent";
/**
 * foodPreferenceModifier
 *
 * NutritionOrder.foodPreferenceModifier: This modifier is used to convey order-specific modifiers about the type of food that should be given. These can be derived from patient allergies, intolerances, or preferences such as Halal, Vegan or Kosher. This modifier applies to the entire nutrition order inclusive of the oral diet, nutritional supplements and enteral formula feedings.
 *
 * http://hl7.org/fhir/foodPreferenceModifier
 */
export declare const foodPreferenceModifier = "http://hl7.org/fhir/foodPreferenceModifier";
/**
 * Immunization
 *
 * Describes the event of a patient being administered a vaccine or a record of an immunization as reported by a patient, a clinician or another party.
 *
 * http://hl7.org/fhir/Immunization
 */
export declare const Immunization = "http://hl7.org/fhir/Immunization";
/**
 * AppointmentRecurrenceTemplateMonthlyTemplateComponent
 *
 * AppointmentRecurrenceTemplateComponent.AppointmentRecurrenceTemplateMonthlyTemplateComponent: Information about monthly recurring appointments.
 *
 * http://hl7.org/fhir/AppointmentRecurrenceTemplateMonthlyTemplateComponent
 */
export declare const AppointmentRecurrenceTemplateMonthlyTemplateComponent = "http://hl7.org/fhir/AppointmentRecurrenceTemplateMonthlyTemplateComponent";
/**
 * preventiveAction
 *
 * AdverseEvent.preventiveAction: Preventive actions that contributed to avoiding the adverse event.
 *
 * http://hl7.org/fhir/preventiveAction
 */
export declare const preventiveAction = "http://hl7.org/fhir/preventiveAction";
/**
 * _AdministrableProductDefinition
 *
 * (Modified) AdministrableProductDefinition
 *
 * http://hl7.org/fhir/_AdministrableProductDefinition
 */
export declare const _AdministrableProductDefinition = "http://hl7.org/fhir/_AdministrableProductDefinition";
/**
 * _deliverFrom
 *
 * (Modified) SupplyRequest.deliverFrom
 *
 * http://hl7.org/fhir/_deliverFrom
 */
export declare const _deliverFrom = "http://hl7.org/fhir/_deliverFrom";
/**
 * _address
 *
 * (Modified) RelatedPerson.address
 *
 * http://hl7.org/fhir/_address
 */
export declare const _address = "http://hl7.org/fhir/_address";
/**
 * intendedUse
 *
 * RegulatedAuthorization.intendedUse: The intended use of the product, e.g. prevention, treatment, diagnosis.
 *
 * http://hl7.org/fhir/intendedUse
 */
export declare const intendedUse = "http://hl7.org/fhir/intendedUse";
/**
 * ElementDefinitionSlicingDiscriminatorComponent
 *
 * ElementDefinitionSlicingComponent.ElementDefinitionSlicingDiscriminatorComponent: Designates which child elements are used to discriminate between the slices when processing an instance. If one or more discriminators are provided, the value of the child elements in the instance data SHALL completely distinguish which slice the element in the resource matches based on the allowed values for those elements in each of the slices.
 *
 * http://hl7.org/fhir/ElementDefinitionSlicingDiscriminatorComponent
 */
export declare const ElementDefinitionSlicingDiscriminatorComponent = "http://hl7.org/fhir/ElementDefinitionSlicingDiscriminatorComponent";
/**
 * SubscriptionTopic
 *
 * Describes a stream of resource state changes identified by trigger criteria and annotated with labels useful to filter projections from this topic.
 *
 * http://hl7.org/fhir/SubscriptionTopic
 */
export declare const SubscriptionTopic = "http://hl7.org/fhir/SubscriptionTopic";
/**
 * GenomicStudy
 *
 * A set of analyses performed to analyze and generate genomic data.
 *
 * http://hl7.org/fhir/GenomicStudy
 */
export declare const GenomicStudy = "http://hl7.org/fhir/GenomicStudy";
/**
 * _partLocation
 *
 * (Modified) SubstanceSourceMaterial.partDescription.partLocation
 *
 * http://hl7.org/fhir/_partLocation
 */
export declare const _partLocation = "http://hl7.org/fhir/_partLocation";
/**
 * _subsumption
 *
 * (Modified) TerminologyCapabilities.codeSystem.subsumption
 *
 * http://hl7.org/fhir/_subsumption
 */
export declare const _subsumption = "http://hl7.org/fhir/_subsumption";
/**
 * BenefitBalance
 *
 * ExplanationOfBenefit.BenefitBalance: Balance by Benefit Category.
 *
 * http://hl7.org/fhir/BenefitBalance
 */
export declare const BenefitBalance = "http://hl7.org/fhir/BenefitBalance";
/**
 * script
 *
 * TestPlan.testCase.testRun.script: The test cases in a structured language e.g. gherkin, Postman, or FHIR TestScript.
 *
 * http://hl7.org/fhir/script
 */
export declare const script = "http://hl7.org/fhir/script";
/**
 * _resourceReference
 *
 * (Modified) Citation.citedArtifact.relatesTo.resourceReference
 *
 * http://hl7.org/fhir/_resourceReference
 */
export declare const _resourceReference = "http://hl7.org/fhir/_resourceReference";
/**
 * lastReviewDate
 *
 * EventDefinition.lastReviewDate: The date on which the resource content was last reviewed. Review happens periodically after approval but does not change the original approval date.
 *
 * http://hl7.org/fhir/lastReviewDate
 */
export declare const lastReviewDate = "http://hl7.org/fhir/lastReviewDate";
/**
 * SubstanceDefinitionNameComponentNameName
 *
 * A translation for this name into another human language.
 *
 * http://hl7.org/fhir/SubstanceDefinitionNameComponentNameName
 */
export declare const SubstanceDefinitionNameComponentNameName = "http://hl7.org/fhir/SubstanceDefinitionNameComponentNameName";
/**
 * length
 *
 * Encounter.length: Actual quantity of time the encounter lasted. This excludes the time during leaves of absence.

When missing it is the time in between the start and end values.
 *
 * http://hl7.org/fhir/length
 */
export declare const length = "http://hl7.org/fhir/length";
/**
 * _overrideReason
 *
 * (Modified) ChargeItem.overrideReason
 *
 * http://hl7.org/fhir/_overrideReason
 */
export declare const _overrideReason = "http://hl7.org/fhir/_overrideReason";
/**
 * _period
 *
 * (Modified) Coverage.costToBeneficiary.exception.period
 *
 * http://hl7.org/fhir/_period
 */
export declare const _period = "http://hl7.org/fhir/_period";
/**
 * TerminologyCapabilities
 *
 * A TerminologyCapabilities resource documents a set of capabilities (behaviors) of a FHIR Terminology Server that may be used as a statement of actual server functionality or a statement of required or desired server implementation.
 *
 * http://hl7.org/fhir/TerminologyCapabilities
 */
export declare const TerminologyCapabilities = "http://hl7.org/fhir/TerminologyCapabilities";
/**
 * _supportingPatientInformation
 *
 * (Modified) ImmunizationRecommendation.recommendation.supportingPatientInformation
 *
 * http://hl7.org/fhir/_supportingPatientInformation
 */
export declare const _supportingPatientInformation = "http://hl7.org/fhir/_supportingPatientInformation";
/**
 * OperationDefinitionParameterBindingComponent
 *
 * OperationDefinitionParameterComponentParameter.OperationDefinitionParameterBindingComponent: Binds to a value set if this parameter is coded (code, Coding, CodeableConcept).
 *
 * http://hl7.org/fhir/OperationDefinitionParameterBindingComponent
 */
export declare const OperationDefinitionParameterBindingComponent = "http://hl7.org/fhir/OperationDefinitionParameterBindingComponent";
/**
 * Task
 *
 * A task to be performed.
 *
 * http://hl7.org/fhir/Task
 */
export declare const Task = "http://hl7.org/fhir/Task";
/**
 * MeasureReportGroupPopulationComponent
 *
 * MeasureReportGroupComponent.MeasureReportGroupPopulationComponent: The populations that make up the population group, one for each type of population appropriate for the measure.
 *
 * http://hl7.org/fhir/MeasureReportGroupPopulationComponent
 */
export declare const MeasureReportGroupPopulationComponent = "http://hl7.org/fhir/MeasureReportGroupPopulationComponent";
/**
 * revInclude
 *
 * SubscriptionTopic.notificationShape.revInclude: Search-style _revinclude directives, rooted in the resource for this shape. Servers SHOULD include resources listed here, if they exist and the user is authorized to receive them.  Clients SHOULD be prepared to receive these additional resources, but SHALL function properly without them.
 *
 * http://hl7.org/fhir/revInclude
 */
export declare const revInclude = "http://hl7.org/fhir/revInclude";
/**
 * _appliesTo
 *
 * (Modified) ObservationDefinition.component.qualifiedValue.appliesTo
 *
 * http://hl7.org/fhir/_appliesTo
 */
export declare const _appliesTo = "http://hl7.org/fhir/_appliesTo";
/**
 * MedicationKnowledgeDefinitionalComponent
 *
 * MedicationKnowledgeDefinitionalComponent: Along with the link to a Medicinal Product Definition resource, this information provides common definitional elements that are needed to understand the specific medication that is being described.
 *
 * http://hl7.org/fhir/MedicationKnowledgeDefinitionalComponent
 */
export declare const MedicationKnowledgeDefinitionalComponent = "http://hl7.org/fhir/MedicationKnowledgeDefinitionalComponent";
/**
 * usageInstruction
 *
 * DeviceDispense.usageInstruction: The full representation of the instructions.
 *
 * http://hl7.org/fhir/usageInstruction
 */
export declare const usageInstruction = "http://hl7.org/fhir/usageInstruction";
/**
 * trigger
 *
 * PlanDefinition.action.action.trigger: A description of when the action should be triggered. When multiple triggers are specified on an action, any triggering event invokes the action.
 *
 * http://hl7.org/fhir/trigger
 */
export declare const trigger = "http://hl7.org/fhir/trigger";
/**
 * mustSupport
 *
 * ElementDefinition.mustSupport: If true, implementations that produce or consume resources SHALL provide "support" for the element in some meaningful way. Note that this is being phased out and replaced by obligations (see below).  If false, the element may be ignored and not supported. If false, whether to populate or use the data element in any way is at the discretion of the implementation.
 *
 * http://hl7.org/fhir/mustSupport
 */
export declare const mustSupport = "http://hl7.org/fhir/mustSupport";
/**
 * TimingRepeatComponent
 *
 * TimingRepeatComponent: A set of rules that describe when the event is scheduled.
 *
 * http://hl7.org/fhir/TimingRepeatComponent
 */
export declare const TimingRepeatComponent = "http://hl7.org/fhir/TimingRepeatComponent";
/**
 * effectiveDosePeriod
 *
 * MedicationRequest.effectiveDosePeriod: The period over which the medication is to be taken.  Where there are multiple dosageInstruction lines (for example, tapering doses), this is the earliest date and the latest end date of the dosageInstructions.
 *
 * http://hl7.org/fhir/effectiveDosePeriod
 */
export declare const effectiveDosePeriod = "http://hl7.org/fhir/effectiveDosePeriod";
/**
 * _textEquivalent
 *
 * (Modified) RequestOrchestration.action.action.textEquivalent
 *
 * http://hl7.org/fhir/_textEquivalent
 */
export declare const _textEquivalent = "http://hl7.org/fhir/_textEquivalent";
/**
 * bodysite
 *
 * ChargeItem.bodysite: The anatomical location where the related service has been applied.
 *
 * http://hl7.org/fhir/bodysite
 */
export declare const bodysite = "http://hl7.org/fhir/bodysite";
/**
 * _appliesToAll
 *
 * (Modified) CoverageEligibilityRequest.supportingInfo.appliesToAll
 *
 * http://hl7.org/fhir/_appliesToAll
 */
export declare const _appliesToAll = "http://hl7.org/fhir/_appliesToAll";
/**
 * comorbidity
 *
 * ClinicalUseDefinition.indication.comorbidity: A comorbidity (concurrent condition) or coinfection as part of the indication.
 *
 * http://hl7.org/fhir/comorbidity
 */
export declare const comorbidity = "http://hl7.org/fhir/comorbidity";
/**
 * TestScriptFixtureComponent
 *
 * TestScriptFixtureComponent: Fixture in the test script - by reference (uri). All fixtures are required for the test script to execute.
 *
 * http://hl7.org/fhir/TestScriptFixtureComponent
 */
export declare const TestScriptFixtureComponent = "http://hl7.org/fhir/TestScriptFixtureComponent";
/**
 * oligoNucleotideType
 *
 * SubstanceNucleicAcid.oligoNucleotideType: (TBC).
 *
 * http://hl7.org/fhir/oligoNucleotideType
 */
export declare const oligoNucleotideType = "http://hl7.org/fhir/oligoNucleotideType";
/**
 * intendedEffect
 *
 * ClinicalUseDefinition.indication.intendedEffect: The intended effect, aim or strategy to be achieved.
 *
 * http://hl7.org/fhir/intendedEffect
 */
export declare const intendedEffect = "http://hl7.org/fhir/intendedEffect";
/**
 * _conformsTo
 *
 * (Modified) DeviceDefinition.conformsTo
 *
 * http://hl7.org/fhir/_conformsTo
 */
export declare const _conformsTo = "http://hl7.org/fhir/_conformsTo";
/**
 * copyright
 *
 * CapabilityStatement.copyright: A copyright statement relating to the capability statement and/or its contents. Copyright statements are generally legal restrictions on the use and publishing of the capability statement.
 *
 * http://hl7.org/fhir/copyright
 */
export declare const copyright = "http://hl7.org/fhir/copyright";
/**
 * _insurance
 *
 * (Modified) Task.insurance
 *
 * http://hl7.org/fhir/_insurance
 */
export declare const _insurance = "http://hl7.org/fhir/_insurance";
/**
 * _partDescription
 *
 * (Modified) SubstanceSourceMaterial.partDescription
 *
 * http://hl7.org/fhir/_partDescription
 */
export declare const _partDescription = "http://hl7.org/fhir/_partDescription";
/**
 * _genomeBuild
 *
 * (Modified) GenomicStudy.analysis.genomeBuild
 *
 * http://hl7.org/fhir/_genomeBuild
 */
export declare const _genomeBuild = "http://hl7.org/fhir/_genomeBuild";
/**
 * Slot
 *
 * A slot of time on a schedule that may be available for booking appointments.
 *
 * http://hl7.org/fhir/Slot
 */
export declare const Slot = "http://hl7.org/fhir/Slot";
/**
 * _medium
 *
 * (Modified) CommunicationRequest.medium
 *
 * http://hl7.org/fhir/_medium
 */
export declare const _medium = "http://hl7.org/fhir/_medium";
/**
 * followUp
 *
 * Procedure.followUp: If the procedure required specific follow up - e.g. removal of sutures. The follow up may be represented as a simple note or could potentially be more complex, in which case the CarePlan resource can be used.
 *
 * http://hl7.org/fhir/followUp
 */
export declare const followUp = "http://hl7.org/fhir/followUp";
/**
 * maxDuration
 *
 * SpecimenDefinition.typeTested.handling.maxDuration: The maximum time interval of preservation of the specimen with these conditions.
 *
 * http://hl7.org/fhir/maxDuration
 */
export declare const maxDuration = "http://hl7.org/fhir/maxDuration";
/**
 * lotNumber
 *
 * Medication.batch.lotNumber: The assigned lot number of a batch of the specified product.
 *
 * http://hl7.org/fhir/lotNumber
 */
export declare const lotNumber = "http://hl7.org/fhir/lotNumber";
/**
 * EncounterHistoryLocationComponent
 *
 * EncounterHistoryLocationComponent: The location of the patient at this point in the encounter, the multiple cardinality permits de-normalizing the levels of the location hierarchy, such as site/ward/room/bed.
 *
 * http://hl7.org/fhir/EncounterHistoryLocationComponent
 */
export declare const EncounterHistoryLocationComponent = "http://hl7.org/fhir/EncounterHistoryLocationComponent";
/**
 * _owner
 *
 * (Modified) Transport.owner
 *
 * http://hl7.org/fhir/_owner
 */
export declare const _owner = "http://hl7.org/fhir/_owner";
/**
 * InventoryItem
 *
 * functional description of an inventory item used in inventory and supply-related workflows.
 *
 * http://hl7.org/fhir/InventoryItem
 */
export declare const InventoryItem = "http://hl7.org/fhir/InventoryItem";
/**
 * content
 *
 * Library.content: The content of the library as an Attachment. The content may be a reference to a url, or may be directly embedded as a base-64 string. Either way, the contentType of the attachment determines how to interpret the content.
 *
 * http://hl7.org/fhir/content
 */
export declare const content = "http://hl7.org/fhir/content";
/**
 * DeviceDefinitionPropertyComponent
 *
 * DeviceDefinitionPropertyComponent: Static or essentially fixed characteristics or features of this kind of device that are otherwise not captured in more specific attributes, e.g., time or timing attributes, resolution, accuracy, and physical attributes.
 *
 * http://hl7.org/fhir/DeviceDefinitionPropertyComponent
 */
export declare const DeviceDefinitionPropertyComponent = "http://hl7.org/fhir/DeviceDefinitionPropertyComponent";
/**
 * enteredDate
 *
 * ChargeItem.enteredDate: Date the charge item was entered.
 *
 * http://hl7.org/fhir/enteredDate
 */
export declare const enteredDate = "http://hl7.org/fhir/enteredDate";
/**
 * _district
 *
 * (Modified) Address.district
 *
 * http://hl7.org/fhir/_district
 */
export declare const _district = "http://hl7.org/fhir/_district";
/**
 * QuestionnaireItemComponentItemItem
 *
 * Text, questions and other groups to be nested beneath a question or group.
 *
 * http://hl7.org/fhir/QuestionnaireItemComponentItemItem
 */
export declare const QuestionnaireItemComponentItemItem = "http://hl7.org/fhir/QuestionnaireItemComponentItemItem";
/**
 * eye
 *
 * VisionPrescription.lensSpecification.eye: The eye for which the lens specification applies.
 *
 * http://hl7.org/fhir/eye
 */
export declare const eye = "http://hl7.org/fhir/eye";
/**
 * facilityType
 *
 * DocumentReference.facilityType: The kind of facility where the patient was seen.
 *
 * http://hl7.org/fhir/facilityType
 */
export declare const facilityType = "http://hl7.org/fhir/facilityType";
/**
 * markdown
 *
 * A string that may contain Github Flavored Markdown syntax for optional processing by a mark down presentation engine
 *
 * http://hl7.org/fhir/markdown
 */
export declare const markdown = "http://hl7.org/fhir/markdown";
/**
 * _friendly
 *
 * (Modified) Contract.friendly
 *
 * http://hl7.org/fhir/_friendly
 */
export declare const _friendly = "http://hl7.org/fhir/_friendly";
/**
 * ManufacturedItemDefinitionComponentComponentComponent
 *
 * A component that this component contains or is made from.
 *
 * http://hl7.org/fhir/ManufacturedItemDefinitionComponentComponentComponent
 */
export declare const ManufacturedItemDefinitionComponentComponentComponent = "http://hl7.org/fhir/ManufacturedItemDefinitionComponentComponentComponent";
/**
 * basedOn
 *
 * NutritionOrder.basedOn: A plan or request that is fulfilled in whole or in part by this nutrition order.
 *
 * http://hl7.org/fhir/basedOn
 */
export declare const basedOn = "http://hl7.org/fhir/basedOn";
/**
 * assessmentMethod
 *
 * AdverseEvent.suspectEntity.causality.assessmentMethod: The method of evaluating the relatedness of the suspected entity to the event.
 *
 * http://hl7.org/fhir/assessmentMethod
 */
export declare const assessmentMethod = "http://hl7.org/fhir/assessmentMethod";
/**
 * _sourceMaterialClass
 *
 * (Modified) SubstanceSourceMaterial.sourceMaterialClass
 *
 * http://hl7.org/fhir/_sourceMaterialClass
 */
export declare const _sourceMaterialClass = "http://hl7.org/fhir/_sourceMaterialClass";
/**
 * CarePlanActivityComponent
 *
 * CarePlanActivityComponent: Identifies an action that has occurred or is a planned action to occur as part of the plan. For example, a medication to be used, lab tests to perform, self-monitoring that has occurred, education etc.
 *
 * http://hl7.org/fhir/CarePlanActivityComponent
 */
export declare const CarePlanActivityComponent = "http://hl7.org/fhir/CarePlanActivityComponent";
/**
 * response
 *
 * ExampleScenario.process.step.process.step.alternative.step.operation.response: A reference to the instance that is transmitted from receiver to requester as part of the operation's synchronous response (if any).
 *
 * http://hl7.org/fhir/response
 */
export declare const response = "http://hl7.org/fhir/response";
/**
 * _singleUse
 *
 * (Modified) SpecimenDefinition.typeTested.singleUse
 *
 * http://hl7.org/fhir/_singleUse
 */
export declare const _singleUse = "http://hl7.org/fhir/_singleUse";
/**
 * ProvenanceAgentComponent
 *
 * ProvenanceAgentComponent: An actor taking a role in an activity  for which it can be assigned some degree of responsibility for the activity taking place.
 *
 * http://hl7.org/fhir/ProvenanceAgentComponent
 */
export declare const ProvenanceAgentComponent = "http://hl7.org/fhir/ProvenanceAgentComponent";
/**
 * _kingdom
 *
 * (Modified) SubstanceSourceMaterial.organism.organismGeneral.kingdom
 *
 * http://hl7.org/fhir/_kingdom
 */
export declare const _kingdom = "http://hl7.org/fhir/_kingdom";
/**
 * error
 *
 * SubscriptionStatus.error: A record of errors that occurred when the server processed a notification.
 *
 * http://hl7.org/fhir/error
 */
export declare const error = "http://hl7.org/fhir/error";
/**
 * effect
 *
 * ClinicalUseDefinition.interaction.effect: The effect of the interaction, for example "reduced gastric absorption of primary medication".
 *
 * http://hl7.org/fhir/effect
 */
export declare const effect = "http://hl7.org/fhir/effect";
/**
 * verifiedWith
 *
 * Consent.verification.verifiedWith: Who verified the instruction (Patient, Relative or other Authorized Person).
 *
 * http://hl7.org/fhir/verifiedWith
 */
export declare const verifiedWith = "http://hl7.org/fhir/verifiedWith";
/**
 * _packaging
 *
 * (Modified) PackagedProductDefinition.packaging.packaging
 *
 * http://hl7.org/fhir/_packaging
 */
export declare const _packaging = "http://hl7.org/fhir/_packaging";
/**
 * position
 *
 * Location.position: The absolute geographic location of the Location, expressed using the WGS84 datum (This is the same co-ordinate system used in KML).
 *
 * http://hl7.org/fhir/position
 */
export declare const position = "http://hl7.org/fhir/position";
/**
 * EvidenceCertaintyComponentCertainty
 *
 * A domain or subdomain of certainty.
 *
 * http://hl7.org/fhir/EvidenceCertaintyComponentCertainty
 */
export declare const EvidenceCertaintyComponentCertainty = "http://hl7.org/fhir/EvidenceCertaintyComponentCertainty";
/**
 * low
 *
 * SubstancePolymer.repeat.repeatUnit.degreeOfPolymerisation.low: A low expected limit of the amount.
 *
 * http://hl7.org/fhir/low
 */
export declare const low = "http://hl7.org/fhir/low";
/**
 * _Device
 *
 * (Modified) Device
 *
 * http://hl7.org/fhir/_Device
 */
export declare const _Device = "http://hl7.org/fhir/_Device";
/**
 * AddedItemSubDetail
 *
 * ClaimResponse.AddedItem.AddedItemDetail.AddedItemSubDetail: The third-tier service adjudications for payor added services.
 *
 * http://hl7.org/fhir/AddedItemSubDetail
 */
export declare const AddedItemSubDetail = "http://hl7.org/fhir/AddedItemSubDetail";
/**
 * _responsible
 *
 * (Modified) PaymentReconciliation.allocation.responsible
 *
 * http://hl7.org/fhir/_responsible
 */
export declare const _responsible = "http://hl7.org/fhir/_responsible";
/**
 * excludingDate
 *
 * Appointment.recurrenceTemplate.excludingDate: Any dates, such as holidays, that should be excluded from the recurrence.
 *
 * http://hl7.org/fhir/excludingDate
 */
export declare const excludingDate = "http://hl7.org/fhir/excludingDate";
/**
 * _verified
 *
 * (Modified) Consent.verification.verified
 *
 * http://hl7.org/fhir/_verified
 */
export declare const _verified = "http://hl7.org/fhir/_verified";
/**
 * TestScriptMetadataCapabilityComponent
 *
 * TestScriptMetadataComponent.TestScriptMetadataCapabilityComponent: Capabilities that must exist and are assumed to function correctly on the FHIR server being tested.
 *
 * http://hl7.org/fhir/TestScriptMetadataCapabilityComponent
 */
export declare const TestScriptMetadataCapabilityComponent = "http://hl7.org/fhir/TestScriptMetadataCapabilityComponent";
/**
 * marketingStatus
 *
 * PackagedProductDefinition.marketingStatus: Allows specifying that an item is on the market for sale, or that it is not available, and the dates and locations associated.
 *
 * http://hl7.org/fhir/marketingStatus
 */
export declare const marketingStatus = "http://hl7.org/fhir/marketingStatus";
/**
 * _ClaimResponse
 *
 * (Modified) ClaimResponse
 *
 * http://hl7.org/fhir/_ClaimResponse
 */
export declare const _ClaimResponse = "http://hl7.org/fhir/_ClaimResponse";
/**
 * request
 *
 * PaymentReconciliation.request: Original request resource reference.
 *
 * http://hl7.org/fhir/request
 */
export declare const request = "http://hl7.org/fhir/request";
/**
 * MolecularSequenceRelativeEditComponent
 *
 * MolecularSequenceRelativeComponent.MolecularSequenceRelativeEditComponent: Changes in sequence from the starting sequence.
 *
 * http://hl7.org/fhir/MolecularSequenceRelativeEditComponent
 */
export declare const MolecularSequenceRelativeEditComponent = "http://hl7.org/fhir/MolecularSequenceRelativeEditComponent";
/**
 * periodType
 *
 * Contract.term.group.asset.periodType: Type of Asset availability for use or ownership.
 *
 * http://hl7.org/fhir/periodType
 */
export declare const periodType = "http://hl7.org/fhir/periodType";
/**
 * approvalDate
 *
 * EvidenceVariable.approvalDate: The date on which the resource content was approved by the publisher. Approval happens once when the content is officially approved for usage.
 *
 * See guidance around (not) making local changes to elements [here](canonicalresource.html#localization).
 *
 * http://hl7.org/fhir/approvalDate
 */
export declare const approvalDate = "http://hl7.org/fhir/approvalDate";
/**
 * _monomerSet
 *
 * (Modified) SubstancePolymer.monomerSet
 *
 * http://hl7.org/fhir/_monomerSet
 */
export declare const _monomerSet = "http://hl7.org/fhir/_monomerSet";
/**
 * _eventTrigger
 *
 * (Modified) SubscriptionTopic.eventTrigger
 *
 * http://hl7.org/fhir/_eventTrigger
 */
export declare const _eventTrigger = "http://hl7.org/fhir/_eventTrigger";
/**
 * _ingredient
 *
 * (Modified) Substance.ingredient
 *
 * http://hl7.org/fhir/_ingredient
 */
export declare const _ingredient = "http://hl7.org/fhir/_ingredient";
/**
 * _biologicalSourceEvent
 *
 * (Modified) NutritionProduct.instance.biologicalSourceEvent
 *
 * http://hl7.org/fhir/_biologicalSourceEvent
 */
export declare const _biologicalSourceEvent = "http://hl7.org/fhir/_biologicalSourceEvent";
/**
 * durationMax
 *
 * Timing.repeat.durationMax: If present, indicates that the duration is a range - so to perform the action between [duration] and [durationMax] time length.
 *
 * http://hl7.org/fhir/durationMax
 */
export declare const durationMax = "http://hl7.org/fhir/durationMax";
/**
 * _MolecularSequence
 *
 * (Modified) MolecularSequence
 *
 * http://hl7.org/fhir/_MolecularSequence
 */
export declare const _MolecularSequence = "http://hl7.org/fhir/_MolecularSequence";
/**
 * _permittedDataType
 *
 * (Modified) ObservationDefinition.component.permittedDataType
 *
 * http://hl7.org/fhir/_permittedDataType
 */
export declare const _permittedDataType = "http://hl7.org/fhir/_permittedDataType";
/**
 * subtitle
 *
 * Measure.subtitle: An explanatory or alternate title for the measure giving additional information about its content.
 *
 * http://hl7.org/fhir/subtitle
 */
export declare const subtitle = "http://hl7.org/fhir/subtitle";
/**
 * _SubscriptionStatus
 *
 * (Modified) SubscriptionStatus
 *
 * http://hl7.org/fhir/_SubscriptionStatus
 */
export declare const _SubscriptionStatus = "http://hl7.org/fhir/_SubscriptionStatus";
/**
 * maxTreatmentPeriod
 *
 * AdministrableProductDefinition.routeOfAdministration.maxTreatmentPeriod: The maximum treatment period during which the product can be administered.
 *
 * http://hl7.org/fhir/maxTreatmentPeriod
 */
export declare const maxTreatmentPeriod = "http://hl7.org/fhir/maxTreatmentPeriod";
/**
 * _relatedIdentifier
 *
 * (Modified) EvidenceReport.relatedIdentifier
 *
 * http://hl7.org/fhir/_relatedIdentifier
 */
export declare const _relatedIdentifier = "http://hl7.org/fhir/_relatedIdentifier";
/**
 * _feature
 *
 * (Modified) Specimen.feature
 *
 * http://hl7.org/fhir/_feature
 */
export declare const _feature = "http://hl7.org/fhir/_feature";
/**
 * ValueSetExpansionComponent
 *
 * ValueSetExpansionComponent: A value set can also be "expanded", where the value set is turned into a simple collection of enumerated codes. This element holds the expansion, if it has been performed.
 *
 * http://hl7.org/fhir/ValueSetExpansionComponent
 */
export declare const ValueSetExpansionComponent = "http://hl7.org/fhir/ValueSetExpansionComponent";
/**
 * _parameterFocus
 *
 * (Modified) ServiceRequest.orderDetail.parameterFocus
 *
 * http://hl7.org/fhir/_parameterFocus
 */
export declare const _parameterFocus = "http://hl7.org/fhir/_parameterFocus";
/**
 * _maxDosePerDay
 *
 * (Modified) AdministrableProductDefinition.routeOfAdministration.maxDosePerDay
 *
 * http://hl7.org/fhir/_maxDosePerDay
 */
export declare const _maxDosePerDay = "http://hl7.org/fhir/_maxDosePerDay";
/**
 * CapabilityStatementMessagingComponent
 *
 * CapabilityStatementMessagingComponent: A description of the messaging capabilities of the solution.
 *
 * http://hl7.org/fhir/CapabilityStatementMessagingComponent
 */
export declare const CapabilityStatementMessagingComponent = "http://hl7.org/fhir/CapabilityStatementMessagingComponent";
/**
 * ResearchStudyObjectiveComponent
 *
 * ResearchStudyObjectiveComponent: A goal that the study is aiming to achieve in terms of a scientific question to be answered by the analysis of data collected during the study.
 *
 * http://hl7.org/fhir/ResearchStudyObjectiveComponent
 */
export declare const ResearchStudyObjectiveComponent = "http://hl7.org/fhir/ResearchStudyObjectiveComponent";
/**
 * MedicationIngredientComponent
 *
 * MedicationIngredientComponent: Identifies a particular constituent of interest in the product.
 *
 * http://hl7.org/fhir/MedicationIngredientComponent
 */
export declare const MedicationIngredientComponent = "http://hl7.org/fhir/MedicationIngredientComponent";
/**
 * SourceElement
 *
 * ConceptMapGroupComponent.SourceElement: Mappings for an individual concept in the source to one or more concepts in the target.
 *
 * http://hl7.org/fhir/SourceElement
 */
export declare const SourceElement = "http://hl7.org/fhir/SourceElement";
/**
 * _sequence
 *
 * (Modified) ExplanationOfBenefit.diagnosis.sequence
 *
 * http://hl7.org/fhir/_sequence
 */
export declare const _sequence = "http://hl7.org/fhir/_sequence";
/**
 * _validateProfileId
 *
 * (Modified) TestScript.test.action.assert.validateProfileId
 *
 * http://hl7.org/fhir/_validateProfileId
 */
export declare const _validateProfileId = "http://hl7.org/fhir/_validateProfileId";
/**
 * responsibility
 *
 * Coverage.paymentBy.responsibility:  Description of the financial responsibility.
 *
 * http://hl7.org/fhir/responsibility
 */
export declare const responsibility = "http://hl7.org/fhir/responsibility";
/**
 * containedItem
 *
 * PackagedProductDefinition.packaging.packaging.containedItem: The item(s) within the packaging.
 *
 * http://hl7.org/fhir/containedItem
 */
export declare const containedItem = "http://hl7.org/fhir/containedItem";
/**
 * completionTime
 *
 * Transport.completionTime: Identifies the completion time of the event (the occurrence).
 *
 * http://hl7.org/fhir/completionTime
 */
export declare const completionTime = "http://hl7.org/fhir/completionTime";
/**
 * _identifier
 *
 * (Modified) Reference.identifier
 *
 * http://hl7.org/fhir/_identifier
 */
export declare const _identifier = "http://hl7.org/fhir/_identifier";
/**
 * _scope
 *
 * (Modified) Contract.term.asset.scope
 *
 * http://hl7.org/fhir/_scope
 */
export declare const _scope = "http://hl7.org/fhir/_scope";
/**
 * currency
 *
 * Account.currency: The default currency for the account.
 *
 * http://hl7.org/fhir/currency
 */
export declare const currency = "http://hl7.org/fhir/currency";
/**
 * _inputProfile
 *
 * (Modified) OperationDefinition.inputProfile
 *
 * http://hl7.org/fhir/_inputProfile
 */
export declare const _inputProfile = "http://hl7.org/fhir/_inputProfile";
/**
 * TestAction
 *
 * TestScriptTestComponent.TestAction: Action would contain either an operation or an assertion.
 *
 * http://hl7.org/fhir/TestAction
 */
export declare const TestAction = "http://hl7.org/fhir/TestAction";
/**
 * _performer
 *
 * (Modified) Procedure.performer
 *
 * http://hl7.org/fhir/_performer
 */
export declare const _performer = "http://hl7.org/fhir/_performer";
/**
 * QuestionnaireResponseItemComponentItemItem
 *
 * Sub-questions, sub-groups or display items nested beneath a group.
 *
 * http://hl7.org/fhir/QuestionnaireResponseItemComponentItemItem
 */
export declare const QuestionnaireResponseItemComponentItemItem = "http://hl7.org/fhir/QuestionnaireResponseItemComponentItemItem";
/**
 * _pushTypeAvailable
 *
 * (Modified) VerificationResult.primarySource.pushTypeAvailable
 *
 * http://hl7.org/fhir/_pushTypeAvailable
 */
export declare const _pushTypeAvailable = "http://hl7.org/fhir/_pushTypeAvailable";
/**
 * communication
 *
 * RelatedPerson.communication: A language which may be used to communicate with the related person about the patient's health.
 *
 * http://hl7.org/fhir/communication
 */
export declare const communication = "http://hl7.org/fhir/communication";
/**
 * interpretation
 *
 * Observation.component.interpretation: A categorical assessment of an observation value.  For example, high, low, normal.
 *
 * http://hl7.org/fhir/interpretation
 */
export declare const interpretation = "http://hl7.org/fhir/interpretation";
/**
 * _capacity
 *
 * (Modified) SpecimenDefinition.typeTested.container.capacity
 *
 * http://hl7.org/fhir/_capacity
 */
export declare const _capacity = "http://hl7.org/fhir/_capacity";
/**
 * topic
 *
 * ConceptMap.topic: Descriptions related to the content of the ConceptMap. Topics provide a high-level categorization as well as keywords for the ConceptMap that can be useful for filtering and searching.
 *
 * http://hl7.org/fhir/topic
 */
export declare const topic = "http://hl7.org/fhir/topic";
/**
 * _undesirableEffect
 *
 * (Modified) ClinicalUseDefinition.undesirableEffect
 *
 * http://hl7.org/fhir/_undesirableEffect
 */
export declare const _undesirableEffect = "http://hl7.org/fhir/_undesirableEffect";
/**
 * _noteNumber
 *
 * (Modified) ExplanationOfBenefit.addItem.detail.subDetail.noteNumber
 *
 * http://hl7.org/fhir/_noteNumber
 */
export declare const _noteNumber = "http://hl7.org/fhir/_noteNumber";
/**
 * _DeviceRequest
 *
 * (Modified) DeviceRequest
 *
 * http://hl7.org/fhir/_DeviceRequest
 */
export declare const _DeviceRequest = "http://hl7.org/fhir/_DeviceRequest";
/**
 * courseOfTherapyType
 *
 * MedicationRequest.courseOfTherapyType: The description of the overall pattern of the administration of the medication to the patient.
 *
 * http://hl7.org/fhir/courseOfTherapyType
 */
export declare const courseOfTherapyType = "http://hl7.org/fhir/courseOfTherapyType";
/**
 * ordinalPosition
 *
 * MolecularSequence.relative.ordinalPosition: Indicates the order in which the sequence should be considered when putting multiple 'relative' elements together.
 *
 * http://hl7.org/fhir/ordinalPosition
 */
export declare const ordinalPosition = "http://hl7.org/fhir/ordinalPosition";
/**
 * ObservationComponentComponentReferenceRange
 *
 * Guidance on how to interpret the value by comparison to a normal or recommended range.
 *
 * http://hl7.org/fhir/ObservationComponentComponentReferenceRange
 */
export declare const ObservationComponentComponentReferenceRange = "http://hl7.org/fhir/ObservationComponentComponentReferenceRange";
/**
 * _actorId
 *
 * (Modified) PlanDefinition.action.action.participant.actorId
 *
 * http://hl7.org/fhir/_actorId
 */
export declare const _actorId = "http://hl7.org/fhir/_actorId";
/**
 * conclusion
 *
 * DiagnosticReport.conclusion: Concise and clinically contextualized summary conclusion (interpretation/impression) of the diagnostic report.
 *
 * http://hl7.org/fhir/conclusion
 */
export declare const conclusion = "http://hl7.org/fhir/conclusion";
/**
 * Resource
 *
 * This is the base resource type for everything.
 *
 * http://hl7.org/fhir/Resource
 */
export declare const Resource = "http://hl7.org/fhir/Resource";
/**
 * accountNumber
 *
 * PaymentReconciliation.accountNumber: A portion of the account number, often the last 4 digits, used for verification not charging purposes.
 *
 * http://hl7.org/fhir/accountNumber
 */
export declare const accountNumber = "http://hl7.org/fhir/accountNumber";
/**
 * deliverTo
 *
 * SupplyRequest.deliverTo: Where the supply is destined to go.
 *
 * http://hl7.org/fhir/deliverTo
 */
export declare const deliverTo = "http://hl7.org/fhir/deliverTo";
/**
 * multipleResultsAllowed
 *
 * ObservationDefinition.multipleResultsAllowed: Multiple results allowed for observations conforming to this ObservationDefinition.
 *
 * http://hl7.org/fhir/multipleResultsAllowed
 */
export declare const multipleResultsAllowed = "http://hl7.org/fhir/multipleResultsAllowed";
/**
 * _asNeeded
 *
 * (Modified) NutritionOrder.supplement.schedule.asNeeded
 *
 * http://hl7.org/fhir/_asNeeded
 */
export declare const _asNeeded = "http://hl7.org/fhir/_asNeeded";
/**
 * _onHold
 *
 * (Modified) Account.guarantor.onHold
 *
 * http://hl7.org/fhir/_onHold
 */
export declare const _onHold = "http://hl7.org/fhir/_onHold";
/**
 * genomeAssembly
 *
 * MolecularSequence.relative.startingSequence.genomeAssembly: The genome assembly used for starting sequence, e.g. GRCh38.
 *
 * http://hl7.org/fhir/genomeAssembly
 */
export declare const genomeAssembly = "http://hl7.org/fhir/genomeAssembly";
/**
 * _preAuthRefPeriod
 *
 * (Modified) ExplanationOfBenefit.preAuthRefPeriod
 *
 * http://hl7.org/fhir/_preAuthRefPeriod
 */
export declare const _preAuthRefPeriod = "http://hl7.org/fhir/_preAuthRefPeriod";
/**
 * itemSequence
 *
 * ClaimResponse.item.itemSequence: A number to uniquely reference the claim item entries.
 *
 * http://hl7.org/fhir/itemSequence
 */
export declare const itemSequence = "http://hl7.org/fhir/itemSequence";
/**
 * _relatedClinicalInformation
 *
 * (Modified) MedicationStatement.relatedClinicalInformation
 *
 * http://hl7.org/fhir/_relatedClinicalInformation
 */
export declare const _relatedClinicalInformation = "http://hl7.org/fhir/_relatedClinicalInformation";
/**
 * ResearchStudy
 *
 * A scientific study of nature that sometimes includes processes involved in health and disease. For example, clinical trials are research studies that involve people. These studies may be related to new ways to screen, prevent, diagnose, and treat disease. They may also study certain outcomes and certain groups of people by looking at data collected in the past or future.
 *
 * http://hl7.org/fhir/ResearchStudy
 */
export declare const ResearchStudy = "http://hl7.org/fhir/ResearchStudy";
/**
 * _action
 *
 * (Modified) PlanDefinition.action.action
 *
 * http://hl7.org/fhir/_action
 */
export declare const _action = "http://hl7.org/fhir/_action";
/**
 * _DocumentReference
 *
 * (Modified) DocumentReference
 *
 * http://hl7.org/fhir/_DocumentReference
 */
export declare const _DocumentReference = "http://hl7.org/fhir/_DocumentReference";
/**
 * _coverageArea
 *
 * (Modified) InsurancePlan.plan.coverageArea
 *
 * http://hl7.org/fhir/_coverageArea
 */
export declare const _coverageArea = "http://hl7.org/fhir/_coverageArea";
/**
 * DataType
 *
 * The base class for all re-useable types defined as part of the FHIR Specification.
 *
 * http://hl7.org/fhir/DataType
 */
export declare const DataType = "http://hl7.org/fhir/DataType";
/**
 * Duration
 *
 * A length of time.
 *
 * http://hl7.org/fhir/Duration
 */
export declare const Duration = "http://hl7.org/fhir/Duration";
/**
 * _Consent
 *
 * (Modified) Consent
 *
 * http://hl7.org/fhir/_Consent
 */
export declare const _Consent = "http://hl7.org/fhir/_Consent";
/**
 * _referencePolicy
 *
 * (Modified) CapabilityStatement.rest.resource.referencePolicy
 *
 * http://hl7.org/fhir/_referencePolicy
 */
export declare const _referencePolicy = "http://hl7.org/fhir/_referencePolicy";
/**
 * _virtualService
 *
 * (Modified) Location.virtualService
 *
 * http://hl7.org/fhir/_virtualService
 */
export declare const _virtualService = "http://hl7.org/fhir/_virtualService";
/**
 * _lastModified
 *
 * (Modified) Transport.lastModified
 *
 * http://hl7.org/fhir/_lastModified
 */
export declare const _lastModified = "http://hl7.org/fhir/_lastModified";
/**
 * destination
 *
 * TestScript.test.action.operation.destination: The server where the request message is destined for.  Must be one of the server numbers listed in TestScript.destination section.
 *
 * http://hl7.org/fhir/destination
 */
export declare const destination = "http://hl7.org/fhir/destination";
/**
 * _whenHandedOver
 *
 * (Modified) MedicationDispense.whenHandedOver
 *
 * http://hl7.org/fhir/_whenHandedOver
 */
export declare const _whenHandedOver = "http://hl7.org/fhir/_whenHandedOver";
/**
 * _typeTested
 *
 * (Modified) SpecimenDefinition.typeTested
 *
 * http://hl7.org/fhir/_typeTested
 */
export declare const _typeTested = "http://hl7.org/fhir/_typeTested";
/**
 * product
 *
 * ActivityDefinition.product
 *
 * http://hl7.org/fhir/product
 */
export declare const product = "http://hl7.org/fhir/product";
/**
 * _referrer
 *
 * (Modified) ImagingStudy.referrer
 *
 * http://hl7.org/fhir/_referrer
 */
export declare const _referrer = "http://hl7.org/fhir/_referrer";
/**
 * plannedEndDate
 *
 * EncounterHistory.plannedEndDate: The planned end date/time (or discharge date) of the encounter.
 *
 * http://hl7.org/fhir/plannedEndDate
 */
export declare const plannedEndDate = "http://hl7.org/fhir/plannedEndDate";
/**
 * _birthDate
 *
 * (Modified) RelatedPerson.birthDate
 *
 * http://hl7.org/fhir/_birthDate
 */
export declare const _birthDate = "http://hl7.org/fhir/_birthDate";
/**
 * _mustHaveValue
 *
 * (Modified) ElementDefinition.mustHaveValue
 *
 * http://hl7.org/fhir/_mustHaveValue
 */
export declare const _mustHaveValue = "http://hl7.org/fhir/_mustHaveValue";
/**
 * ClinicalUseDefinition
 *
 * A single issue - either an indication, contraindication, interaction or an undesirable effect for a medicinal product, medication, device or procedure.
 *
 * http://hl7.org/fhir/ClinicalUseDefinition
 */
export declare const ClinicalUseDefinition = "http://hl7.org/fhir/ClinicalUseDefinition";
/**
 * dynamicValue
 *
 * PlanDefinition.action.dynamicValue: Customizations that should be applied to the statically defined resource. For example, if the dosage of a medication must be computed based on the patient's weight, a customization would be used to specify an expression that calculated the weight, and the path on the resource that would contain the result.
 *
 * http://hl7.org/fhir/dynamicValue
 */
export declare const dynamicValue = "http://hl7.org/fhir/dynamicValue";
/**
 * _detailSequence
 *
 * (Modified) ExplanationOfBenefit.addItem.detailSequence
 *
 * http://hl7.org/fhir/_detailSequence
 */
export declare const _detailSequence = "http://hl7.org/fhir/_detailSequence";
/**
 * SupportingInformation
 *
 * Claim.SupportingInformation: Additional information codes regarding exceptions, special considerations, the condition, situation, prior or concurrent issues.
 *
 * http://hl7.org/fhir/SupportingInformation
 */
export declare const SupportingInformation = "http://hl7.org/fhir/SupportingInformation";
/**
 * CitationStatusDateComponent
 *
 * CitationStatusDateComponent: The state or status of the citation record paired with an effective date or period for that state.
 *
 * http://hl7.org/fhir/CitationStatusDateComponent
 */
export declare const CitationStatusDateComponent = "http://hl7.org/fhir/CitationStatusDateComponent";
/**
 * subscriberId
 *
 * Coverage.subscriberId: The insurer assigned ID for the Subscriber.
 *
 * http://hl7.org/fhir/subscriberId
 */
export declare const subscriberId = "http://hl7.org/fhir/subscriberId";
/**
 * node
 *
 * GraphDefinition.node: Potential target for the link.
 *
 * http://hl7.org/fhir/node
 */
export declare const node = "http://hl7.org/fhir/node";
/**
 * details
 *
 * OperationOutcome.issue.details: Additional details about the error. This may be a text description of the error or a system code that identifies the error.
 *
 * http://hl7.org/fhir/details
 */
export declare const details = "http://hl7.org/fhir/details";
/**
 * GenomicStudyAnalysisInputComponent
 *
 * GenomicStudyAnalysisComponent.GenomicStudyAnalysisInputComponent: Inputs for the analysis event.
 *
 * http://hl7.org/fhir/GenomicStudyAnalysisInputComponent
 */
export declare const GenomicStudyAnalysisInputComponent = "http://hl7.org/fhir/GenomicStudyAnalysisInputComponent";
/**
 * contract
 *
 * Coverage.contract: The policy(s) which constitute this insurance coverage.
 *
 * http://hl7.org/fhir/contract
 */
export declare const contract = "http://hl7.org/fhir/contract";
/**
 * _paymentIssuer
 *
 * (Modified) PaymentReconciliation.paymentIssuer
 *
 * http://hl7.org/fhir/_paymentIssuer
 */
export declare const _paymentIssuer = "http://hl7.org/fhir/_paymentIssuer";
/**
 * _clinicalTrial
 *
 * (Modified) MedicinalProductDefinition.clinicalTrial
 *
 * http://hl7.org/fhir/_clinicalTrial
 */
export declare const _clinicalTrial = "http://hl7.org/fhir/_clinicalTrial";
/**
 * Adjudication
 *
 * ExplanationOfBenefit.Item.Adjudication: If this item is a group then the values here are a summary of the adjudication of the detail items. If this item is a simple product or service then this is the result of the adjudication of this item.
 *
 * http://hl7.org/fhir/Adjudication
 */
export declare const Adjudication = "http://hl7.org/fhir/Adjudication";
/**
 * AdverseEventMitigatingActionComponent
 *
 * AdverseEventMitigatingActionComponent: The ameliorating action taken after the adverse event occured in order to reduce the extent of harm.
 *
 * http://hl7.org/fhir/AdverseEventMitigatingActionComponent
 */
export declare const AdverseEventMitigatingActionComponent = "http://hl7.org/fhir/AdverseEventMitigatingActionComponent";
/**
 * ratioType
 *
 * SubstancePolymer.monomerSet.ratioType: Captures the type of ratio to the entire polymer, e.g. Monomer/Polymer ratio, SRU/Polymer Ratio.
 *
 * http://hl7.org/fhir/ratioType
 */
export declare const ratioType = "http://hl7.org/fhir/ratioType";
/**
 * authoritative
 *
 * NamingSystem.uniqueId.authoritative: Indicates whether this identifier ie endorsed by the official owner of the associated naming system.
 *
 * http://hl7.org/fhir/authoritative
 */
export declare const authoritative = "http://hl7.org/fhir/authoritative";
/**
 * chromosome
 *
 * MolecularSequence.relative.startingSequence.chromosome: Structural unit composed of a nucleic acid molecule which controls its own replication through the interaction of specific proteins at one or more origins of replication ([SO:0000340](http://www.sequenceontology.org/browser/current_svn/term/SO:0000340)).
 *
 * http://hl7.org/fhir/chromosome
 */
export declare const chromosome = "http://hl7.org/fhir/chromosome";
/**
 * referralMethod
 *
 * HealthcareService.referralMethod: Ways that the service accepts referrals, if this is not provided then it is implied that no referral is required.
 *
 * http://hl7.org/fhir/referralMethod
 */
export declare const referralMethod = "http://hl7.org/fhir/referralMethod";
/**
 * MedicationKnowledgeDefinitionalDrugCharacteristicComponent
 *
 * MedicationKnowledgeDefinitionalComponent.MedicationKnowledgeDefinitionalDrugCharacteristicComponent: Specifies descriptive properties of the medicine, such as color, shape, imprints, etc.
 *
 * http://hl7.org/fhir/MedicationKnowledgeDefinitionalDrugCharacteristicComponent
 */
export declare const MedicationKnowledgeDefinitionalDrugCharacteristicComponent = "http://hl7.org/fhir/MedicationKnowledgeDefinitionalDrugCharacteristicComponent";
/**
 * _filterParameter
 *
 * (Modified) SubscriptionTopic.canFilterBy.filterParameter
 *
 * http://hl7.org/fhir/_filterParameter
 */
export declare const _filterParameter = "http://hl7.org/fhir/_filterParameter";
/**
 * _costCenter
 *
 * (Modified) ChargeItem.costCenter
 *
 * http://hl7.org/fhir/_costCenter
 */
export declare const _costCenter = "http://hl7.org/fhir/_costCenter";
/**
 * _maternalOrganismName
 *
 * (Modified) SubstanceSourceMaterial.organism.hybrid.maternalOrganismName
 *
 * http://hl7.org/fhir/_maternalOrganismName
 */
export declare const _maternalOrganismName = "http://hl7.org/fhir/_maternalOrganismName";
/**
 * _CommunicationRequest
 *
 * (Modified) CommunicationRequest
 *
 * http://hl7.org/fhir/_CommunicationRequest
 */
export declare const _CommunicationRequest = "http://hl7.org/fhir/_CommunicationRequest";
/**
 * _mapping
 *
 * (Modified) StructureDefinition.mapping
 *
 * http://hl7.org/fhir/_mapping
 */
export declare const _mapping = "http://hl7.org/fhir/_mapping";
/**
 * _spatialReference
 *
 * (Modified) BodyStructure.excludedStructure.spatialReference
 *
 * http://hl7.org/fhir/_spatialReference
 */
export declare const _spatialReference = "http://hl7.org/fhir/_spatialReference";
/**
 * _AppointmentResponse
 *
 * (Modified) AppointmentResponse
 *
 * http://hl7.org/fhir/_AppointmentResponse
 */
export declare const _AppointmentResponse = "http://hl7.org/fhir/_AppointmentResponse";
/**
 * preparation
 *
 * SpecimenDefinition.typeTested.container.preparation: Special processing that should be applied to the container for this kind of specimen.
 *
 * http://hl7.org/fhir/preparation
 */
export declare const preparation = "http://hl7.org/fhir/preparation";
/**
 * _outcome
 *
 * (Modified) FamilyMemberHistory.condition.outcome
 *
 * http://hl7.org/fhir/_outcome
 */
export declare const _outcome = "http://hl7.org/fhir/_outcome";
/**
 * _policy
 *
 * (Modified) Provenance.policy
 *
 * http://hl7.org/fhir/_policy
 */
export declare const _policy = "http://hl7.org/fhir/_policy";
/**
 * planningHorizon
 *
 * Schedule.planningHorizon: The period of time that the slots that reference this Schedule resource cover (even if none exist). These  cover the amount of time that an organization's planning horizon; the interval for which they are currently accepting appointments. This does not define a "template" for planning outside these dates.
 *
 * http://hl7.org/fhir/planningHorizon
 */
export declare const planningHorizon = "http://hl7.org/fhir/planningHorizon";
/**
 * _targetSpecies
 *
 * (Modified) AdministrableProductDefinition.routeOfAdministration.targetSpecies
 *
 * http://hl7.org/fhir/_targetSpecies
 */
export declare const _targetSpecies = "http://hl7.org/fhir/_targetSpecies";
/**
 * EvidenceVariableCharacteristicComponent
 *
 * EvidenceVariableCharacteristicComponent: A defining factor of the EvidenceVariable. Multiple characteristics are applied with "and" semantics.
 *
 * http://hl7.org/fhir/EvidenceVariableCharacteristicComponent
 */
export declare const EvidenceVariableCharacteristicComponent = "http://hl7.org/fhir/EvidenceVariableCharacteristicComponent";
/**
 * _authorization
 *
 * (Modified) Provenance.authorization
 *
 * http://hl7.org/fhir/_authorization
 */
export declare const _authorization = "http://hl7.org/fhir/_authorization";
/**
 * software
 *
 * TerminologyCapabilities.software: Software that is covered by this terminology capability statement.  It is used when the statement describes the capabilities of a particular software version, independent of an installation.
 *
 * http://hl7.org/fhir/software
 */
export declare const software = "http://hl7.org/fhir/software";
/**
 * _lastReviewDate
 *
 * (Modified) ArtifactAssessment.lastReviewDate
 *
 * http://hl7.org/fhir/_lastReviewDate
 */
export declare const _lastReviewDate = "http://hl7.org/fhir/_lastReviewDate";
/**
 * _derivedFromCanonical
 *
 * (Modified) SpecimenDefinition.derivedFromCanonical
 *
 * http://hl7.org/fhir/_derivedFromCanonical
 */
export declare const _derivedFromCanonical = "http://hl7.org/fhir/_derivedFromCanonical";
/**
 * specialCourtesy
 *
 * Encounter.specialCourtesy: Special courtesies that may be provided to the patient during the encounter (VIP, board member, professional courtesy).
 *
 * http://hl7.org/fhir/specialCourtesy
 */
export declare const specialCourtesy = "http://hl7.org/fhir/specialCourtesy";
/**
 * intraspecificType
 *
 * SubstanceSourceMaterial.organism.intraspecificType: The Intraspecific type of an organism shall be specified.
 *
 * http://hl7.org/fhir/intraspecificType
 */
export declare const intraspecificType = "http://hl7.org/fhir/intraspecificType";
/**
 * shortTitle
 *
 * EvidenceVariable.shortTitle: The short title provides an alternate title for use in informal descriptive contexts where the full, formal title is not necessary.
 *
 * http://hl7.org/fhir/shortTitle
 */
export declare const shortTitle = "http://hl7.org/fhir/shortTitle";
/**
 * channelType
 *
 * Subscription.channelType: The type of channel to send notifications on.
 *
 * http://hl7.org/fhir/channelType
 */
export declare const channelType = "http://hl7.org/fhir/channelType";
/**
 * _subSite
 *
 * (Modified) ExplanationOfBenefit.addItem.bodySite.subSite
 *
 * http://hl7.org/fhir/_subSite
 */
export declare const _subSite = "http://hl7.org/fhir/_subSite";
/**
 * use
 *
 * ValueSet.compose.include.concept.designation.use: A code that represents types of uses of designations.
 *
 * http://hl7.org/fhir/use
 */
export declare const use = "http://hl7.org/fhir/use";
/**
 * webLocation
 *
 * Citation.citedArtifact.webLocation: Used for any URL for the article or artifact cited.
 *
 * http://hl7.org/fhir/webLocation
 */
export declare const webLocation = "http://hl7.org/fhir/webLocation";
/**
 * PlanDefinitionGoalTargetComponent
 *
 * PlanDefinitionGoalComponent.PlanDefinitionGoalTargetComponent: Indicates what should be done and within what timeframe.
 *
 * http://hl7.org/fhir/PlanDefinitionGoalTargetComponent
 */
export declare const PlanDefinitionGoalTargetComponent = "http://hl7.org/fhir/PlanDefinitionGoalTargetComponent";
/**
 * _entryQuantity
 *
 * (Modified) EvidenceReport.section.section.entryQuantity
 *
 * http://hl7.org/fhir/_entryQuantity
 */
export declare const _entryQuantity = "http://hl7.org/fhir/_entryQuantity";
/**
 * _seriousness
 *
 * (Modified) AdverseEvent.seriousness
 *
 * http://hl7.org/fhir/_seriousness
 */
export declare const _seriousness = "http://hl7.org/fhir/_seriousness";
/**
 * _born
 *
 * (Modified) FamilyMemberHistory.born
 *
 * http://hl7.org/fhir/_born
 */
export declare const _born = "http://hl7.org/fhir/_born";
/**
 * initiator
 *
 * ExampleScenario.process.step.process.step.alternative.step.operation.initiator: The system that invokes the action/transmits the data.
 *
 * http://hl7.org/fhir/initiator
 */
export declare const initiator = "http://hl7.org/fhir/initiator";
/**
 * geometry
 *
 * SubstancePolymer.geometry: Polymer geometry, e.g. linear, branched, cross-linked, network or dendritic.
 *
 * http://hl7.org/fhir/geometry
 */
export declare const geometry = "http://hl7.org/fhir/geometry";
/**
 * _organismGeneral
 *
 * (Modified) SubstanceSourceMaterial.organism.organismGeneral
 *
 * http://hl7.org/fhir/_organismGeneral
 */
export declare const _organismGeneral = "http://hl7.org/fhir/_organismGeneral";
/**
 * TestReportSetupComponent
 *
 * TestReportSetupComponent: The results of the series of required setup operations before the tests were executed.
 *
 * http://hl7.org/fhir/TestReportSetupComponent
 */
export declare const TestReportSetupComponent = "http://hl7.org/fhir/TestReportSetupComponent";
/**
 * message
 *
 * MessageDefinition.allowedResponse.message: A reference to the message definition that must be adhered to by this supported response.
 *
 * http://hl7.org/fhir/message
 */
export declare const message = "http://hl7.org/fhir/message";
/**
 * PlanDefinitionActionInputComponent
 *
 * PlanDefinitionActionComponentAction.PlanDefinitionActionInputComponent: Defines input data requirements for the action.
 *
 * http://hl7.org/fhir/PlanDefinitionActionInputComponent
 */
export declare const PlanDefinitionActionInputComponent = "http://hl7.org/fhir/PlanDefinitionActionInputComponent";
/**
 * Dosage
 *
 * Indicates how the medication is/was taken or should be taken by the patient.
 *
 * http://hl7.org/fhir/Dosage
 */
export declare const Dosage = "http://hl7.org/fhir/Dosage";
/**
 * _structureType
 *
 * (Modified) ExampleScenario.instance.structureType
 *
 * http://hl7.org/fhir/_structureType
 */
export declare const _structureType = "http://hl7.org/fhir/_structureType";
/**
 * onAdmission
 *
 * ExplanationOfBenefit.diagnosis.onAdmission: Indication of whether the diagnosis was present on admission to a facility.
 *
 * http://hl7.org/fhir/onAdmission
 */
export declare const onAdmission = "http://hl7.org/fhir/onAdmission";
/**
 * EncounterLocationComponent
 *
 * EncounterLocationComponent: List of locations where  the patient has been during this encounter.
 *
 * http://hl7.org/fhir/EncounterLocationComponent
 */
export declare const EncounterLocationComponent = "http://hl7.org/fhir/EncounterLocationComponent";
/**
 * statusHistory
 *
 * EpisodeOfCare.statusHistory: The history of statuses that the EpisodeOfCare has been through (without requiring processing the history of the resource).
 *
 * http://hl7.org/fhir/statusHistory
 */
export declare const statusHistory = "http://hl7.org/fhir/statusHistory";
/**
 * CitationCitedArtifactComponent
 *
 * CitationCitedArtifactComponent: The article or artifact being described.
 *
 * http://hl7.org/fhir/CitationCitedArtifactComponent
 */
export declare const CitationCitedArtifactComponent = "http://hl7.org/fhir/CitationCitedArtifactComponent";
/**
 * _paymentTerms
 *
 * (Modified) Invoice.paymentTerms
 *
 * http://hl7.org/fhir/_paymentTerms
 */
export declare const _paymentTerms = "http://hl7.org/fhir/_paymentTerms";
/**
 * _intendedEffect
 *
 * (Modified) ClinicalUseDefinition.indication.intendedEffect
 *
 * http://hl7.org/fhir/_intendedEffect
 */
export declare const _intendedEffect = "http://hl7.org/fhir/_intendedEffect";
/**
 * SubstanceSourceMaterialOrganismAuthorComponent
 *
 * SubstanceSourceMaterialOrganismComponent.SubstanceSourceMaterialOrganismAuthorComponent: 4.9.13.6.1 Author type (Conditional).
 *
 * http://hl7.org/fhir/SubstanceSourceMaterialOrganismAuthorComponent
 */
export declare const SubstanceSourceMaterialOrganismAuthorComponent = "http://hl7.org/fhir/SubstanceSourceMaterialOrganismAuthorComponent";
/**
 * listMode
 *
 * StructureMap.group.rule.source.listMode: How to handle the list mode for this element.
 *
 * http://hl7.org/fhir/listMode
 */
export declare const listMode = "http://hl7.org/fhir/listMode";
/**
 * _typeCollected
 *
 * (Modified) SpecimenDefinition.typeCollected
 *
 * http://hl7.org/fhir/_typeCollected
 */
export declare const _typeCollected = "http://hl7.org/fhir/_typeCollected";
/**
 * definitional
 *
 * MedicationKnowledge.definitional: Along with the link to a Medicinal Product Definition resource, this information provides common definitional elements that are needed to understand the specific medication that is being described.
 *
 * http://hl7.org/fhir/definitional
 */
export declare const definitional = "http://hl7.org/fhir/definitional";
/**
 * improvementNotation
 *
 * MeasureReport.improvementNotation: Whether improvement in the measure is noted by an increase or decrease in the measure score.
 *
 * http://hl7.org/fhir/improvementNotation
 */
export declare const improvementNotation = "http://hl7.org/fhir/improvementNotation";
/**
 * ValuedItem
 *
 * Contract.TermTerm.ContractAsset.ValuedItem: Contract Valued Item List.
 *
 * http://hl7.org/fhir/ValuedItem
 */
export declare const ValuedItem = "http://hl7.org/fhir/ValuedItem";
/**
 * ElementDefinitionBaseComponent
 *
 * ElementDefinitionBaseComponent: Information about the base definition of the element, provided to make it unnecessary for tools to trace the deviation of the element through the derived and related profiles. When the element definition is not the original definition of an element - e.g. either in a constraint on another type, or for elements from a super type in a snap shot - then the information in provided in the element definition may be different to the base definition. On the original definition of the element, it will be same.
 *
 * http://hl7.org/fhir/ElementDefinitionBaseComponent
 */
export declare const ElementDefinitionBaseComponent = "http://hl7.org/fhir/ElementDefinitionBaseComponent";
/**
 * Errors
 *
 * CoverageEligibilityResponse.Errors: Errors encountered during the processing of the request.
 *
 * http://hl7.org/fhir/Errors
 */
export declare const Errors = "http://hl7.org/fhir/Errors";
/**
 * pattern
 *
 * http://hl7.org/fhir/pattern
 */
export declare const pattern = "http://hl7.org/fhir/pattern";
/**
 * TestScriptDestinationComponent
 *
 * TestScriptDestinationComponent: An abstract server used in operations within this test script in the destination element.
 *
 * http://hl7.org/fhir/TestScriptDestinationComponent
 */
export declare const TestScriptDestinationComponent = "http://hl7.org/fhir/TestScriptDestinationComponent";
/**
 * CoveragePaymentByComponent
 *
 * CoveragePaymentByComponent: Link to the paying party and optionally what specifically they will be responsible to pay.
 *
 * http://hl7.org/fhir/CoveragePaymentByComponent
 */
export declare const CoveragePaymentByComponent = "http://hl7.org/fhir/CoveragePaymentByComponent";
/**
 * _AuditEvent
 *
 * (Modified) AuditEvent
 *
 * http://hl7.org/fhir/_AuditEvent
 */
export declare const _AuditEvent = "http://hl7.org/fhir/_AuditEvent";
/**
 * requirements
 *
 * ElementDefinition.constraint.requirements: Description of why this constraint is necessary or appropriate.
 *
 * http://hl7.org/fhir/requirements
 */
export declare const requirements = "http://hl7.org/fhir/requirements";
/**
 * authority
 *
 * SubstanceDefinition.name.synonym.official.authority: Which authority uses this official name.
 *
 * http://hl7.org/fhir/authority
 */
export declare const authority = "http://hl7.org/fhir/authority";
/**
 * _compareToSourceId
 *
 * (Modified) TestScript.test.action.assert.compareToSourceId
 *
 * http://hl7.org/fhir/_compareToSourceId
 */
export declare const _compareToSourceId = "http://hl7.org/fhir/_compareToSourceId";
/**
 * _Contract
 *
 * (Modified) Contract
 *
 * http://hl7.org/fhir/_Contract
 */
export declare const _Contract = "http://hl7.org/fhir/_Contract";
/**
 * _occurrenceChanged
 *
 * (Modified) Appointment.occurrenceChanged
 *
 * http://hl7.org/fhir/_occurrenceChanged
 */
export declare const _occurrenceChanged = "http://hl7.org/fhir/_occurrenceChanged";
/**
 * typeReference
 *
 * RequestOrchestration.action.action.participant.typeReference: The type of participant in the action.
 *
 * http://hl7.org/fhir/typeReference
 */
export declare const typeReference = "http://hl7.org/fhir/typeReference";
/**
 * detail
 *
 * TestReport.setup.action.assert.detail: A link to further details on the result.
 *
 * http://hl7.org/fhir/detail
 */
export declare const detail = "http://hl7.org/fhir/detail";
/**
 * _alternative
 *
 * (Modified) ExampleScenario.process.step.alternative.step.alternative
 *
 * http://hl7.org/fhir/_alternative
 */
export declare const _alternative = "http://hl7.org/fhir/_alternative";
/**
 * ClaimResponseAdjudication
 *
 * The adjudication results which are presented at the header level rather than at the line-item or add-item levels.
 *
 * http://hl7.org/fhir/ClaimResponseAdjudication
 */
export declare const ClaimResponseAdjudication = "http://hl7.org/fhir/ClaimResponseAdjudication";
/**
 * Person
 *
 * Demographics and administrative information about a person independent of a specific health-related context.
 *
 * http://hl7.org/fhir/Person
 */
export declare const Person = "http://hl7.org/fhir/Person";
/**
 * readHistory
 *
 * CapabilityStatement.rest.resource.readHistory: A flag for whether the server is able to return past versions as part of the vRead operation.
 *
 * http://hl7.org/fhir/readHistory
 */
export declare const readHistory = "http://hl7.org/fhir/readHistory";
/**
 * _subjects
 *
 * (Modified) MeasureReport.group.stratifier.stratum.population.subjects
 *
 * http://hl7.org/fhir/_subjects
 */
export declare const _subjects = "http://hl7.org/fhir/_subjects";
/**
 * membership
 *
 * Group.membership: Basis for membership in the Group:
 *
 * * 'definitional': The Group.characteristics specified are both necessary and sufficient to determine membership. All entities that meet the criteria are considered to be members of the group, whether referenced by the group or not. If members are present, they are individuals that happen to be known as meeting the Group.characteristics. The list cannot be presumed to be complete.
 * * 'enumerated': The Group.characteristics are necessary but not sufficient to determine membership. Membership is determined by being listed as one of the Group.member.
 *
 * http://hl7.org/fhir/membership
 */
export declare const membership = "http://hl7.org/fhir/membership";
/**
 * studyUid
 *
 * ImagingSelection.studyUid: The Study Instance UID for the DICOM Study from which the images were selected.
 *
 * http://hl7.org/fhir/studyUid
 */
export declare const studyUid = "http://hl7.org/fhir/studyUid";
/**
 * GraphDefinitionLinkCompartmentComponent
 *
 * GraphDefinitionLinkComponent.GraphDefinitionLinkCompartmentComponent: Compartment Consistency Rules.
 *
 * http://hl7.org/fhir/GraphDefinitionLinkCompartmentComponent
 */
export declare const GraphDefinitionLinkCompartmentComponent = "http://hl7.org/fhir/GraphDefinitionLinkCompartmentComponent";
/**
 * _occurrence
 *
 * (Modified) SupplyRequest.occurrence
 *
 * http://hl7.org/fhir/_occurrence
 */
export declare const _occurrence = "http://hl7.org/fhir/_occurrence";
/**
 * _dayOfMonth
 *
 * (Modified) Appointment.recurrenceTemplate.monthlyTemplate.dayOfMonth
 *
 * http://hl7.org/fhir/_dayOfMonth
 */
export declare const _dayOfMonth = "http://hl7.org/fhir/_dayOfMonth";
/**
 * Extension
 *
 * Optional Extension Element - found in all resources.
 *
 * http://hl7.org/fhir/Extension
 */
export declare const Extension = "http://hl7.org/fhir/Extension";
/**
 * _proxyIdentityCertificate
 *
 * (Modified) VerificationResult.attestation.proxyIdentityCertificate
 *
 * http://hl7.org/fhir/_proxyIdentityCertificate
 */
export declare const _proxyIdentityCertificate = "http://hl7.org/fhir/_proxyIdentityCertificate";
/**
 * emptyReason
 *
 * EvidenceReport.section.section.emptyReason: If the section is empty, why the list is empty. An empty section typically has some text explaining the empty reason.
 *
 * http://hl7.org/fhir/emptyReason
 */
export declare const emptyReason = "http://hl7.org/fhir/emptyReason";
/**
 * ConceptMapGroupComponent
 *
 * ConceptMapGroupComponent: A group of mappings that all have the same source and target system.
 *
 * http://hl7.org/fhir/ConceptMapGroupComponent
 */
export declare const ConceptMapGroupComponent = "http://hl7.org/fhir/ConceptMapGroupComponent";
/**
 * laterality
 *
 * BodyStructure.includedStructure.laterality: Code that represents the included structure laterality.
 *
 * http://hl7.org/fhir/laterality
 */
export declare const laterality = "http://hl7.org/fhir/laterality";
/**
 * _previous
 *
 * (Modified) SubscriptionTopic.resourceTrigger.queryCriteria.previous
 *
 * http://hl7.org/fhir/_previous
 */
export declare const _previous = "http://hl7.org/fhir/_previous";
/**
 * _claimResponse
 *
 * (Modified) ExplanationOfBenefit.claimResponse
 *
 * http://hl7.org/fhir/_claimResponse
 */
export declare const _claimResponse = "http://hl7.org/fhir/_claimResponse";
/**
 * dataUpdateType
 *
 * MeasureReport.dataUpdateType: Indicates whether the data submitted in a data-exchange report represents a snapshot or incremental update. A snapshot update replaces all previously submitted data for the receiver, whereas an incremental update represents only updated and/or changed data and should be applied as a differential update to the existing submitted data for the receiver.
 *
 * http://hl7.org/fhir/dataUpdateType
 */
export declare const dataUpdateType = "http://hl7.org/fhir/dataUpdateType";
/**
 * paymentDate
 *
 * PaymentNotice.paymentDate: The date when the above payment action occurred.
 *
 * http://hl7.org/fhir/paymentDate
 */
export declare const paymentDate = "http://hl7.org/fhir/paymentDate";
/**
 * baseFormulaProductName
 *
 * NutritionOrder.enteralFormula.baseFormulaProductName: The product or brand name of the enteral or infant formula product such as "ACME Adult Standard Formula".
 *
 * http://hl7.org/fhir/baseFormulaProductName
 */
export declare const baseFormulaProductName = "http://hl7.org/fhir/baseFormulaProductName";
/**
 * performed
 *
 * FamilyMemberHistory.procedure.performed
 *
 * http://hl7.org/fhir/performed
 */
export declare const performed = "http://hl7.org/fhir/performed";
/**
 * ServiceRequestOrderDetailComponent
 *
 * ServiceRequestOrderDetailComponent: Additional details and instructions about the how the services are to be delivered.   For example, and order for a urinary catheter may have an order detail for an external or indwelling catheter, or an order for a bandage may require additional instructions specifying how the bandage should be applied.
 *
 * http://hl7.org/fhir/ServiceRequestOrderDetailComponent
 */
export declare const ServiceRequestOrderDetailComponent = "http://hl7.org/fhir/ServiceRequestOrderDetailComponent";
/**
 * _informationSequence
 *
 * (Modified) ExplanationOfBenefit.item.informationSequence
 *
 * http://hl7.org/fhir/_informationSequence
 */
export declare const _informationSequence = "http://hl7.org/fhir/_informationSequence";
/**
 * _wednesday
 *
 * (Modified) Appointment.recurrenceTemplate.weeklyTemplate.wednesday
 *
 * http://hl7.org/fhir/_wednesday
 */
export declare const _wednesday = "http://hl7.org/fhir/_wednesday";
/**
 * _id
 *
 * (Modified) Resource.id
 *
 * http://hl7.org/fhir/_id
 */
export declare const _id = "http://hl7.org/fhir/_id";
/**
 * nucleicAcid
 *
 * SubstanceDefinition.nucleicAcid: Data items specific to nucleic acids.
 *
 * http://hl7.org/fhir/nucleicAcid
 */
export declare const nucleicAcid = "http://hl7.org/fhir/nucleicAcid";
/**
 * implementation
 *
 * TerminologyCapabilities.implementation: Identifies a specific implementation instance that is described by the terminology capability statement - i.e. a particular installation, rather than the capabilities of a software program.
 *
 * http://hl7.org/fhir/implementation
 */
export declare const implementation = "http://hl7.org/fhir/implementation";
/**
 * _species
 *
 * (Modified) SubstanceSourceMaterial.organism.species
 *
 * http://hl7.org/fhir/_species
 */
export declare const _species = "http://hl7.org/fhir/_species";
/**
 * _goalId
 *
 * (Modified) PlanDefinition.action.action.goalId
 *
 * http://hl7.org/fhir/_goalId
 */
export declare const _goalId = "http://hl7.org/fhir/_goalId";
/**
 * manager
 *
 * Consent.manager: The actor that manages the consent through its lifecycle.
 *
 * http://hl7.org/fhir/manager
 */
export declare const manager = "http://hl7.org/fhir/manager";
/**
 * Meta
 *
 * The metadata about a resource. This is content in the resource that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.
 *
 * http://hl7.org/fhir/Meta
 */
export declare const Meta = "http://hl7.org/fhir/Meta";
/**
 * interpreter
 *
 * GenomicStudy.interpreter: Healthcare professionals who interpreted the genomic study.
 *
 * http://hl7.org/fhir/interpreter
 */
export declare const interpreter = "http://hl7.org/fhir/interpreter";
/**
 * situation
 *
 * MessageDefinition.allowedResponse.situation: Provides a description of the circumstances in which this response should be used (as opposed to one of the alternative responses).
 *
 * http://hl7.org/fhir/situation
 */
export declare const situation = "http://hl7.org/fhir/situation";
/**
 * _recorded
 *
 * (Modified) Provenance.recorded
 *
 * http://hl7.org/fhir/_recorded
 */
export declare const _recorded = "http://hl7.org/fhir/_recorded";
/**
 * DiagnosticReport
 *
 * The findings and interpretation of diagnostic tests performed on patients, groups of patients, products, substances, devices, and locations, and/or specimens derived from these. The report includes clinical context such as requesting provider information, and some mix of atomic results, images, textual and coded interpretations, and formatted representation of diagnostic reports. The report also includes non-clinical context such as batch analysis and stability reporting of products and substances.
 *
 * http://hl7.org/fhir/DiagnosticReport
 */
export declare const DiagnosticReport = "http://hl7.org/fhir/DiagnosticReport";
/**
 * drugCharacteristic
 *
 * MedicationKnowledge.definitional.drugCharacteristic: Specifies descriptive properties of the medicine, such as color, shape, imprints, etc.
 *
 * http://hl7.org/fhir/drugCharacteristic
 */
export declare const drugCharacteristic = "http://hl7.org/fhir/drugCharacteristic";
/**
 * SubstanceDefinitionStructureRepresentationComponent
 *
 * SubstanceDefinitionStructureComponent.SubstanceDefinitionStructureRepresentationComponent: A depiction of the structure of the substance.
 *
 * http://hl7.org/fhir/SubstanceDefinitionStructureRepresentationComponent
 */
export declare const SubstanceDefinitionStructureRepresentationComponent = "http://hl7.org/fhir/SubstanceDefinitionStructureRepresentationComponent";
/**
 * RequestOrchestrationActionRelatedActionComponent
 *
 * RequestOrchestrationActionComponentAction.RequestOrchestrationActionRelatedActionComponent: A relationship to another action such as "before" or "30-60 minutes after start of".
 *
 * http://hl7.org/fhir/RequestOrchestrationActionRelatedActionComponent
 */
export declare const RequestOrchestrationActionRelatedActionComponent = "http://hl7.org/fhir/RequestOrchestrationActionRelatedActionComponent";
/**
 * variableRole
 *
 * Evidence.variableDefinition.variableRole: population | subpopulation | exposure | referenceExposure | measuredVariable | confounder.
 *
 * http://hl7.org/fhir/variableRole
 */
export declare const variableRole = "http://hl7.org/fhir/variableRole";
/**
 * failureAction
 *
 * VerificationResult.failureAction: The result if validation fails (fatal; warning; record only; none).
 *
 * http://hl7.org/fhir/failureAction
 */
export declare const failureAction = "http://hl7.org/fhir/failureAction";
/**
 * suppliedItem
 *
 * SupplyDelivery.suppliedItem: The item that is being delivered or has been supplied.
 *
 * http://hl7.org/fhir/suppliedItem
 */
export declare const suppliedItem = "http://hl7.org/fhir/suppliedItem";
/**
 * abstract
 *
 * StructureDefinition.abstract: Whether structure this definition describes is abstract or not  - that is, whether the structure is not intended to be instantiated. For Resources and Data types, abstract types will never be exchanged  between systems.
 *
 * http://hl7.org/fhir/abstract
 */
export declare const abstract = "http://hl7.org/fhir/abstract";
/**
 * valueRange
 *
 * Evidence.statistic.modelCharacteristic.variable.valueRange: Range of values for grouping of ordinal or polychotomous variables.
 *
 * http://hl7.org/fhir/valueRange
 */
export declare const valueRange = "http://hl7.org/fhir/valueRange";
/**
 * _query
 *
 * (Modified) AuditEvent.entity.query
 *
 * http://hl7.org/fhir/_query
 */
export declare const _query = "http://hl7.org/fhir/_query";
/**
 * sigFormat
 *
 * Signature.sigFormat: A mime type that indicates the technical format of the signature. Important mime types are application/signature+xml for X ML DigSig, application/jose for JWS, and image/* for a graphical image of a signature, etc.
 *
 * http://hl7.org/fhir/sigFormat
 */
export declare const sigFormat = "http://hl7.org/fhir/sigFormat";
/**
 * VirtualServiceDetail
 *
 * Virtual Service Contact Details.
 *
 * http://hl7.org/fhir/VirtualServiceDetail
 */
export declare const VirtualServiceDetail = "http://hl7.org/fhir/VirtualServiceDetail";
/**
 * _rest
 *
 * (Modified) CapabilityStatement.rest
 *
 * http://hl7.org/fhir/_rest
 */
export declare const _rest = "http://hl7.org/fhir/_rest";
/**
 * packageCode
 *
 * Account.procedure.packageCode: The package code can be used to group procedures that may be priced or delivered as a single product. Such as DRGs.
 *
 * http://hl7.org/fhir/packageCode
 */
export declare const packageCode = "http://hl7.org/fhir/packageCode";
/**
 * _reaction
 *
 * (Modified) Immunization.reaction
 *
 * http://hl7.org/fhir/_reaction
 */
export declare const _reaction = "http://hl7.org/fhir/_reaction";
/**
 * _contributor
 *
 * (Modified) Citation.citedArtifact.contributorship.entry.contributor
 *
 * http://hl7.org/fhir/_contributor
 */
export declare const _contributor = "http://hl7.org/fhir/_contributor";
/**
 * _normalValue
 *
 * (Modified) Observation.component.referenceRange.normalValue
 *
 * http://hl7.org/fhir/_normalValue
 */
export declare const _normalValue = "http://hl7.org/fhir/_normalValue";
/**
 * _resultsInterpreter
 *
 * (Modified) DiagnosticReport.resultsInterpreter
 *
 * http://hl7.org/fhir/_resultsInterpreter
 */
export declare const _resultsInterpreter = "http://hl7.org/fhir/_resultsInterpreter";
/**
 * _tester
 *
 * (Modified) TestReport.tester
 *
 * http://hl7.org/fhir/_tester
 */
export declare const _tester = "http://hl7.org/fhir/_tester";
/**
 * denominator
 *
 * RatioRange.denominator: The value of the denominator.
 *
 * http://hl7.org/fhir/denominator
 */
export declare const denominator = "http://hl7.org/fhir/denominator";
/**
 * uniqueId
 *
 * NamingSystem.uniqueId: Indicates how the system may be identified when referenced in electronic exchange.
 *
 * http://hl7.org/fhir/uniqueId
 */
export declare const uniqueId = "http://hl7.org/fhir/uniqueId";
/**
 * readOnly
 *
 * Questionnaire.item.item.readOnly: An indication, when true, that the value cannot be changed by a human respondent to the Questionnaire.
 *
 * http://hl7.org/fhir/readOnly
 */
export declare const readOnly = "http://hl7.org/fhir/readOnly";
/**
 * _effectiveDosePeriod
 *
 * (Modified) MedicationRequest.effectiveDosePeriod
 *
 * http://hl7.org/fhir/_effectiveDosePeriod
 */
export declare const _effectiveDosePeriod = "http://hl7.org/fhir/_effectiveDosePeriod";
/**
 * _patientInstruction
 *
 * (Modified) ServiceRequest.patientInstruction
 *
 * http://hl7.org/fhir/_patientInstruction
 */
export declare const _patientInstruction = "http://hl7.org/fhir/_patientInstruction";
/**
 * focusReference
 *
 * EvidenceReport.section.section.focusReference: A definitional Resource identifying the kind of content contained within the section. This should be consistent with the section title.
 *
 * http://hl7.org/fhir/focusReference
 */
export declare const focusReference = "http://hl7.org/fhir/focusReference";
/**
 * _sopClass
 *
 * (Modified) ImagingStudy.series.instance.sopClass
 *
 * http://hl7.org/fhir/_sopClass
 */
export declare const _sopClass = "http://hl7.org/fhir/_sopClass";
/**
 * _brand
 *
 * (Modified) VisionPrescription.lensSpecification.brand
 *
 * http://hl7.org/fhir/_brand
 */
export declare const _brand = "http://hl7.org/fhir/_brand";
/**
 * SubscriptionStatusNotificationEventComponent
 *
 * SubscriptionStatusNotificationEventComponent: Detailed information about events relevant to this subscription notification.
 *
 * http://hl7.org/fhir/SubscriptionStatusNotificationEventComponent
 */
export declare const SubscriptionStatusNotificationEventComponent = "http://hl7.org/fhir/SubscriptionStatusNotificationEventComponent";
/**
 * specialArrangement
 *
 * Encounter.specialArrangement: Any special requests that have been made for this encounter, such as the provision of specific equipment or other things.
 *
 * http://hl7.org/fhir/specialArrangement
 */
export declare const specialArrangement = "http://hl7.org/fhir/specialArrangement";
/**
 * _autocreate
 *
 * (Modified) TestScript.fixture.autocreate
 *
 * http://hl7.org/fhir/_autocreate
 */
export declare const _autocreate = "http://hl7.org/fhir/_autocreate";
/**
 * _responsibility
 *
 * (Modified) Coverage.paymentBy.responsibility
 *
 * http://hl7.org/fhir/_responsibility
 */
export declare const _responsibility = "http://hl7.org/fhir/_responsibility";
/**
 * any
 *
 * ElementDefinition.binding.additional.any: Whether the binding applies to all repeats, or just to any one of them. This is only relevant for elements that can repeat.
 *
 * http://hl7.org/fhir/any
 */
export declare const any = "http://hl7.org/fhir/any";
/**
 * protocolApplied
 *
 * Immunization.protocolApplied: The protocol (set of recommendations) being followed by the provider who administered the dose.
 *
 * http://hl7.org/fhir/protocolApplied
 */
export declare const protocolApplied = "http://hl7.org/fhir/protocolApplied";
/**
 * PaymentNotice
 *
 * This resource provides the status of the payment for goods and services rendered, and the request and response resource references.
 *
 * http://hl7.org/fhir/PaymentNotice
 */
export declare const PaymentNotice = "http://hl7.org/fhir/PaymentNotice";
/**
 * _completionTime
 *
 * (Modified) Transport.completionTime
 *
 * http://hl7.org/fhir/_completionTime
 */
export declare const _completionTime = "http://hl7.org/fhir/_completionTime";
/**
 * _preAdmissionIdentifier
 *
 * (Modified) Encounter.admission.preAdmissionIdentifier
 *
 * http://hl7.org/fhir/_preAdmissionIdentifier
 */
export declare const _preAdmissionIdentifier = "http://hl7.org/fhir/_preAdmissionIdentifier";
/**
 * _interpretation
 *
 * (Modified) Observation.component.interpretation
 *
 * http://hl7.org/fhir/_interpretation
 */
export declare const _interpretation = "http://hl7.org/fhir/_interpretation";
/**
 * testingDestination
 *
 * SpecimenDefinition.typeTested.testingDestination: Where the specimen will be tested: e.g., lab, sector, device or any combination of these.
 *
 * http://hl7.org/fhir/testingDestination
 */
export declare const testingDestination = "http://hl7.org/fhir/testingDestination";
/**
 * ExtendedContactDetail
 *
 * Specifies contact information for a specific purpose over a period of time, might be handled/monitored by a specific named person or organization.
 *
 * http://hl7.org/fhir/ExtendedContactDetail
 */
export declare const ExtendedContactDetail = "http://hl7.org/fhir/ExtendedContactDetail";
/**
 * administrableDoseForm
 *
 * AdministrableProductDefinition.administrableDoseForm: The dose form of the final product after necessary reconstitution or processing. Contrasts to the manufactured dose form (see ManufacturedItemDefinition). If the manufactured form was 'powder for solution for injection', the administrable dose form could be 'solution for injection' (once mixed with another item having manufactured form 'solvent for solution for injection').
 *
 * http://hl7.org/fhir/administrableDoseForm
 */
export declare const administrableDoseForm = "http://hl7.org/fhir/administrableDoseForm";
/**
 * repeat
 *
 * SubstancePolymer.repeat: Specifies and quantifies the repeated units and their configuration.
 *
 * http://hl7.org/fhir/repeat
 */
export declare const repeat = "http://hl7.org/fhir/repeat";
/**
 * CapabilityStatementRestResourceSearchParamComponent
 *
 * CapabilityStatementRestComponent.CapabilityStatementRestResourceComponent.CapabilityStatementRestResourceSearchParamComponent: Search parameters for implementations to support and/or make use of - either references to ones defined in the specification, or additional ones defined for/by the implementation.
 *
 * http://hl7.org/fhir/CapabilityStatementRestResourceSearchParamComponent
 */
export declare const CapabilityStatementRestResourceSearchParamComponent = "http://hl7.org/fhir/CapabilityStatementRestResourceSearchParamComponent";
/**
 * interactant
 *
 * ClinicalUseDefinition.interaction.interactant: The specific medication, product, food, substance etc. or laboratory test that interacts.
 *
 * http://hl7.org/fhir/interactant
 */
export declare const interactant = "http://hl7.org/fhir/interactant";
/**
 * _groupDefinition
 *
 * (Modified) Measure.group.stratifier.component.groupDefinition
 *
 * http://hl7.org/fhir/_groupDefinition
 */
export declare const _groupDefinition = "http://hl7.org/fhir/_groupDefinition";
/**
 * _effective
 *
 * (Modified) Observation.effective
 *
 * http://hl7.org/fhir/_effective
 */
export declare const _effective = "http://hl7.org/fhir/_effective";
/**
 * _service
 *
 * (Modified) ChargeItem.service
 *
 * http://hl7.org/fhir/_service
 */
export declare const _service = "http://hl7.org/fhir/_service";
/**
 * admitSource
 *
 * Encounter.admission.admitSource: From where patient was admitted (physician referral, transfer).
 *
 * http://hl7.org/fhir/admitSource
 */
export declare const admitSource = "http://hl7.org/fhir/admitSource";
/**
 * _cap
 *
 * (Modified) SpecimenDefinition.typeTested.container.cap
 *
 * http://hl7.org/fhir/_cap
 */
export declare const _cap = "http://hl7.org/fhir/_cap";
/**
 * _structure
 *
 * (Modified) SubstanceDefinition.structure
 *
 * http://hl7.org/fhir/_structure
 */
export declare const _structure = "http://hl7.org/fhir/_structure";
/**
 * _preferred
 *
 * (Modified) SubstanceDefinition.name.translation.preferred
 *
 * http://hl7.org/fhir/_preferred
 */
export declare const _preferred = "http://hl7.org/fhir/_preferred";
/**
 * human
 *
 * ElementDefinition.constraint.human: Text that can be used to describe the constraint in messages identifying that the constraint has been violated.
 *
 * http://hl7.org/fhir/human
 */
export declare const human = "http://hl7.org/fhir/human";
/**
 * _genomeAssembly
 *
 * (Modified) MolecularSequence.relative.startingSequence.genomeAssembly
 *
 * http://hl7.org/fhir/_genomeAssembly
 */
export declare const _genomeAssembly = "http://hl7.org/fhir/_genomeAssembly";
/**
 * _dimensions
 *
 * (Modified) SampledData.dimensions
 *
 * http://hl7.org/fhir/_dimensions
 */
export declare const _dimensions = "http://hl7.org/fhir/_dimensions";
/**
 * Reason
 *
 * Encounter.Reason: The list of medical reasons that are expected to be addressed during the episode of care.
 *
 * http://hl7.org/fhir/Reason
 */
export declare const Reason = "http://hl7.org/fhir/Reason";
/**
 * eligibility
 *
 * ResearchStudy.recruitment.eligibility: Inclusion and exclusion criteria.
 *
 * http://hl7.org/fhir/eligibility
 */
export declare const eligibility = "http://hl7.org/fhir/eligibility";
/**
 * resultForCreate
 *
 * SubscriptionTopic.resourceTrigger.queryCriteria.resultForCreate: For `create` interactions, should the `previous` criteria count as an automatic pass or an automatic fail. If not present, the testing behavior during `create` interactions is unspecified (server discretion).
 *
 * http://hl7.org/fhir/resultForCreate
 */
export declare const resultForCreate = "http://hl7.org/fhir/resultForCreate";
/**
 * PersonLinkComponent
 *
 * PersonLinkComponent: Link to a resource that concerns the same actual person.
 *
 * http://hl7.org/fhir/PersonLinkComponent
 */
export declare const PersonLinkComponent = "http://hl7.org/fhir/PersonLinkComponent";
/**
 * EvidenceCertaintyComponent
 *
 * EvidenceCertaintyComponent: Assessment of certainty, confidence in the estimates, or quality of the evidence.
 *
 * http://hl7.org/fhir/EvidenceCertaintyComponent
 */
export declare const EvidenceCertaintyComponent = "http://hl7.org/fhir/EvidenceCertaintyComponent";
/**
 * texture
 *
 * NutritionOrder.oralDiet.texture: Class that describes any texture modifications required for the patient to safely consume various types of solid foods.
 *
 * http://hl7.org/fhir/texture
 */
export declare const texture = "http://hl7.org/fhir/texture";
/**
 * characterization
 *
 * SubstanceDefinition.characterization: General specifications for this substance.
 *
 * http://hl7.org/fhir/characterization
 */
export declare const characterization = "http://hl7.org/fhir/characterization";
/**
 * TerminologyCapabilitiesExpansionComponent
 *
 * TerminologyCapabilitiesExpansionComponent: Information about the [ValueSet/$expand](valueset-operation-expand.html) operation.
 *
 * http://hl7.org/fhir/TerminologyCapabilitiesExpansionComponent
 */
export declare const TerminologyCapabilitiesExpansionComponent = "http://hl7.org/fhir/TerminologyCapabilitiesExpansionComponent";
/**
 * DataRequirementCodeFilterComponent
 *
 * DataRequirementCodeFilterComponent: Code filters specify additional constraints on the data, specifying the value set of interest for a particular element of the data. Each code filter defines an additional constraint on the data, i.e. code filters are AND'ed, not OR'ed.
 *
 * http://hl7.org/fhir/DataRequirementCodeFilterComponent
 */
export declare const DataRequirementCodeFilterComponent = "http://hl7.org/fhir/DataRequirementCodeFilterComponent";
/**
 * _derivedFrom
 *
 * (Modified) Requirements.statement.derivedFrom
 *
 * http://hl7.org/fhir/_derivedFrom
 */
export declare const _derivedFrom = "http://hl7.org/fhir/_derivedFrom";
/**
 * _doseAdministrationAid
 *
 * (Modified) MedicationRequest.dispenseRequest.doseAdministrationAid
 *
 * http://hl7.org/fhir/_doseAdministrationAid
 */
export declare const _doseAdministrationAid = "http://hl7.org/fhir/_doseAdministrationAid";
/**
 * productOrService
 *
 * ExplanationOfBenefit.item.detail.subDetail.productOrService: When the value is a group code then this item collects a set of related item details, otherwise this contains the product, service, drug or other billing code for the item. This element may be the start of a range of .productOrService codes used in conjunction with .productOrServiceEnd or it may be a solo element where .productOrServiceEnd is not used.
 *
 * http://hl7.org/fhir/productOrService
 */
export declare const productOrService = "http://hl7.org/fhir/productOrService";
/**
 * _plannedEndDate
 *
 * (Modified) EncounterHistory.plannedEndDate
 *
 * http://hl7.org/fhir/_plannedEndDate
 */
export declare const _plannedEndDate = "http://hl7.org/fhir/_plannedEndDate";
/**
 * conformsTo
 *
 * DeviceDefinition.conformsTo: Identifies the standards, specifications, or formal guidances for the capabilities supported by the device. The device may be certified as conformant to these specifications e.g., communication, performance, process, measurement, or specialization standards.
 *
 * http://hl7.org/fhir/conformsTo
 */
export declare const conformsTo = "http://hl7.org/fhir/conformsTo";
/**
 * _detected
 *
 * (Modified) AdverseEvent.detected
 *
 * http://hl7.org/fhir/_detected
 */
export declare const _detected = "http://hl7.org/fhir/_detected";
/**
 * _threePrime
 *
 * (Modified) SubstanceNucleicAcid.subunit.threePrime
 *
 * http://hl7.org/fhir/_threePrime
 */
export declare const _threePrime = "http://hl7.org/fhir/_threePrime";
/**
 * referencedFrom
 *
 * OperationDefinition.parameter.part.referencedFrom: Identifies other resource parameters within the operation invocation that are expected to resolve to this resource.
 *
 * http://hl7.org/fhir/referencedFrom
 */
export declare const referencedFrom = "http://hl7.org/fhir/referencedFrom";
/**
 * targetFormat
 *
 * Signature.targetFormat: A mime type that indicates the technical format of the target resources signed by the signature.
 *
 * http://hl7.org/fhir/targetFormat
 */
export declare const targetFormat = "http://hl7.org/fhir/targetFormat";
/**
 * _characteristicType
 *
 * (Modified) InventoryItem.characteristic.characteristicType
 *
 * http://hl7.org/fhir/_characteristicType
 */
export declare const _characteristicType = "http://hl7.org/fhir/_characteristicType";
/**
 * StructureDefinitionMappingComponent
 *
 * StructureDefinitionMappingComponent: An external specification that the content is mapped to.
 *
 * http://hl7.org/fhir/StructureDefinitionMappingComponent
 */
export declare const StructureDefinitionMappingComponent = "http://hl7.org/fhir/StructureDefinitionMappingComponent";
/**
 * _initiatorActive
 *
 * (Modified) ExampleScenario.process.step.alternative.step.operation.initiatorActive
 *
 * http://hl7.org/fhir/_initiatorActive
 */
export declare const _initiatorActive = "http://hl7.org/fhir/_initiatorActive";
/**
 * supportedInteraction
 *
 * SubscriptionTopic.resourceTrigger.supportedInteraction: The FHIR RESTful interaction which can be used to trigger a notification for the SubscriptionTopic. Multiple values are considered OR joined (e.g., CREATE or UPDATE). If not present, all supported interactions are assumed.
 *
 * http://hl7.org/fhir/supportedInteraction
 */
export declare const supportedInteraction = "http://hl7.org/fhir/supportedInteraction";
/**
 * vaccineCode
 *
 * ImmunizationRecommendation.recommendation.vaccineCode: Vaccine(s) or vaccine group that pertain to the recommendation.
 *
 * http://hl7.org/fhir/vaccineCode
 */
export declare const vaccineCode = "http://hl7.org/fhir/vaccineCode";
/**
 * seriesNumber
 *
 * ImagingSelection.seriesNumber: The Series Number for the DICOM Series from which the images were selected.
 *
 * http://hl7.org/fhir/seriesNumber
 */
export declare const seriesNumber = "http://hl7.org/fhir/seriesNumber";
/**
 * pageCount
 *
 * Citation.citedArtifact.publicationForm.pageCount: Actual or approximate number of pages or screens. Distinct from reporting the page numbers.
 *
 * http://hl7.org/fhir/pageCount
 */
export declare const pageCount = "http://hl7.org/fhir/pageCount";
/**
 * _who
 *
 * (Modified) VerificationResult.attestation.who
 *
 * http://hl7.org/fhir/_who
 */
export declare const _who = "http://hl7.org/fhir/_who";
/**
 * PermissionRuleActivityComponent
 *
 * Permission.Rule.PermissionRuleActivityComponent: A description or definition of which activities are allowed to be done on the data.
 *
 * http://hl7.org/fhir/PermissionRuleActivityComponent
 */
export declare const PermissionRuleActivityComponent = "http://hl7.org/fhir/PermissionRuleActivityComponent";
/**
 * careManager
 *
 * EpisodeOfCare.careManager: The practitioner that is the care manager/care coordinator for this patient.
 *
 * http://hl7.org/fhir/careManager
 */
export declare const careManager = "http://hl7.org/fhir/careManager";
/**
 * CodeSystem
 *
 * The CodeSystem resource is used to declare the existence of and describe a code system or code system supplement and its key properties, and optionally define a part or all of its content.
 *
 * http://hl7.org/fhir/CodeSystem
 */
export declare const CodeSystem = "http://hl7.org/fhir/CodeSystem";
/**
 * MedicinalProductDefinitionNamePartComponent
 *
 * MedicinalProductDefinitionNameComponent.MedicinalProductDefinitionNamePartComponent: Coding words or phrases of the name.
 *
 * http://hl7.org/fhir/MedicinalProductDefinitionNamePartComponent
 */
export declare const MedicinalProductDefinitionNamePartComponent = "http://hl7.org/fhir/MedicinalProductDefinitionNamePartComponent";
/**
 * _requestingOrganization
 *
 * (Modified) ChargeItem.requestingOrganization
 *
 * http://hl7.org/fhir/_requestingOrganization
 */
export declare const _requestingOrganization = "http://hl7.org/fhir/_requestingOrganization";
/**
 * _referralMethod
 *
 * (Modified) HealthcareService.referralMethod
 *
 * http://hl7.org/fhir/_referralMethod
 */
export declare const _referralMethod = "http://hl7.org/fhir/_referralMethod";
/**
 * _suspectEntity
 *
 * (Modified) AdverseEvent.suspectEntity
 *
 * http://hl7.org/fhir/_suspectEntity
 */
export declare const _suspectEntity = "http://hl7.org/fhir/_suspectEntity";
/**
 * _exclusionCriteria
 *
 * (Modified) ValueSet.scope.exclusionCriteria
 *
 * http://hl7.org/fhir/_exclusionCriteria
 */
export declare const _exclusionCriteria = "http://hl7.org/fhir/_exclusionCriteria";
/**
 * ObservationComponentComponent
 *
 * ObservationComponentComponent: Some observations have multiple component observations.  These component observations are expressed as separate code value pairs that share the same attributes.  Examples include systolic and diastolic component observations for blood pressure measurement and multiple component observations for genetics observations.
 *
 * http://hl7.org/fhir/ObservationComponentComponent
 */
export declare const ObservationComponentComponent = "http://hl7.org/fhir/ObservationComponentComponent";
/**
 * _testScript
 *
 * (Modified) TestReport.testScript
 *
 * http://hl7.org/fhir/_testScript
 */
export declare const _testScript = "http://hl7.org/fhir/_testScript";
/**
 * manufactureDate
 *
 * Device.manufactureDate: The date and time when the device was manufactured.
 *
 * http://hl7.org/fhir/manufactureDate
 */
export declare const manufactureDate = "http://hl7.org/fhir/manufactureDate";
/**
 * _textPresentation
 *
 * (Modified) Ingredient.substance.strength.textPresentation
 *
 * http://hl7.org/fhir/_textPresentation
 */
export declare const _textPresentation = "http://hl7.org/fhir/_textPresentation";
/**
 * TestReportSetupActionOperationComponent
 *
 * TestReportSetupComponent.SetupAction.TestReportSetupActionOperationComponent: The operation performed.
 *
 * http://hl7.org/fhir/TestReportSetupActionOperationComponent
 */
export declare const TestReportSetupActionOperationComponent = "http://hl7.org/fhir/TestReportSetupActionOperationComponent";
/**
 * legal
 *
 * Contract.legal: List of Legal expressions or representations of this Contract.
 *
 * http://hl7.org/fhir/legal
 */
export declare const legal = "http://hl7.org/fhir/legal";
/**
 * provider
 *
 * ExplanationOfBenefit.addItem.provider: The providers who are authorized for the services rendered to the patient.
 *
 * http://hl7.org/fhir/provider
 */
export declare const provider = "http://hl7.org/fhir/provider";
/**
 * exitCriteria
 *
 * TestPlan.exitCriteria: The threshold or criteria for the test plan to be considered successfully executed - narrative.
 *
 * http://hl7.org/fhir/exitCriteria
 */
export declare const exitCriteria = "http://hl7.org/fhir/exitCriteria";
/**
 * image
 *
 * ImplementationGuide.manifest.image: Indicates a relative path to an image that exists within the IG.
 *
 * http://hl7.org/fhir/image
 */
export declare const image = "http://hl7.org/fhir/image";
/**
 * SupplyRequest
 *
 * A record of a non-patient specific request for a medication, substance, device, certain types of biologically derived product, and nutrition product used in the healthcare setting.
 *
 * http://hl7.org/fhir/SupplyRequest
 */
export declare const SupplyRequest = "http://hl7.org/fhir/SupplyRequest";
/**
 * _periodMax
 *
 * (Modified) Timing.repeat.periodMax
 *
 * http://hl7.org/fhir/_periodMax
 */
export declare const _periodMax = "http://hl7.org/fhir/_periodMax";
/**
 * _monograph
 *
 * (Modified) MedicationKnowledge.monograph
 *
 * http://hl7.org/fhir/_monograph
 */
export declare const _monograph = "http://hl7.org/fhir/_monograph";
/**
 * _decision
 *
 * (Modified) ExplanationOfBenefit.item.detail.subDetail.reviewOutcome.decision
 *
 * http://hl7.org/fhir/_decision
 */
export declare const _decision = "http://hl7.org/fhir/_decision";
/**
 * _diagnostics
 *
 * (Modified) OperationOutcome.issue.diagnostics
 *
 * http://hl7.org/fhir/_diagnostics
 */
export declare const _diagnostics = "http://hl7.org/fhir/_diagnostics";
/**
 * _origin
 *
 * (Modified) TestScript.teardown.action.operation.origin
 *
 * http://hl7.org/fhir/_origin
 */
export declare const _origin = "http://hl7.org/fhir/_origin";
/**
 * _durationUnit
 *
 * (Modified) Timing.repeat.durationUnit
 *
 * http://hl7.org/fhir/_durationUnit
 */
export declare const _durationUnit = "http://hl7.org/fhir/_durationUnit";
/**
 * contact
 *
 * MessageHeader.source.contact: An e-mail, phone, website or other contact point to use to resolve issues with message communications.
 *
 * http://hl7.org/fhir/contact
 */
export declare const contact = "http://hl7.org/fhir/contact";
/**
 * _disabledDisplay
 *
 * (Modified) Questionnaire.item.item.disabledDisplay
 *
 * http://hl7.org/fhir/_disabledDisplay
 */
export declare const _disabledDisplay = "http://hl7.org/fhir/_disabledDisplay";
/**
 * _attestation
 *
 * (Modified) VerificationResult.attestation
 *
 * http://hl7.org/fhir/_attestation
 */
export declare const _attestation = "http://hl7.org/fhir/_attestation";
/**
 * PackagedProductDefinitionPackagingComponentPackaging
 *
 * Allows containers (and parts of containers) within containers, still as a part of a single packaged product. See also PackagedProductDefinition.packaging.containedItem.item(PackagedProductDefinition).
 *
 * http://hl7.org/fhir/PackagedProductDefinitionPackagingComponentPackaging
 */
export declare const PackagedProductDefinitionPackagingComponentPackaging = "http://hl7.org/fhir/PackagedProductDefinitionPackagingComponentPackaging";
/**
 * OperationOutcomeIssueComponent
 *
 * OperationOutcomeIssueComponent: An error, warning, or information message that results from a system action.
 *
 * http://hl7.org/fhir/OperationOutcomeIssueComponent
 */
export declare const OperationOutcomeIssueComponent = "http://hl7.org/fhir/OperationOutcomeIssueComponent";
/**
 * _hash
 *
 * (Modified) Attachment.hash
 *
 * http://hl7.org/fhir/_hash
 */
export declare const _hash = "http://hl7.org/fhir/_hash";
/**
 * _pageString
 *
 * (Modified) Citation.citedArtifact.publicationForm.pageString
 *
 * http://hl7.org/fhir/_pageString
 */
export declare const _pageString = "http://hl7.org/fhir/_pageString";
/**
 * _constituent
 *
 * (Modified) ManufacturedItemDefinition.component.component.constituent
 *
 * http://hl7.org/fhir/_constituent
 */
export declare const _constituent = "http://hl7.org/fhir/_constituent";
/**
 * DeviceAssociation
 *
 * A record of association of a device.
 *
 * http://hl7.org/fhir/DeviceAssociation
 */
export declare const DeviceAssociation = "http://hl7.org/fhir/DeviceAssociation";
/**
 * _dayOfWeek
 *
 * (Modified) Appointment.recurrenceTemplate.monthlyTemplate.dayOfWeek
 *
 * http://hl7.org/fhir/_dayOfWeek
 */
export declare const _dayOfWeek = "http://hl7.org/fhir/_dayOfWeek";
/**
 * _inventoryListing
 *
 * (Modified) InventoryReport.inventoryListing
 *
 * http://hl7.org/fhir/_inventoryListing
 */
export declare const _inventoryListing = "http://hl7.org/fhir/_inventoryListing";
/**
 * _hierarchyMeaning
 *
 * (Modified) CodeSystem.hierarchyMeaning
 *
 * http://hl7.org/fhir/_hierarchyMeaning
 */
export declare const _hierarchyMeaning = "http://hl7.org/fhir/_hierarchyMeaning";
/**
 * _dispenseRequest
 *
 * (Modified) MedicationRequest.dispenseRequest
 *
 * http://hl7.org/fhir/_dispenseRequest
 */
export declare const _dispenseRequest = "http://hl7.org/fhir/_dispenseRequest";
/**
 * legallyBinding
 *
 * Contract.legallyBinding
 *
 * http://hl7.org/fhir/legallyBinding
 */
export declare const legallyBinding = "http://hl7.org/fhir/legallyBinding";
/**
 * _manufacturer
 *
 * (Modified) SubstanceDefinition.manufacturer
 *
 * http://hl7.org/fhir/_manufacturer
 */
export declare const _manufacturer = "http://hl7.org/fhir/_manufacturer";
/**
 * _answerConstraint
 *
 * (Modified) Questionnaire.item.item.answerConstraint
 *
 * http://hl7.org/fhir/_answerConstraint
 */
export declare const _answerConstraint = "http://hl7.org/fhir/_answerConstraint";
/**
 * _when
 *
 * (Modified) ClaimResponse.event.when
 *
 * http://hl7.org/fhir/_when
 */
export declare const _when = "http://hl7.org/fhir/_when";
/**
 * _form
 *
 * (Modified) SubstanceDefinition.characterization.form
 *
 * http://hl7.org/fhir/_form
 */
export declare const _form = "http://hl7.org/fhir/_form";
/**
 * businessStatus
 *
 * Task.businessStatus: Contains business-specific nuances of the business state.
 *
 * http://hl7.org/fhir/businessStatus
 */
export declare const businessStatus = "http://hl7.org/fhir/businessStatus";
/**
 * comparisonGroup
 *
 * ResearchStudy.comparisonGroup: Describes an expected event or sequence of events for one of the subjects of a study. E.g. for a living subject: exposure to drug A, wash-out, exposure to drug B, wash-out, follow-up. E.g. for a stability study: {store sample from lot A at 25 degrees for 1 month}, {store sample from lot A at 40 degrees for 1 month}.
 *
 * http://hl7.org/fhir/comparisonGroup
 */
export declare const comparisonGroup = "http://hl7.org/fhir/comparisonGroup";
/**
 * _instance
 *
 * (Modified) ExampleScenario.instance
 *
 * http://hl7.org/fhir/_instance
 */
export declare const _instance = "http://hl7.org/fhir/_instance";
/**
 * _itemStatus
 *
 * (Modified) InventoryReport.inventoryListing.itemStatus
 *
 * http://hl7.org/fhir/_itemStatus
 */
export declare const _itemStatus = "http://hl7.org/fhir/_itemStatus";
/**
 * _conditionalDelete
 *
 * (Modified) CapabilityStatement.rest.resource.conditionalDelete
 *
 * http://hl7.org/fhir/_conditionalDelete
 */
export declare const _conditionalDelete = "http://hl7.org/fhir/_conditionalDelete";
/**
 * _grade
 *
 * (Modified) SubstanceDefinition.grade
 *
 * http://hl7.org/fhir/_grade
 */
export declare const _grade = "http://hl7.org/fhir/_grade";
/**
 * _process
 *
 * (Modified) ExampleScenario.process.step.alternative.step.process
 *
 * http://hl7.org/fhir/_process
 */
export declare const _process = "http://hl7.org/fhir/_process";
/**
 * _articleDate
 *
 * (Modified) Citation.citedArtifact.publicationForm.articleDate
 *
 * http://hl7.org/fhir/_articleDate
 */
export declare const _articleDate = "http://hl7.org/fhir/_articleDate";
/**
 * additionalMonitoringIndicator
 *
 * MedicinalProductDefinition.additionalMonitoringIndicator: Whether the Medicinal Product is subject to additional monitoring for regulatory reasons, such as heightened reporting requirements.
 *
 * http://hl7.org/fhir/additionalMonitoringIndicator
 */
export declare const additionalMonitoringIndicator = "http://hl7.org/fhir/additionalMonitoringIndicator";
/**
 * title
 *
 * ValueSet.title: A short, descriptive, user-friendly title for the value set.
 *
 * http://hl7.org/fhir/title
 */
export declare const title = "http://hl7.org/fhir/title";
/**
 * _courseOfTherapyType
 *
 * (Modified) MedicationRequest.courseOfTherapyType
 *
 * http://hl7.org/fhir/_courseOfTherapyType
 */
export declare const _courseOfTherapyType = "http://hl7.org/fhir/_courseOfTherapyType";
/**
 * _identity
 *
 * (Modified) StructureDefinition.mapping.identity
 *
 * http://hl7.org/fhir/_identity
 */
export declare const _identity = "http://hl7.org/fhir/_identity";
/**
 * CapabilityStatementRestComponent
 *
 * CapabilityStatementRestComponent: A definition of the restful capabilities of the solution, if any.
 *
 * http://hl7.org/fhir/CapabilityStatementRestComponent
 */
export declare const CapabilityStatementRestComponent = "http://hl7.org/fhir/CapabilityStatementRestComponent";
/**
 * additionalAttribute
 *
 * ConceptMap.additionalAttribute: An additionalAttribute defines an additional data element found in the source or target data model where the data will come from or be mapped to. Some mappings are based on data in addition to the source data element, where codes in multiple fields are combined to a single field (or vice versa).
 *
 * http://hl7.org/fhir/additionalAttribute
 */
export declare const additionalAttribute = "http://hl7.org/fhir/additionalAttribute";
/**
 * monomerSet
 *
 * SubstancePolymer.monomerSet: Todo.
 *
 * http://hl7.org/fhir/monomerSet
 */
export declare const monomerSet = "http://hl7.org/fhir/monomerSet";
/**
 * ingredient
 *
 * Medication.ingredient: Identifies a particular constituent of interest in the product.
 *
 * http://hl7.org/fhir/ingredient
 */
export declare const ingredient = "http://hl7.org/fhir/ingredient";
/**
 * _subPotentReason
 *
 * (Modified) MedicationAdministration.subPotentReason
 *
 * http://hl7.org/fhir/_subPotentReason
 */
export declare const _subPotentReason = "http://hl7.org/fhir/_subPotentReason";
/**
 * _supportedMessage
 *
 * (Modified) CapabilityStatement.messaging.supportedMessage
 *
 * http://hl7.org/fhir/_supportedMessage
 */
export declare const _supportedMessage = "http://hl7.org/fhir/_supportedMessage";
/**
 * DataRequirementDateFilterComponent
 *
 * DataRequirementDateFilterComponent: Date filters specify additional constraints on the data in terms of the applicable date range for specific elements. Each date filter specifies an additional constraint on the data, i.e. date filters are AND'ed, not OR'ed.
 *
 * http://hl7.org/fhir/DataRequirementDateFilterComponent
 */
export declare const DataRequirementDateFilterComponent = "http://hl7.org/fhir/DataRequirementDateFilterComponent";
/**
 * _performedActivity
 *
 * (Modified) CarePlan.activity.performedActivity
 *
 * http://hl7.org/fhir/_performedActivity
 */
export declare const _performedActivity = "http://hl7.org/fhir/_performedActivity";
/**
 * _specialty
 *
 * (Modified) Claim.careTeam.specialty
 *
 * http://hl7.org/fhir/_specialty
 */
export declare const _specialty = "http://hl7.org/fhir/_specialty";
/**
 * _weekInterval
 *
 * (Modified) Appointment.recurrenceTemplate.weeklyTemplate.weekInterval
 *
 * http://hl7.org/fhir/_weekInterval
 */
export declare const _weekInterval = "http://hl7.org/fhir/_weekInterval";
/**
 * publicationDate
 *
 * Contract.contentDefinition.publicationDate: The date (and optionally time) when the contract was last significantly changed. The date must change when the business version changes and it must change if the status code changes. In addition, it should change when the substantive content of the contract changes.
 *
 * http://hl7.org/fhir/publicationDate
 */
export declare const publicationDate = "http://hl7.org/fhir/publicationDate";
/**
 * administrationInstruction
 *
 * NutritionOrder.enteralFormula.administrationInstruction: Free text formula administration, feeding instructions or additional instructions or information.
 *
 * http://hl7.org/fhir/administrationInstruction
 */
export declare const administrationInstruction = "http://hl7.org/fhir/administrationInstruction";
/**
 * fivePrime
 *
 * SubstanceNucleicAcid.subunit.fivePrime: The nucleotide present at the 5’ terminal shall be specified based on a controlled vocabulary. Since the sequence is represented from the 5' to the 3' end, the 5’ prime nucleotide is the letter at the first position in the sequence. A separate representation would be redundant.
 *
 * http://hl7.org/fhir/fivePrime
 */
export declare const fivePrime = "http://hl7.org/fhir/fivePrime";
/**
 * _points
 *
 * (Modified) Contract.term.group.asset.valuedItem.points
 *
 * http://hl7.org/fhir/_points
 */
export declare const _points = "http://hl7.org/fhir/_points";
/**
 * TestScriptSetupActionAssertComponent
 *
 * TestScriptSetupComponent.SetupAction.TestScriptSetupActionAssertComponent: Evaluates the results of previous operations to determine if the server under test behaves appropriately.
 *
 * http://hl7.org/fhir/TestScriptSetupActionAssertComponent
 */
export declare const TestScriptSetupActionAssertComponent = "http://hl7.org/fhir/TestScriptSetupActionAssertComponent";
/**
 * referralRequest
 *
 * EpisodeOfCare.referralRequest: Referral Request(s) that are fulfilled by this EpisodeOfCare, incoming referrals.
 *
 * http://hl7.org/fhir/referralRequest
 */
export declare const referralRequest = "http://hl7.org/fhir/referralRequest";
/**
 * _timeAspect
 *
 * (Modified) SpecimenDefinition.timeAspect
 *
 * http://hl7.org/fhir/_timeAspect
 */
export declare const _timeAspect = "http://hl7.org/fhir/_timeAspect";
/**
 * _presentedForm
 *
 * (Modified) DiagnosticReport.presentedForm
 *
 * http://hl7.org/fhir/_presentedForm
 */
export declare const _presentedForm = "http://hl7.org/fhir/_presentedForm";
/**
 * _seriesDoses
 *
 * (Modified) ImmunizationRecommendation.recommendation.seriesDoses
 *
 * http://hl7.org/fhir/_seriesDoses
 */
export declare const _seriesDoses = "http://hl7.org/fhir/_seriesDoses";
/**
 * milestone
 *
 * ResearchSubject.progress.milestone: The milestones the subject has passed through.
 *
 * http://hl7.org/fhir/milestone
 */
export declare const milestone = "http://hl7.org/fhir/milestone";
/**
 * MedicationAdministrationPerformerComponent
 *
 * MedicationAdministrationPerformerComponent: The performer of the medication treatment.  For devices this is the device that performed the administration of the medication.  An IV Pump would be an example of a device that is performing the administration. Both the IV Pump and the practitioner that set the rate or bolus on the pump can be listed as performers.
 *
 * http://hl7.org/fhir/MedicationAdministrationPerformerComponent
 */
export declare const MedicationAdministrationPerformerComponent = "http://hl7.org/fhir/MedicationAdministrationPerformerComponent";
/**
 * Invoice
 *
 * Invoice containing collected ChargeItems from an Account with calculated individual and total price for Billing purpose.
 *
 * http://hl7.org/fhir/Invoice
 */
export declare const Invoice = "http://hl7.org/fhir/Invoice";
/**
 * additionalContext
 *
 * SubscriptionStatus.notificationEvent.additionalContext: Additional context information for this event. Generally, this will contain references to additional resources included with the event (e.g., the Patient relevant to an Encounter), however it MAY refer to non-FHIR objects.
 *
 * http://hl7.org/fhir/additionalContext
 */
export declare const additionalContext = "http://hl7.org/fhir/additionalContext";
/**
 * _satisfiedBy
 *
 * (Modified) Requirements.statement.satisfiedBy
 *
 * http://hl7.org/fhir/_satisfiedBy
 */
export declare const _satisfiedBy = "http://hl7.org/fhir/_satisfiedBy";
/**
 * identifier
 *
 * ImplementationGuide.identifier: A formal identifier that is used to identify this implementation guide when it is represented in other formats, or referenced in a specification, model, design or an instance.
 *
 * http://hl7.org/fhir/identifier
 */
export declare const identifier = "http://hl7.org/fhir/identifier";
/**
 * SubstanceNucleicAcid
 *
 * Nucleic acids are defined by three distinct elements: the base, sugar and linkage. Individual substance/moiety IDs will be created for each of these elements. The nucleotide sequence will be always entered in the 5’-3’ direction.
 *
 * http://hl7.org/fhir/SubstanceNucleicAcid
 */
export declare const SubstanceNucleicAcid = "http://hl7.org/fhir/SubstanceNucleicAcid";
/**
 * resourceTrigger
 *
 * SubscriptionTopic.resourceTrigger: A definition of a resource-based event that triggers a notification based on the SubscriptionTopic. The criteria may be just a human readable description and/or a full FHIR search string or FHIRPath expression. Multiple triggers are considered OR joined (e.g., a resource update matching ANY of the definitions will trigger a notification).
 *
 * http://hl7.org/fhir/resourceTrigger
 */
export declare const resourceTrigger = "http://hl7.org/fhir/resourceTrigger";
/**
 * _overload
 *
 * (Modified) OperationDefinition.overload
 *
 * http://hl7.org/fhir/_overload
 */
export declare const _overload = "http://hl7.org/fhir/_overload";
/**
 * organization
 *
 * VerificationResult.validator.organization: Reference to the organization validating information.
 *
 * http://hl7.org/fhir/organization
 */
export declare const organization = "http://hl7.org/fhir/organization";
/**
 * PlanDefinitionActionConditionComponent
 *
 * PlanDefinitionActionComponentAction.PlanDefinitionActionConditionComponent: An expression that describes applicability criteria or start/stop conditions for the action.
 *
 * http://hl7.org/fhir/PlanDefinitionActionConditionComponent
 */
export declare const PlanDefinitionActionConditionComponent = "http://hl7.org/fhir/PlanDefinitionActionConditionComponent";
/**
 * RegulatedAuthorizationCaseComponentCaseCase
 *
 * A regulatory submission from an organization to a regulator, as part of an assessing case. Multiple applications may occur over time, with more or different information to support or modify the submission or the authorization. The applications can be considered as steps within the longer running case or procedure for this authorization process.
 *
 * http://hl7.org/fhir/RegulatedAuthorizationCaseComponentCaseCase
 */
export declare const RegulatedAuthorizationCaseComponentCaseCase = "http://hl7.org/fhir/RegulatedAuthorizationCaseComponentCaseCase";
/**
 * sliceIsConstraining
 *
 * ElementDefinition.sliceIsConstraining: If true, indicates that this slice definition is constraining a slice definition with the same name in an inherited profile. If false, the slice is not overriding any slice in an inherited profile. If missing, the slice might or might not be overriding a slice in an inherited profile, depending on the sliceName.
 *
 * http://hl7.org/fhir/sliceIsConstraining
 */
export declare const sliceIsConstraining = "http://hl7.org/fhir/sliceIsConstraining";
/**
 * _dataUpdateType
 *
 * (Modified) MeasureReport.dataUpdateType
 *
 * http://hl7.org/fhir/_dataUpdateType
 */
export declare const _dataUpdateType = "http://hl7.org/fhir/_dataUpdateType";
/**
 * noteNumber
 *
 * ClaimResponse.item.detail.noteNumber: The numbers associated with notes below which apply to the adjudication of this item.
 *
 * http://hl7.org/fhir/noteNumber
 */
export declare const noteNumber = "http://hl7.org/fhir/noteNumber";
/**
 * installDate
 *
 * Device.version.installDate: The date the version was installed on the device.
 *
 * http://hl7.org/fhir/installDate
 */
export declare const installDate = "http://hl7.org/fhir/installDate";
/**
 * cardBrand
 *
 * PaymentReconciliation.cardBrand: The card brand such as debit, Visa, Amex etc. used if a card is the method of payment.
 *
 * http://hl7.org/fhir/cardBrand
 */
export declare const cardBrand = "http://hl7.org/fhir/cardBrand";
/**
 * _fullUrl
 *
 * (Modified) Bundle.entry.fullUrl
 *
 * http://hl7.org/fhir/_fullUrl
 */
export declare const _fullUrl = "http://hl7.org/fhir/_fullUrl";
/**
 * codeMap
 *
 * SampledData.codeMap: Reference to ConceptMap that defines the codes used in the data.
 *
 * http://hl7.org/fhir/codeMap
 */
export declare const codeMap = "http://hl7.org/fhir/codeMap";
/**
 * ConditionDefinitionObservationComponent
 *
 * ConditionDefinitionObservationComponent: Observations particularly relevant to this condition.
 *
 * http://hl7.org/fhir/ConditionDefinitionObservationComponent
 */
export declare const ConditionDefinitionObservationComponent = "http://hl7.org/fhir/ConditionDefinitionObservationComponent";
/**
 * FamilyMemberHistory
 *
 * Significant health conditions for a person related to the patient relevant in the context of care for the patient.
 *
 * http://hl7.org/fhir/FamilyMemberHistory
 */
export declare const FamilyMemberHistory = "http://hl7.org/fhir/FamilyMemberHistory";
/**
 * operationTypeReason
 *
 * InventoryReport.operationTypeReason: The reason for this count - regular count, ad-hoc count, new arrivals, etc.
 *
 * http://hl7.org/fhir/operationTypeReason
 */
export declare const operationTypeReason = "http://hl7.org/fhir/operationTypeReason";
/**
 * SpecimenDefinitionTypeTestedContainerAdditiveComponent
 *
 * SpecimenDefinitionTypeTestedComponent.SpecimenDefinitionTypeTestedContainerComponent.SpecimenDefinitionTypeTestedContainerAdditiveComponent: Substance introduced in the kind of container to preserve, maintain or enhance the specimen. Examples: Formalin, Citrate, EDTA.
 *
 * http://hl7.org/fhir/SpecimenDefinitionTypeTestedContainerAdditiveComponent
 */
export declare const SpecimenDefinitionTypeTestedContainerAdditiveComponent = "http://hl7.org/fhir/SpecimenDefinitionTypeTestedContainerAdditiveComponent";
/**
 * _element
 *
 * (Modified) StructureDefinition.differential.element
 *
 * http://hl7.org/fhir/_element
 */
export declare const _element = "http://hl7.org/fhir/_element";
/**
 * _attachedDocument
 *
 * (Modified) RegulatedAuthorization.attachedDocument
 *
 * http://hl7.org/fhir/_attachedDocument
 */
export declare const _attachedDocument = "http://hl7.org/fhir/_attachedDocument";
/**
 * _implementation
 *
 * (Modified) TerminologyCapabilities.implementation
 *
 * http://hl7.org/fhir/_implementation
 */
export declare const _implementation = "http://hl7.org/fhir/_implementation";
/**
 * sourceMaterialType
 *
 * SubstanceSourceMaterial.sourceMaterialType: The type of the source material shall be specified based on a controlled vocabulary. For vaccines, this subclause refers to the class of infectious agent.
 *
 * http://hl7.org/fhir/sourceMaterialType
 */
export declare const sourceMaterialType = "http://hl7.org/fhir/sourceMaterialType";
/**
 * _substance
 *
 * (Modified) Substance.ingredient.substance
 *
 * http://hl7.org/fhir/_substance
 */
export declare const _substance = "http://hl7.org/fhir/_substance";
/**
 * _qualification
 *
 * (Modified) Practitioner.qualification
 *
 * http://hl7.org/fhir/_qualification
 */
export declare const _qualification = "http://hl7.org/fhir/_qualification";
/**
 * _countType
 *
 * (Modified) InventoryReport.countType
 *
 * http://hl7.org/fhir/_countType
 */
export declare const _countType = "http://hl7.org/fhir/_countType";
/**
 * sourceMaterialState
 *
 * SubstanceSourceMaterial.sourceMaterialState: The state of the source material when extracted.
 *
 * http://hl7.org/fhir/sourceMaterialState
 */
export declare const sourceMaterialState = "http://hl7.org/fhir/sourceMaterialState";
/**
 * _observationResultRequirement
 *
 * (Modified) ActivityDefinition.observationResultRequirement
 *
 * http://hl7.org/fhir/_observationResultRequirement
 */
export declare const _observationResultRequirement = "http://hl7.org/fhir/_observationResultRequirement";
/**
 * attestationSignature
 *
 * VerificationResult.validator.attestationSignature: Signed assertion by the validator that they have validated the information.
 *
 * http://hl7.org/fhir/attestationSignature
 */
export declare const attestationSignature = "http://hl7.org/fhir/attestationSignature";
/**
 * PackagedProductDefinitionPackagingComponentPackagingPackaging
 *
 * Allows containers (and parts of containers) within containers, still as a part of a single packaged product. See also PackagedProductDefinition.packaging.containedItem.item(PackagedProductDefinition).
 *
 * http://hl7.org/fhir/PackagedProductDefinitionPackagingComponentPackagingPackaging
 */
export declare const PackagedProductDefinitionPackagingComponentPackagingPackaging = "http://hl7.org/fhir/PackagedProductDefinitionPackagingComponentPackagingPackaging";
/**
 * _marketingAuthorizationHolder
 *
 * (Modified) Medication.marketingAuthorizationHolder
 *
 * http://hl7.org/fhir/_marketingAuthorizationHolder
 */
export declare const _marketingAuthorizationHolder = "http://hl7.org/fhir/_marketingAuthorizationHolder";
/**
 * _decisionMode
 *
 * (Modified) Contract.term.group.offer.decisionMode
 *
 * http://hl7.org/fhir/_decisionMode
 */
export declare const _decisionMode = "http://hl7.org/fhir/_decisionMode";
/**
 * repeats
 *
 * Questionnaire.item.item.repeats: An indication, if true, that a QuestionnaireResponse for this item may include multiple answers associated with a single instance of this item (for question-type items) or multiple repetitions of the item (for group-type items).
 *
 * http://hl7.org/fhir/repeats
 */
export declare const repeats = "http://hl7.org/fhir/repeats";
/**
 * typeTested
 *
 * SpecimenDefinition.typeTested: Specimen conditioned in a container as expected by the testing laboratory.
 *
 * http://hl7.org/fhir/typeTested
 */
export declare const typeTested = "http://hl7.org/fhir/typeTested";
/**
 * _rankingOrder
 *
 * (Modified) Citation.citedArtifact.contributorship.entry.rankingOrder
 *
 * http://hl7.org/fhir/_rankingOrder
 */
export declare const _rankingOrder = "http://hl7.org/fhir/_rankingOrder";
/**
 * end
 *
 * MolecularSequence.relative.edit.end: End position of the edit on the starting sequence. If the coordinate system is 0-based then end is exclusive and does not include the last position. If the coordinate system is 1-base, then end is inclusive and includes the last position.
 *
 * http://hl7.org/fhir/end
 */
export declare const end = "http://hl7.org/fhir/end";
/**
 * GenomicStudyAnalysisComponent
 *
 * GenomicStudyAnalysisComponent: The details about a specific analysis that was performed in this GenomicStudy.
 *
 * http://hl7.org/fhir/GenomicStudyAnalysisComponent
 */
export declare const GenomicStudyAnalysisComponent = "http://hl7.org/fhir/GenomicStudyAnalysisComponent";
/**
 * excluded
 *
 * ExplanationOfBenefit.benefitBalance.excluded: True if the indicated class of service is excluded from the plan, missing or False indicates the product or service is included in the coverage.
 *
 * http://hl7.org/fhir/excluded
 */
export declare const excluded = "http://hl7.org/fhir/excluded";
/**
 * BundleEntryRequestComponent
 *
 * BundleEntryComponent.BundleEntryRequestComponent: Additional information about how this entry should be processed as part of a transaction or batch.  For history, it shows how the entry was processed to create the version contained in the entry.
 *
 * http://hl7.org/fhir/BundleEntryRequestComponent
 */
export declare const BundleEntryRequestComponent = "http://hl7.org/fhir/BundleEntryRequestComponent";
/**
 * DeviceDefinitionDeviceNameComponent
 *
 * DeviceDefinitionDeviceNameComponent: The name or names of the device as given by the manufacturer.
 *
 * http://hl7.org/fhir/DeviceDefinitionDeviceNameComponent
 */
export declare const DeviceDefinitionDeviceNameComponent = "http://hl7.org/fhir/DeviceDefinitionDeviceNameComponent";
/**
 * _eventNumber
 *
 * (Modified) SubscriptionStatus.notificationEvent.eventNumber
 *
 * http://hl7.org/fhir/_eventNumber
 */
export declare const _eventNumber = "http://hl7.org/fhir/_eventNumber";
/**
 * FormularyItem
 *
 * This resource describes a product or service that is available through a program and includes the conditions and constraints of availability.  All of the information in this resource is specific to the inclusion of the item in the formulary and is not inherent to the item itself.
 *
 * http://hl7.org/fhir/FormularyItem
 */
export declare const FormularyItem = "http://hl7.org/fhir/FormularyItem";
/**
 * _marketDistribution
 *
 * (Modified) DeviceDefinition.packaging.packaging.udiDeviceIdentifier.marketDistribution
 *
 * http://hl7.org/fhir/_marketDistribution
 */
export declare const _marketDistribution = "http://hl7.org/fhir/_marketDistribution";
/**
 * _searchParam
 *
 * (Modified) CapabilityStatement.rest.searchParam
 *
 * http://hl7.org/fhir/_searchParam
 */
export declare const _searchParam = "http://hl7.org/fhir/_searchParam";
/**
 * countryOfOrigin
 *
 * SubstanceSourceMaterial.countryOfOrigin: The country where the plant material is harvested or the countries where the plasma is sourced from as laid down in accordance with the Plasma Master File. For “Plasma-derived substances” the attribute country of origin provides information about the countries used for the manufacturing of the Cryopoor plama or Crioprecipitate.
 *
 * http://hl7.org/fhir/countryOfOrigin
 */
export declare const countryOfOrigin = "http://hl7.org/fhir/countryOfOrigin";
/**
 * AuditEventAgentComponent
 *
 * AuditEventAgentComponent: An actor taking an active role in the event or activity that is logged.
 *
 * http://hl7.org/fhir/AuditEventAgentComponent
 */
export declare const AuditEventAgentComponent = "http://hl7.org/fhir/AuditEventAgentComponent";
/**
 * _regulatoryAuthority
 *
 * (Modified) MedicationKnowledge.regulatory.regulatoryAuthority
 *
 * http://hl7.org/fhir/_regulatoryAuthority
 */
export declare const _regulatoryAuthority = "http://hl7.org/fhir/_regulatoryAuthority";
/**
 * _subjectState
 *
 * (Modified) ResearchSubject.progress.subjectState
 *
 * http://hl7.org/fhir/_subjectState
 */
export declare const _subjectState = "http://hl7.org/fhir/_subjectState";
/**
 * actualComparisonGroup
 *
 * ResearchSubject.actualComparisonGroup: The name of the arm in the study the subject actually followed as part of this study.
 *
 * http://hl7.org/fhir/actualComparisonGroup
 */
export declare const actualComparisonGroup = "http://hl7.org/fhir/actualComparisonGroup";
/**
 * _focusReference
 *
 * (Modified) EvidenceReport.section.section.focusReference
 *
 * http://hl7.org/fhir/_focusReference
 */
export declare const _focusReference = "http://hl7.org/fhir/_focusReference";
/**
 * _statusReason
 *
 * (Modified) Transport.statusReason
 *
 * http://hl7.org/fhir/_statusReason
 */
export declare const _statusReason = "http://hl7.org/fhir/_statusReason";
/**
 * ingredientLabel
 *
 * NutritionIntake.ingredientLabel: Total nutrient amounts for the whole meal, product, serving, etc.
 *
 * http://hl7.org/fhir/ingredientLabel
 */
export declare const ingredientLabel = "http://hl7.org/fhir/ingredientLabel";
/**
 * _whenPrepared
 *
 * (Modified) MedicationDispense.whenPrepared
 *
 * http://hl7.org/fhir/_whenPrepared
 */
export declare const _whenPrepared = "http://hl7.org/fhir/_whenPrepared";
/**
 * costCenter
 *
 * ChargeItem.costCenter: The financial cost center permits the tracking of charge attribution.
 *
 * http://hl7.org/fhir/costCenter
 */
export declare const costCenter = "http://hl7.org/fhir/costCenter";
/**
 * outputParameters
 *
 * GuidanceResponse.outputParameters: The output parameters of the evaluation, if any. Many modules will result in the return of specific resources such as procedure or communication requests that are returned as part of the operation result. However, modules may define specific outputs that would be returned as the result of the evaluation, and these would be returned in this element.
 *
 * http://hl7.org/fhir/outputParameters
 */
export declare const outputParameters = "http://hl7.org/fhir/outputParameters";
/**
 * DevicePropertyComponent
 *
 * DevicePropertyComponent: Static or essentially fixed characteristics or features of the device (e.g., time or timing attributes, resolution, accuracy, intended use or instructions for use, and physical attributes) that are not otherwise captured in more specific attributes.
 *
 * http://hl7.org/fhir/DevicePropertyComponent
 */
export declare const DevicePropertyComponent = "http://hl7.org/fhir/DevicePropertyComponent";
/**
 * productCategory
 *
 * BiologicallyDerivedProduct.productCategory: Broad category of this product.
 *
 * http://hl7.org/fhir/productCategory
 */
export declare const productCategory = "http://hl7.org/fhir/productCategory";
/**
 * serviceType
 *
 * Schedule.serviceType: The specific service that is to be performed during this appointment.
 *
 * http://hl7.org/fhir/serviceType
 */
export declare const serviceType = "http://hl7.org/fhir/serviceType";
/**
 * _verification
 *
 * (Modified) Consent.verification
 *
 * http://hl7.org/fhir/_verification
 */
export declare const _verification = "http://hl7.org/fhir/_verification";
/**
 * reliableCache
 *
 * CapabilityStatement.messaging.reliableCache: Length if the receiver's reliable messaging cache in minutes (if a receiver) or how long the cache length on the receiver should be (if a sender).
 *
 * http://hl7.org/fhir/reliableCache
 */
export declare const reliableCache = "http://hl7.org/fhir/reliableCache";
/**
 * _Flag
 *
 * (Modified) Flag
 *
 * http://hl7.org/fhir/_Flag
 */
export declare const _Flag = "http://hl7.org/fhir/_Flag";
/**
 * numberAffected
 *
 * Evidence.statistic.numberAffected: The number of participants affected where the unit of analysis is the same as sampleSize.knownDataCount and sampleSize.numberOfParticipants.
 *
 * http://hl7.org/fhir/numberAffected
 */
export declare const numberAffected = "http://hl7.org/fhir/numberAffected";
/**
 * StructureMapGroupRuleDependentComponent
 *
 * StructureMapGroupComponent.StructureMapGroupRuleComponentRule.StructureMapGroupRuleDependentComponent: Which other rules to apply in the context of this rule.
 *
 * http://hl7.org/fhir/StructureMapGroupRuleDependentComponent
 */
export declare const StructureMapGroupRuleDependentComponent = "http://hl7.org/fhir/StructureMapGroupRuleDependentComponent";
/**
 * relationshipType
 *
 * ClinicalUseDefinition.indication.otherTherapy.relationshipType: The type of relationship between the medicinal product indication or contraindication and another therapy.
 *
 * http://hl7.org/fhir/relationshipType
 */
export declare const relationshipType = "http://hl7.org/fhir/relationshipType";
/**
 * _statement
 *
 * (Modified) Requirements.statement
 *
 * http://hl7.org/fhir/_statement
 */
export declare const _statement = "http://hl7.org/fhir/_statement";
/**
 * _Goal
 *
 * (Modified) Goal
 *
 * http://hl7.org/fhir/_Goal
 */
export declare const _Goal = "http://hl7.org/fhir/_Goal";
/**
 * issued
 *
 * TestReport.issued: When the TestScript was executed and this TestReport was generated.
 *
 * http://hl7.org/fhir/issued
 */
export declare const issued = "http://hl7.org/fhir/issued";
/**
 * _instruction
 *
 * (Modified) SpecimenDefinition.typeTested.handling.instruction
 *
 * http://hl7.org/fhir/_instruction
 */
export declare const _instruction = "http://hl7.org/fhir/_instruction";
/**
 * inclusionCriteria
 *
 * ValueSet.scope.inclusionCriteria: Criteria describing which concepts or codes should be included and why.
 *
 * http://hl7.org/fhir/inclusionCriteria
 */
export declare const inclusionCriteria = "http://hl7.org/fhir/inclusionCriteria";
/**
 * about
 *
 * CommunicationRequest.about: Other resources that pertain to this communication request and to which this communication request should be associated.
 *
 * http://hl7.org/fhir/about
 */
export declare const about = "http://hl7.org/fhir/about";
/**
 * Practitioner
 *
 * A person who is directly or indirectly involved in the provisioning of healthcare or related services.
 *
 * http://hl7.org/fhir/Practitioner
 */
export declare const Practitioner = "http://hl7.org/fhir/Practitioner";
/**
 * prognosisCodeableConcept
 *
 * ClinicalImpression.prognosisCodeableConcept: Estimate of likely outcome.
 *
 * http://hl7.org/fhir/prognosisCodeableConcept
 */
export declare const prognosisCodeableConcept = "http://hl7.org/fhir/prognosisCodeableConcept";
/**
 * AdverseEventParticipantComponent
 *
 * AdverseEventParticipantComponent: Indicates who or what participated in the adverse event and how they were involved.
 *
 * http://hl7.org/fhir/AdverseEventParticipantComponent
 */
export declare const AdverseEventParticipantComponent = "http://hl7.org/fhir/AdverseEventParticipantComponent";
/**
 * _maxValue
 *
 * (Modified) ElementDefinition.maxValue
 *
 * http://hl7.org/fhir/_maxValue
 */
export declare const _maxValue = "http://hl7.org/fhir/_maxValue";
/**
 * ItemDetail
 *
 * ClaimResponse.Item.ItemDetail: A claim detail. Either a simple (a product or service) or a 'group' of sub-details which are simple items.
 *
 * http://hl7.org/fhir/ItemDetail
 */
export declare const ItemDetail = "http://hl7.org/fhir/ItemDetail";
/**
 * _hasBodySite
 *
 * (Modified) ConditionDefinition.hasBodySite
 *
 * http://hl7.org/fhir/_hasBodySite
 */
export declare const _hasBodySite = "http://hl7.org/fhir/_hasBodySite";
/**
 * _metadata
 *
 * (Modified) TestScript.metadata
 *
 * http://hl7.org/fhir/_metadata
 */
export declare const _metadata = "http://hl7.org/fhir/_metadata";
/**
 * rejectionCriterion
 *
 * SpecimenDefinition.typeTested.rejectionCriterion: Criterion for rejection of the specimen in its container by the laboratory.
 *
 * http://hl7.org/fhir/rejectionCriterion
 */
export declare const rejectionCriterion = "http://hl7.org/fhir/rejectionCriterion";
/**
 * cors
 *
 * CapabilityStatement.rest.security.cors: Server adds CORS headers when responding to requests - this enables Javascript applications to use the server.
 *
 * http://hl7.org/fhir/cors
 */
export declare const cors = "http://hl7.org/fhir/cors";
/**
 * _option
 *
 * (Modified) PlanDefinition.actor.option
 *
 * http://hl7.org/fhir/_option
 */
export declare const _option = "http://hl7.org/fhir/_option";
/**
 * TypeRefComponent
 *
 * ElementDefinition.TypeRefComponent: The data type or resource that the value of this element is permitted to be.
 *
 * http://hl7.org/fhir/TypeRefComponent
 */
export declare const TypeRefComponent = "http://hl7.org/fhir/TypeRefComponent";
/**
 * minValue
 *
 * ElementDefinition.minValue
 *
 * http://hl7.org/fhir/minValue
 */
export declare const minValue = "http://hl7.org/fhir/minValue";
/**
 * _tuesday
 *
 * (Modified) Appointment.recurrenceTemplate.weeklyTemplate.tuesday
 *
 * http://hl7.org/fhir/_tuesday
 */
export declare const _tuesday = "http://hl7.org/fhir/_tuesday";
/**
 * _offset
 *
 * (Modified) ValueSet.expansion.offset
 *
 * http://hl7.org/fhir/_offset
 */
export declare const _offset = "http://hl7.org/fhir/_offset";
/**
 * report
 *
 * Procedure.report: This could be a histology result, pathology report, surgical report, etc.
 *
 * http://hl7.org/fhir/report
 */
export declare const report = "http://hl7.org/fhir/report";
/**
 * _fhirPathCriteria
 *
 * (Modified) SubscriptionTopic.resourceTrigger.fhirPathCriteria
 *
 * http://hl7.org/fhir/_fhirPathCriteria
 */
export declare const _fhirPathCriteria = "http://hl7.org/fhir/_fhirPathCriteria";
/**
 * editor
 *
 * ValueSet.editor: An individual or organization primarily responsible for internal coherence of the ValueSet.
 *
 * http://hl7.org/fhir/editor
 */
export declare const editor = "http://hl7.org/fhir/editor";
/**
 * _firstDose
 *
 * (Modified) AdministrableProductDefinition.routeOfAdministration.firstDose
 *
 * http://hl7.org/fhir/_firstDose
 */
export declare const _firstDose = "http://hl7.org/fhir/_firstDose";
/**
 * procedureSequence
 *
 * ExplanationOfBenefit.item.procedureSequence: Procedures applicable for this service or product.
 *
 * http://hl7.org/fhir/procedureSequence
 */
export declare const procedureSequence = "http://hl7.org/fhir/procedureSequence";
/**
 * MedicinalProductDefinitionContactComponent
 *
 * MedicinalProductDefinitionContactComponent: A product specific contact, person (in a role), or an organization.
 *
 * http://hl7.org/fhir/MedicinalProductDefinitionContactComponent
 */
export declare const MedicinalProductDefinitionContactComponent = "http://hl7.org/fhir/MedicinalProductDefinitionContactComponent";
/**
 * _Communication
 *
 * (Modified) Communication
 *
 * http://hl7.org/fhir/_Communication
 */
export declare const _Communication = "http://hl7.org/fhir/_Communication";
/**
 * _controller
 *
 * (Modified) Consent.controller
 *
 * http://hl7.org/fhir/_controller
 */
export declare const _controller = "http://hl7.org/fhir/_controller";
/**
 * TestScriptSetupActionAssertRequirementComponent
 *
 * TestScriptTestComponent.TestActionAssert.TestScriptSetupActionAssertRequirementComponent: Links or references providing traceability to the testing requirements for this assert.
 *
 * http://hl7.org/fhir/TestScriptSetupActionAssertRequirementComponent
 */
export declare const TestScriptSetupActionAssertRequirementComponent = "http://hl7.org/fhir/TestScriptSetupActionAssertRequirementComponent";
/**
 * _allocation
 *
 * (Modified) PaymentReconciliation.allocation
 *
 * http://hl7.org/fhir/_allocation
 */
export declare const _allocation = "http://hl7.org/fhir/_allocation";
/**
 * otherTherapy
 *
 * ClinicalUseDefinition.indication.otherTherapy: Information about the use of the medicinal product in relation to other therapies described as part of the indication.
 *
 * http://hl7.org/fhir/otherTherapy
 */
export declare const otherTherapy = "http://hl7.org/fhir/otherTherapy";
/**
 * _requestedLocation
 *
 * (Modified) Transport.requestedLocation
 *
 * http://hl7.org/fhir/_requestedLocation
 */
export declare const _requestedLocation = "http://hl7.org/fhir/_requestedLocation";
/**
 * _referencedFrom
 *
 * (Modified) OperationDefinition.parameter.part.referencedFrom
 *
 * http://hl7.org/fhir/_referencedFrom
 */
export declare const _referencedFrom = "http://hl7.org/fhir/_referencedFrom";
/**
 * eventsSinceSubscriptionStart
 *
 * SubscriptionStatus.eventsSinceSubscriptionStart: The total number of actual events which have been generated since the Subscription was created (inclusive of this notification) - regardless of how many have been successfully communicated.  This number is NOT incremented for handshake and heartbeat notifications.
 *
 * http://hl7.org/fhir/eventsSinceSubscriptionStart
 */
export declare const eventsSinceSubscriptionStart = "http://hl7.org/fhir/eventsSinceSubscriptionStart";
/**
 * _question
 *
 * (Modified) Questionnaire.item.item.enableWhen.question
 *
 * http://hl7.org/fhir/_question
 */
export declare const _question = "http://hl7.org/fhir/_question";
/**
 * _drugCharacteristic
 *
 * (Modified) MedicationKnowledge.definitional.drugCharacteristic
 *
 * http://hl7.org/fhir/_drugCharacteristic
 */
export declare const _drugCharacteristic = "http://hl7.org/fhir/_drugCharacteristic";
/**
 * _total
 *
 * (Modified) ValueSet.expansion.total
 *
 * http://hl7.org/fhir/_total
 */
export declare const _total = "http://hl7.org/fhir/_total";
/**
 * AuditEvent
 *
 * A record of an event relevant for purposes such as operations, privacy, security, maintenance, and performance analysis.
 *
 * http://hl7.org/fhir/AuditEvent
 */
export declare const AuditEvent = "http://hl7.org/fhir/AuditEvent";
/**
 * _environmentType
 *
 * (Modified) Endpoint.environmentType
 *
 * http://hl7.org/fhir/_environmentType
 */
export declare const _environmentType = "http://hl7.org/fhir/_environmentType";
/**
 * AssetContext
 *
 * Contract.TermTerm.ContractAsset.AssetContext: Circumstance of the asset.
 *
 * http://hl7.org/fhir/AssetContext
 */
export declare const AssetContext = "http://hl7.org/fhir/AssetContext";
/**
 * _rangeCategory
 *
 * (Modified) ObservationDefinition.component.qualifiedValue.rangeCategory
 *
 * http://hl7.org/fhir/_rangeCategory
 */
export declare const _rangeCategory = "http://hl7.org/fhir/_rangeCategory";
/**
 * Location
 *
 * Details and position information for a place where services are provided and resources and participants may be stored, found, contained, or accommodated.
 *
 * http://hl7.org/fhir/Location
 */
export declare const Location = "http://hl7.org/fhir/Location";
/**
 * rank
 *
 * ContactPoint.rank: Specifies a preferred order in which to use a set of contacts. ContactPoints with lower rank values are more preferred than those with higher rank values.
 *
 * http://hl7.org/fhir/rank
 */
export declare const rank = "http://hl7.org/fhir/rank";
/**
 * PlanDefinitionActionComponentActionAction
 *
 * Sub actions that are contained within the action. The behavior of this action determines the functionality of the sub-actions. For example, a selection behavior of at-most-one indicates that of the sub-actions, at most one may be chosen as part of realizing the action definition.
 *
 * http://hl7.org/fhir/PlanDefinitionActionComponentActionAction
 */
export declare const PlanDefinitionActionComponentActionAction = "http://hl7.org/fhir/PlanDefinitionActionComponentActionAction";
/**
 * _occurrenceCount
 *
 * (Modified) Appointment.recurrenceTemplate.occurrenceCount
 *
 * http://hl7.org/fhir/_occurrenceCount
 */
export declare const _occurrenceCount = "http://hl7.org/fhir/_occurrenceCount";
/**
 * entryType
 *
 * Device.udiCarrier.entryType: A coded entry to indicate how the data was entered.
 *
 * http://hl7.org/fhir/entryType
 */
export declare const entryType = "http://hl7.org/fhir/entryType";
/**
 * _trigger
 *
 * (Modified) PlanDefinition.action.action.trigger
 *
 * http://hl7.org/fhir/_trigger
 */
export declare const _trigger = "http://hl7.org/fhir/_trigger";
/**
 * _contextInvariant
 *
 * (Modified) StructureDefinition.contextInvariant
 *
 * http://hl7.org/fhir/_contextInvariant
 */
export declare const _contextInvariant = "http://hl7.org/fhir/_contextInvariant";
/**
 * id
 *
 * Element.id: Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.
 *
 * http://hl7.org/fhir/id
 */
export declare const id = "http://hl7.org/fhir/id";
/**
 * _productionIdentifierInUDI
 *
 * (Modified) DeviceDefinition.productionIdentifierInUDI
 *
 * http://hl7.org/fhir/_productionIdentifierInUDI
 */
export declare const _productionIdentifierInUDI = "http://hl7.org/fhir/_productionIdentifierInUDI";
/**
 * _variable
 *
 * (Modified) TestScript.variable
 *
 * http://hl7.org/fhir/_variable
 */
export declare const _variable = "http://hl7.org/fhir/_variable";
/**
 * occurrence
 *
 * Immunization.occurrence
 *
 * http://hl7.org/fhir/occurrence
 */
export declare const occurrence = "http://hl7.org/fhir/occurrence";
/**
 * dayOfMonth
 *
 * Appointment.recurrenceTemplate.monthlyTemplate.dayOfMonth: Indicates that appointments in the series of recurring appointments should occur on a specific day of the month.
 *
 * http://hl7.org/fhir/dayOfMonth
 */
export declare const dayOfMonth = "http://hl7.org/fhir/dayOfMonth";
/**
 * _maxDosePerPeriod
 *
 * (Modified) Dosage.maxDosePerPeriod
 *
 * http://hl7.org/fhir/_maxDosePerPeriod
 */
export declare const _maxDosePerPeriod = "http://hl7.org/fhir/_maxDosePerPeriod";
/**
 * _MeasureReport
 *
 * (Modified) MeasureReport
 *
 * http://hl7.org/fhir/_MeasureReport
 */
export declare const _MeasureReport = "http://hl7.org/fhir/_MeasureReport";
/**
 * MedicationKnowledgeCostComponent
 *
 * MedicationKnowledgeCostComponent: The price of the medication.
 *
 * http://hl7.org/fhir/MedicationKnowledgeCostComponent
 */
export declare const MedicationKnowledgeCostComponent = "http://hl7.org/fhir/MedicationKnowledgeCostComponent";
/**
 * uuid
 *
 * A UUID, represented as a URI
 *
 * http://hl7.org/fhir/uuid
 */
export declare const uuid = "http://hl7.org/fhir/uuid";
/**
 * _range
 *
 * (Modified) ObservationDefinition.component.qualifiedValue.range
 *
 * http://hl7.org/fhir/_range
 */
export declare const _range = "http://hl7.org/fhir/_range";
/**
 * related
 *
 * ExplanationOfBenefit.related: Other claims which are related to this claim such as prior submissions or claims for related services or for the same event.
 *
 * http://hl7.org/fhir/related
 */
export declare const related = "http://hl7.org/fhir/related";
/**
 * endpoint
 *
 * ImagingStudy.endpoint: The network service providing access (e.g., query, view, or retrieval) for the study. See implementation notes for information about using DICOM endpoints. A study-level endpoint applies to each series in the study, unless overridden by a series-level endpoint with the same Endpoint.connectionType.
 *
 * http://hl7.org/fhir/endpoint
 */
export declare const endpoint = "http://hl7.org/fhir/endpoint";
/**
 * ValueSetExpansionParameterComponent
 *
 * ValueSetExpansionComponent.ValueSetExpansionParameterComponent: A parameter that controlled the expansion process. These parameters may be used by users of expanded value sets to check whether the expansion is suitable for a particular purpose, or to pick the correct expansion.
 *
 * http://hl7.org/fhir/ValueSetExpansionParameterComponent
 */
export declare const ValueSetExpansionParameterComponent = "http://hl7.org/fhir/ValueSetExpansionParameterComponent";
/**
 * _logMessage
 *
 * (Modified) StructureMap.group.rule.rule.source.logMessage
 *
 * http://hl7.org/fhir/_logMessage
 */
export declare const _logMessage = "http://hl7.org/fhir/_logMessage";
/**
 * SubscriptionTopicResourceTriggerQueryCriteriaComponent
 *
 * SubscriptionTopicResourceTriggerComponent.SubscriptionTopicResourceTriggerQueryCriteriaComponent: The FHIR query based rules that the server should use to determine when to trigger a notification for this subscription topic.
 *
 * http://hl7.org/fhir/SubscriptionTopicResourceTriggerQueryCriteriaComponent
 */
export declare const SubscriptionTopicResourceTriggerQueryCriteriaComponent = "http://hl7.org/fhir/SubscriptionTopicResourceTriggerQueryCriteriaComponent";
/**
 * _supportingImmunization
 *
 * (Modified) ImmunizationRecommendation.recommendation.supportingImmunization
 *
 * http://hl7.org/fhir/_supportingImmunization
 */
export declare const _supportingImmunization = "http://hl7.org/fhir/_supportingImmunization";
/**
 * StructureMapConstComponent
 *
 * StructureMapConstComponent: Definition of a constant value used in the map rules.
 *
 * http://hl7.org/fhir/StructureMapConstComponent
 */
export declare const StructureMapConstComponent = "http://hl7.org/fhir/StructureMapConstComponent";
/**
 * NutritionIntakeConsumedItemComponent
 *
 * NutritionIntakeConsumedItemComponent: What food or fluid product or item was consumed.
 *
 * http://hl7.org/fhir/NutritionIntakeConsumedItemComponent
 */
export declare const NutritionIntakeConsumedItemComponent = "http://hl7.org/fhir/NutritionIntakeConsumedItemComponent";
/**
 * PlanDefinitionGoalComponent
 *
 * PlanDefinitionGoalComponent: A goal describes an expected outcome that activities within the plan are intended to achieve. For example, weight loss, restoring an activity of daily living, obtaining herd immunity via immunization, meeting a process improvement objective, meeting the acceptance criteria for a test as specified by a quality specification, etc.
 *
 * http://hl7.org/fhir/PlanDefinitionGoalComponent
 */
export declare const PlanDefinitionGoalComponent = "http://hl7.org/fhir/PlanDefinitionGoalComponent";
/**
 * precondition
 *
 * ConditionDefinition.precondition: An observation that suggests that this condition applies.
 *
 * http://hl7.org/fhir/precondition
 */
export declare const precondition = "http://hl7.org/fhir/precondition";
/**
 * _CoverageEligibilityResponse
 *
 * (Modified) CoverageEligibilityResponse
 *
 * http://hl7.org/fhir/_CoverageEligibilityResponse
 */
export declare const _CoverageEligibilityResponse = "http://hl7.org/fhir/_CoverageEligibilityResponse";
/**
 * _duration
 *
 * (Modified) Attachment.duration
 *
 * http://hl7.org/fhir/_duration
 */
export declare const _duration = "http://hl7.org/fhir/_duration";
/**
 * _routeOfAdministration
 *
 * (Modified) NutritionOrder.enteralFormula.routeOfAdministration
 *
 * http://hl7.org/fhir/_routeOfAdministration
 */
export declare const _routeOfAdministration = "http://hl7.org/fhir/_routeOfAdministration";
/**
 * _legallyBinding
 *
 * (Modified) Contract.legallyBinding
 *
 * http://hl7.org/fhir/_legallyBinding
 */
export declare const _legallyBinding = "http://hl7.org/fhir/_legallyBinding";
/**
 * rendering
 *
 * ImplementationGuide.manifest.rendering: A pointer to official web page, PDF or other rendering of the implementation guide.
 *
 * http://hl7.org/fhir/rendering
 */
export declare const rendering = "http://hl7.org/fhir/rendering";
/**
 * _hierarchical
 *
 * (Modified) TerminologyCapabilities.expansion.hierarchical
 *
 * http://hl7.org/fhir/_hierarchical
 */
export declare const _hierarchical = "http://hl7.org/fhir/_hierarchical";
/**
 * _nameType
 *
 * (Modified) InventoryItem.name.nameType
 *
 * http://hl7.org/fhir/_nameType
 */
export declare const _nameType = "http://hl7.org/fhir/_nameType";
/**
 * _businessStatus
 *
 * (Modified) Task.businessStatus
 *
 * http://hl7.org/fhir/_businessStatus
 */
export declare const _businessStatus = "http://hl7.org/fhir/_businessStatus";
/**
 * _maxLength
 *
 * (Modified) Questionnaire.item.item.maxLength
 *
 * http://hl7.org/fhir/_maxLength
 */
export declare const _maxLength = "http://hl7.org/fhir/_maxLength";
/**
 * SubstancePolymerRepeatComponent
 *
 * SubstancePolymerRepeatComponent: Specifies and quantifies the repeated units and their configuration.
 *
 * http://hl7.org/fhir/SubstancePolymerRepeatComponent
 */
export declare const SubstancePolymerRepeatComponent = "http://hl7.org/fhir/SubstancePolymerRepeatComponent";
/**
 * responsibleParty
 *
 * MedicationDispense.substitution.responsibleParty: The person or organization that has primary responsibility for the substitution.
 *
 * http://hl7.org/fhir/responsibleParty
 */
export declare const responsibleParty = "http://hl7.org/fhir/responsibleParty";
/**
 * BundleEntryComponent
 *
 * BundleEntryComponent: An entry in a bundle resource - will either contain a resource or information about a resource (transactions and history only).
 *
 * http://hl7.org/fhir/BundleEntryComponent
 */
export declare const BundleEntryComponent = "http://hl7.org/fhir/BundleEntryComponent";
/**
 * _input
 *
 * (Modified) RequestOrchestration.action.input
 *
 * http://hl7.org/fhir/_input
 */
export declare const _input = "http://hl7.org/fhir/_input";
/**
 * _languageCode
 *
 * (Modified) DeviceDefinition.languageCode
 *
 * http://hl7.org/fhir/_languageCode
 */
export declare const _languageCode = "http://hl7.org/fhir/_languageCode";
/**
 * _patient
 *
 * (Modified) SupplyDelivery.patient
 *
 * http://hl7.org/fhir/_patient
 */
export declare const _patient = "http://hl7.org/fhir/_patient";
/**
 * direction
 *
 * TestScript.test.action.assert.direction: The direction to use for the assertion.
 *
 * http://hl7.org/fhir/direction
 */
export declare const direction = "http://hl7.org/fhir/direction";
/**
 * _publicationDateSeason
 *
 * (Modified) Citation.citedArtifact.publicationForm.publicationDateSeason
 *
 * http://hl7.org/fhir/_publicationDateSeason
 */
export declare const _publicationDateSeason = "http://hl7.org/fhir/_publicationDateSeason";
/**
 * maritalStatus
 *
 * Person.maritalStatus: This field contains a person's most recent marital (civil) status.
 *
 * http://hl7.org/fhir/maritalStatus
 */
export declare const maritalStatus = "http://hl7.org/fhir/maritalStatus";
/**
 * AllergyIntoleranceReactionComponent
 *
 * AllergyIntoleranceReactionComponent: Details about each adverse reaction event linked to exposure to the identified substance.
 *
 * http://hl7.org/fhir/AllergyIntoleranceReactionComponent
 */
export declare const AllergyIntoleranceReactionComponent = "http://hl7.org/fhir/AllergyIntoleranceReactionComponent";
/**
 * _observer
 *
 * (Modified) AuditEvent.source.observer
 *
 * http://hl7.org/fhir/_observer
 */
export declare const _observer = "http://hl7.org/fhir/_observer";
/**
 * SubscriptionParameterComponent
 *
 * SubscriptionParameterComponent: Channel-dependent information to send as part of the notification (e.g., HTTP Headers).
 *
 * http://hl7.org/fhir/SubscriptionParameterComponent
 */
export declare const SubscriptionParameterComponent = "http://hl7.org/fhir/SubscriptionParameterComponent";
/**
 * doseAdministrationAid
 *
 * MedicationRequest.dispenseRequest.doseAdministrationAid: Provides information about the type of adherence packaging to be supplied for the medication dispense.
 *
 * http://hl7.org/fhir/doseAdministrationAid
 */
export declare const doseAdministrationAid = "http://hl7.org/fhir/doseAdministrationAid";
/**
 * DeviceDefinitionClassificationComponent
 *
 * DeviceDefinitionClassificationComponent: What kind of device or device system this is.
 *
 * http://hl7.org/fhir/DeviceDefinitionClassificationComponent
 */
export declare const DeviceDefinitionClassificationComponent = "http://hl7.org/fhir/DeviceDefinitionClassificationComponent";
/**
 * _measure
 *
 * (Modified) PlanDefinition.goal.target.measure
 *
 * http://hl7.org/fhir/_measure
 */
export declare const _measure = "http://hl7.org/fhir/_measure";
/**
 * _maxDosePerAdministration
 *
 * (Modified) Dosage.maxDosePerAdministration
 *
 * http://hl7.org/fhir/_maxDosePerAdministration
 */
export declare const _maxDosePerAdministration = "http://hl7.org/fhir/_maxDosePerAdministration";
/**
 * CompositionAttesterComponent
 *
 * CompositionAttesterComponent: A participant who has attested to the accuracy of the composition/document.
 *
 * http://hl7.org/fhir/CompositionAttesterComponent
 */
export declare const CompositionAttesterComponent = "http://hl7.org/fhir/CompositionAttesterComponent";
/**
 * _valueFilter
 *
 * (Modified) DataRequirement.valueFilter
 *
 * http://hl7.org/fhir/_valueFilter
 */
export declare const _valueFilter = "http://hl7.org/fhir/_valueFilter";
/**
 * studyDesign
 *
 * ResearchStudy.studyDesign: Codes categorizing the type of study such as investigational vs. observational, type of blinding, type of randomization, safety vs. efficacy, etc.
 *
 * http://hl7.org/fhir/studyDesign
 */
export declare const studyDesign = "http://hl7.org/fhir/studyDesign";
/**
 * _relation
 *
 * (Modified) DeviceDefinition.link.relation
 *
 * http://hl7.org/fhir/_relation
 */
export declare const _relation = "http://hl7.org/fhir/_relation";
/**
 * _priority
 *
 * (Modified) ExplanationOfBenefit.priority
 *
 * http://hl7.org/fhir/_priority
 */
export declare const _priority = "http://hl7.org/fhir/_priority";
/**
 * MessageDefinition
 *
 * Defines the characteristics of a message that can be shared between systems, including the type of event that initiates the message, the content to be transmitted and what response(s), if any, are permitted.
 *
 * http://hl7.org/fhir/MessageDefinition
 */
export declare const MessageDefinition = "http://hl7.org/fhir/MessageDefinition";
/**
 * _description
 *
 * (Modified) RequestOrchestration.action.action.description
 *
 * http://hl7.org/fhir/_description
 */
export declare const _description = "http://hl7.org/fhir/_description";
/**
 * TestPlanTestCaseTestDataComponent
 *
 * TestPlanTestCaseComponent.TestPlanTestCaseTestDataComponent: The test data used in the test case.
 *
 * http://hl7.org/fhir/TestPlanTestCaseTestDataComponent
 */
export declare const TestPlanTestCaseTestDataComponent = "http://hl7.org/fhir/TestPlanTestCaseTestDataComponent";
/**
 * HealthcareServiceEligibilityComponent
 *
 * HealthcareServiceEligibilityComponent: Does this service have specific eligibility requirements that need to be met in order to use the service?
 *
 * http://hl7.org/fhir/HealthcareServiceEligibilityComponent
 */
export declare const HealthcareServiceEligibilityComponent = "http://hl7.org/fhir/HealthcareServiceEligibilityComponent";
/**
 * category
 *
 * Flag.category: Allows a flag to be divided into different categories like clinical, administrative etc. Intended to be used as a means of filtering which flags are displayed to particular user or in a given context.
 *
 * http://hl7.org/fhir/category
 */
export declare const category = "http://hl7.org/fhir/category";
/**
 * Details
 *
 * CoverageEligibilityRequest.Details: Service categories or billable services for which benefit details and/or an authorization prior to service delivery may be required by the payor.
 *
 * http://hl7.org/fhir/Details
 */
export declare const Details = "http://hl7.org/fhir/Details";
/**
 * verificationDate
 *
 * Consent.verification.verificationDate: Date(s) verification was collected.
 *
 * http://hl7.org/fhir/verificationDate
 */
export declare const verificationDate = "http://hl7.org/fhir/verificationDate";
/**
 * ExampleScenarioActorComponent
 *
 * ExampleScenarioActorComponent: A system or person who shares or receives an instance within the scenario.
 *
 * http://hl7.org/fhir/ExampleScenarioActorComponent
 */
export declare const ExampleScenarioActorComponent = "http://hl7.org/fhir/ExampleScenarioActorComponent";
/**
 * _specimenQuantity
 *
 * (Modified) Specimen.container.specimenQuantity
 *
 * http://hl7.org/fhir/_specimenQuantity
 */
export declare const _specimenQuantity = "http://hl7.org/fhir/_specimenQuantity";
/**
 * DeviceDefinitionPackagingComponent
 *
 * DeviceDefinitionPackagingComponent: Information about the packaging of the device, i.e. how the device is packaged.
 *
 * http://hl7.org/fhir/DeviceDefinitionPackagingComponent
 */
export declare const DeviceDefinitionPackagingComponent = "http://hl7.org/fhir/DeviceDefinitionPackagingComponent";
/**
 * autocreate
 *
 * TestScript.fixture.autocreate: Whether or not to implicitly create the fixture during setup. If true, the fixture is automatically created on each server being tested during setup, therefore no create operation is required for this fixture in the TestScript.setup section.
 *
 * http://hl7.org/fhir/autocreate
 */
export declare const autocreate = "http://hl7.org/fhir/autocreate";
/**
 * _structuralRepresentation
 *
 * (Modified) SubstancePolymer.repeat.repeatUnit.structuralRepresentation
 *
 * http://hl7.org/fhir/_structuralRepresentation
 */
export declare const _structuralRepresentation = "http://hl7.org/fhir/_structuralRepresentation";
/**
 * agent
 *
 * AuditEvent.entity.agent: The entity is attributed to an agent to express the agent's responsibility for that entity in the activity. This is most used to indicate when persistence media (the entity) are used by an agent. For example when importing data from a device, the device would be described in an entity, and the user importing data from that media would be indicated as the entity.agent.
 *
 * http://hl7.org/fhir/agent
 */
export declare const agent = "http://hl7.org/fhir/agent";
/**
 * _request
 *
 * (Modified) ExplanationOfBenefit.item.request
 *
 * http://hl7.org/fhir/_request
 */
export declare const _request = "http://hl7.org/fhir/_request";
/**
 * _deliverTo
 *
 * (Modified) SupplyRequest.deliverTo
 *
 * http://hl7.org/fhir/_deliverTo
 */
export declare const _deliverTo = "http://hl7.org/fhir/_deliverTo";
/**
 * _textConcentration
 *
 * (Modified) Ingredient.substance.strength.textConcentration
 *
 * http://hl7.org/fhir/_textConcentration
 */
export declare const _textConcentration = "http://hl7.org/fhir/_textConcentration";
/**
 * benefitPeriod
 *
 * ExplanationOfBenefit.benefitPeriod: The term of the benefits documented in this response.
 *
 * http://hl7.org/fhir/benefitPeriod
 */
export declare const benefitPeriod = "http://hl7.org/fhir/benefitPeriod";
/**
 * SpecimenDefinitionTypeTestedContainerComponent
 *
 * SpecimenDefinitionTypeTestedComponent.SpecimenDefinitionTypeTestedContainerComponent: The specimen's container.
 *
 * http://hl7.org/fhir/SpecimenDefinitionTypeTestedContainerComponent
 */
export declare const SpecimenDefinitionTypeTestedContainerComponent = "http://hl7.org/fhir/SpecimenDefinitionTypeTestedContainerComponent";
/**
 * ServiceRequestPatientInstructionComponent
 *
 * ServiceRequestPatientInstructionComponent: Instructions in terms that are understood by the patient or consumer.
 *
 * http://hl7.org/fhir/ServiceRequestPatientInstructionComponent
 */
export declare const ServiceRequestPatientInstructionComponent = "http://hl7.org/fhir/ServiceRequestPatientInstructionComponent";
/**
 * _adjustment
 *
 * (Modified) ExplanationOfBenefit.payment.adjustment
 *
 * http://hl7.org/fhir/_adjustment
 */
export declare const _adjustment = "http://hl7.org/fhir/_adjustment";
/**
 * _guidance
 *
 * (Modified) Measure.guidance
 *
 * http://hl7.org/fhir/_guidance
 */
export declare const _guidance = "http://hl7.org/fhir/_guidance";
/**
 * productReference
 *
 * InventoryItem.productReference: Link to a product resource used in clinical workflows.
 *
 * http://hl7.org/fhir/productReference
 */
export declare const productReference = "http://hl7.org/fhir/productReference";
/**
 * _for
 *
 * (Modified) Transport.for
 *
 * http://hl7.org/fhir/_for
 */
export declare const _for = "http://hl7.org/fhir/_for";
/**
 * _intended
 *
 * (Modified) Evidence.variableDefinition.intended
 *
 * http://hl7.org/fhir/_intended
 */
export declare const _intended = "http://hl7.org/fhir/_intended";
/**
 * _additionalUse
 *
 * (Modified) ValueSet.expansion.contains.contains.designation.additionalUse
 *
 * http://hl7.org/fhir/_additionalUse
 */
export declare const _additionalUse = "http://hl7.org/fhir/_additionalUse";
/**
 * MetadataResource
 *
 * Common Interface declaration for conformance and knowledge artifact resources.
 *
 * http://hl7.org/fhir/MetadataResource
 */
export declare const MetadataResource = "http://hl7.org/fhir/MetadataResource";
/**
 * _startingSequence
 *
 * (Modified) MolecularSequence.relative.startingSequence
 *
 * http://hl7.org/fhir/_startingSequence
 */
export declare const _startingSequence = "http://hl7.org/fhir/_startingSequence";
/**
 * MedicationStatement
 *
 * A record of a medication that is being consumed by a patient.   A MedicationStatement may indicate that the patient may be taking the medication now or has taken the medication in the past or will be taking the medication in the future.  The source of this information can be the patient, significant other (such as a family member or spouse), or a clinician.  A common scenario where this information is captured is during the history taking process during a patient visit or stay.   The medication information may come from sources such as the patient's memory, from a prescription bottle,  or from a list of medications the patient, clinician or other party maintains.
 *
 * The primary difference between a medicationstatement and a medicationadministration is that the medication administration has complete administration information and is based on actual administration information from the person who administered the medication.  A medicationstatement is often, if not always, less specific.  There is no required date/time when the medication was administered, in fact we only know that a source has reported the patient is taking this medication, where details such as time, quantity, or rate or even medication product may be incomplete or missing or less precise.  As stated earlier, the Medication Statement information may come from the patient's memory, from a prescription bottle or from a list of medications the patient, clinician or other party maintains.  Medication administration is more formal and is not missing detailed information.
 *
 * http://hl7.org/fhir/MedicationStatement
 */
export declare const MedicationStatement = "http://hl7.org/fhir/MedicationStatement";
/**
 * medium
 *
 * CommunicationRequest.medium: A channel that was used for this communication (e.g. email, fax).
 *
 * http://hl7.org/fhir/medium
 */
export declare const medium = "http://hl7.org/fhir/medium";
/**
 * _baseUnit
 *
 * (Modified) InventoryItem.baseUnit
 *
 * http://hl7.org/fhir/_baseUnit
 */
export declare const _baseUnit = "http://hl7.org/fhir/_baseUnit";
/**
 * _doseStatusReason
 *
 * (Modified) ImmunizationEvaluation.doseStatusReason
 *
 * http://hl7.org/fhir/_doseStatusReason
 */
export declare const _doseStatusReason = "http://hl7.org/fhir/_doseStatusReason";
/**
 * unitOfPresentation
 *
 * ManufacturedItemDefinition.unitOfPresentation: The “real-world” units in which the quantity of the manufactured item is described.
 *
 * http://hl7.org/fhir/unitOfPresentation
 */
export declare const unitOfPresentation = "http://hl7.org/fhir/unitOfPresentation";
/**
 * CareTeam
 *
 * ExplanationOfBenefit.CareTeam: The members of the team who provided the products and services.
 *
 * http://hl7.org/fhir/CareTeam
 */
export declare const CareTeam = "http://hl7.org/fhir/CareTeam";
/**
 * sourceSignature
 *
 * VerificationResult.attestation.sourceSignature: Signed assertion by the attestation source that they have attested to the information.
 *
 * http://hl7.org/fhir/sourceSignature
 */
export declare const sourceSignature = "http://hl7.org/fhir/sourceSignature";
/**
 * availableStartTime
 *
 * Availability.availableTime.availableStartTime: Opening time of day (ignored if allDay = true).
 *
 * http://hl7.org/fhir/availableStartTime
 */
export declare const availableStartTime = "http://hl7.org/fhir/availableStartTime";
/**
 * _effectiveDate
 *
 * (Modified) MedicinalProductDefinition.operation.effectiveDate
 *
 * http://hl7.org/fhir/_effectiveDate
 */
export declare const _effectiveDate = "http://hl7.org/fhir/_effectiveDate";
/**
 * _relevantHistory
 *
 * (Modified) Transport.relevantHistory
 *
 * http://hl7.org/fhir/_relevantHistory
 */
export declare const _relevantHistory = "http://hl7.org/fhir/_relevantHistory";
/**
 * ParametersParameterComponent
 *
 * ParametersParameterComponent: A parameter passed to or received from the operation.
 *
 * http://hl7.org/fhir/ParametersParameterComponent
 */
export declare const ParametersParameterComponent = "http://hl7.org/fhir/ParametersParameterComponent";
/**
 * MessageDefinitionFocusComponent
 *
 * MessageDefinitionFocusComponent: Identifies the resource (or resources) that are being addressed by the event.  For example, the Encounter for an admit message or two Account records for a merge.
 *
 * http://hl7.org/fhir/MessageDefinitionFocusComponent
 */
export declare const MessageDefinitionFocusComponent = "http://hl7.org/fhir/MessageDefinitionFocusComponent";
/**
 * EnrollmentResponse
 *
 * This resource provides enrollment and plan details from the processing of an EnrollmentRequest resource.
 *
 * http://hl7.org/fhir/EnrollmentResponse
 */
export declare const EnrollmentResponse = "http://hl7.org/fhir/EnrollmentResponse";
/**
 * ListEntryComponent
 *
 * ListEntryComponent: Entries in this list.
 *
 * http://hl7.org/fhir/ListEntryComponent
 */
export declare const ListEntryComponent = "http://hl7.org/fhir/ListEntryComponent";
/**
 * _subset
 *
 * (Modified) ImagingSelection.instance.subset
 *
 * http://hl7.org/fhir/_subset
 */
export declare const _subset = "http://hl7.org/fhir/_subset";
/**
 * dimensions
 *
 * SampledData.dimensions: The number of sample points at each time point. If this value is greater than one, then the dimensions will be interlaced - all the sample points for a point in time will be recorded at once.
 *
 * http://hl7.org/fhir/dimensions
 */
export declare const dimensions = "http://hl7.org/fhir/dimensions";
/**
 * _function
 *
 * (Modified) ManufacturedItemDefinition.component.component.function
 *
 * http://hl7.org/fhir/_function
 */
export declare const _function = "http://hl7.org/fhir/_function";
/**
 * recommendation
 *
 * ImmunizationRecommendation.recommendation: Vaccine administration recommendations.
 *
 * http://hl7.org/fhir/recommendation
 */
export declare const recommendation = "http://hl7.org/fhir/recommendation";
/**
 * _prescription
 *
 * (Modified) ExplanationOfBenefit.prescription
 *
 * http://hl7.org/fhir/_prescription
 */
export declare const _prescription = "http://hl7.org/fhir/_prescription";
/**
 * prognosisReference
 *
 * ClinicalImpression.prognosisReference: RiskAssessment expressing likely outcome.
 *
 * http://hl7.org/fhir/prognosisReference
 */
export declare const prognosisReference = "http://hl7.org/fhir/prognosisReference";
/**
 * _hint
 *
 * (Modified) TestScript.variable.hint
 *
 * http://hl7.org/fhir/_hint
 */
export declare const _hint = "http://hl7.org/fhir/_hint";
/**
 * _ownedBy
 *
 * (Modified) InsurancePlan.ownedBy
 *
 * http://hl7.org/fhir/_ownedBy
 */
export declare const _ownedBy = "http://hl7.org/fhir/_ownedBy";
/**
 * measurementFrequency
 *
 * DeviceMetric.measurementFrequency: The frequency at which the metric is taken or recorded. Devices measure metrics at a wide range of frequencies; for example, an ECG might sample measurements in the millisecond range, while an NIBP might trigger only once an hour. Less often, the measurementFrequency may be based on a unit other than time, such as distance (e.g. for a measuring wheel). The update period may be different than the measurement frequency, if the device does not update the published observed value with the same frequency as it was measured.
 *
 * http://hl7.org/fhir/measurementFrequency
 */
export declare const measurementFrequency = "http://hl7.org/fhir/measurementFrequency";
/**
 * _traceNumber
 *
 * (Modified) ClaimResponse.addItem.detail.traceNumber
 *
 * http://hl7.org/fhir/_traceNumber
 */
export declare const _traceNumber = "http://hl7.org/fhir/_traceNumber";
/**
 * _excludingDate
 *
 * (Modified) Appointment.recurrenceTemplate.excludingDate
 *
 * http://hl7.org/fhir/_excludingDate
 */
export declare const _excludingDate = "http://hl7.org/fhir/_excludingDate";
/**
 * _required
 *
 * (Modified) TestScript.metadata.capability.required
 *
 * http://hl7.org/fhir/_required
 */
export declare const _required = "http://hl7.org/fhir/_required";
/**
 * correctiveAction
 *
 * DeviceDefinition.correctiveAction: Tracking of latest field safety corrective action.
 *
 * http://hl7.org/fhir/correctiveAction
 */
export declare const correctiveAction = "http://hl7.org/fhir/correctiveAction";
/**
 * schedule
 *
 * MedicationKnowledge.regulatory.schedule: Specifies the schedule of a medication in jurisdiction.
 *
 * http://hl7.org/fhir/schedule
 */
export declare const schedule = "http://hl7.org/fhir/schedule";
/**
 * _referral
 *
 * (Modified) ExplanationOfBenefit.referral
 *
 * http://hl7.org/fhir/_referral
 */
export declare const _referral = "http://hl7.org/fhir/_referral";
/**
 * alternate
 *
 * DeviceDefinition.material.alternate: Indicates an alternative material of the device.
 *
 * http://hl7.org/fhir/alternate
 */
export declare const alternate = "http://hl7.org/fhir/alternate";
/**
 * intendedExposure
 *
 * ResearchStudy.comparisonGroup.intendedExposure: Interventions or exposures in this comparisonGroup or cohort.
 *
 * http://hl7.org/fhir/intendedExposure
 */
export declare const intendedExposure = "http://hl7.org/fhir/intendedExposure";
/**
 * threePrime
 *
 * SubstanceNucleicAcid.subunit.threePrime: The nucleotide present at the 3’ terminal shall be specified based on a controlled vocabulary. Since the sequence is represented from the 5' to the 3' end, the 5’ prime nucleotide is the letter at the last position in the sequence. A separate representation would be redundant.
 *
 * http://hl7.org/fhir/threePrime
 */
export declare const threePrime = "http://hl7.org/fhir/threePrime";
/**
 * param
 *
 * CompartmentDefinition.resource.param: The name of a search parameter that represents the link to the compartment. More than one may be listed because a resource may be linked to a compartment in more than one way,.
 *
 * http://hl7.org/fhir/param
 */
export declare const param = "http://hl7.org/fhir/param";
/**
 * _proposedNewTime
 *
 * (Modified) AppointmentResponse.proposedNewTime
 *
 * http://hl7.org/fhir/_proposedNewTime
 */
export declare const _proposedNewTime = "http://hl7.org/fhir/_proposedNewTime";
/**
 * power
 *
 * VisionPrescription.lensSpecification.power: Contact lens power measured in dioptres (0.25 units).
 *
 * http://hl7.org/fhir/power
 */
export declare const power = "http://hl7.org/fhir/power";
/**
 * cardinalityBehavior
 *
 * RequestOrchestration.action.action.cardinalityBehavior: Defines whether the action can be selected multiple times.
 *
 * http://hl7.org/fhir/cardinalityBehavior
 */
export declare const cardinalityBehavior = "http://hl7.org/fhir/cardinalityBehavior";
/**
 * supportingPatientInformation
 *
 * ImmunizationRecommendation.recommendation.supportingPatientInformation: Patient Information that supports the status and recommendation.  This includes patient observations, adverse reactions and allergy/intolerance information.
 *
 * http://hl7.org/fhir/supportingPatientInformation
 */
export declare const supportingPatientInformation = "http://hl7.org/fhir/supportingPatientInformation";
/**
 * _predecessor
 *
 * (Modified) TestPlan.testCase.dependency.predecessor
 *
 * http://hl7.org/fhir/_predecessor
 */
export declare const _predecessor = "http://hl7.org/fhir/_predecessor";
/**
 * allergenicIndicator
 *
 * Ingredient.allergenicIndicator: If the ingredient is a known or suspected allergen. Note that this is a property of the substance, so if a reference to a SubstanceDefinition is used to decribe that (rather than just a code), the allergen information should go there, not here.
 *
 * http://hl7.org/fhir/allergenicIndicator
 */
export declare const allergenicIndicator = "http://hl7.org/fhir/allergenicIndicator";
/**
 * _regulator
 *
 * (Modified) RegulatedAuthorization.regulator
 *
 * http://hl7.org/fhir/_regulator
 */
export declare const _regulator = "http://hl7.org/fhir/_regulator";
/**
 * issue
 *
 * OperationOutcome.issue: An error, warning, or information message that results from a system action.
 *
 * http://hl7.org/fhir/issue
 */
export declare const issue = "http://hl7.org/fhir/issue";
/**
 * _admission
 *
 * (Modified) Encounter.admission
 *
 * http://hl7.org/fhir/_admission
 */
export declare const _admission = "http://hl7.org/fhir/_admission";
/**
 * _extension
 *
 * (Modified) DomainResource.extension
 *
 * http://hl7.org/fhir/_extension
 */
export declare const _extension = "http://hl7.org/fhir/_extension";
/**
 * _notificationShape
 *
 * (Modified) SubscriptionTopic.notificationShape
 *
 * http://hl7.org/fhir/_notificationShape
 */
export declare const _notificationShape = "http://hl7.org/fhir/_notificationShape";
/**
 * Device
 *
 * This resource describes the properties (regulated, has real time clock, etc.), adminstrative (manufacturer name, model number, serial number, firmware, etc.), and type (knee replacement, blood pressure cuff, MRI, etc.) of a physical unit (these values do not change much within a given module, for example the serail number, manufacturer name, and model number). An actual unit may consist of several modules in a distinct hierarchy and these are represented by multiple Device resources and bound through the 'parent' element.
 *
 * http://hl7.org/fhir/Device
 */
export declare const Device = "http://hl7.org/fhir/Device";
/**
 * Range
 *
 * A set of ordered Quantities defined by a low and high limit.
 *
 * http://hl7.org/fhir/Range
 */
export declare const Range = "http://hl7.org/fhir/Range";
/**
 * ItemBodySite
 *
 * ExplanationOfBenefit.Item.ItemBodySite: Physical location where the service is performed or applies.
 *
 * http://hl7.org/fhir/ItemBodySite
 */
export declare const ItemBodySite = "http://hl7.org/fhir/ItemBodySite";
/**
 * average
 *
 * SubstancePolymer.repeat.repeatUnit.degreeOfPolymerisation.average: An average amount of polymerisation.
 *
 * http://hl7.org/fhir/average
 */
export declare const average = "http://hl7.org/fhir/average";
/**
 * SubstanceNucleicAcidSubunitSugarComponent
 *
 * SubstanceNucleicAcidSubunitComponent.SubstanceNucleicAcidSubunitSugarComponent: 5.3.6.8.1 Sugar ID (Mandatory).
 *
 * http://hl7.org/fhir/SubstanceNucleicAcidSubunitSugarComponent
 */
export declare const SubstanceNucleicAcidSubunitSugarComponent = "http://hl7.org/fhir/SubstanceNucleicAcidSubunitSugarComponent";
/**
 * Composition
 *
 * A set of healthcare-related information that is assembled together into a single logical package that provides a single coherent statement of meaning, establishes its own context and that has clinical attestation with regard to who is making the statement. A Composition defines the structure and narrative content necessary for a document. However, a Composition alone does not constitute a document. Rather, the Composition must be the first entry in a Bundle where Bundle.type=document, and any other resources referenced from Composition must be included as subsequent entries in the Bundle (for example Patient, Practitioner, Encounter, etc.).
 *
 * http://hl7.org/fhir/Composition
 */
export declare const Composition = "http://hl7.org/fhir/Composition";
/**
 * _otherMap
 *
 * (Modified) ConceptMap.group.unmapped.otherMap
 *
 * http://hl7.org/fhir/_otherMap
 */
export declare const _otherMap = "http://hl7.org/fhir/_otherMap";
/**
 * Rule
 *
 * Permission.Rule: A set of rules.
 *
 * http://hl7.org/fhir/Rule
 */
export declare const Rule = "http://hl7.org/fhir/Rule";
/**
 * testScript
 *
 * TestReport.testScript: Ideally this is an absolute URL that is used to identify the version-specific TestScript that was executed, matching the `TestScript.url`.
 *
 * http://hl7.org/fhir/testScript
 */
export declare const testScript = "http://hl7.org/fhir/testScript";
/**
 * targetId
 *
 * GraphDefinition.link.targetId: The target node for this link.
 *
 * http://hl7.org/fhir/targetId
 */
export declare const targetId = "http://hl7.org/fhir/targetId";
/**
 * _additionalAttribute
 *
 * (Modified) ConceptMap.additionalAttribute
 *
 * http://hl7.org/fhir/_additionalAttribute
 */
export declare const _additionalAttribute = "http://hl7.org/fhir/_additionalAttribute";
/**
 * _validity
 *
 * (Modified) Permission.validity
 *
 * http://hl7.org/fhir/_validity
 */
export declare const _validity = "http://hl7.org/fhir/_validity";
/**
 * _product
 *
 * (Modified) VisionPrescription.lensSpecification.product
 *
 * http://hl7.org/fhir/_product
 */
export declare const _product = "http://hl7.org/fhir/_product";
/**
 * objective
 *
 * ResearchStudy.objective: A goal that the study is aiming to achieve in terms of a scientific question to be answered by the analysis of data collected during the study.
 *
 * http://hl7.org/fhir/objective
 */
export declare const objective = "http://hl7.org/fhir/objective";
/**
 * _containedItem
 *
 * (Modified) PackagedProductDefinition.packaging.packaging.containedItem
 *
 * http://hl7.org/fhir/_containedItem
 */
export declare const _containedItem = "http://hl7.org/fhir/_containedItem";
/**
 * MedicationKnowledgePackagingComponentCost
 *
 * The cost of the packaged medication.
 *
 * http://hl7.org/fhir/MedicationKnowledgePackagingComponentCost
 */
export declare const MedicationKnowledgePackagingComponentCost = "http://hl7.org/fhir/MedicationKnowledgePackagingComponentCost";
/**
 * relatedDevice
 *
 * DeviceDefinition.link.relatedDevice: A reference to the linked device.
 *
 * http://hl7.org/fhir/relatedDevice
 */
export declare const relatedDevice = "http://hl7.org/fhir/relatedDevice";
/**
 * QuestionnaireItemEnableWhenComponent
 *
 * QuestionnaireItemComponentItem.QuestionnaireItemEnableWhenComponent: A constraint indicating that this item should only be enabled (displayed/allow answers to be captured) when the specified condition is true.
 *
 * http://hl7.org/fhir/QuestionnaireItemEnableWhenComponent
 */
export declare const QuestionnaireItemEnableWhenComponent = "http://hl7.org/fhir/QuestionnaireItemEnableWhenComponent";
/**
 * _numberAffected
 *
 * (Modified) Evidence.statistic.numberAffected
 *
 * http://hl7.org/fhir/_numberAffected
 */
export declare const _numberAffected = "http://hl7.org/fhir/_numberAffected";
/**
 * _batch
 *
 * (Modified) Medication.batch
 *
 * http://hl7.org/fhir/_batch
 */
export declare const _batch = "http://hl7.org/fhir/_batch";
/**
 * preparationInstruction
 *
 * MedicationKnowledge.preparationInstruction: The instructions for preparing the medication.
 *
 * http://hl7.org/fhir/preparationInstruction
 */
export declare const preparationInstruction = "http://hl7.org/fhir/preparationInstruction";
/**
 * EpisodeOfCare
 *
 * An association between a patient and an organization / healthcare provider(s) during which time encounters may occur. The managing organization assumes a level of responsibility for the patient during this time.
 *
 * http://hl7.org/fhir/EpisodeOfCare
 */
export declare const EpisodeOfCare = "http://hl7.org/fhir/EpisodeOfCare";
/**
 * _entity
 *
 * (Modified) Provenance.entity
 *
 * http://hl7.org/fhir/_entity
 */
export declare const _entity = "http://hl7.org/fhir/_entity";
/**
 * _initiator
 *
 * (Modified) ExampleScenario.process.step.alternative.step.operation.initiator
 *
 * http://hl7.org/fhir/_initiator
 */
export declare const _initiator = "http://hl7.org/fhir/_initiator";
/**
 * _communication
 *
 * (Modified) RelatedPerson.communication
 *
 * http://hl7.org/fhir/_communication
 */
export declare const _communication = "http://hl7.org/fhir/_communication";
/**
 * programEligibility
 *
 * Immunization.programEligibility: Indicates a patient's eligibility for a funding program.
 *
 * http://hl7.org/fhir/programEligibility
 */
export declare const programEligibility = "http://hl7.org/fhir/programEligibility";
/**
 * addItem
 *
 * ExplanationOfBenefit.addItem: The first-tier service adjudications for payor added product or service lines.
 *
 * http://hl7.org/fhir/addItem
 */
export declare const addItem = "http://hl7.org/fhir/addItem";
/**
 * _details
 *
 * (Modified) OperationOutcome.issue.details
 *
 * http://hl7.org/fhir/_details
 */
export declare const _details = "http://hl7.org/fhir/_details";
/**
 * pageString
 *
 * Citation.citedArtifact.publicationForm.pageString: Used for full display of pagination.
 *
 * http://hl7.org/fhir/pageString
 */
export declare const pageString = "http://hl7.org/fhir/pageString";
/**
 * expansion
 *
 * ValueSet.expansion: A value set can also be "expanded", where the value set is turned into a simple collection of enumerated codes. This element holds the expansion, if it has been performed.
 *
 * http://hl7.org/fhir/expansion
 */
export declare const expansion = "http://hl7.org/fhir/expansion";
/**
 * MedicationKnowledgeRegulatoryComponent
 *
 * MedicationKnowledgeRegulatoryComponent: Regulatory information about a medication.
 *
 * http://hl7.org/fhir/MedicationKnowledgeRegulatoryComponent
 */
export declare const MedicationKnowledgeRegulatoryComponent = "http://hl7.org/fhir/MedicationKnowledgeRegulatoryComponent";
/**
 * _affiliation
 *
 * (Modified) Citation.citedArtifact.contributorship.entry.affiliation
 *
 * http://hl7.org/fhir/_affiliation
 */
export declare const _affiliation = "http://hl7.org/fhir/_affiliation";
/**
 * _contentDefinition
 *
 * (Modified) Contract.contentDefinition
 *
 * http://hl7.org/fhir/_contentDefinition
 */
export declare const _contentDefinition = "http://hl7.org/fhir/_contentDefinition";
/**
 * marketPeriod
 *
 * DeviceDefinition.packaging.packaging.udiDeviceIdentifier.marketDistribution.marketPeriod: Begin and end dates for the commercial distribution of the device.
 *
 * http://hl7.org/fhir/marketPeriod
 */
export declare const marketPeriod = "http://hl7.org/fhir/marketPeriod";
/**
 * _reportingPeriod
 *
 * (Modified) InventoryReport.reportingPeriod
 *
 * http://hl7.org/fhir/_reportingPeriod
 */
export declare const _reportingPeriod = "http://hl7.org/fhir/_reportingPeriod";
/**
 * _accountNumber
 *
 * (Modified) PaymentReconciliation.accountNumber
 *
 * http://hl7.org/fhir/_accountNumber
 */
export declare const _accountNumber = "http://hl7.org/fhir/_accountNumber";
/**
 * _geneSequenceOrigin
 *
 * (Modified) SubstanceReferenceInformation.gene.geneSequenceOrigin
 *
 * http://hl7.org/fhir/_geneSequenceOrigin
 */
export declare const _geneSequenceOrigin = "http://hl7.org/fhir/_geneSequenceOrigin";
/**
 * subpotentReason
 *
 * Immunization.subpotentReason: Reason why a dose is considered to be subpotent.
 *
 * http://hl7.org/fhir/subpotentReason
 */
export declare const subpotentReason = "http://hl7.org/fhir/subpotentReason";
/**
 * inventoryStatus
 *
 * InventoryItem.inventoryStatus: The usage status e.g. recalled, in use, discarded... This can be used to indicate that the items have been taken out of inventory, or are in use, etc.
 *
 * http://hl7.org/fhir/inventoryStatus
 */
export declare const inventoryStatus = "http://hl7.org/fhir/inventoryStatus";
/**
 * subunit
 *
 * SubstanceProtein.subunit: This subclause refers to the description of each subunit constituting the SubstanceProtein. A subunit is a linear sequence of amino acids linked through peptide bonds. The Subunit information shall be provided when the finished SubstanceProtein is a complex of multiple sequences; subunits are not used to delineate domains within a single sequence. Subunits are listed in order of decreasing length; sequences of the same length will be ordered by decreasing molecular weight; subunits that have identical sequences will be repeated multiple times.
 *
 * http://hl7.org/fhir/subunit
 */
export declare const subunit = "http://hl7.org/fhir/subunit";
/**
 * orderer
 *
 * NutritionOrder.orderer: The practitioner that holds legal responsibility for ordering the diet, nutritional supplement, or formula feedings.
 *
 * http://hl7.org/fhir/orderer
 */
export declare const orderer = "http://hl7.org/fhir/orderer";
/**
 * ExampleScenarioInstanceVersionComponent
 *
 * ExampleScenarioInstanceComponent.ExampleScenarioInstanceVersionComponent: Represents the instance as it was at a specific time-point.
 *
 * http://hl7.org/fhir/ExampleScenarioInstanceVersionComponent
 */
export declare const ExampleScenarioInstanceVersionComponent = "http://hl7.org/fhir/ExampleScenarioInstanceVersionComponent";
/**
 * itemStatus
 *
 * InventoryReport.inventoryListing.itemStatus: The status of the items.
 *
 * http://hl7.org/fhir/itemStatus
 */
export declare const itemStatus = "http://hl7.org/fhir/itemStatus";
/**
 * _ResearchStudy
 *
 * (Modified) ResearchStudy
 *
 * http://hl7.org/fhir/_ResearchStudy
 */
export declare const _ResearchStudy = "http://hl7.org/fhir/_ResearchStudy";
/**
 * resourceType
 *
 * Subscription.filterBy.resourceType: A resource listed in the `SubscriptionTopic` this `Subscription` references (`SubscriptionTopic.canFilterBy.resource`). This element can be used to differentiate filters for topics that include more than one resource type.
 *
 * http://hl7.org/fhir/resourceType
 */
export declare const resourceType = "http://hl7.org/fhir/resourceType";
/**
 * Quantity
 *
 * A measured amount (or an amount that can potentially be measured). Note that measured amounts include amounts that are not precisely quantified, including amounts involving arbitrary units and floating currencies.
 *
 * http://hl7.org/fhir/Quantity
 */
export declare const Quantity = "http://hl7.org/fhir/Quantity";
/**
 * contained
 *
 * DomainResource.contained: These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, nor can they have their own independent transaction scope. This is allowed to be a Parameters resource if and only if it is referenced by a resource that provides context/meaning.
 *
 * http://hl7.org/fhir/contained
 */
export declare const contained = "http://hl7.org/fhir/contained";
/**
 * _appointmentType
 *
 * (Modified) Slot.appointmentType
 *
 * http://hl7.org/fhir/_appointmentType
 */
export declare const _appointmentType = "http://hl7.org/fhir/_appointmentType";
/**
 * SpecimenDefinitionTypeTestedComponent
 *
 * SpecimenDefinitionTypeTestedComponent: Specimen conditioned in a container as expected by the testing laboratory.
 *
 * http://hl7.org/fhir/SpecimenDefinitionTypeTestedComponent
 */
export declare const SpecimenDefinitionTypeTestedComponent = "http://hl7.org/fhir/SpecimenDefinitionTypeTestedComponent";
/**
 * _actual
 *
 * (Modified) ResearchStudy.progressStatus.actual
 *
 * http://hl7.org/fhir/_actual
 */
export declare const _actual = "http://hl7.org/fhir/_actual";
/**
 * CostToBeneficiary
 *
 * Coverage.CostToBeneficiary: A suite of codes indicating the cost category and associated amount which have been detailed in the policy and may have been  included on the health card.
 *
 * http://hl7.org/fhir/CostToBeneficiary
 */
export declare const CostToBeneficiary = "http://hl7.org/fhir/CostToBeneficiary";
/**
 * _Schedule
 *
 * (Modified) Schedule
 *
 * http://hl7.org/fhir/_Schedule
 */
export declare const _Schedule = "http://hl7.org/fhir/_Schedule";
/**
 * programCode
 *
 * ExplanationOfBenefit.addItem.programCode: Identifies the program under which this may be recovered.
 *
 * http://hl7.org/fhir/programCode
 */
export declare const programCode = "http://hl7.org/fhir/programCode";
/**
 * _PractitionerRole
 *
 * (Modified) PractitionerRole
 *
 * http://hl7.org/fhir/_PractitionerRole
 */
export declare const _PractitionerRole = "http://hl7.org/fhir/_PractitionerRole";
/**
 * guarantor
 *
 * Account.guarantor: The parties responsible for balancing the account if other payment options fall short.
 *
 * http://hl7.org/fhir/guarantor
 */
export declare const guarantor = "http://hl7.org/fhir/guarantor";
/**
 * _FamilyMemberHistory
 *
 * (Modified) FamilyMemberHistory
 *
 * http://hl7.org/fhir/_FamilyMemberHistory
 */
export declare const _FamilyMemberHistory = "http://hl7.org/fhir/_FamilyMemberHistory";
/**
 * _operationTypeReason
 *
 * (Modified) InventoryReport.operationTypeReason
 *
 * http://hl7.org/fhir/_operationTypeReason
 */
export declare const _operationTypeReason = "http://hl7.org/fhir/_operationTypeReason";
/**
 * _programStatus
 *
 * (Modified) Immunization.programEligibility.programStatus
 *
 * http://hl7.org/fhir/_programStatus
 */
export declare const _programStatus = "http://hl7.org/fhir/_programStatus";
/**
 * _performerLinkId
 *
 * (Modified) Contract.term.group.action.performerLinkId
 *
 * http://hl7.org/fhir/_performerLinkId
 */
export declare const _performerLinkId = "http://hl7.org/fhir/_performerLinkId";
/**
 * onHold
 *
 * Account.guarantor.onHold: A guarantor may be placed on credit hold or otherwise have their role temporarily suspended.
 *
 * http://hl7.org/fhir/onHold
 */
export declare const onHold = "http://hl7.org/fhir/onHold";
/**
 * _copackagedIndicator
 *
 * (Modified) PackagedProductDefinition.copackagedIndicator
 *
 * http://hl7.org/fhir/_copackagedIndicator
 */
export declare const _copackagedIndicator = "http://hl7.org/fhir/_copackagedIndicator";
/**
 * storageGuideline
 *
 * MedicationKnowledge.storageGuideline: Information on how the medication should be stored, for example, refrigeration temperatures and length of stability at a given temperature.
 *
 * http://hl7.org/fhir/storageGuideline
 */
export declare const storageGuideline = "http://hl7.org/fhir/storageGuideline";
/**
 * _receiver
 *
 * (Modified) SupplyDelivery.receiver
 *
 * http://hl7.org/fhir/_receiver
 */
export declare const _receiver = "http://hl7.org/fhir/_receiver";
/**
 * _whyStopped
 *
 * (Modified) ResearchStudy.whyStopped
 *
 * http://hl7.org/fhir/_whyStopped
 */
export declare const _whyStopped = "http://hl7.org/fhir/_whyStopped";
/**
 * _packageFor
 *
 * (Modified) PackagedProductDefinition.packageFor
 *
 * http://hl7.org/fhir/_packageFor
 */
export declare const _packageFor = "http://hl7.org/fhir/_packageFor";
/**
 * action
 *
 * RequestOrchestration.action.action: Sub actions.
 *
 * http://hl7.org/fhir/action
 */
export declare const action = "http://hl7.org/fhir/action";
/**
 * _sourceMaterialState
 *
 * (Modified) SubstanceSourceMaterial.sourceMaterialState
 *
 * http://hl7.org/fhir/_sourceMaterialState
 */
export declare const _sourceMaterialState = "http://hl7.org/fhir/_sourceMaterialState";
/**
 * indicationGuideline
 *
 * MedicationKnowledge.indicationGuideline: Guidelines or protocols that are applicable for the administration of the medication based on indication.
 *
 * http://hl7.org/fhir/indicationGuideline
 */
export declare const indicationGuideline = "http://hl7.org/fhir/indicationGuideline";
/**
 * _interaction
 *
 * (Modified) SubstanceReferenceInformation.target.interaction
 *
 * http://hl7.org/fhir/_interaction
 */
export declare const _interaction = "http://hl7.org/fhir/_interaction";
/**
 * aggregateMethod
 *
 * Measure.group.population.aggregateMethod: Specifies which method should be used to aggregate measure observation values. For most scoring types, this is implied by scoring (e.g. a proportion measure counts members of the populations). For continuous variables, however, this information must be specified to ensure correct calculation.
 *
 * http://hl7.org/fhir/aggregateMethod
 */
export declare const aggregateMethod = "http://hl7.org/fhir/aggregateMethod";
/**
 * _authorizingPrescription
 *
 * (Modified) MedicationDispense.authorizingPrescription
 *
 * http://hl7.org/fhir/_authorizingPrescription
 */
export declare const _authorizingPrescription = "http://hl7.org/fhir/_authorizingPrescription";
/**
 * _authoritative
 *
 * (Modified) NamingSystem.uniqueId.authoritative
 *
 * http://hl7.org/fhir/_authoritative
 */
export declare const _authoritative = "http://hl7.org/fhir/_authoritative";
/**
 * timeAspect
 *
 * SpecimenDefinition.timeAspect: Time aspect of specimen collection (duration or offset).
 *
 * http://hl7.org/fhir/timeAspect
 */
export declare const timeAspect = "http://hl7.org/fhir/timeAspect";
/**
 * _valueSet
 *
 * (Modified) ElementDefinition.binding.additional.valueSet
 *
 * http://hl7.org/fhir/_valueSet
 */
export declare const _valueSet = "http://hl7.org/fhir/_valueSet";
/**
 * OperationOutcome
 *
 * A collection of error, warning, or information messages that result from a system action.
 *
 * http://hl7.org/fhir/OperationOutcome
 */
export declare const OperationOutcome = "http://hl7.org/fhir/OperationOutcome";
/**
 * Contributor
 *
 * A contributor to the content of a knowledge asset, including authors, editors, reviewers, and endorsers.
 *
 * http://hl7.org/fhir/Contributor
 */
export declare const Contributor = "http://hl7.org/fhir/Contributor";
/**
 * _message
 *
 * (Modified) TestReport.teardown.action.operation.message
 *
 * http://hl7.org/fhir/_message
 */
export declare const _message = "http://hl7.org/fhir/_message";
/**
 * import
 *
 * StructureMap.import: Other maps used by this map (canonical URLs).
 * Note that `import` is a reserved Javascript keyword, and is therefore suffixed by `__workaround`.
 * For a list of reserved keywords, see https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Lexical_grammar#Keywords.
 *
 * http://hl7.org/fhir/import
 */
export declare const import__workaround = "http://hl7.org/fhir/import";
/**
 * definitionByTypeAndValue
 *
 * EvidenceVariable.characteristic.definitionByCombination.characteristic.definitionByTypeAndValue: Defines the characteristic using both a type and value[x] elements.
 *
 * http://hl7.org/fhir/definitionByTypeAndValue
 */
export declare const definitionByTypeAndValue = "http://hl7.org/fhir/definitionByTypeAndValue";
/**
 * TestScriptSetupActionOperationComponent
 *
 * TestScriptSetupComponent.SetupAction.TestScriptSetupActionOperationComponent: The operation to perform.
 *
 * http://hl7.org/fhir/TestScriptSetupActionOperationComponent
 */
export declare const TestScriptSetupActionOperationComponent = "http://hl7.org/fhir/TestScriptSetupActionOperationComponent";
/**
 * mitigatingAction
 *
 * AdverseEvent.mitigatingAction: The ameliorating action taken after the adverse event occured in order to reduce the extent of harm.
 *
 * http://hl7.org/fhir/mitigatingAction
 */
export declare const mitigatingAction = "http://hl7.org/fhir/mitigatingAction";
/**
 * validationDate
 *
 * VerificationResult.primarySource.validationDate: When the target was validated against the primary source.
 *
 * http://hl7.org/fhir/validationDate
 */
export declare const validationDate = "http://hl7.org/fhir/validationDate";
/**
 * healthcareService
 *
 * PractitionerRole.healthcareService: The list of healthcare services that this worker provides for this role's Organization/Location(s).
 *
 * http://hl7.org/fhir/healthcareService
 */
export declare const healthcareService = "http://hl7.org/fhir/healthcareService";
/**
 * conditionalPatch
 *
 * CapabilityStatement.rest.resource.conditionalPatch: A flag that indicates that the server supports conditional patch.
 *
 * http://hl7.org/fhir/conditionalPatch
 */
export declare const conditionalPatch = "http://hl7.org/fhir/conditionalPatch";
/**
 * minimumVolume
 *
 * SpecimenDefinition.typeTested.container.minimumVolume
 *
 * http://hl7.org/fhir/minimumVolume
 */
export declare const minimumVolume = "http://hl7.org/fhir/minimumVolume";
/**
 * _practiceSetting
 *
 * (Modified) DocumentReference.practiceSetting
 *
 * http://hl7.org/fhir/_practiceSetting
 */
export declare const _practiceSetting = "http://hl7.org/fhir/_practiceSetting";
/**
 * protocol
 *
 * ResearchStudy.protocol: The set of steps expected to be performed as part of the execution of the study.
 *
 * http://hl7.org/fhir/protocol
 */
export declare const protocol = "http://hl7.org/fhir/protocol";
/**
 * _structureProfile
 *
 * (Modified) ExampleScenario.instance.structureProfile
 *
 * http://hl7.org/fhir/_structureProfile
 */
export declare const _structureProfile = "http://hl7.org/fhir/_structureProfile";
/**
 * _Coverage
 *
 * (Modified) Coverage
 *
 * http://hl7.org/fhir/_Coverage
 */
export declare const _Coverage = "http://hl7.org/fhir/_Coverage";
/**
 * _issuerType
 *
 * (Modified) PaymentReconciliation.issuerType
 *
 * http://hl7.org/fhir/_issuerType
 */
export declare const _issuerType = "http://hl7.org/fhir/_issuerType";
/**
 * MedicationRequest
 *
 * An order or request for both supply of the medication and the instructions for administration of the medication to a patient. The resource is called "MedicationRequest" rather than "MedicationPrescription" or "MedicationOrder" to generalize the use across inpatient and outpatient settings, including care plans, etc., and to harmonize with workflow patterns.
 *
 * http://hl7.org/fhir/MedicationRequest
 */
export declare const MedicationRequest = "http://hl7.org/fhir/MedicationRequest";
/**
 * _pattern
 *
 * (Modified) ElementDefinition.pattern
 *
 * http://hl7.org/fhir/_pattern
 */
export declare const _pattern = "http://hl7.org/fhir/_pattern";
/**
 * processingFacility
 *
 * BiologicallyDerivedProduct.processingFacility: Processing facilities responsible for the labeling and distribution of this biologically derived product.
 *
 * http://hl7.org/fhir/processingFacility
 */
export declare const processingFacility = "http://hl7.org/fhir/processingFacility";
/**
 * _situation
 *
 * (Modified) MessageDefinition.allowedResponse.situation
 *
 * http://hl7.org/fhir/_situation
 */
export declare const _situation = "http://hl7.org/fhir/_situation";
/**
 * _patchFormat
 *
 * (Modified) CapabilityStatement.patchFormat
 *
 * http://hl7.org/fhir/_patchFormat
 */
export declare const _patchFormat = "http://hl7.org/fhir/_patchFormat";
/**
 * alternateMaterial
 *
 * PackagedProductDefinition.packaging.packaging.alternateMaterial: A possible alternate material for this part of the packaging, that is allowed to be used instead of the usual material (e.g. different types of plastic for a blister sleeve).
 *
 * http://hl7.org/fhir/alternateMaterial
 */
export declare const alternateMaterial = "http://hl7.org/fhir/alternateMaterial";
/**
 * responsible
 *
 * NamingSystem.responsible: The name of the organization that is responsible for issuing identifiers or codes for this namespace and ensuring their non-collision.
 *
 * http://hl7.org/fhir/responsible
 */
export declare const responsible = "http://hl7.org/fhir/responsible";
/**
 * PlanDefinitionActionRelatedActionComponent
 *
 * PlanDefinitionActionComponent.PlanDefinitionActionRelatedActionComponent: A relationship to another action such as "before" or "30-60 minutes after start of".
 *
 * http://hl7.org/fhir/PlanDefinitionActionRelatedActionComponent
 */
export declare const PlanDefinitionActionRelatedActionComponent = "http://hl7.org/fhir/PlanDefinitionActionRelatedActionComponent";
/**
 * _security
 *
 * (Modified) Permission.rule.data.security
 *
 * http://hl7.org/fhir/_security
 */
export declare const _security = "http://hl7.org/fhir/_security";
/**
 * combined
 *
 * Specimen.combined: This element signifies if the specimen is part of a group or pooled.
 *
 * http://hl7.org/fhir/combined
 */
export declare const combined = "http://hl7.org/fhir/combined";
/**
 * contains
 *
 * ValueSet.expansion.contains: The codes that are contained in the value set expansion.
 *
 * http://hl7.org/fhir/contains
 */
export declare const contains = "http://hl7.org/fhir/contains";
/**
 * _addresses
 *
 * (Modified) PlanDefinition.goal.addresses
 *
 * http://hl7.org/fhir/_addresses
 */
export declare const _addresses = "http://hl7.org/fhir/_addresses";
/**
 * expirationDate
 *
 * Immunization.expirationDate: Date vaccine batch expires.
 *
 * http://hl7.org/fhir/expirationDate
 */
export declare const expirationDate = "http://hl7.org/fhir/expirationDate";
/**
 * compartment
 *
 * GraphDefinition.link.compartment: Compartment Consistency Rules.
 *
 * http://hl7.org/fhir/compartment
 */
export declare const compartment = "http://hl7.org/fhir/compartment";
/**
 * _scoring
 *
 * (Modified) MeasureReport.scoring
 *
 * http://hl7.org/fhir/_scoring
 */
export declare const _scoring = "http://hl7.org/fhir/_scoring";
/**
 * policy
 *
 * AuditEvent.agent.policy: Where the policy(ies) are known that authorized the agent participation in the event. Typically, a single activity may have multiple applicable policies, such as patient consent, guarantor funding, etc. The policy would also indicate the security token used.
 *
 * http://hl7.org/fhir/policy
 */
export declare const policy = "http://hl7.org/fhir/policy";
/**
 * recordedDate
 *
 * AdverseEvent.recordedDate: The date on which the existence of the AdverseEvent was first recorded.
 *
 * http://hl7.org/fhir/recordedDate
 */
export declare const recordedDate = "http://hl7.org/fhir/recordedDate";
/**
 * _sourceScope
 *
 * (Modified) ConceptMap.sourceScope
 *
 * http://hl7.org/fhir/_sourceScope
 */
export declare const _sourceScope = "http://hl7.org/fhir/_sourceScope";
/**
 * _chain
 *
 * (Modified) SearchParameter.chain
 *
 * http://hl7.org/fhir/_chain
 */
export declare const _chain = "http://hl7.org/fhir/_chain";
/**
 * ImplementationGuideManifestComponent
 *
 * ImplementationGuideManifestComponent: Information about an assembled implementation guide, created by the publication tooling.
 *
 * http://hl7.org/fhir/ImplementationGuideManifestComponent
 */
export declare const ImplementationGuideManifestComponent = "http://hl7.org/fhir/ImplementationGuideManifestComponent";
/**
 * _contributedToDeath
 *
 * (Modified) FamilyMemberHistory.procedure.contributedToDeath
 *
 * http://hl7.org/fhir/_contributedToDeath
 */
export declare const _contributedToDeath = "http://hl7.org/fhir/_contributedToDeath";
/**
 * _diagnosisRelatedGroup
 *
 * (Modified) ExplanationOfBenefit.diagnosisRelatedGroup
 *
 * http://hl7.org/fhir/_diagnosisRelatedGroup
 */
export declare const _diagnosisRelatedGroup = "http://hl7.org/fhir/_diagnosisRelatedGroup";
/**
 * _referenceNumber
 *
 * (Modified) PaymentReconciliation.referenceNumber
 *
 * http://hl7.org/fhir/_referenceNumber
 */
export declare const _referenceNumber = "http://hl7.org/fhir/_referenceNumber";
/**
 * _template
 *
 * (Modified) ImplementationGuide.definition.template
 *
 * http://hl7.org/fhir/_template
 */
export declare const _template = "http://hl7.org/fhir/_template";
/**
 * _preConditions
 *
 * (Modified) ExampleScenario.process.step.alternative.step.process.preConditions
 *
 * http://hl7.org/fhir/_preConditions
 */
export declare const _preConditions = "http://hl7.org/fhir/_preConditions";
/**
 * _score
 *
 * (Modified) TestReport.score
 *
 * http://hl7.org/fhir/_score
 */
export declare const _score = "http://hl7.org/fhir/_score";
/**
 * SubstancePolymerMonomerSetComponent
 *
 * SubstancePolymerMonomerSetComponent: Todo.
 *
 * http://hl7.org/fhir/SubstancePolymerMonomerSetComponent
 */
export declare const SubstancePolymerMonomerSetComponent = "http://hl7.org/fhir/SubstancePolymerMonomerSetComponent";
/**
 * _requiredBehavior
 *
 * (Modified) RequestOrchestration.action.action.requiredBehavior
 *
 * http://hl7.org/fhir/_requiredBehavior
 */
export declare const _requiredBehavior = "http://hl7.org/fhir/_requiredBehavior";
/**
 * _statusHistory
 *
 * (Modified) EpisodeOfCare.statusHistory
 *
 * http://hl7.org/fhir/_statusHistory
 */
export declare const _statusHistory = "http://hl7.org/fhir/_statusHistory";
/**
 * replacementSequence
 *
 * MolecularSequence.relative.edit.replacementSequence: Allele that was observed. Nucleotide(s)/amino acids from start position of sequence to stop position of sequence on the positive (+) strand of the observed sequence. When the sequence type is DNA, it should be the sequence on the positive (+) strand. This will lay in the range between variant.start and variant.end.
 *
 * http://hl7.org/fhir/replacementSequence
 */
export declare const replacementSequence = "http://hl7.org/fhir/replacementSequence";
/**
 * _file
 *
 * (Modified) SubstanceDefinition.characterization.file
 *
 * http://hl7.org/fhir/_file
 */
export declare const _file = "http://hl7.org/fhir/_file";
/**
 * _height
 *
 * (Modified) Attachment.height
 *
 * http://hl7.org/fhir/_height
 */
export declare const _height = "http://hl7.org/fhir/_height";
/**
 * _groupSize
 *
 * (Modified) InsurancePlan.plan.generalCost.groupSize
 *
 * http://hl7.org/fhir/_groupSize
 */
export declare const _groupSize = "http://hl7.org/fhir/_groupSize";
/**
 * observedGroup
 *
 * ResearchStudy.comparisonGroup.observedGroup: Group of participants who were enrolled in study comparisonGroup.
 *
 * http://hl7.org/fhir/observedGroup
 */
export declare const observedGroup = "http://hl7.org/fhir/observedGroup";
/**
 * receivedTime
 *
 * Specimen.receivedTime: Time when specimen is received by the testing laboratory for processing or testing.
 *
 * http://hl7.org/fhir/receivedTime
 */
export declare const receivedTime = "http://hl7.org/fhir/receivedTime";
/**
 * _doseAndRate
 *
 * (Modified) Dosage.doseAndRate
 *
 * http://hl7.org/fhir/_doseAndRate
 */
export declare const _doseAndRate = "http://hl7.org/fhir/_doseAndRate";
/**
 * definitionCanonical
 *
 * EvidenceVariable.characteristic.definitionByCombination.characteristic.definitionCanonical: Defines the characteristic using Canonical.
 *
 * http://hl7.org/fhir/definitionCanonical
 */
export declare const definitionCanonical = "http://hl7.org/fhir/definitionCanonical";
/**
 * QuestionnaireResponseItemComponent
 *
 * QuestionnaireResponseItemComponent: A group or question item from the original questionnaire for which answers are provided.
 *
 * http://hl7.org/fhir/QuestionnaireResponseItemComponent
 */
export declare const QuestionnaireResponseItemComponent = "http://hl7.org/fhir/QuestionnaireResponseItemComponent";
/**
 * _typeReference
 *
 * (Modified) PlanDefinition.actor.option.typeReference
 *
 * http://hl7.org/fhir/_typeReference
 */
export declare const _typeReference = "http://hl7.org/fhir/_typeReference";
/**
 * PractitionerQualificationComponent
 *
 * PractitionerQualificationComponent: The official qualifications, certifications, accreditations, training, licenses (and other types of educations/skills/capabilities) that authorize or otherwise pertain to the provision of care by the practitioner.

For example, a medical license issued by a medical board of licensure authorizing the practitioner to practice medicine within a certain locality.
 *
 * http://hl7.org/fhir/PractitionerQualificationComponent
 */
export declare const PractitionerQualificationComponent = "http://hl7.org/fhir/PractitionerQualificationComponent";
/**
 * cTerminalModificationId
 *
 * SubstanceProtein.subunit.cTerminalModificationId: Unique identifier for molecular fragment modification based on the ISO 11238 Substance ID.
 *
 * http://hl7.org/fhir/cTerminalModificationId
 */
export declare const cTerminalModificationId = "http://hl7.org/fhir/cTerminalModificationId";
/**
 * _requireBoth
 *
 * (Modified) SubscriptionTopic.resourceTrigger.queryCriteria.requireBoth
 *
 * http://hl7.org/fhir/_requireBoth
 */
export declare const _requireBoth = "http://hl7.org/fhir/_requireBoth";
/**
 * dataAbsentReason
 *
 * Observation.component.dataAbsentReason: Provides a reason why the expected value in the element Observation.component.value[x] is missing.
 *
 * http://hl7.org/fhir/dataAbsentReason
 */
export declare const dataAbsentReason = "http://hl7.org/fhir/dataAbsentReason";
/**
 * _criticality
 *
 * (Modified) AllergyIntolerance.criticality
 *
 * http://hl7.org/fhir/_criticality
 */
export declare const _criticality = "http://hl7.org/fhir/_criticality";
/**
 * _subjectStatus
 *
 * (Modified) EncounterHistory.subjectStatus
 *
 * http://hl7.org/fhir/_subjectStatus
 */
export declare const _subjectStatus = "http://hl7.org/fhir/_subjectStatus";
/**
 * _expiry
 *
 * (Modified) Substance.expiry
 *
 * http://hl7.org/fhir/_expiry
 */
export declare const _expiry = "http://hl7.org/fhir/_expiry";
/**
 * usage
 *
 * ActivityDefinition.usage: A detailed description of how the activity definition is used from a clinical perspective.
 *
 * http://hl7.org/fhir/usage
 */
export declare const usage = "http://hl7.org/fhir/usage";
/**
 * city
 *
 * Address.city: The name of the city, town, suburb, village or other community or delivery center.
 *
 * http://hl7.org/fhir/city
 */
export declare const city = "http://hl7.org/fhir/city";
/**
 * _instances
 *
 * (Modified) EvidenceVariable.characteristic.instances
 *
 * http://hl7.org/fhir/_instances
 */
export declare const _instances = "http://hl7.org/fhir/_instances";
/**
 * stratum
 *
 * MeasureReport.group.stratifier.stratum: This element contains the results for a single stratum within the stratifier. For example, when stratifying on administrative gender, there will be four strata, one for each possible gender value.
 *
 * http://hl7.org/fhir/stratum
 */
export declare const stratum = "http://hl7.org/fhir/stratum";
/**
 * MeasureReportGroupStratifierComponent
 *
 * MeasureReportGroupComponent.MeasureReportGroupStratifierComponent: When a measure includes multiple stratifiers, there will be a stratifier group for each stratifier defined by the measure.
 *
 * http://hl7.org/fhir/MeasureReportGroupStratifierComponent
 */
export declare const MeasureReportGroupStratifierComponent = "http://hl7.org/fhir/MeasureReportGroupStratifierComponent";
/**
 * _ratioHighLimitAmount
 *
 * (Modified) SubstanceDefinition.relationship.ratioHighLimitAmount
 *
 * http://hl7.org/fhir/_ratioHighLimitAmount
 */
export declare const _ratioHighLimitAmount = "http://hl7.org/fhir/_ratioHighLimitAmount";
/**
 * route
 *
 * Dosage.route: How drug should enter body.
 *
 * http://hl7.org/fhir/route
 */
export declare const route = "http://hl7.org/fhir/route";
/**
 * TestScriptMetadataLinkComponent
 *
 * TestScriptMetadataComponent.TestScriptMetadataLinkComponent: A link to the FHIR specification that this test is covering.
 *
 * http://hl7.org/fhir/TestScriptMetadataLinkComponent
 */
export declare const TestScriptMetadataLinkComponent = "http://hl7.org/fhir/TestScriptMetadataLinkComponent";
/**
 * DeviceDispensePerformerComponent
 *
 * DeviceDispensePerformerComponent: Indicates who or what performed the event.
 *
 * http://hl7.org/fhir/DeviceDispensePerformerComponent
 */
export declare const DeviceDispensePerformerComponent = "http://hl7.org/fhir/DeviceDispensePerformerComponent";
/**
 * frequencyMax
 *
 * Timing.repeat.frequencyMax: If present, indicates that the frequency is a range - so to repeat between [frequency] and [frequencyMax] times within the period or period range.
 *
 * http://hl7.org/fhir/frequencyMax
 */
export declare const frequencyMax = "http://hl7.org/fhir/frequencyMax";
/**
 * _number
 *
 * (Modified) ExampleScenario.process.step.process.step.number
 *
 * http://hl7.org/fhir/_number
 */
export declare const _number = "http://hl7.org/fhir/_number";
/**
 * QuestionnaireResponse
 *
 * A structured set of questions and their answers. The questions are ordered and grouped into coherent subsets, corresponding to the structure of the grouping of the questionnaire being responded to.
 *
 * http://hl7.org/fhir/QuestionnaireResponse
 */
export declare const QuestionnaireResponse = "http://hl7.org/fhir/QuestionnaireResponse";
/**
 * MappingProperty
 *
 * ConceptMapGroupComponent.SourceElement.TargetElement.MappingProperty: A property value for this source -> target mapping.
 *
 * http://hl7.org/fhir/MappingProperty
 */
export declare const MappingProperty = "http://hl7.org/fhir/MappingProperty";
/**
 * _securityContext
 *
 * (Modified) Binary.securityContext
 *
 * http://hl7.org/fhir/_securityContext
 */
export declare const _securityContext = "http://hl7.org/fhir/_securityContext";
/**
 * display
 *
 * TestReport.participant.display: The display name of the participant.
 *
 * http://hl7.org/fhir/display
 */
export declare const display = "http://hl7.org/fhir/display";
/**
 * yearlyTemplate
 *
 * Appointment.recurrenceTemplate.yearlyTemplate: Information about yearly recurring appointments.
 *
 * http://hl7.org/fhir/yearlyTemplate
 */
export declare const yearlyTemplate = "http://hl7.org/fhir/yearlyTemplate";
/**
 * ChargeItemPerformerComponent
 *
 * ChargeItemPerformerComponent: Indicates who or what performed or participated in the charged service.
 *
 * http://hl7.org/fhir/ChargeItemPerformerComponent
 */
export declare const ChargeItemPerformerComponent = "http://hl7.org/fhir/ChargeItemPerformerComponent";
/**
 * Contact
 *
 * Patient.Contact: A contact party (e.g. guardian, partner, friend) for the patient.
 *
 * http://hl7.org/fhir/Contact
 */
export declare const Contact = "http://hl7.org/fhir/Contact";
/**
 * EndpointPayloadComponent
 *
 * EndpointPayloadComponent: The set of payloads that are provided/available at this endpoint.
 *
 * http://hl7.org/fhir/EndpointPayloadComponent
 */
export declare const EndpointPayloadComponent = "http://hl7.org/fhir/EndpointPayloadComponent";
/**
 * _relatedArtifact
 *
 * (Modified) ChargeItemDefinition.propertyGroup.applicability.relatedArtifact
 *
 * http://hl7.org/fhir/_relatedArtifact
 */
export declare const _relatedArtifact = "http://hl7.org/fhir/_relatedArtifact";
/**
 * updateCreate
 *
 * CapabilityStatement.rest.resource.updateCreate: A flag to indicate that the server allows or needs to allow the client to create new identities on the server (that is, the client PUTs to a location where there is no existing resource). Allowing this operation means that the server allows the client to create new identities on the server.
 *
 * http://hl7.org/fhir/updateCreate
 */
export declare const updateCreate = "http://hl7.org/fhir/updateCreate";
/**
 * _subtype
 *
 * (Modified) Contract.term.group.asset.subtype
 *
 * http://hl7.org/fhir/_subtype
 */
export declare const _subtype = "http://hl7.org/fhir/_subtype";
/**
 * _stereochemistry
 *
 * (Modified) SubstanceDefinition.structure.stereochemistry
 *
 * http://hl7.org/fhir/_stereochemistry
 */
export declare const _stereochemistry = "http://hl7.org/fhir/_stereochemistry";
/**
 * _upperLimit
 *
 * (Modified) SampledData.upperLimit
 *
 * http://hl7.org/fhir/_upperLimit
 */
export declare const _upperLimit = "http://hl7.org/fhir/_upperLimit";
/**
 * routeOfAdministration
 *
 * NutritionOrder.enteralFormula.routeOfAdministration: The route or physiological path of administration into the patient's gastrointestinal  tract for purposes of providing the formula feeding, e.g. nasogastric tube.
 *
 * http://hl7.org/fhir/routeOfAdministration
 */
export declare const routeOfAdministration = "http://hl7.org/fhir/routeOfAdministration";
/**
 * _amountType
 *
 * (Modified) SubstanceReferenceInformation.target.amountType
 *
 * http://hl7.org/fhir/_amountType
 */
export declare const _amountType = "http://hl7.org/fhir/_amountType";
/**
 * _organismType
 *
 * (Modified) SubstanceReferenceInformation.target.organismType
 *
 * http://hl7.org/fhir/_organismType
 */
export declare const _organismType = "http://hl7.org/fhir/_organismType";
/**
 * bodySite
 *
 * Specimen.collection.bodySite: Anatomical location from which the specimen was collected (if subject is a patient). This is the target site.  This element is not used for environmental specimens.
 *
 * http://hl7.org/fhir/bodySite
 */
export declare const bodySite = "http://hl7.org/fhir/bodySite";
/**
 * _moiety
 *
 * (Modified) SubstanceDefinition.moiety
 *
 * http://hl7.org/fhir/_moiety
 */
export declare const _moiety = "http://hl7.org/fhir/_moiety";
/**
 * _recommendation
 *
 * (Modified) ImmunizationRecommendation.recommendation
 *
 * http://hl7.org/fhir/_recommendation
 */
export declare const _recommendation = "http://hl7.org/fhir/_recommendation";
/**
 * grouping
 *
 * ImplementationGuide.definition.grouping: A logical group of resources. Logical groups can be used when building pages.
 *
 * http://hl7.org/fhir/grouping
 */
export declare const grouping = "http://hl7.org/fhir/grouping";
/**
 * _pause
 *
 * (Modified) ExampleScenario.process.step.pause
 *
 * http://hl7.org/fhir/_pause
 */
export declare const _pause = "http://hl7.org/fhir/_pause";
/**
 * _primaryPurposeType
 *
 * (Modified) ResearchStudy.primaryPurposeType
 *
 * http://hl7.org/fhir/_primaryPurposeType
 */
export declare const _primaryPurposeType = "http://hl7.org/fhir/_primaryPurposeType";
/**
 * ConceptSubProperty
 *
 * ValueSetExpansionComponent.ValueSetExpansionContainsComponentContains.ConceptProperty.ConceptSubProperty: A subproperty value for this concept.
 *
 * http://hl7.org/fhir/ConceptSubProperty
 */
export declare const ConceptSubProperty = "http://hl7.org/fhir/ConceptSubProperty";
/**
 * subscription
 *
 * SubscriptionStatus.subscription: The reference to the Subscription which generated this notification.
 *
 * http://hl7.org/fhir/subscription
 */
export declare const subscription = "http://hl7.org/fhir/subscription";
/**
 * _lastPage
 *
 * (Modified) Citation.citedArtifact.publicationForm.lastPage
 *
 * http://hl7.org/fhir/_lastPage
 */
export declare const _lastPage = "http://hl7.org/fhir/_lastPage";
/**
 * partLocation
 *
 * SubstanceSourceMaterial.partDescription.partLocation: The detailed anatomic location when the part can be extracted from different anatomical locations of the organism. Multiple alternative locations may apply.
 *
 * http://hl7.org/fhir/partLocation
 */
export declare const partLocation = "http://hl7.org/fhir/partLocation";
/**
 * controller
 *
 * Consent.controller: The actor that controls/enforces the access according to the consent.
 *
 * http://hl7.org/fhir/controller
 */
export declare const controller = "http://hl7.org/fhir/controller";
/**
 * publicationDateSeason
 *
 * Citation.citedArtifact.publicationForm.publicationDateSeason: Spring, Summer, Fall/Autumn, Winter.
 *
 * http://hl7.org/fhir/publicationDateSeason
 */
export declare const publicationDateSeason = "http://hl7.org/fhir/publicationDateSeason";
/**
 * imports
 *
 * CapabilityStatement.imports: Reference to a canonical URL of another CapabilityStatement that this software adds to. The capability statement automatically includes everything in the other statement, and it is not duplicated, though the server may repeat the same resources, interactions and operations to add additional details to them.
 *
 * http://hl7.org/fhir/imports
 */
export declare const imports = "http://hl7.org/fhir/imports";
/**
 * allocation
 *
 * PaymentReconciliation.allocation: Distribution of the payment amount for a previously acknowledged payable.
 *
 * http://hl7.org/fhir/allocation
 */
export declare const allocation = "http://hl7.org/fhir/allocation";
/**
 * _pageCount
 *
 * (Modified) Citation.citedArtifact.publicationForm.pageCount
 *
 * http://hl7.org/fhir/_pageCount
 */
export declare const _pageCount = "http://hl7.org/fhir/_pageCount";
/**
 * _failureAction
 *
 * (Modified) VerificationResult.failureAction
 *
 * http://hl7.org/fhir/_failureAction
 */
export declare const _failureAction = "http://hl7.org/fhir/_failureAction";
/**
 * profile
 *
 * ImplementationGuide.global.profile: A reference to the profile that all instances must conform to.
 *
 * http://hl7.org/fhir/profile
 */
export declare const profile = "http://hl7.org/fhir/profile";
/**
 * cylinder
 *
 * VisionPrescription.lensSpecification.cylinder: Power adjustment for astigmatism measured in dioptres (0.25 units).
 *
 * http://hl7.org/fhir/cylinder
 */
export declare const cylinder = "http://hl7.org/fhir/cylinder";
/**
 * deleted
 *
 * List.entry.deleted: True if this item is marked as deleted in the list.
 *
 * http://hl7.org/fhir/deleted
 */
export declare const deleted = "http://hl7.org/fhir/deleted";
/**
 * episodeOfCare
 *
 * Encounter.episodeOfCare: Where a specific encounter should be classified as a part of a specific episode(s) of care this field should be used. This association can facilitate grouping of related encounters together for a specific purpose, such as government reporting, issue tracking, association via a common problem.  The association is recorded on the encounter as these are typically created after the episode of care and grouped on entry rather than editing the episode of care to append another encounter to it (the episode of care could span years).
 *
 * http://hl7.org/fhir/episodeOfCare
 */
export declare const episodeOfCare = "http://hl7.org/fhir/episodeOfCare";
/**
 * saturday
 *
 * Appointment.recurrenceTemplate.weeklyTemplate.saturday: Indicates that recurring appointments should occur on Saturdays.
 *
 * http://hl7.org/fhir/saturday
 */
export declare const saturday = "http://hl7.org/fhir/saturday";
/**
 * _expectedInResearchStudy
 *
 * (Modified) AdverseEvent.expectedInResearchStudy
 *
 * http://hl7.org/fhir/_expectedInResearchStudy
 */
export declare const _expectedInResearchStudy = "http://hl7.org/fhir/_expectedInResearchStudy";
/**
 * CommunicationRequestPayloadComponent
 *
 * CommunicationRequestPayloadComponent: Text, attachment(s), or resource(s) to be communicated to the recipient.
 *
 * http://hl7.org/fhir/CommunicationRequestPayloadComponent
 */
export declare const CommunicationRequestPayloadComponent = "http://hl7.org/fhir/CommunicationRequestPayloadComponent";
/**
 * _calculatedAt
 *
 * (Modified) Account.calculatedAt
 *
 * http://hl7.org/fhir/_calculatedAt
 */
export declare const _calculatedAt = "http://hl7.org/fhir/_calculatedAt";
/**
 * _impurity
 *
 * (Modified) MedicinalProductDefinition.impurity
 *
 * http://hl7.org/fhir/_impurity
 */
export declare const _impurity = "http://hl7.org/fhir/_impurity";
/**
 * type
 *
 * NamingSystem.type: Categorizes a naming system for easier search by grouping related naming systems.
 *
 * http://hl7.org/fhir/type
 */
export declare const type = "http://hl7.org/fhir/type";
/**
 * goalId
 *
 * PlanDefinition.action.action.goalId: Identifies goals that this action supports. The reference must be to a goal element defined within this plan definition. In pharmaceutical quality, a goal represents acceptance criteria (Goal) for a given action (Test), so the goalId would be the unique id of a defined goal element establishing the acceptance criteria for the action.
 *
 * http://hl7.org/fhir/goalId
 */
export declare const goalId = "http://hl7.org/fhir/goalId";
/**
 * ObservationDefinitionComponentComponent
 *
 * ObservationDefinitionComponentComponent: Some observations have multiple component observations, expressed as separate code value pairs.
 *
 * http://hl7.org/fhir/ObservationDefinitionComponentComponent
 */
export declare const ObservationDefinitionComponentComponent = "http://hl7.org/fhir/ObservationDefinitionComponentComponent";
/**
 * TestScriptSetupComponent
 *
 * TestScriptSetupComponent: A series of required setup operations before tests are executed.
 *
 * http://hl7.org/fhir/TestScriptSetupComponent
 */
export declare const TestScriptSetupComponent = "http://hl7.org/fhir/TestScriptSetupComponent";
/**
 * Appointment
 *
 * A booking of a healthcare event among patient(s), practitioner(s), related person(s) and/or device(s) for a specific date/time. This may result in one or more Encounter(s).
 *
 * http://hl7.org/fhir/Appointment
 */
export declare const Appointment = "http://hl7.org/fhir/Appointment";
/**
 * _groupIdentifier
 *
 * (Modified) Transport.groupIdentifier
 *
 * http://hl7.org/fhir/_groupIdentifier
 */
export declare const _groupIdentifier = "http://hl7.org/fhir/_groupIdentifier";
/**
 * _countMax
 *
 * (Modified) Timing.repeat.countMax
 *
 * http://hl7.org/fhir/_countMax
 */
export declare const _countMax = "http://hl7.org/fhir/_countMax";
/**
 * patientCharacteristic
 *
 * MedicationKnowledge.indicationGuideline.dosingGuideline.patientCharacteristic: Characteristics of the patient that are relevant to the administration guidelines (for example, height, weight, gender, etc.).
 *
 * http://hl7.org/fhir/patientCharacteristic
 */
export declare const patientCharacteristic = "http://hl7.org/fhir/patientCharacteristic";
/**
 * lowNumerator
 *
 * RatioRange.lowNumerator: The value of the low limit numerator.
 *
 * http://hl7.org/fhir/lowNumerator
 */
export declare const lowNumerator = "http://hl7.org/fhir/lowNumerator";
/**
 * _texture
 *
 * (Modified) NutritionOrder.oralDiet.texture
 *
 * http://hl7.org/fhir/_texture
 */
export declare const _texture = "http://hl7.org/fhir/_texture";
/**
 * _causality
 *
 * (Modified) AdverseEvent.suspectEntity.causality
 *
 * http://hl7.org/fhir/_causality
 */
export declare const _causality = "http://hl7.org/fhir/_causality";
/**
 * operator
 *
 * CodeSystem.filter.operator: A list of operators that can be used with the filter.
 *
 * http://hl7.org/fhir/operator
 */
export declare const operator = "http://hl7.org/fhir/operator";
/**
 * fixed
 *
 * http://hl7.org/fhir/fixed
 */
export declare const fixed = "http://hl7.org/fhir/fixed";
/**
 * nTerminalModificationId
 *
 * SubstanceProtein.subunit.nTerminalModificationId: Unique identifier for molecular fragment modification based on the ISO 11238 Substance ID.
 *
 * http://hl7.org/fhir/nTerminalModificationId
 */
export declare const nTerminalModificationId = "http://hl7.org/fhir/nTerminalModificationId";
/**
 * InventoryItemNameComponent
 *
 * InventoryItemNameComponent: The item name(s) - the brand name, or common name, functional name, generic name.
 *
 * http://hl7.org/fhir/InventoryItemNameComponent
 */
export declare const InventoryItemNameComponent = "http://hl7.org/fhir/InventoryItemNameComponent";
/**
 * _minimumId
 *
 * (Modified) TestScript.test.action.assert.minimumId
 *
 * http://hl7.org/fhir/_minimumId
 */
export declare const _minimumId = "http://hl7.org/fhir/_minimumId";
/**
 * verificationStatus
 *
 * Condition.verificationStatus: The verification status to support the clinical status of the condition.  The verification status pertains to the condition, itself, not to any specific condition attribute.
 *
 * http://hl7.org/fhir/verificationStatus
 */
export declare const verificationStatus = "http://hl7.org/fhir/verificationStatus";
/**
 * _PaymentNotice
 *
 * (Modified) PaymentNotice
 *
 * http://hl7.org/fhir/_PaymentNotice
 */
export declare const _PaymentNotice = "http://hl7.org/fhir/_PaymentNotice";
/**
 * _dateAccessed
 *
 * (Modified) Citation.citedArtifact.dateAccessed
 *
 * http://hl7.org/fhir/_dateAccessed
 */
export declare const _dateAccessed = "http://hl7.org/fhir/_dateAccessed";
/**
 * logMessage
 *
 * StructureMap.group.rule.rule.source.logMessage: A FHIRPath expression which specifies a message to put in the transform log when content matching the source rule is found.
 *
 * http://hl7.org/fhir/logMessage
 */
export declare const logMessage = "http://hl7.org/fhir/logMessage";
/**
 * ResearchStudyProgressStatusComponent
 *
 * ResearchStudyProgressStatusComponent: Status of study with time for that status.
 *
 * http://hl7.org/fhir/ResearchStudyProgressStatusComponent
 */
export declare const ResearchStudyProgressStatusComponent = "http://hl7.org/fhir/ResearchStudyProgressStatusComponent";
/**
 * _residueSite
 *
 * (Modified) SubstanceNucleicAcid.subunit.sugar.residueSite
 *
 * http://hl7.org/fhir/_residueSite
 */
export declare const _residueSite = "http://hl7.org/fhir/_residueSite";
/**
 * MonetaryComponent
 *
 * Availability data for an {item}.
 *
 * http://hl7.org/fhir/MonetaryComponent
 */
export declare const MonetaryComponent = "http://hl7.org/fhir/MonetaryComponent";
/**
 * TeardownAction
 *
 * TestScriptTeardownComponent.TeardownAction: The teardown action will only contain an operation.
 *
 * http://hl7.org/fhir/TeardownAction
 */
export declare const TeardownAction = "http://hl7.org/fhir/TeardownAction";
/**
 * clinicalUseIssue
 *
 * MedicationKnowledge.clinicalUseIssue: Potential clinical issue with or between medication(s) (for example, drug-drug interaction, drug-disease contraindication, drug-allergy interaction, etc.).
 *
 * http://hl7.org/fhir/clinicalUseIssue
 */
export declare const clinicalUseIssue = "http://hl7.org/fhir/clinicalUseIssue";
/**
 * classification
 *
 * MedicinalProductDefinition.classification: Allows the product to be classified by various systems, commonly WHO ATC.
 *
 * http://hl7.org/fhir/classification
 */
export declare const classification = "http://hl7.org/fhir/classification";
/**
 * _lifecycleStatus
 *
 * (Modified) Goal.lifecycleStatus
 *
 * http://hl7.org/fhir/_lifecycleStatus
 */
export declare const _lifecycleStatus = "http://hl7.org/fhir/_lifecycleStatus";
/**
 * signature
 *
 * Bundle.signature: Digital Signature - base64 encoded. XML-DSig or a JWS.
 *
 * http://hl7.org/fhir/signature
 */
export declare const signature = "http://hl7.org/fhir/signature";
/**
 * reviewer
 *
 * EvidenceVariable.reviewer: An individual or organization asserted by the publisher to be primarily responsible for review of some aspect of the content.
 *
 * http://hl7.org/fhir/reviewer
 */
export declare const reviewer = "http://hl7.org/fhir/reviewer";
/**
 * _usePeriod
 *
 * (Modified) Contract.term.group.asset.usePeriod
 *
 * http://hl7.org/fhir/_usePeriod
 */
export declare const _usePeriod = "http://hl7.org/fhir/_usePeriod";
/**
 * BodyStructureIncludedStructureComponent
 *
 * BodyStructureIncludedStructureComponent: The anatomical location(s) or region(s) of the specimen, lesion, or body structure.
 *
 * http://hl7.org/fhir/BodyStructureIncludedStructureComponent
 */
export declare const BodyStructureIncludedStructureComponent = "http://hl7.org/fhir/BodyStructureIncludedStructureComponent";
/**
 * next
 *
 * ValueSet.expansion.next: As per paging Search results, the next URLs are opaque to the client, have no dictated structure, and only the server understands them.
 *
 * http://hl7.org/fhir/next
 */
export declare const next = "http://hl7.org/fhir/next";
/**
 * _changeType
 *
 * (Modified) GenomicStudy.analysis.changeType
 *
 * http://hl7.org/fhir/_changeType
 */
export declare const _changeType = "http://hl7.org/fhir/_changeType";
/**
 * _ImmunizationEvaluation
 *
 * (Modified) ImmunizationEvaluation
 *
 * http://hl7.org/fhir/_ImmunizationEvaluation
 */
export declare const _ImmunizationEvaluation = "http://hl7.org/fhir/_ImmunizationEvaluation";
/**
 * requestingOrganization
 *
 * ChargeItem.requestingOrganization: The organization requesting the service.
 *
 * http://hl7.org/fhir/requestingOrganization
 */
export declare const requestingOrganization = "http://hl7.org/fhir/requestingOrganization";
/**
 * _unitOfPresentation
 *
 * (Modified) ManufacturedItemDefinition.unitOfPresentation
 *
 * http://hl7.org/fhir/_unitOfPresentation
 */
export declare const _unitOfPresentation = "http://hl7.org/fhir/_unitOfPresentation";
/**
 * requestedPeriod
 *
 * Task.requestedPeriod: Indicates the start and/or end of the period of time when completion of the task is desired to take place.
 *
 * http://hl7.org/fhir/requestedPeriod
 */
export declare const requestedPeriod = "http://hl7.org/fhir/requestedPeriod";
/**
 * Answer
 *
 * Contract.TermTerm.ContractOffer.Answer: Response to offer text.
 *
 * http://hl7.org/fhir/Answer
 */
export declare const Answer = "http://hl7.org/fhir/Answer";
/**
 * count
 *
 * MeasureReport.group.stratifier.stratum.population.count: The number of members of the population in this stratum.
 *
 * http://hl7.org/fhir/count
 */
export declare const count = "http://hl7.org/fhir/count";
/**
 * ContractOffer
 *
 * Contract.TermTerm.ContractOffer: The matter of concern in the context of this provision of the agrement.
 *
 * http://hl7.org/fhir/ContractOffer
 */
export declare const ContractOffer = "http://hl7.org/fhir/ContractOffer";
/**
 * composition
 *
 * DiagnosticReport.composition: Reference to a Composition resource instance that provides structure for organizing the contents of the DiagnosticReport.
 *
 * http://hl7.org/fhir/composition
 */
export declare const composition = "http://hl7.org/fhir/composition";
/**
 * _EnrollmentResponse
 *
 * (Modified) EnrollmentResponse
 *
 * http://hl7.org/fhir/_EnrollmentResponse
 */
export declare const _EnrollmentResponse = "http://hl7.org/fhir/_EnrollmentResponse";
/**
 * ConditionStageComponent
 *
 * ConditionStageComponent: A simple summary of the stage such as "Stage 3" or "Early Onset". The determination of the stage is disease-specific, such as cancer, retinopathy of prematurity, kidney diseases, Alzheimer's, or Parkinson disease.
 *
 * http://hl7.org/fhir/ConditionStageComponent
 */
export declare const ConditionStageComponent = "http://hl7.org/fhir/ConditionStageComponent";
/**
 * ResearchSubjectProgressComponent
 *
 * ResearchSubjectProgressComponent: The current state (status) of the subject and resons for status change where appropriate.
 *
 * http://hl7.org/fhir/ResearchSubjectProgressComponent
 */
export declare const ResearchSubjectProgressComponent = "http://hl7.org/fhir/ResearchSubjectProgressComponent";
/**
 * key
 *
 * ExampleScenario.instance.key: A unique string within the scenario that is used to reference the instance.
 *
 * http://hl7.org/fhir/key
 */
export declare const key = "http://hl7.org/fhir/key";
/**
 * assertion
 *
 * TestPlan.testCase.assertion: The test assertions - the expectations of test results from the execution of the test case.
 *
 * http://hl7.org/fhir/assertion
 */
export declare const assertion = "http://hl7.org/fhir/assertion";
/**
 * MedicationKnowledgeIndicationGuidelineDosingGuidelinePatientCharacteristicComponent
 *
 * MedicationKnowledgeIndicationGuidelineComponent.MedicationKnowledgeIndicationGuidelineDosingGuidelineComponent.MedicationKnowledgeIndicationGuidelineDosingGuidelinePatientCharacteristicComponent: Characteristics of the patient that are relevant to the administration guidelines (for example, height, weight, gender, etc.).
 *
 * http://hl7.org/fhir/MedicationKnowledgeIndicationGuidelineDosingGuidelinePatientCharacteristicComponent
 */
export declare const MedicationKnowledgeIndicationGuidelineDosingGuidelinePatientCharacteristicComponent = "http://hl7.org/fhir/MedicationKnowledgeIndicationGuidelineDosingGuidelinePatientCharacteristicComponent";
/**
 * alternative
 *
 * ExampleScenario.process.step.alternative: Indicates an alternative step that can be taken instead of the sub-process, scenario or operation.  E.g. to represent non-happy-path/exceptional/atypical circumstances.
 *
 * http://hl7.org/fhir/alternative
 */
export declare const alternative = "http://hl7.org/fhir/alternative";
/**
 * plan
 *
 * InsurancePlan.plan: Details about an insurance plan.
 *
 * http://hl7.org/fhir/plan
 */
export declare const plan = "http://hl7.org/fhir/plan";
/**
 * _criteria
 *
 * (Modified) Measure.supplementalData.criteria
 *
 * http://hl7.org/fhir/_criteria
 */
export declare const _criteria = "http://hl7.org/fhir/_criteria";
/**
 * cycle
 *
 * Device.cycle: The series of occurrences that repeats during the operation of the device.
 *
 * http://hl7.org/fhir/cycle
 */
export declare const cycle = "http://hl7.org/fhir/cycle";
/**
 * _latitude
 *
 * (Modified) Location.position.latitude
 *
 * http://hl7.org/fhir/_latitude
 */
export declare const _latitude = "http://hl7.org/fhir/_latitude";
/**
 * modifier
 *
 * SubscriptionTopic.canFilterBy.modifier: Modifiers allowed for the filter parameter.
 *
 * http://hl7.org/fhir/modifier
 */
export declare const modifier = "http://hl7.org/fhir/modifier";
/**
 * _scoringUnit
 *
 * (Modified) Measure.group.scoringUnit
 *
 * http://hl7.org/fhir/_scoringUnit
 */
export declare const _scoringUnit = "http://hl7.org/fhir/_scoringUnit";
/**
 * subJurisdiction
 *
 * DeviceDefinition.packaging.packaging.udiDeviceIdentifier.marketDistribution.subJurisdiction: National state or territory to which the marketDistribution recers, typically where the device is commercialized.
 *
 * http://hl7.org/fhir/subJurisdiction
 */
export declare const subJurisdiction = "http://hl7.org/fhir/subJurisdiction";
/**
 * _search
 *
 * (Modified) CompartmentDefinition.search
 *
 * http://hl7.org/fhir/_search
 */
export declare const _search = "http://hl7.org/fhir/_search";
/**
 * assignedComparisonGroup
 *
 * ResearchSubject.assignedComparisonGroup: The name of the arm in the study the subject is expected to follow as part of this study.
 *
 * http://hl7.org/fhir/assignedComparisonGroup
 */
export declare const assignedComparisonGroup = "http://hl7.org/fhir/assignedComparisonGroup";
/**
 * _alias
 *
 * (Modified) StructureMap.structure.alias
 *
 * http://hl7.org/fhir/_alias
 */
export declare const _alias = "http://hl7.org/fhir/_alias";
/**
 * _status
 *
 * (Modified) ActorDefinition.status
 *
 * http://hl7.org/fhir/_status
 */
export declare const _status = "http://hl7.org/fhir/_status";
/**
 * recurring
 *
 * AppointmentResponse.recurring: Indicates that this AppointmentResponse applies to all occurrences in a recurring request.
 *
 * http://hl7.org/fhir/recurring
 */
export declare const recurring = "http://hl7.org/fhir/recurring";
/**
 * InventoryItemInstanceComponent
 *
 * InventoryItemInstanceComponent: Instances or occurrences of the product.
 *
 * http://hl7.org/fhir/InventoryItemInstanceComponent
 */
export declare const InventoryItemInstanceComponent = "http://hl7.org/fhir/InventoryItemInstanceComponent";
/**
 * frameOfReferenceUid
 *
 * ImagingSelection.frameOfReferenceUid: The Frame of Reference UID identifying the coordinate system that conveys spatial and/or temporal information for the selected images or frames.
 *
 * http://hl7.org/fhir/frameOfReferenceUid
 */
export declare const frameOfReferenceUid = "http://hl7.org/fhir/frameOfReferenceUid";
/**
 * _validationDate
 *
 * (Modified) VerificationResult.primarySource.validationDate
 *
 * http://hl7.org/fhir/_validationDate
 */
export declare const _validationDate = "http://hl7.org/fhir/_validationDate";
/**
 * NutritionOrderEnteralFormulaComponent
 *
 * NutritionOrderEnteralFormulaComponent: Feeding provided through the gastrointestinal tract via a tube, catheter, or stoma that delivers nutrition distal to the oral cavity.
 *
 * http://hl7.org/fhir/NutritionOrderEnteralFormulaComponent
 */
export declare const NutritionOrderEnteralFormulaComponent = "http://hl7.org/fhir/NutritionOrderEnteralFormulaComponent";
/**
 * deliveryDevice
 *
 * NutritionOrder.enteralFormula.deliveryDevice: The intended type of device that is to be used for the administration of the enteral formula.
 *
 * http://hl7.org/fhir/deliveryDevice
 */
export declare const deliveryDevice = "http://hl7.org/fhir/deliveryDevice";
/**
 * _cardBrand
 *
 * (Modified) PaymentReconciliation.cardBrand
 *
 * http://hl7.org/fhir/_cardBrand
 */
export declare const _cardBrand = "http://hl7.org/fhir/_cardBrand";
/**
 * adjustment
 *
 * ExplanationOfBenefit.payment.adjustment: Total amount of all adjustments to this payment included in this transaction which are not related to this claim's adjudication.
 *
 * http://hl7.org/fhir/adjustment
 */
export declare const adjustment = "http://hl7.org/fhir/adjustment";
/**
 * _cors
 *
 * (Modified) CapabilityStatement.rest.security.cors
 *
 * http://hl7.org/fhir/_cors
 */
export declare const _cors = "http://hl7.org/fhir/_cors";
/**
 * _allergenicIndicator
 *
 * (Modified) Ingredient.allergenicIndicator
 *
 * http://hl7.org/fhir/_allergenicIndicator
 */
export declare const _allergenicIndicator = "http://hl7.org/fhir/_allergenicIndicator";
/**
 * _timezone
 *
 * (Modified) Appointment.recurrenceTemplate.timezone
 *
 * http://hl7.org/fhir/_timezone
 */
export declare const _timezone = "http://hl7.org/fhir/_timezone";
/**
 * _actor
 *
 * (Modified) Consent.provision.actor
 *
 * http://hl7.org/fhir/_actor
 */
export declare const _actor = "http://hl7.org/fhir/_actor";
/**
 * valueQuantity
 *
 * Evidence.statistic.modelCharacteristic.variable.valueQuantity: Discrete value for grouping of ordinal or polychotomous variables.
 *
 * http://hl7.org/fhir/valueQuantity
 */
export declare const valueQuantity = "http://hl7.org/fhir/valueQuantity";
/**
 * _versionId
 *
 * (Modified) Meta.versionId
 *
 * http://hl7.org/fhir/_versionId
 */
export declare const _versionId = "http://hl7.org/fhir/_versionId";
/**
 * requester
 *
 * SupplyRequest.requester: The device, practitioner, etc. who initiated the request.
 *
 * http://hl7.org/fhir/requester
 */
export declare const requester = "http://hl7.org/fhir/requester";
/**
 * _SupplyRequest
 *
 * (Modified) SupplyRequest
 *
 * http://hl7.org/fhir/_SupplyRequest
 */
export declare const _SupplyRequest = "http://hl7.org/fhir/_SupplyRequest";
/**
 * MeasureTermComponent
 *
 * MeasureTermComponent: Provides a description of an individual term used within the measure.
 *
 * http://hl7.org/fhir/MeasureTermComponent
 */
export declare const MeasureTermComponent = "http://hl7.org/fhir/MeasureTermComponent";
/**
 * _containedItemQuantity
 *
 * (Modified) PackagedProductDefinition.containedItemQuantity
 *
 * http://hl7.org/fhir/_containedItemQuantity
 */
export declare const _containedItemQuantity = "http://hl7.org/fhir/_containedItemQuantity";
/**
 * _daysSupply
 *
 * (Modified) MedicationDispense.daysSupply
 *
 * http://hl7.org/fhir/_daysSupply
 */
export declare const _daysSupply = "http://hl7.org/fhir/_daysSupply";
/**
 * reportingVendor
 *
 * MeasureReport.reportingVendor: A reference to the vendor who queried the data, calculated results and/or generated the report. The ‘reporting vendor’ is intended to represent the submitting entity when it is not the same as the reporting entity. This extension is used when the Receiver is interested in getting vendor information in the report.
 *
 * http://hl7.org/fhir/reportingVendor
 */
export declare const reportingVendor = "http://hl7.org/fhir/reportingVendor";
/**
 * current
 *
 * SubscriptionTopic.resourceTrigger.queryCriteria.current: The FHIR query based rules are applied to the current resource state (e.g., state after an update).
 *
 * http://hl7.org/fhir/current
 */
export declare const current = "http://hl7.org/fhir/current";
/**
 * uid
 *
 * ImagingStudy.series.instance.uid: The DICOM SOP Instance UID for this image or other DICOM content.
 *
 * http://hl7.org/fhir/uid
 */
export declare const uid = "http://hl7.org/fhir/uid";
/**
 * order
 *
 * SubstanceSourceMaterial.organism.organismGeneral.order: The order of an organism shall be specified,.
 *
 * http://hl7.org/fhir/order
 */
export declare const order = "http://hl7.org/fhir/order";
/**
 * priorPrescription
 *
 * MedicationRequest.priorPrescription: Reference to an order/prescription that is being replaced by this MedicationRequest.
 *
 * http://hl7.org/fhir/priorPrescription
 */
export declare const priorPrescription = "http://hl7.org/fhir/priorPrescription";
/**
 * distanceFromLandmark
 *
 * BodyStructure.excludedStructure.bodyLandmarkOrientation.distanceFromLandmark: The distance in centimeters a certain observation is made from a body landmark.
 *
 * http://hl7.org/fhir/distanceFromLandmark
 */
export declare const distanceFromLandmark = "http://hl7.org/fhir/distanceFromLandmark";
/**
 * VerificationResultValidatorComponent
 *
 * VerificationResultValidatorComponent: Information about the entity validating information.
 *
 * http://hl7.org/fhir/VerificationResultValidatorComponent
 */
export declare const VerificationResultValidatorComponent = "http://hl7.org/fhir/VerificationResultValidatorComponent";
/**
 * _recurrenceTemplate
 *
 * (Modified) Appointment.recurrenceTemplate
 *
 * http://hl7.org/fhir/_recurrenceTemplate
 */
export declare const _recurrenceTemplate = "http://hl7.org/fhir/_recurrenceTemplate";
/**
 * tenderedAmount
 *
 * PaymentReconciliation.tenderedAmount: The amount offered by the issuer, typically applies to cash when the issuer provides an amount in bank note denominations equal to or excess of the amount actually being paid.
 *
 * http://hl7.org/fhir/tenderedAmount
 */
export declare const tenderedAmount = "http://hl7.org/fhir/tenderedAmount";
/**
 * _diseaseStatus
 *
 * (Modified) ClinicalUseDefinition.indication.diseaseStatus
 *
 * http://hl7.org/fhir/_diseaseStatus
 */
export declare const _diseaseStatus = "http://hl7.org/fhir/_diseaseStatus";
/**
 * _expirationDate
 *
 * (Modified) PaymentReconciliation.expirationDate
 *
 * http://hl7.org/fhir/_expirationDate
 */
export declare const _expirationDate = "http://hl7.org/fhir/_expirationDate";
/**
 * _dataPeriod
 *
 * (Modified) Consent.provision.provision.dataPeriod
 *
 * http://hl7.org/fhir/_dataPeriod
 */
export declare const _dataPeriod = "http://hl7.org/fhir/_dataPeriod";
/**
 * note
 *
 * GenomicStudy.note: Comments related to the genomic study.
 *
 * http://hl7.org/fhir/note
 */
export declare const note = "http://hl7.org/fhir/note";
/**
 * _manipulated
 *
 * (Modified) Procedure.focalDevice.manipulated
 *
 * http://hl7.org/fhir/_manipulated
 */
export declare const _manipulated = "http://hl7.org/fhir/_manipulated";
/**
 * _Invoice
 *
 * (Modified) Invoice
 *
 * http://hl7.org/fhir/_Invoice
 */
export declare const _Invoice = "http://hl7.org/fhir/_Invoice";
/**
 * RatioRange
 *
 * A range of ratios expressed as a low and high numerator and a denominator.
 *
 * http://hl7.org/fhir/RatioRange
 */
export declare const RatioRange = "http://hl7.org/fhir/RatioRange";
/**
 * _requisition
 *
 * (Modified) ServiceRequest.requisition
 *
 * http://hl7.org/fhir/_requisition
 */
export declare const _requisition = "http://hl7.org/fhir/_requisition";
/**
 * ClinicalImpression
 *
 * A record of a clinical assessment performed to determine what problem(s) may affect the patient and before planning the treatments or management strategies that are best to manage a patient's condition. Assessments are often 1:1 with a clinical consultation / encounter,  but this varies greatly depending on the clinical workflow. This resource is called "ClinicalImpression" rather than "ClinicalAssessment" to avoid confusion with the recording of assessment tools such as Apgar score.
 *
 * http://hl7.org/fhir/ClinicalImpression
 */
export declare const ClinicalImpression = "http://hl7.org/fhir/ClinicalImpression";
/**
 * _claim
 *
 * (Modified) ExplanationOfBenefit.claim
 *
 * http://hl7.org/fhir/_claim
 */
export declare const _claim = "http://hl7.org/fhir/_claim";
/**
 * need
 *
 * VerificationResult.need: The frequency with which the target must be validated (none; initial; periodic).
 *
 * http://hl7.org/fhir/need
 */
export declare const need = "http://hl7.org/fhir/need";
/**
 * contributor
 *
 * Citation.citedArtifact.contributorship.entry.contributor: The identity of the individual contributor.
 *
 * http://hl7.org/fhir/contributor
 */
export declare const contributor = "http://hl7.org/fhir/contributor";
/**
 * ConceptProperty
 *
 * ValueSetExpansionComponent.ValueSetExpansionContainsComponent.ConceptProperty: A property value for this concept.
 *
 * http://hl7.org/fhir/ConceptProperty
 */
export declare const ConceptProperty = "http://hl7.org/fhir/ConceptProperty";
/**
 * ConsentVerificationComponent
 *
 * ConsentVerificationComponent: Whether a treatment instruction (e.g. artificial respiration: yes or no) was verified with the patient, his/her family or another authorized person.
 *
 * http://hl7.org/fhir/ConsentVerificationComponent
 */
export declare const ConsentVerificationComponent = "http://hl7.org/fhir/ConsentVerificationComponent";
/**
 * TestReportTeardownComponent
 *
 * TestReportTeardownComponent: The results of the series of operations required to clean up after all the tests were executed (successfully or otherwise).
 *
 * http://hl7.org/fhir/TestReportTeardownComponent
 */
export declare const TestReportTeardownComponent = "http://hl7.org/fhir/TestReportTeardownComponent";
/**
 * _genus
 *
 * (Modified) SubstanceSourceMaterial.organism.genus
 *
 * http://hl7.org/fhir/_genus
 */
export declare const _genus = "http://hl7.org/fhir/_genus";
/**
 * extraDetails
 *
 * HealthcareService.extraDetails: Extra details about the service that can't be placed in the other fields.
 *
 * http://hl7.org/fhir/extraDetails
 */
export declare const extraDetails = "http://hl7.org/fhir/extraDetails";
/**
 * _location
 *
 * (Modified) InventoryItem.instance.location
 *
 * http://hl7.org/fhir/_location
 */
export declare const _location = "http://hl7.org/fhir/_location";
/**
 * _reported
 *
 * (Modified) Procedure.reported
 *
 * http://hl7.org/fhir/_reported
 */
export declare const _reported = "http://hl7.org/fhir/_reported";
/**
 * _codeMap
 *
 * (Modified) SampledData.codeMap
 *
 * http://hl7.org/fhir/_codeMap
 */
export declare const _codeMap = "http://hl7.org/fhir/_codeMap";
/**
 * firstPage
 *
 * Citation.citedArtifact.publicationForm.firstPage: Used for isolated representation of first page.
 *
 * http://hl7.org/fhir/firstPage
 */
export declare const firstPage = "http://hl7.org/fhir/firstPage";
/**
 * _setup
 *
 * (Modified) TestScript.setup
 *
 * http://hl7.org/fhir/_setup
 */
export declare const _setup = "http://hl7.org/fhir/_setup";
/**
 * _paymentBy
 *
 * (Modified) Coverage.paymentBy
 *
 * http://hl7.org/fhir/_paymentBy
 */
export declare const _paymentBy = "http://hl7.org/fhir/_paymentBy";
/**
 * custodian
 *
 * DocumentReference.custodian: Identifies the organization or group who is responsible for ongoing maintenance of and access to the document.
 *
 * http://hl7.org/fhir/custodian
 */
export declare const custodian = "http://hl7.org/fhir/custodian";
/**
 * estimatedAge
 *
 * FamilyMemberHistory.estimatedAge: If true, indicates that the age value specified is an estimated value.
 *
 * http://hl7.org/fhir/estimatedAge
 */
export declare const estimatedAge = "http://hl7.org/fhir/estimatedAge";
/**
 * _observation
 *
 * (Modified) Observation.triggeredBy.observation
 *
 * http://hl7.org/fhir/_observation
 */
export declare const _observation = "http://hl7.org/fhir/_observation";
/**
 * technique
 *
 * SubstanceDefinition.structure.technique: The method used to elucidate the structure of the drug substance. Examples: X-ray, NMR, Peptide mapping, Ligand binding assay.
 *
 * http://hl7.org/fhir/technique
 */
export declare const technique = "http://hl7.org/fhir/technique";
/**
 * Requirements
 *
 * The Requirements resource is used to describe an actor - a human or an application that plays a role in data exchange, and that may have obligations associated with the role the actor plays.
 *
 * http://hl7.org/fhir/Requirements
 */
export declare const Requirements = "http://hl7.org/fhir/Requirements";
/**
 * supplementalData
 *
 * MeasureReport.supplementalData: A reference to a Resource that represents additional information collected for the report. If the value of the supplemental data is not a Resource (i.e. evaluating the supplementalData expression for this case in the measure results in a value that is not a FHIR Resource), it is reported as a reference to a contained Observation resource.
 *
 * http://hl7.org/fhir/supplementalData
 */
export declare const supplementalData = "http://hl7.org/fhir/supplementalData";
/**
 * SimpleQuantity
 *
 * The comparator is not used on a SimpleQuantity
 *
 * http://hl7.org/fhir/SimpleQuantity
 */
export declare const SimpleQuantity = "http://hl7.org/fhir/SimpleQuantity";
/**
 * ProvenanceEntityComponent
 *
 * ProvenanceEntityComponent: An entity used in this activity.
 *
 * http://hl7.org/fhir/ProvenanceEntityComponent
 */
export declare const ProvenanceEntityComponent = "http://hl7.org/fhir/ProvenanceEntityComponent";
/**
 * condition
 *
 * ObservationDefinition.component.qualifiedValue.condition: Text based condition for which the the set of qualified values is valid.
 *
 * http://hl7.org/fhir/condition
 */
export declare const condition = "http://hl7.org/fhir/condition";
/**
 * excludeFoodModifier
 *
 * NutritionOrder.excludeFoodModifier: This modifier is used to convey Order-specific modifier about the type of oral food or oral fluids that should not be given. These can be derived from patient allergies, intolerances, or preferences such as No Red Meat, No Soy or No Wheat or  Gluten-Free.  While it should not be necessary to repeat allergy or intolerance information captured in the referenced AllergyIntolerance resource in the excludeFoodModifier, this element may be used to convey additional specificity related to foods that should be eliminated from the patient’s diet for any reason.  This modifier applies to the entire nutrition order inclusive of the oral diet, nutritional supplements and enteral formula feedings.
 *
 * http://hl7.org/fhir/excludeFoodModifier
 */
export declare const excludeFoodModifier = "http://hl7.org/fhir/excludeFoodModifier";
/**
 * coverageArea
 *
 * InsurancePlan.plan.coverageArea: The geographic region in which a health insurance plan's benefits apply.
 *
 * http://hl7.org/fhir/coverageArea
 */
export declare const coverageArea = "http://hl7.org/fhir/coverageArea";
/**
 * contributionInstance
 *
 * Citation.citedArtifact.contributorship.entry.contributionInstance: Contributions with accounting for time or number.
 *
 * http://hl7.org/fhir/contributionInstance
 */
export declare const contributionInstance = "http://hl7.org/fhir/contributionInstance";
/**
 * _productCode
 *
 * (Modified) BiologicallyDerivedProduct.productCode
 *
 * http://hl7.org/fhir/_productCode
 */
export declare const _productCode = "http://hl7.org/fhir/_productCode";
/**
 * _language
 *
 * (Modified) Attachment.language
 *
 * http://hl7.org/fhir/_language
 */
export declare const _language = "http://hl7.org/fhir/_language";
/**
 * base
 *
 * VisionPrescription.lensSpecification.prism.base: The relative base, or reference lens edge, for the prism.
 *
 * http://hl7.org/fhir/base
 */
export declare const base = "http://hl7.org/fhir/base";
/**
 * _windowStart
 *
 * (Modified) MolecularSequence.relative.startingSequence.windowStart
 *
 * http://hl7.org/fhir/_windowStart
 */
export declare const _windowStart = "http://hl7.org/fhir/_windowStart";
/**
 * district
 *
 * Address.district: The name of the administrative area (county).
 *
 * http://hl7.org/fhir/district
 */
export declare const district = "http://hl7.org/fhir/district";
/**
 * forenameInitials
 *
 * Citation.citedArtifact.contributorship.entry.forenameInitials: For citation styles that use initials.
 *
 * http://hl7.org/fhir/forenameInitials
 */
export declare const forenameInitials = "http://hl7.org/fhir/forenameInitials";
/**
 * _state
 *
 * (Modified) ResearchStudy.progressStatus.state
 *
 * http://hl7.org/fhir/_state
 */
export declare const _state = "http://hl7.org/fhir/_state";
/**
 * friendly
 *
 * Contract.friendly: The "patient friendly language" versionof the Contract in whole or in parts. "Patient friendly language" means the representation of the Contract and Contract Provisions in a manner that is readily accessible and understandable by a layperson in accordance with best practices for communication styles that ensure that those agreeing to or signing the Contract understand the roles, actions, obligations, responsibilities, and implication of the agreement.
 *
 * http://hl7.org/fhir/friendly
 */
export declare const friendly = "http://hl7.org/fhir/friendly";
/**
 * AdditionalAttribute
 *
 * ConceptMap.AdditionalAttribute: An additionalAttribute defines an additional data element found in the source or target data model where the data will come from or be mapped to. Some mappings are based on data in addition to the source data element, where codes in multiple fields are combined to a single field (or vice versa).
 *
 * http://hl7.org/fhir/AdditionalAttribute
 */
export declare const AdditionalAttribute = "http://hl7.org/fhir/AdditionalAttribute";
/**
 * _Transport
 *
 * (Modified) Transport
 *
 * http://hl7.org/fhir/_Transport
 */
export declare const _Transport = "http://hl7.org/fhir/_Transport";
/**
 * xhtml
 *
 * http://hl7.org/fhir/xhtml
 */
export declare const xhtml = "http://hl7.org/fhir/xhtml";
/**
 * _official
 *
 * (Modified) SubstanceDefinition.name.official
 *
 * http://hl7.org/fhir/_official
 */
export declare const _official = "http://hl7.org/fhir/_official";
/**
 * CodeSystemConceptDesignationComponent
 *
 * CodeSystem.ConceptDefinition.CodeSystemConceptDesignationComponent: Additional representations for the concept - other languages, aliases, specialized purposes, used for particular purposes, etc.
 *
 * http://hl7.org/fhir/CodeSystemConceptDesignationComponent
 */
export declare const CodeSystemConceptDesignationComponent = "http://hl7.org/fhir/CodeSystemConceptDesignationComponent";
/**
 * _precedence
 *
 * (Modified) ExplanationOfBenefit.precedence
 *
 * http://hl7.org/fhir/_precedence
 */
export declare const _precedence = "http://hl7.org/fhir/_precedence";
/**
 * _result
 *
 * (Modified) TestPlan.testCase.assertion.result
 *
 * http://hl7.org/fhir/_result
 */
export declare const _result = "http://hl7.org/fhir/_result";
/**
 * _sliceName
 *
 * (Modified) GraphDefinition.link.sliceName
 *
 * http://hl7.org/fhir/_sliceName
 */
export declare const _sliceName = "http://hl7.org/fhir/_sliceName";
/**
 * points
 *
 * Contract.term.group.asset.valuedItem.points: An amount that expresses the weighting (based on difficulty, cost and/or resource intensiveness) associated with the Contract Valued Item delivered. The concept of Points allows for assignment of point values for a Contract Valued Item, such that a monetary amount can be assigned to each point.
 *
 * http://hl7.org/fhir/points
 */
export declare const points = "http://hl7.org/fhir/points";
/**
 * finding
 *
 * ClinicalImpression.finding: Specific findings or diagnoses that were considered likely or relevant to ongoing treatment.
 *
 * http://hl7.org/fhir/finding
 */
export declare const finding = "http://hl7.org/fhir/finding";
/**
 * _yearlyTemplate
 *
 * (Modified) Appointment.recurrenceTemplate.yearlyTemplate
 *
 * http://hl7.org/fhir/_yearlyTemplate
 */
export declare const _yearlyTemplate = "http://hl7.org/fhir/_yearlyTemplate";
/**
 * _isModifierReason
 *
 * (Modified) ElementDefinition.isModifierReason
 *
 * http://hl7.org/fhir/_isModifierReason
 */
export declare const _isModifierReason = "http://hl7.org/fhir/_isModifierReason";
/**
 * _experimental
 *
 * (Modified) StructureDefinition.experimental
 *
 * http://hl7.org/fhir/_experimental
 */
export declare const _experimental = "http://hl7.org/fhir/_experimental";
/**
 * _overbooked
 *
 * (Modified) Slot.overbooked
 *
 * http://hl7.org/fhir/_overbooked
 */
export declare const _overbooked = "http://hl7.org/fhir/_overbooked";
/**
 * ExampleScenario
 *
 * A walkthrough of a workflow showing the interaction between systems and the instances shared, possibly including the evolution of instances over time.
 *
 * http://hl7.org/fhir/ExampleScenario
 */
export declare const ExampleScenario = "http://hl7.org/fhir/ExampleScenario";
/**
 * AvailabilityNotAvailableTimeComponent
 *
 * AvailabilityNotAvailableTimeComponent: Not available during this time due to provided reason.
 *
 * http://hl7.org/fhir/AvailabilityNotAvailableTimeComponent
 */
export declare const AvailabilityNotAvailableTimeComponent = "http://hl7.org/fhir/AvailabilityNotAvailableTimeComponent";
/**
 * derivedFrom
 *
 * DeviceUsage.derivedFrom: Allows linking the DeviceUsage to the underlying Request, or to other information that supports or is used to derive the DeviceUsage.
 *
 * http://hl7.org/fhir/derivedFrom
 */
export declare const derivedFrom = "http://hl7.org/fhir/derivedFrom";
/**
 * _postalCode
 *
 * (Modified) Address.postalCode
 *
 * http://hl7.org/fhir/_postalCode
 */
export declare const _postalCode = "http://hl7.org/fhir/_postalCode";
/**
 * _endorser
 *
 * (Modified) EvidenceVariable.endorser
 *
 * http://hl7.org/fhir/_endorser
 */
export declare const _endorser = "http://hl7.org/fhir/_endorser";
/**
 * modifierExtension
 *
 * DomainResource.modifierExtension: May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and managable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.
 *
 * Modifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself).
 *
 * http://hl7.org/fhir/modifierExtension
 */
export declare const modifierExtension = "http://hl7.org/fhir/modifierExtension";
/**
 * verified
 *
 * Consent.verification.verified: Has the instruction been verified.
 *
 * http://hl7.org/fhir/verified
 */
export declare const verified = "http://hl7.org/fhir/verified";
/**
 * warning
 *
 * DeviceDefinition.guideline.warning: Specific hazard alert information that a user needs to know before using the device.
 *
 * http://hl7.org/fhir/warning
 */
export declare const warning = "http://hl7.org/fhir/warning";
/**
 * _color
 *
 * (Modified) VisionPrescription.lensSpecification.color
 *
 * http://hl7.org/fhir/_color
 */
export declare const _color = "http://hl7.org/fhir/_color";
/**
 * _global
 *
 * (Modified) ImplementationGuide.global
 *
 * http://hl7.org/fhir/_global
 */
export declare const _global = "http://hl7.org/fhir/_global";
/**
 * _policyBasis
 *
 * (Modified) Consent.policyBasis
 *
 * http://hl7.org/fhir/_policyBasis
 */
export declare const _policyBasis = "http://hl7.org/fhir/_policyBasis";
/**
 * timeFromEvent
 *
 * EvidenceVariable.characteristic.timeFromEvent: Timing in which the characteristic is determined.
 *
 * http://hl7.org/fhir/timeFromEvent
 */
export declare const timeFromEvent = "http://hl7.org/fhir/timeFromEvent";
/**
 * costToBeneficiary
 *
 * Coverage.costToBeneficiary: A suite of codes indicating the cost category and associated amount which have been detailed in the policy and may have been  included on the health card.
 *
 * http://hl7.org/fhir/costToBeneficiary
 */
export declare const costToBeneficiary = "http://hl7.org/fhir/costToBeneficiary";
/**
 * Questionnaire
 *
 * A structured set of questions intended to guide the collection of answers from end-users. Questionnaires provide detailed control over order, presentation, phraseology and grouping to allow coherent, consistent data collection.
 *
 * http://hl7.org/fhir/Questionnaire
 */
export declare const Questionnaire = "http://hl7.org/fhir/Questionnaire";
/**
 * _FormularyItem
 *
 * (Modified) FormularyItem
 *
 * http://hl7.org/fhir/_FormularyItem
 */
export declare const _FormularyItem = "http://hl7.org/fhir/_FormularyItem";
/**
 * _permittedUnit
 *
 * (Modified) ObservationDefinition.component.permittedUnit
 *
 * http://hl7.org/fhir/_permittedUnit
 */
export declare const _permittedUnit = "http://hl7.org/fhir/_permittedUnit";
/**
 * data
 *
 * Signature.data: The base64 encoding of the Signature content. When signature is not recorded electronically this element would be empty.
 *
 * http://hl7.org/fhir/data
 */
export declare const data = "http://hl7.org/fhir/data";
/**
 * _targetItem
 *
 * (Modified) PaymentReconciliation.allocation.targetItem
 *
 * http://hl7.org/fhir/_targetItem
 */
export declare const _targetItem = "http://hl7.org/fhir/_targetItem";
/**
 * whyStopped
 *
 * ResearchStudy.whyStopped: A description and/or code explaining the premature termination of the study.
 *
 * http://hl7.org/fhir/whyStopped
 */
export declare const whyStopped = "http://hl7.org/fhir/whyStopped";
/**
 * _practitioner
 *
 * (Modified) PractitionerRole.practitioner
 *
 * http://hl7.org/fhir/_practitioner
 */
export declare const _practitioner = "http://hl7.org/fhir/_practitioner";
/**
 * packageFor
 *
 * PackagedProductDefinition.packageFor: The product this package model relates to, not the contents of the package (for which see package.containedItem).
 *
 * http://hl7.org/fhir/packageFor
 */
export declare const packageFor = "http://hl7.org/fhir/packageFor";
/**
 * _informationSource
 *
 * (Modified) SubstanceDefinition.informationSource
 *
 * http://hl7.org/fhir/_informationSource
 */
export declare const _informationSource = "http://hl7.org/fhir/_informationSource";
/**
 * hasMember
 *
 * ObservationDefinition.hasMember: This ObservationDefinition defines a group  observation (e.g. a battery, a panel of tests, a set of vital sign measurements) that includes the target as a member of the group.
 *
 * http://hl7.org/fhir/hasMember
 */
export declare const hasMember = "http://hl7.org/fhir/hasMember";
/**
 * _paymentIdentifier
 *
 * (Modified) PaymentReconciliation.paymentIdentifier
 *
 * http://hl7.org/fhir/_paymentIdentifier
 */
export declare const _paymentIdentifier = "http://hl7.org/fhir/_paymentIdentifier";
/**
 * allowedType
 *
 * OperationDefinition.parameter.part.allowedType: Support for polymorphic types. If the parameter type is abstract, this element lists allowed sub-types for the parameter.
 *
 * http://hl7.org/fhir/allowedType
 */
export declare const allowedType = "http://hl7.org/fhir/allowedType";
/**
 * _intraspecificType
 *
 * (Modified) SubstanceSourceMaterial.organism.intraspecificType
 *
 * http://hl7.org/fhir/_intraspecificType
 */
export declare const _intraspecificType = "http://hl7.org/fhir/_intraspecificType";
/**
 * _isDefault
 *
 * (Modified) TerminologyCapabilities.codeSystem.version.isDefault
 *
 * http://hl7.org/fhir/_isDefault
 */
export declare const _isDefault = "http://hl7.org/fhir/_isDefault";
/**
 * _supportedProfile
 *
 * (Modified) CapabilityStatement.rest.resource.supportedProfile
 *
 * http://hl7.org/fhir/_supportedProfile
 */
export declare const _supportedProfile = "http://hl7.org/fhir/_supportedProfile";
/**
 * _authored
 *
 * (Modified) QuestionnaireResponse.authored
 *
 * http://hl7.org/fhir/_authored
 */
export declare const _authored = "http://hl7.org/fhir/_authored";
/**
 * stabilityDuration
 *
 * MedicationKnowledge.storageGuideline.stabilityDuration: Duration that the medication remains stable if the environmentalSetting is respected.
 *
 * http://hl7.org/fhir/stabilityDuration
 */
export declare const stabilityDuration = "http://hl7.org/fhir/stabilityDuration";
/**
 * InsurancePlanCoverageBenefitLimitComponent
 *
 * InsurancePlanCoverageComponent.CoverageBenefit.InsurancePlanCoverageBenefitLimitComponent: The specific limits on the benefit.
 *
 * http://hl7.org/fhir/InsurancePlanCoverageBenefitLimitComponent
 */
export declare const InsurancePlanCoverageBenefitLimitComponent = "http://hl7.org/fhir/InsurancePlanCoverageBenefitLimitComponent";
/**
 * compareToSourcePath
 *
 * TestScript.test.action.assert.compareToSourcePath: XPath or JSONPath expression to evaluate against the source fixture. When compareToSourceId is defined, either compareToSourceExpression or compareToSourcePath must be defined, but not both.
 *
 * http://hl7.org/fhir/compareToSourcePath
 */
export declare const compareToSourcePath = "http://hl7.org/fhir/compareToSourcePath";
/**
 * _dosageInstruction
 *
 * (Modified) MedicationRequest.dosageInstruction
 *
 * http://hl7.org/fhir/_dosageInstruction
 */
export declare const _dosageInstruction = "http://hl7.org/fhir/_dosageInstruction";
/**
 * sequence
 *
 * SubstanceNucleicAcid.subunit.sequence: Actual nucleotide sequence notation from 5' to 3' end using standard single letter codes. In addition to the base sequence, sugar and type of phosphate or non-phosphate linkage should also be captured.
 *
 * http://hl7.org/fhir/sequence
 */
export declare const sequence = "http://hl7.org/fhir/sequence";
/**
 * revenue
 *
 * ExplanationOfBenefit.item.revenue: The type of revenue or cost center providing the product and/or service.
 *
 * http://hl7.org/fhir/revenue
 */
export declare const revenue = "http://hl7.org/fhir/revenue";
/**
 * SystemInteraction
 *
 * CapabilityStatementRestComponent.SystemInteraction: A specification of restful operations supported by the system.
 *
 * http://hl7.org/fhir/SystemInteraction
 */
export declare const SystemInteraction = "http://hl7.org/fhir/SystemInteraction";
/**
 * SubscriptionFilterByComponent
 *
 * SubscriptionFilterByComponent: The filter properties to be applied to narrow the subscription topic stream.  When multiple filters are applied, evaluates to true if all the conditions applicable to that resource are met; otherwise it returns false (i.e., logical AND).
 *
 * http://hl7.org/fhir/SubscriptionFilterByComponent
 */
export declare const SubscriptionFilterByComponent = "http://hl7.org/fhir/SubscriptionFilterByComponent";
/**
 * _requirement
 *
 * (Modified) TestReport.setup.action.assert.requirement
 *
 * http://hl7.org/fhir/_requirement
 */
export declare const _requirement = "http://hl7.org/fhir/_requirement";
/**
 * _reliableCache
 *
 * (Modified) CapabilityStatement.messaging.reliableCache
 *
 * http://hl7.org/fhir/_reliableCache
 */
export declare const _reliableCache = "http://hl7.org/fhir/_reliableCache";
/**
 * nextScheduled
 *
 * VerificationResult.nextScheduled: The date when target is next validated, if appropriate.
 *
 * http://hl7.org/fhir/nextScheduled
 */
export declare const nextScheduled = "http://hl7.org/fhir/nextScheduled";
/**
 * MeasureGroupComponent
 *
 * MeasureGroupComponent: A group of population criteria for the measure.
 *
 * http://hl7.org/fhir/MeasureGroupComponent
 */
export declare const MeasureGroupComponent = "http://hl7.org/fhir/MeasureGroupComponent";
/**
 * processNote
 *
 * PaymentReconciliation.processNote: A note that describes or explains the processing in a human readable form.
 *
 * http://hl7.org/fhir/processNote
 */
export declare const processNote = "http://hl7.org/fhir/processNote";
/**
 * StratifierGroupPopulation
 *
 * MeasureReportGroupComponent.MeasureReportGroupStratifierComponent.StratifierGroup.StratifierGroupPopulation: The populations that make up the stratum, one for each type of population appropriate to the measure.
 *
 * http://hl7.org/fhir/StratifierGroupPopulation
 */
export declare const StratifierGroupPopulation = "http://hl7.org/fhir/StratifierGroupPopulation";
/**
 * issuerType
 *
 * PaymentReconciliation.issuerType: The type of the source such as patient or insurance.
 *
 * http://hl7.org/fhir/issuerType
 */
export declare const issuerType = "http://hl7.org/fhir/issuerType";
/**
 * capacity
 *
 * SpecimenDefinition.typeTested.container.capacity: The capacity (volume or other measure) of this kind of container.
 *
 * http://hl7.org/fhir/capacity
 */
export declare const capacity = "http://hl7.org/fhir/capacity";
/**
 * _rendering
 *
 * (Modified) ImplementationGuide.manifest.rendering
 *
 * http://hl7.org/fhir/_rendering
 */
export declare const _rendering = "http://hl7.org/fhir/_rendering";
/**
 * TestScriptTeardownComponent
 *
 * TestScriptTeardownComponent: A series of operations required to clean up after all the tests are executed (successfully or otherwise).
 *
 * http://hl7.org/fhir/TestScriptTeardownComponent
 */
export declare const TestScriptTeardownComponent = "http://hl7.org/fhir/TestScriptTeardownComponent";
/**
 * requestIdentifier
 *
 * GuidanceResponse.requestIdentifier: The identifier of the request associated with this response. If an identifier was given as part of the request, it will be reproduced here to enable the requester to more easily identify the response in a multi-request scenario.
 *
 * http://hl7.org/fhir/requestIdentifier
 */
export declare const requestIdentifier = "http://hl7.org/fhir/requestIdentifier";
/**
 * _definitionCanonical
 *
 * (Modified) EvidenceVariable.characteristic.definitionByCombination.characteristic.definitionCanonical
 *
 * http://hl7.org/fhir/_definitionCanonical
 */
export declare const _definitionCanonical = "http://hl7.org/fhir/_definitionCanonical";
/**
 * fhir:v
 *
 * http://hl7.org/fhir/v
 */
export declare const v = "http://hl7.org/fhir/v";
/**
 * _classification
 *
 * (Modified) Citation.classification
 *
 * http://hl7.org/fhir/_classification
 */
export declare const _classification = "http://hl7.org/fhir/_classification";
/**
 * Claim
 *
 * A provider issued list of professional services and products which have been provided, or are to be provided, to a patient which is sent to an insurer for reimbursement.
 *
 * http://hl7.org/fhir/Claim
 */
export declare const Claim = "http://hl7.org/fhir/Claim";
/**
 * asNeeded
 *
 * PlanDefinition.asNeeded
 *
 * http://hl7.org/fhir/asNeeded
 */
export declare const asNeeded = "http://hl7.org/fhir/asNeeded";
/**
 * defaultManualCompletion
 *
 * TestScript.test.action.assert.defaultManualCompletion: The default manual completion outcome applied to this assertion.
 *
 * http://hl7.org/fhir/defaultManualCompletion
 */
export declare const defaultManualCompletion = "http://hl7.org/fhir/defaultManualCompletion";
/**
 * partDescription
 *
 * SubstanceSourceMaterial.partDescription: To do.
 *
 * http://hl7.org/fhir/partDescription
 */
export declare const partDescription = "http://hl7.org/fhir/partDescription";
/**
 * articleDate
 *
 * Citation.citedArtifact.publicationForm.articleDate: The date the article was added to the database, or the date the article was released.
 *
 * http://hl7.org/fhir/articleDate
 */
export declare const articleDate = "http://hl7.org/fhir/articleDate";
/**
 * narrative
 *
 * TestPlan.testCase.testRun.narrative: The narrative description of the tests.
 *
 * http://hl7.org/fhir/narrative
 */
export declare const narrative = "http://hl7.org/fhir/narrative";
/**
 * participant
 *
 * AllergyIntolerance.participant: Indicates who or what participated in the activities related to the allergy or intolerance and how they were involved.
 *
 * http://hl7.org/fhir/participant
 */
export declare const participant = "http://hl7.org/fhir/participant";
/**
 * incidence
 *
 * ClinicalUseDefinition.interaction.incidence: The incidence of the interaction, e.g. theoretical, observed.
 *
 * http://hl7.org/fhir/incidence
 */
export declare const incidence = "http://hl7.org/fhir/incidence";
/**
 * div
 *
 * Narrative.div: The actual narrative content, a stripped down version of XHTML.
 *
 * http://hl7.org/fhir/div
 */
export declare const div = "http://hl7.org/fhir/div";
/**
 * _versioning
 *
 * (Modified) CapabilityStatement.rest.resource.versioning
 *
 * http://hl7.org/fhir/_versioning
 */
export declare const _versioning = "http://hl7.org/fhir/_versioning";
/**
 * RelatedClaim
 *
 * ExplanationOfBenefit.RelatedClaim: Other claims which are related to this claim such as prior submissions or claims for related services or for the same event.
 *
 * http://hl7.org/fhir/RelatedClaim
 */
export declare const RelatedClaim = "http://hl7.org/fhir/RelatedClaim";
/**
 * _page
 *
 * (Modified) ImplementationGuide.manifest.page
 *
 * http://hl7.org/fhir/_page
 */
export declare const _page = "http://hl7.org/fhir/_page";
/**
 * appointment
 *
 * Encounter.appointment: The appointment that scheduled this encounter.
 *
 * http://hl7.org/fhir/appointment
 */
export declare const appointment = "http://hl7.org/fhir/appointment";
/**
 * AuditEventEntityDetailComponent
 *
 * AuditEventEntityComponent.AuditEventEntityDetailComponent: Tagged value pairs for conveying additional information about the entity.
 *
 * http://hl7.org/fhir/AuditEventEntityDetailComponent
 */
export declare const AuditEventEntityDetailComponent = "http://hl7.org/fhir/AuditEventEntityDetailComponent";
/**
 * productionIdentifierInUDI
 *
 * DeviceDefinition.productionIdentifierInUDI: Indicates the production identifier(s) that are expected to appear in the UDI carrier on the device label.
 *
 * http://hl7.org/fhir/productionIdentifierInUDI
 */
export declare const productionIdentifierInUDI = "http://hl7.org/fhir/productionIdentifierInUDI";
/**
 * _photo
 *
 * (Modified) RelatedPerson.photo
 *
 * http://hl7.org/fhir/_photo
 */
export declare const _photo = "http://hl7.org/fhir/_photo";
/**
 * formOf
 *
 * AdministrableProductDefinition.formOf: References a product from which one or more of the constituent parts of that product can be prepared and used as described by this administrable product.  If this administrable product describes the administration of a crushed tablet, the 'formOf' would be the product representing a distribution containing tablets and possibly also a cream.  This is distinct from the 'producedFrom' which refers to the specific components of the product that are used in this preparation, rather than the product as a whole.
 *
 * http://hl7.org/fhir/formOf
 */
export declare const formOf = "http://hl7.org/fhir/formOf";
/**
 * referrer
 *
 * ImagingStudy.referrer: The requesting/referring physician.
 *
 * http://hl7.org/fhir/referrer
 */
export declare const referrer = "http://hl7.org/fhir/referrer";
/**
 * _subdetailSequence
 *
 * (Modified) ClaimResponse.addItem.subdetailSequence
 *
 * http://hl7.org/fhir/_subdetailSequence
 */
export declare const _subdetailSequence = "http://hl7.org/fhir/_subdetailSequence";
/**
 * CareTeamParticipantComponent
 *
 * CareTeamParticipantComponent: Identifies all people and organizations who are expected to be involved in the care team.
 *
 * http://hl7.org/fhir/CareTeamParticipantComponent
 */
export declare const CareTeamParticipantComponent = "http://hl7.org/fhir/CareTeamParticipantComponent";
/**
 * SpecimenDefinition
 *
 * A kind of specimen with associated set of requirements.
 *
 * http://hl7.org/fhir/SpecimenDefinition
 */
export declare const SpecimenDefinition = "http://hl7.org/fhir/SpecimenDefinition";
/**
 * _affectsState
 *
 * (Modified) OperationDefinition.affectsState
 *
 * http://hl7.org/fhir/_affectsState
 */
export declare const _affectsState = "http://hl7.org/fhir/_affectsState";
/**
 * _inputPopulationId
 *
 * (Modified) Measure.group.population.inputPopulationId
 *
 * http://hl7.org/fhir/_inputPopulationId
 */
export declare const _inputPopulationId = "http://hl7.org/fhir/_inputPopulationId";
/**
 * outputProfile
 *
 * OperationDefinition.outputProfile: Additional validation information for the out parameters - a single profile that covers all the parameters. The profile is a constraint on the parameters resource.
 *
 * http://hl7.org/fhir/outputProfile
 */
export declare const outputProfile = "http://hl7.org/fhir/outputProfile";
/**
 * MessageDefinitionAllowedResponseComponent
 *
 * MessageDefinitionAllowedResponseComponent: Indicates what types of messages may be sent as an application-level response to this message.
 *
 * http://hl7.org/fhir/MessageDefinitionAllowedResponseComponent
 */
export declare const MessageDefinitionAllowedResponseComponent = "http://hl7.org/fhir/MessageDefinitionAllowedResponseComponent";
/**
 * numberOfInstances
 *
 * ImagingStudy.series.numberOfInstances: Number of SOP Instances in the Study. The value given may be larger than the number of instance elements this resource contains due to resource availability, security, or other factors. This element should be present if any instance elements are present.
 *
 * http://hl7.org/fhir/numberOfInstances
 */
export declare const numberOfInstances = "http://hl7.org/fhir/numberOfInstances";
/**
 * Term
 *
 * Contract.Term: One or more Contract Provisions, which may be related and conveyed as a group, and may contain nested groups.
 *
 * http://hl7.org/fhir/Term
 */
export declare const Term = "http://hl7.org/fhir/Term";
/**
 * supportingImmunization
 *
 * ImmunizationRecommendation.recommendation.supportingImmunization: Immunization event history and/or evaluation that supports the status and recommendation.
 *
 * http://hl7.org/fhir/supportingImmunization
 */
export declare const supportingImmunization = "http://hl7.org/fhir/supportingImmunization";
/**
 * previousAppointment
 *
 * Appointment.previousAppointment: The previous appointment in a series of related appointments.
 *
 * http://hl7.org/fhir/previousAppointment
 */
export declare const previousAppointment = "http://hl7.org/fhir/previousAppointment";
/**
 * seriesDoses
 *
 * ImmunizationRecommendation.recommendation.seriesDoses: The recommended number of doses to achieve immunity as determined by the evaluation and forecasting process.
 *
 * http://hl7.org/fhir/seriesDoses
 */
export declare const seriesDoses = "http://hl7.org/fhir/seriesDoses";
/**
 * propertyGroup
 *
 * ChargeItemDefinition.propertyGroup: Group of properties which are applicable under the same conditions. If no applicability rules are established for the group, then all properties always apply.
 *
 * http://hl7.org/fhir/propertyGroup
 */
export declare const propertyGroup = "http://hl7.org/fhir/propertyGroup";
/**
 * option
 *
 * PlanDefinition.actor.option: The characteristics of the candidates that could serve as the actor.
 *
 * http://hl7.org/fhir/option
 */
export declare const option = "http://hl7.org/fhir/option";
/**
 * component
 *
 * ArtifactAssessment.content.component.component: If the informationType is container, the components of the content.
 *
 * http://hl7.org/fhir/component
 */
export declare const component = "http://hl7.org/fhir/component";
/**
 * offset
 *
 * Timing.repeat.offset: The number of minutes from the event. If the event code does not indicate whether the minutes is before or after the event, then the offset is assumed to be after the event.
 *
 * http://hl7.org/fhir/offset
 */
export declare const offset = "http://hl7.org/fhir/offset";
/**
 * materialType
 *
 * SubstanceSourceMaterial.fractionDescription.materialType: The specific type of the material constituting the component. For Herbal preparations the particulars of the extracts (liquid/dry) is described in Specified Substance Group 1.
 *
 * http://hl7.org/fhir/materialType
 */
export declare const materialType = "http://hl7.org/fhir/materialType";
/**
 * marketingAuthorizationHolder
 *
 * Medication.marketingAuthorizationHolder: The company or other legal entity that has authorization, from the appropriate drug regulatory authority,  to market a medicine in one or more jurisdictions.  Typically abbreviated MAH.Note:  The MAH may manufacture the product and may also contract the manufacturing of the product to one or more companies (organizations).
 *
 * http://hl7.org/fhir/marketingAuthorizationHolder
 */
export declare const marketingAuthorizationHolder = "http://hl7.org/fhir/marketingAuthorizationHolder";
/**
 * requestedPerformer
 *
 * Task.requestedPerformer: The kind of participant or specific participant that should perform the task.
 *
 * http://hl7.org/fhir/requestedPerformer
 */
export declare const requestedPerformer = "http://hl7.org/fhir/requestedPerformer";
/**
 * developmentStage
 *
 * SubstanceSourceMaterial.developmentStage: Stage of life for animals, plants, insects and microorganisms. This information shall be provided only when the substance is significantly different in these stages (e.g. foetal bovine serum).
 *
 * http://hl7.org/fhir/developmentStage
 */
export declare const developmentStage = "http://hl7.org/fhir/developmentStage";
/**
 * _deliveryDevice
 *
 * (Modified) NutritionOrder.enteralFormula.deliveryDevice
 *
 * http://hl7.org/fhir/_deliveryDevice
 */
export declare const _deliveryDevice = "http://hl7.org/fhir/_deliveryDevice";
/**
 * _Timing
 *
 * (Modified) Timing
 *
 * http://hl7.org/fhir/_Timing
 */
export declare const _Timing = "http://hl7.org/fhir/_Timing";
/**
 * AdverseEventSuspectEntityCausalityComponent
 *
 * AdverseEventSuspectEntityComponent.AdverseEventSuspectEntityCausalityComponent: Information on the possible cause of the event.
 *
 * http://hl7.org/fhir/AdverseEventSuspectEntityCausalityComponent
 */
export declare const AdverseEventSuspectEntityCausalityComponent = "http://hl7.org/fhir/AdverseEventSuspectEntityCausalityComponent";
/**
 * add
 *
 * VisionPrescription.lensSpecification.add: Power adjustment for multifocal lenses measured in dioptres (0.25 units).
 *
 * http://hl7.org/fhir/add
 */
export declare const add = "http://hl7.org/fhir/add";
/**
 * ImmunizationPerformerComponent
 *
 * ImmunizationPerformerComponent: Indicates who performed the immunization event.
 *
 * http://hl7.org/fhir/ImmunizationPerformerComponent
 */
export declare const ImmunizationPerformerComponent = "http://hl7.org/fhir/ImmunizationPerformerComponent";
/**
 * _BodyStructure
 *
 * (Modified) BodyStructure
 *
 * http://hl7.org/fhir/_BodyStructure
 */
export declare const _BodyStructure = "http://hl7.org/fhir/_BodyStructure";
/**
 * _organismName
 *
 * (Modified) SubstanceSourceMaterial.organismName
 *
 * http://hl7.org/fhir/_organismName
 */
export declare const _organismName = "http://hl7.org/fhir/_organismName";
/**
 * _monthlyTemplate
 *
 * (Modified) Appointment.recurrenceTemplate.monthlyTemplate
 *
 * http://hl7.org/fhir/_monthlyTemplate
 */
export declare const _monthlyTemplate = "http://hl7.org/fhir/_monthlyTemplate";
/**
 * versionAlgorithm
 *
 * ObservationDefinition.versionAlgorithm
 *
 * http://hl7.org/fhir/versionAlgorithm
 */
export declare const versionAlgorithm = "http://hl7.org/fhir/versionAlgorithm";
/**
 * _deliverFor
 *
 * (Modified) SupplyRequest.deliverFor
 *
 * http://hl7.org/fhir/_deliverFor
 */
export declare const _deliverFor = "http://hl7.org/fhir/_deliverFor";
/**
 * ElementDefinitionSlicingComponent
 *
 * ElementDefinitionSlicingComponent: Indicates that the element is sliced into a set of alternative definitions (i.e. in a structure definition, there are multiple different constraints on a single element in the base resource). Slicing can be used in any resource that has cardinality ..* on the base resource, or any resource with a choice of types. The set of slices is any elements that come after this in the element sequence that have the same path, until a shorter path occurs (the shorter path terminates the set).
 *
 * http://hl7.org/fhir/ElementDefinitionSlicingComponent
 */
export declare const ElementDefinitionSlicingComponent = "http://hl7.org/fhir/ElementDefinitionSlicingComponent";
/**
 * _responseId
 *
 * (Modified) TestScript.teardown.action.operation.responseId
 *
 * http://hl7.org/fhir/_responseId
 */
export declare const _responseId = "http://hl7.org/fhir/_responseId";
/**
 * _tenderedAmount
 *
 * (Modified) PaymentReconciliation.tenderedAmount
 *
 * http://hl7.org/fhir/_tenderedAmount
 */
export declare const _tenderedAmount = "http://hl7.org/fhir/_tenderedAmount";
/**
 * upperLimit
 *
 * SampledData.upperLimit: The upper limit of detection of the measured points. This is needed if any of the data points have the value "U" (higher than detection limit).
 *
 * http://hl7.org/fhir/upperLimit
 */
export declare const upperLimit = "http://hl7.org/fhir/upperLimit";
/**
 * _verificationStatus
 *
 * (Modified) Condition.verificationStatus
 *
 * http://hl7.org/fhir/_verificationStatus
 */
export declare const _verificationStatus = "http://hl7.org/fhir/_verificationStatus";
/**
 * amountType
 *
 * SubstanceReferenceInformation.target.amountType: Todo.
 *
 * http://hl7.org/fhir/amountType
 */
export declare const amountType = "http://hl7.org/fhir/amountType";
/**
 * _patientPaid
 *
 * (Modified) ExplanationOfBenefit.addItem.detail.subDetail.patientPaid
 *
 * http://hl7.org/fhir/_patientPaid
 */
export declare const _patientPaid = "http://hl7.org/fhir/_patientPaid";
/**
 * RequestOrchestrationActionOutputComponent
 *
 * RequestOrchestrationActionComponentAction.RequestOrchestrationActionOutputComponent: Defines the outputs of the action, if any.
 *
 * http://hl7.org/fhir/RequestOrchestrationActionOutputComponent
 */
export declare const RequestOrchestrationActionOutputComponent = "http://hl7.org/fhir/RequestOrchestrationActionOutputComponent";
/**
 * _quantity
 *
 * (Modified) Contract.term.group.asset.valuedItem.quantity
 *
 * http://hl7.org/fhir/_quantity
 */
export declare const _quantity = "http://hl7.org/fhir/_quantity";
/**
 * InsurancePlanPlanSpecificCostBenefitCostComponent
 *
 * InsurancePlanPlanComponent.InsurancePlanPlanSpecificCostComponent.PlanBenefit.InsurancePlanPlanSpecificCostBenefitCostComponent: List of the costs associated with a specific benefit.
 *
 * http://hl7.org/fhir/InsurancePlanPlanSpecificCostBenefitCostComponent
 */
export declare const InsurancePlanPlanSpecificCostBenefitCostComponent = "http://hl7.org/fhir/InsurancePlanPlanSpecificCostBenefitCostComponent";
/**
 * _alternate
 *
 * (Modified) DeviceDefinition.material.alternate
 *
 * http://hl7.org/fhir/_alternate
 */
export declare const _alternate = "http://hl7.org/fhir/_alternate";
/**
 * _contributingFactor
 *
 * (Modified) AdverseEvent.contributingFactor
 *
 * http://hl7.org/fhir/_contributingFactor
 */
export declare const _contributingFactor = "http://hl7.org/fhir/_contributingFactor";
/**
 * _sourceIdentityCertificate
 *
 * (Modified) VerificationResult.attestation.sourceIdentityCertificate
 *
 * http://hl7.org/fhir/_sourceIdentityCertificate
 */
export declare const _sourceIdentityCertificate = "http://hl7.org/fhir/_sourceIdentityCertificate";
/**
 * eventNumber
 *
 * SubscriptionStatus.notificationEvent.eventNumber: Either the sequential number of this event in this subscription context or a relative event number for this notification.
 *
 * http://hl7.org/fhir/eventNumber
 */
export declare const eventNumber = "http://hl7.org/fhir/eventNumber";
/**
 * AdministrableProductDefinitionPropertyComponent
 *
 * AdministrableProductDefinitionPropertyComponent: Characteristics e.g. a product's onset of action.
 *
 * http://hl7.org/fhir/AdministrableProductDefinitionPropertyComponent
 */
export declare const AdministrableProductDefinitionPropertyComponent = "http://hl7.org/fhir/AdministrableProductDefinitionPropertyComponent";
/**
 * responseRequired
 *
 * MessageDefinition.responseRequired: Declare at a message definition level whether a response is required or only upon error or success, or never.
 *
 * http://hl7.org/fhir/responseRequired
 */
export declare const responseRequired = "http://hl7.org/fhir/responseRequired";
/**
 * _verifiedBy
 *
 * (Modified) Consent.verification.verifiedBy
 *
 * http://hl7.org/fhir/_verifiedBy
 */
export declare const _verifiedBy = "http://hl7.org/fhir/_verifiedBy";
/**
 * _maritalStatus
 *
 * (Modified) Person.maritalStatus
 *
 * http://hl7.org/fhir/_maritalStatus
 */
export declare const _maritalStatus = "http://hl7.org/fhir/_maritalStatus";
/**
 * _timeOfDay
 *
 * (Modified) Timing.repeat.timeOfDay
 *
 * http://hl7.org/fhir/_timeOfDay
 */
export declare const _timeOfDay = "http://hl7.org/fhir/_timeOfDay";
/**
 * contraindication
 *
 * DeviceDefinition.guideline.contraindication: A specific situation when a device should not be used because it may cause harm.
 *
 * http://hl7.org/fhir/contraindication
 */
export declare const contraindication = "http://hl7.org/fhir/contraindication";
/**
 * patientPreparation
 *
 * SpecimenDefinition.patientPreparation: Preparation of the patient for specimen collection.
 *
 * http://hl7.org/fhir/patientPreparation
 */
export declare const patientPreparation = "http://hl7.org/fhir/patientPreparation";
/**
 * _expression
 *
 * (Modified) Permission.rule.data.expression
 *
 * http://hl7.org/fhir/_expression
 */
export declare const _expression = "http://hl7.org/fhir/_expression";
/**
 * _min
 *
 * (Modified) ElementDefinition.base.min
 *
 * http://hl7.org/fhir/_min
 */
export declare const _min = "http://hl7.org/fhir/_min";
/**
 * _attester
 *
 * (Modified) DocumentReference.attester
 *
 * http://hl7.org/fhir/_attester
 */
export declare const _attester = "http://hl7.org/fhir/_attester";
/**
 * _progress
 *
 * (Modified) ResearchSubject.progress
 *
 * http://hl7.org/fhir/_progress
 */
export declare const _progress = "http://hl7.org/fhir/_progress";
/**
 * _collection
 *
 * (Modified) SpecimenDefinition.collection
 *
 * http://hl7.org/fhir/_collection
 */
export declare const _collection = "http://hl7.org/fhir/_collection";
/**
 * base64Binary
 *
 * A stream of bytes
 *
 * http://hl7.org/fhir/base64Binary
 */
export declare const base64Binary = "http://hl7.org/fhir/base64Binary";
/**
 * ExampleScenarioProcessStepComponent
 *
 * ExampleScenarioProcessComponent.ExampleScenarioProcessStepComponent.ExampleScenarioProcessStepAlternativeComponentStepProcess.ExampleScenarioProcessStepComponent: A significant action that occurs as part of the process.
 *
 * http://hl7.org/fhir/ExampleScenarioProcessStepComponent
 */
export declare const ExampleScenarioProcessStepComponent = "http://hl7.org/fhir/ExampleScenarioProcessStepComponent";
/**
 * _comprisedOf
 *
 * (Modified) MedicinalProductDefinition.comprisedOf
 *
 * http://hl7.org/fhir/_comprisedOf
 */
export declare const _comprisedOf = "http://hl7.org/fhir/_comprisedOf";
/**
 * _factor
 *
 * (Modified) ClaimResponse.addItem.detail.factor
 *
 * http://hl7.org/fhir/_factor
 */
export declare const _factor = "http://hl7.org/fhir/_factor";
/**
 * _endRelationship
 *
 * (Modified) RequestOrchestration.action.action.relatedAction.endRelationship
 *
 * http://hl7.org/fhir/_endRelationship
 */
export declare const _endRelationship = "http://hl7.org/fhir/_endRelationship";
/**
 * _startingMaterial
 *
 * (Modified) SubstancePolymer.monomerSet.startingMaterial
 *
 * http://hl7.org/fhir/_startingMaterial
 */
export declare const _startingMaterial = "http://hl7.org/fhir/_startingMaterial";
/**
 * expectedSupplyDuration
 *
 * MedicationRequest.dispenseRequest.expectedSupplyDuration: Identifies the period time over which the supplied product is expected to be used, or the length of time the dispense is expected to last.
 *
 * http://hl7.org/fhir/expectedSupplyDuration
 */
export declare const expectedSupplyDuration = "http://hl7.org/fhir/expectedSupplyDuration";
/**
 * totalPriceComponent
 *
 * Invoice.totalPriceComponent: The total amount for the Invoice may be calculated as the sum of the line items with surcharges/deductions that apply in certain conditions.  The priceComponent element can be used to offer transparency to the recipient of the Invoice of how the total price was calculated.
 *
 * http://hl7.org/fhir/totalPriceComponent
 */
export declare const totalPriceComponent = "http://hl7.org/fhir/totalPriceComponent";
/**
 * _signer
 *
 * (Modified) Contract.signer
 *
 * http://hl7.org/fhir/_signer
 */
export declare const _signer = "http://hl7.org/fhir/_signer";
/**
 * enableBehavior
 *
 * Questionnaire.item.item.enableBehavior: Controls how multiple enableWhen values are interpreted -  whether all or any must be true.
 *
 * http://hl7.org/fhir/enableBehavior
 */
export declare const enableBehavior = "http://hl7.org/fhir/enableBehavior";
/**
 * Contract
 *
 * Legally enforceable, formally recorded unilateral or bilateral directive i.e., a policy or agreement.
 *
 * http://hl7.org/fhir/Contract
 */
export declare const Contract = "http://hl7.org/fhir/Contract";
/**
 * _cTerminalModificationId
 *
 * (Modified) SubstanceProtein.subunit.cTerminalModificationId
 *
 * http://hl7.org/fhir/_cTerminalModificationId
 */
export declare const _cTerminalModificationId = "http://hl7.org/fhir/_cTerminalModificationId";
/**
 * ObservationReferenceRangeComponent
 *
 * ObservationReferenceRangeComponent: Guidance on how to interpret the value by comparison to a normal or recommended range.  Multiple reference ranges are interpreted as an "OR".   In other words, to represent two distinct target populations, two `referenceRange` elements would be used.
 *
 * http://hl7.org/fhir/ObservationReferenceRangeComponent
 */
export declare const ObservationReferenceRangeComponent = "http://hl7.org/fhir/ObservationReferenceRangeComponent";
/**
 * maxVolumeToDeliver
 *
 * NutritionOrder.enteralFormula.maxVolumeToDeliver: The maximum total quantity of formula that may be administered to a subject over the period of time, e.g. 1440 mL over 24 hours.
 *
 * http://hl7.org/fhir/maxVolumeToDeliver
 */
export declare const maxVolumeToDeliver = "http://hl7.org/fhir/maxVolumeToDeliver";
/**
 * CapabilityStatementRestResourceOperationComponent
 *
 * CapabilityStatementRestComponent.CapabilityStatementRestResourceComponent.CapabilityStatementRestResourceOperationComponent: Definition of an operation or a named query together with its parameters and their meaning and type. Consult the definition of the operation for details about how to invoke the operation, and the parameters.
 *
 * http://hl7.org/fhir/CapabilityStatementRestResourceOperationComponent
 */
export declare const CapabilityStatementRestResourceOperationComponent = "http://hl7.org/fhir/CapabilityStatementRestResourceOperationComponent";
/**
 * isDerived
 *
 * SpecimenDefinition.typeTested.isDerived: Primary of secondary specimen.
 *
 * http://hl7.org/fhir/isDerived
 */
export declare const isDerived = "http://hl7.org/fhir/isDerived";
/**
 * conditionalUpdate
 *
 * CapabilityStatement.rest.resource.conditionalUpdate: A flag that indicates that the server supports conditional update.
 *
 * http://hl7.org/fhir/conditionalUpdate
 */
export declare const conditionalUpdate = "http://hl7.org/fhir/conditionalUpdate";
/**
 * repeatUnitAmountType
 *
 * SubstancePolymer.repeat.repeatUnitAmountType: How the quantitative amount of Structural Repeat Units is captured (e.g. Exact, Numeric, Average).
 *
 * http://hl7.org/fhir/repeatUnitAmountType
 */
export declare const repeatUnitAmountType = "http://hl7.org/fhir/repeatUnitAmountType";
/**
 * subjects
 *
 * MeasureReport.group.stratifier.stratum.population.subjects: Optional Group identifying the individuals that make up the population.
 *
 * http://hl7.org/fhir/subjects
 */
export declare const subjects = "http://hl7.org/fhir/subjects";
/**
 * EvidenceVariableCharacteristicTimeFromEventComponent
 *
 * EvidenceVariableCharacteristicComponent.EvidenceVariableCharacteristicTimeFromEventComponent: Timing in which the characteristic is determined.
 *
 * http://hl7.org/fhir/EvidenceVariableCharacteristicTimeFromEventComponent
 */
export declare const EvidenceVariableCharacteristicTimeFromEventComponent = "http://hl7.org/fhir/EvidenceVariableCharacteristicTimeFromEventComponent";
/**
 * _expansion
 *
 * (Modified) ValueSet.expansion
 *
 * http://hl7.org/fhir/_expansion
 */
export declare const _expansion = "http://hl7.org/fhir/_expansion";
/**
 * _Ingredient
 *
 * (Modified) Ingredient
 *
 * http://hl7.org/fhir/_Ingredient
 */
export declare const _Ingredient = "http://hl7.org/fhir/_Ingredient";
/**
 * _phase
 *
 * (Modified) TestScript.scope.phase
 *
 * http://hl7.org/fhir/_phase
 */
export declare const _phase = "http://hl7.org/fhir/_phase";
/**
 * _benefitPeriod
 *
 * (Modified) ExplanationOfBenefit.benefitPeriod
 *
 * http://hl7.org/fhir/_benefitPeriod
 */
export declare const _benefitPeriod = "http://hl7.org/fhir/_benefitPeriod";
/**
 * Organization
 *
 * A formally or informally recognized grouping of people or organizations formed for the purpose of achieving some form of collective action.  Includes companies, institutions, corporations, departments, community groups, healthcare practice groups, payer/insurer, etc.
 *
 * http://hl7.org/fhir/Organization
 */
export declare const Organization = "http://hl7.org/fhir/Organization";
/**
 * _referenceStrength
 *
 * (Modified) Ingredient.substance.strength.referenceStrength
 *
 * http://hl7.org/fhir/_referenceStrength
 */
export declare const _referenceStrength = "http://hl7.org/fhir/_referenceStrength";
/**
 * StructureMapGroupComponent
 *
 * StructureMapGroupComponent: Organizes the mapping into managable chunks for human review/ease of maintenance.
 *
 * http://hl7.org/fhir/StructureMapGroupComponent
 */
export declare const StructureMapGroupComponent = "http://hl7.org/fhir/StructureMapGroupComponent";
/**
 * referencePolicy
 *
 * CapabilityStatement.rest.resource.referencePolicy: A set of flags that defines how references are supported.
 *
 * http://hl7.org/fhir/referencePolicy
 */
export declare const referencePolicy = "http://hl7.org/fhir/referencePolicy";
/**
 * previous
 *
 * SubscriptionTopic.resourceTrigger.queryCriteria.previous: The FHIR query based rules are applied to the previous resource state (e.g., state before an update).
 *
 * http://hl7.org/fhir/previous
 */
export declare const previous = "http://hl7.org/fhir/previous";
/**
 * _stage
 *
 * (Modified) ConditionDefinition.stage
 *
 * http://hl7.org/fhir/_stage
 */
export declare const _stage = "http://hl7.org/fhir/_stage";
/**
 * PlanDefinitionActionOutputComponent
 *
 * PlanDefinitionActionComponentAction.PlanDefinitionActionOutputComponent: Defines the outputs of the action, if any.
 *
 * http://hl7.org/fhir/PlanDefinitionActionOutputComponent
 */
export declare const PlanDefinitionActionOutputComponent = "http://hl7.org/fhir/PlanDefinitionActionOutputComponent";
/**
 * _publisherLocation
 *
 * (Modified) Citation.citedArtifact.publicationForm.publishedIn.publisherLocation
 *
 * http://hl7.org/fhir/_publisherLocation
 */
export declare const _publisherLocation = "http://hl7.org/fhir/_publisherLocation";
/**
 * MedicationKnowledgeIndicationGuidelineDosingGuidelineDosageComponent
 *
 * MedicationKnowledgeIndicationGuidelineComponent.MedicationKnowledgeIndicationGuidelineDosingGuidelineComponent.MedicationKnowledgeIndicationGuidelineDosingGuidelineDosageComponent: Dosage for the medication for the specific guidelines.
 *
 * http://hl7.org/fhir/MedicationKnowledgeIndicationGuidelineDosingGuidelineDosageComponent
 */
export declare const MedicationKnowledgeIndicationGuidelineDosingGuidelineDosageComponent = "http://hl7.org/fhir/MedicationKnowledgeIndicationGuidelineDosingGuidelineDosageComponent";
/**
 * containedItemQuantity
 *
 * PackagedProductDefinition.containedItemQuantity: A total of the complete count of contained items of a particular type/form, independent of sub-packaging or organization. This can be considered as the pack size. This attribute differs from containedItem.amount in that it can give a single aggregated count of all tablet types in a pack, even when these are different manufactured items. For example a pill pack of 21 tablets plus 7 sugar tablets, can be denoted here as '28 tablets'. This attribute is repeatable so that the different item types in one pack type can be counted (e.g. a count of vials and count of syringes). Each repeat must have different units, so that it is clear what the different sets of counted items are, and it is not intended to allow different counts of similar items (e.g. not '2 tubes and 3 tubes'). Repeats are not to be used to represent different pack sizes (e.g. 20 pack vs. 50 pack) - which would be different instances of this resource.
 *
 * http://hl7.org/fhir/containedItemQuantity
 */
export declare const containedItemQuantity = "http://hl7.org/fhir/containedItemQuantity";
/**
 * copyrightLabel
 *
 * GraphDefinition.copyrightLabel: A short string (<50 characters), suitable for inclusion in a page footer that identifies the copyright holder, effective period, and optionally whether rights are resctricted. (e.g. 'All rights reserved', 'Some rights reserved').
 *
 * http://hl7.org/fhir/copyrightLabel
 */
export declare const copyrightLabel = "http://hl7.org/fhir/copyrightLabel";
/**
 * BodyStructureIncludedStructureBodyLandmarkOrientationComponent
 *
 * BodyStructureIncludedStructureBodyLandmarkOrientationComponent: Body locations in relation to a specific body landmark (tatoo, scar, other body structure).
 *
 * http://hl7.org/fhir/BodyStructureIncludedStructureBodyLandmarkOrientationComponent
 */
export declare const BodyStructureIncludedStructureBodyLandmarkOrientationComponent = "http://hl7.org/fhir/BodyStructureIncludedStructureBodyLandmarkOrientationComponent";
/**
 * hasBodySite
 *
 * ConditionDefinition.hasBodySite: Whether bodySite is appropriate to collect for this condition.
 *
 * http://hl7.org/fhir/hasBodySite
 */
export declare const hasBodySite = "http://hl7.org/fhir/hasBodySite";
/**
 * _valuedItem
 *
 * (Modified) Contract.term.group.asset.valuedItem
 *
 * http://hl7.org/fhir/_valuedItem
 */
export declare const _valuedItem = "http://hl7.org/fhir/_valuedItem";
/**
 * Period
 *
 * A time period defined by a start and end date and optionally time.
 *
 * http://hl7.org/fhir/Period
 */
export declare const Period = "http://hl7.org/fhir/Period";
/**
 * questionnaire
 *
 * QuestionnaireResponse.questionnaire: The Questionnaire that defines and organizes the questions for which answers are being provided.
 *
 * http://hl7.org/fhir/questionnaire
 */
export declare const questionnaire = "http://hl7.org/fhir/questionnaire";
/**
 * specificCost
 *
 * InsurancePlan.plan.specificCost: Costs associated with the coverage provided by the product.
 *
 * http://hl7.org/fhir/specificCost
 */
export declare const specificCost = "http://hl7.org/fhir/specificCost";
/**
 * _collected
 *
 * (Modified) Specimen.collection.collected
 *
 * http://hl7.org/fhir/_collected
 */
export declare const _collected = "http://hl7.org/fhir/_collected";
/**
 * _notAvailableTime
 *
 * (Modified) Availability.notAvailableTime
 *
 * http://hl7.org/fhir/_notAvailableTime
 */
export declare const _notAvailableTime = "http://hl7.org/fhir/_notAvailableTime";
/**
 * AllergyIntoleranceParticipantComponent
 *
 * AllergyIntoleranceParticipantComponent: Indicates who or what participated in the activities related to the allergy or intolerance and how they were involved.
 *
 * http://hl7.org/fhir/AllergyIntoleranceParticipantComponent
 */
export declare const AllergyIntoleranceParticipantComponent = "http://hl7.org/fhir/AllergyIntoleranceParticipantComponent";
/**
 * headerField
 *
 * TestScript.test.action.assert.headerField: The HTTP header field name e.g. 'Location'.
 *
 * http://hl7.org/fhir/headerField
 */
export declare const headerField = "http://hl7.org/fhir/headerField";
/**
 * _contained
 *
 * (Modified) DomainResource.contained
 *
 * http://hl7.org/fhir/_contained
 */
export declare const _contained = "http://hl7.org/fhir/_contained";
/**
 * _assigner
 *
 * (Modified) Identifier.assigner
 *
 * http://hl7.org/fhir/_assigner
 */
export declare const _assigner = "http://hl7.org/fhir/_assigner";
/**
 * _ifNoneMatch
 *
 * (Modified) Bundle.entry.request.ifNoneMatch
 *
 * http://hl7.org/fhir/_ifNoneMatch
 */
export declare const _ifNoneMatch = "http://hl7.org/fhir/_ifNoneMatch";
/**
 * DeviceAssociationOperationComponent
 *
 * DeviceAssociationOperationComponent: The details about the device when it is in use to describe its operation.
 *
 * http://hl7.org/fhir/DeviceAssociationOperationComponent
 */
export declare const DeviceAssociationOperationComponent = "http://hl7.org/fhir/DeviceAssociationOperationComponent";
/**
 * _graph
 *
 * (Modified) MessageDefinition.graph
 *
 * http://hl7.org/fhir/_graph
 */
export declare const _graph = "http://hl7.org/fhir/_graph";
/**
 * changeType
 *
 * GenomicStudy.analysis.changeType: Type of the genomic changes studied in the analysis, e.g., DNA, RNA, or amino acid change.
 *
 * http://hl7.org/fhir/changeType
 */
export declare const changeType = "http://hl7.org/fhir/changeType";
/**
 * _orientation
 *
 * (Modified) SubstancePolymer.repeat.repeatUnit.orientation
 *
 * http://hl7.org/fhir/_orientation
 */
export declare const _orientation = "http://hl7.org/fhir/_orientation";
/**
 * parentSubstanceId
 *
 * SubstanceSourceMaterial.parentSubstanceId: The parent of the herbal drug Ginkgo biloba, Leaf is the substance ID of the substance (fresh) of Ginkgo biloba L. or Ginkgo biloba L. (Whole plant).
 *
 * http://hl7.org/fhir/parentSubstanceId
 */
export declare const parentSubstanceId = "http://hl7.org/fhir/parentSubstanceId";
/**
 * recorded
 *
 * MedicationAdministration.recorded: The date the occurrence of the  MedicationAdministration was first captured in the record - potentially significantly after the occurrence of the event.
 *
 * http://hl7.org/fhir/recorded
 */
export declare const recorded = "http://hl7.org/fhir/recorded";
/**
 * _contributionType
 *
 * (Modified) Citation.citedArtifact.contributorship.entry.contributionType
 *
 * http://hl7.org/fhir/_contributionType
 */
export declare const _contributionType = "http://hl7.org/fhir/_contributionType";
/**
 * filterParameter
 *
 * SubscriptionTopic.canFilterBy.filterParameter: Either the canonical URL to a search parameter (like "http://hl7.org/fhir/SearchParameter/encounter-patient") or topic-defined parameter (like "hub.event") which is a label for the filter.
 *
 * http://hl7.org/fhir/filterParameter
 */
export declare const filterParameter = "http://hl7.org/fhir/filterParameter";
/**
 * positiveInt
 *
 * An integer with a value that is positive (e.g. >0)
 *
 * http://hl7.org/fhir/positiveInt
 */
export declare const positiveInt = "http://hl7.org/fhir/positiveInt";
/**
 * docStatus
 *
 * DocumentReference.docStatus: The status of the underlying document.
 *
 * http://hl7.org/fhir/docStatus
 */
export declare const docStatus = "http://hl7.org/fhir/docStatus";
/**
 * CoverageBenefit
 *
 * InsurancePlanCoverageComponent.CoverageBenefit: Specific benefits under this type of coverage.
 *
 * http://hl7.org/fhir/CoverageBenefit
 */
export declare const CoverageBenefit = "http://hl7.org/fhir/CoverageBenefit";
/**
 * durationUnit
 *
 * Timing.repeat.durationUnit: The units of time for the duration, in UCUM units
 * Normal practice is to use the 'mo' code as a calendar month when calculating the next occurrence.
 *
 * http://hl7.org/fhir/durationUnit
 */
export declare const durationUnit = "http://hl7.org/fhir/durationUnit";
/**
 * contentType
 *
 * Attachment.contentType: Identifies the type of the data in the attachment and allows a method to be chosen to interpret or render the data. Includes mime type parameters such as charset where appropriate.
 *
 * http://hl7.org/fhir/contentType
 */
export declare const contentType = "http://hl7.org/fhir/contentType";
/**
 * _addItem
 *
 * (Modified) ExplanationOfBenefit.addItem
 *
 * http://hl7.org/fhir/_addItem
 */
export declare const _addItem = "http://hl7.org/fhir/_addItem";
/**
 * MedicationKnowledgeIndicationGuidelineDosingGuidelineComponent
 *
 * MedicationKnowledgeIndicationGuidelineComponent.MedicationKnowledgeIndicationGuidelineDosingGuidelineComponent: The guidelines for the dosage of the medication for the indication.
 *
 * http://hl7.org/fhir/MedicationKnowledgeIndicationGuidelineDosingGuidelineComponent
 */
export declare const MedicationKnowledgeIndicationGuidelineDosingGuidelineComponent = "http://hl7.org/fhir/MedicationKnowledgeIndicationGuidelineDosingGuidelineComponent";
/**
 * dateRange
 *
 * MarketingStatus.dateRange: The date when the Medicinal Product is placed on the market by the Marketing Authorization Holder (or where applicable, the manufacturer/distributor) in a country and/or jurisdiction shall be provided A complete date consisting of day, month and year shall be specified using the ISO 8601 date format NOTE “Placed on the market” refers to the release of the Medicinal Product into the distribution chain.
 *
 * http://hl7.org/fhir/dateRange
 */
export declare const dateRange = "http://hl7.org/fhir/dateRange";
/**
 * used
 *
 * Procedure.used: Identifies medications, devices and any other substance used as part of the procedure.
 *
 * http://hl7.org/fhir/used
 */
export declare const used = "http://hl7.org/fhir/used";
/**
 * _city
 *
 * (Modified) Address.city
 *
 * http://hl7.org/fhir/_city
 */
export declare const _city = "http://hl7.org/fhir/_city";
/**
 * reaction
 *
 * Immunization.reaction: Categorical data indicating that an adverse event is associated in time to an immunization.
 *
 * http://hl7.org/fhir/reaction
 */
export declare const reaction = "http://hl7.org/fhir/reaction";
/**
 * subset
 *
 * ImagingSelection.instance.subset: Selected subset of the SOP Instance. The content and format of the subset item is determined by the SOP Class of the selected instance.
 *        May be one of:
 *        - A list of frame numbers selected from a multiframe SOP Instance.
 *        - A list of Content Item Observation UID values selected from a DICOM SR or other structured document SOP Instance.
 *        - A list of segment numbers selected from a segmentation SOP Instance.
 *        - A list of Region of Interest (ROI) numbers selected from a radiotherapy structure set SOP Instance.
 *
 * http://hl7.org/fhir/subset
 */
export declare const subset = "http://hl7.org/fhir/subset";
/**
 * performerRole
 *
 * Contract.term.group.action.performerRole: The type of role or competency of an individual desired or required to perform or not perform the action.
 *
 * http://hl7.org/fhir/performerRole
 */
export declare const performerRole = "http://hl7.org/fhir/performerRole";
/**
 * retentionTime
 *
 * SpecimenDefinition.typeTested.retentionTime: The usual time that a specimen of this kind is retained after the ordered tests are completed, for the purpose of additional testing.
 *
 * http://hl7.org/fhir/retentionTime
 */
export declare const retentionTime = "http://hl7.org/fhir/retentionTime";
/**
 * _ClinicalImpression
 *
 * (Modified) ClinicalImpression
 *
 * http://hl7.org/fhir/_ClinicalImpression
 */
export declare const _ClinicalImpression = "http://hl7.org/fhir/_ClinicalImpression";
/**
 * _generalCost
 *
 * (Modified) InsurancePlan.plan.generalCost
 *
 * http://hl7.org/fhir/_generalCost
 */
export declare const _generalCost = "http://hl7.org/fhir/_generalCost";
/**
 * instanceReference
 *
 * ExampleScenario.process.step.alternative.step.operation.request.instanceReference: A reference to the key of an instance found within this one.
 *
 * http://hl7.org/fhir/instanceReference
 */
export declare const instanceReference = "http://hl7.org/fhir/instanceReference";
/**
 * _history
 *
 * (Modified) Transport.history
 *
 * http://hl7.org/fhir/_history
 */
export declare const _history = "http://hl7.org/fhir/_history";
/**
 * molecularFormulaByMoiety
 *
 * SubstanceDefinition.structure.molecularFormulaByMoiety: Specified per moiety according to the Hill system, i.e. first C, then H, then alphabetical, each moiety separated by a dot.
 *
 * http://hl7.org/fhir/molecularFormulaByMoiety
 */
export declare const molecularFormulaByMoiety = "http://hl7.org/fhir/molecularFormulaByMoiety";
/**
 * _orderer
 *
 * (Modified) NutritionOrder.orderer
 *
 * http://hl7.org/fhir/_orderer
 */
export declare const _orderer = "http://hl7.org/fhir/_orderer";
/**
 * _payee
 *
 * (Modified) PaymentReconciliation.allocation.payee
 *
 * http://hl7.org/fhir/_payee
 */
export declare const _payee = "http://hl7.org/fhir/_payee";
/**
 * _windowEnd
 *
 * (Modified) MolecularSequence.relative.startingSequence.windowEnd
 *
 * http://hl7.org/fhir/_windowEnd
 */
export declare const _windowEnd = "http://hl7.org/fhir/_windowEnd";
/**
 * _maxDosePerTreatmentPeriod
 *
 * (Modified) AdministrableProductDefinition.routeOfAdministration.maxDosePerTreatmentPeriod
 *
 * http://hl7.org/fhir/_maxDosePerTreatmentPeriod
 */
export declare const _maxDosePerTreatmentPeriod = "http://hl7.org/fhir/_maxDosePerTreatmentPeriod";
/**
 * sopClass
 *
 * ImagingStudy.series.instance.sopClass: DICOM instance  type.
 *
 * http://hl7.org/fhir/sopClass
 */
export declare const sopClass = "http://hl7.org/fhir/sopClass";
/**
 * PlanDefinitionActorOptionComponent
 *
 * PlanDefinitionActorComponent.PlanDefinitionActorOptionComponent: The characteristics of the candidates that could serve as the actor.
 *
 * http://hl7.org/fhir/PlanDefinitionActorOptionComponent
 */
export declare const PlanDefinitionActorOptionComponent = "http://hl7.org/fhir/PlanDefinitionActorOptionComponent";
/**
 * ExampleScenarioInstanceComponent
 *
 * ExampleScenarioInstanceComponent: A single data collection that is shared as part of the scenario.
 *
 * http://hl7.org/fhir/ExampleScenarioInstanceComponent
 */
export declare const ExampleScenarioInstanceComponent = "http://hl7.org/fhir/ExampleScenarioInstanceComponent";
/**
 * organismGeneral
 *
 * SubstanceSourceMaterial.organism.organismGeneral: 4.9.13.7.1 Kingdom (Conditional).
 *
 * http://hl7.org/fhir/organismGeneral
 */
export declare const organismGeneral = "http://hl7.org/fhir/organismGeneral";
/**
 * abatement
 *
 * Condition.abatement
 *
 * http://hl7.org/fhir/abatement
 */
export declare const abatement = "http://hl7.org/fhir/abatement";
/**
 * _relatedDevice
 *
 * (Modified) DeviceDefinition.link.relatedDevice
 *
 * http://hl7.org/fhir/_relatedDevice
 */
export declare const _relatedDevice = "http://hl7.org/fhir/_relatedDevice";
/**
 * daysSupply
 *
 * MedicationDispense.daysSupply: The amount of medication expressed as a timing amount.
 *
 * http://hl7.org/fhir/daysSupply
 */
export declare const daysSupply = "http://hl7.org/fhir/daysSupply";
/**
 * _legal
 *
 * (Modified) Contract.legal
 *
 * http://hl7.org/fhir/_legal
 */
export declare const _legal = "http://hl7.org/fhir/_legal";
/**
 * _EpisodeOfCare
 *
 * (Modified) EpisodeOfCare
 *
 * http://hl7.org/fhir/_EpisodeOfCare
 */
export declare const _EpisodeOfCare = "http://hl7.org/fhir/_EpisodeOfCare";
/**
 * _excludeFoodModifier
 *
 * (Modified) NutritionOrder.excludeFoodModifier
 *
 * http://hl7.org/fhir/_excludeFoodModifier
 */
export declare const _excludeFoodModifier = "http://hl7.org/fhir/_excludeFoodModifier";
/**
 * weekInterval
 *
 * Appointment.recurrenceTemplate.weeklyTemplate.weekInterval: The interval defines if the recurrence is every nth week. The default is every week, so it is expected that this value will be 2 or more.

e.g. For recurring every second week this interval would be 2, or every third week the interval would be 3.
 *
 * http://hl7.org/fhir/weekInterval
 */
export declare const weekInterval = "http://hl7.org/fhir/weekInterval";
/**
 * _measureScore
 *
 * (Modified) MeasureReport.group.stratifier.stratum.measureScore
 *
 * http://hl7.org/fhir/_measureScore
 */
export declare const _measureScore = "http://hl7.org/fhir/_measureScore";
/**
 * _const
 *
 * (Modified) StructureMap.const
 *
 * http://hl7.org/fhir/_const
 */
export declare const _const = "http://hl7.org/fhir/_const";
/**
 * _hybrid
 *
 * (Modified) SubstanceSourceMaterial.organism.hybrid
 *
 * http://hl7.org/fhir/_hybrid
 */
export declare const _hybrid = "http://hl7.org/fhir/_hybrid";
/**
 * PackagedProductDefinitionPackagingComponent
 *
 * PackagedProductDefinitionPackagingComponent: A packaging item, as a container for medically related items, possibly with other packaging items within, or a packaging component, such as bottle cap (which is not a device or a medication manufactured item).
 *
 * http://hl7.org/fhir/PackagedProductDefinitionPackagingComponent
 */
export declare const PackagedProductDefinitionPackagingComponent = "http://hl7.org/fhir/PackagedProductDefinitionPackagingComponent";
/**
 * _prefix
 *
 * (Modified) RequestOrchestration.action.action.prefix
 *
 * http://hl7.org/fhir/_prefix
 */
export declare const _prefix = "http://hl7.org/fhir/_prefix";
/**
 * _publicationDateText
 *
 * (Modified) Citation.citedArtifact.publicationForm.publicationDateText
 *
 * http://hl7.org/fhir/_publicationDateText
 */
export declare const _publicationDateText = "http://hl7.org/fhir/_publicationDateText";
/**
 * ConceptSet
 *
 * ValueSetComposeComponent.ConceptSet: Include one or more codes from a code system or other value set(s).
 *
 * http://hl7.org/fhir/ConceptSet
 */
export declare const ConceptSet = "http://hl7.org/fhir/ConceptSet";
/**
 * payeeType
 *
 * ClaimResponse.payeeType: Type of Party to be reimbursed: subscriber, provider, other.
 *
 * http://hl7.org/fhir/payeeType
 */
export declare const payeeType = "http://hl7.org/fhir/payeeType";
/**
 * _shelfLifeStorage
 *
 * (Modified) PackagedProductDefinition.packaging.packaging.shelfLifeStorage
 *
 * http://hl7.org/fhir/_shelfLifeStorage
 */
export declare const _shelfLifeStorage = "http://hl7.org/fhir/_shelfLifeStorage";
/**
 * balance
 *
 * Account.balance: The calculated account balances - these are calculated and processed by the finance system.

The balances with a `term` that is not current are usually generated/updated by an invoicing or similar process.
 *
 * http://hl7.org/fhir/balance
 */
export declare const balance = "http://hl7.org/fhir/balance";
/**
 * _type
 *
 * (Modified) ManufacturedItemDefinition.component.component.property.type
 *
 * http://hl7.org/fhir/_type
 */
export declare const _type = "http://hl7.org/fhir/_type";
/**
 * dataPeriod
 *
 * Consent.provision.provision.dataPeriod: Clinical or Operational Relevant period of time that bounds the data controlled by this provision.
 *
 * http://hl7.org/fhir/dataPeriod
 */
export declare const dataPeriod = "http://hl7.org/fhir/dataPeriod";
/**
 * _Immunization
 *
 * (Modified) Immunization
 *
 * http://hl7.org/fhir/_Immunization
 */
export declare const _Immunization = "http://hl7.org/fhir/_Immunization";
/**
 * resourceReference
 *
 * Citation.citedArtifact.relatesTo.resourceReference: The related artifact, if the artifact is not a canonical resource, or a resource reference to a canonical resource.
 *
 * http://hl7.org/fhir/resourceReference
 */
export declare const resourceReference = "http://hl7.org/fhir/resourceReference";
/**
 * _providedBy
 *
 * (Modified) HealthcareService.providedBy
 *
 * http://hl7.org/fhir/_providedBy
 */
export declare const _providedBy = "http://hl7.org/fhir/_providedBy";
/**
 * _fhirVersion
 *
 * (Modified) StructureDefinition.fhirVersion
 *
 * http://hl7.org/fhir/_fhirVersion
 */
export declare const _fhirVersion = "http://hl7.org/fhir/_fhirVersion";
/**
 * _HealthcareService
 *
 * (Modified) HealthcareService
 *
 * http://hl7.org/fhir/_HealthcareService
 */
export declare const _HealthcareService = "http://hl7.org/fhir/_HealthcareService";
/**
 * submitter
 *
 * PaymentReconciliation.allocation.submitter: The party which submitted the claim or financial transaction.
 *
 * http://hl7.org/fhir/submitter
 */
export declare const submitter = "http://hl7.org/fhir/submitter";
/**
 * description
 *
 * Availability.notAvailableTime.description: Reason presented to the user explaining why time not available.
 *
 * http://hl7.org/fhir/description
 */
export declare const description = "http://hl7.org/fhir/description";
/**
 * combinedPharmaceuticalDoseForm
 *
 * MedicinalProductDefinition.combinedPharmaceuticalDoseForm: The dose form for a single part product, or combined form of a multiple part product. This is one concept that describes all the components. It does not represent the form with components physically mixed, if that might be necessary, for which see (AdministrableProductDefinition.administrableDoseForm).
 *
 * http://hl7.org/fhir/combinedPharmaceuticalDoseForm
 */
export declare const combinedPharmaceuticalDoseForm = "http://hl7.org/fhir/combinedPharmaceuticalDoseForm";
/**
 * _targetScope
 *
 * (Modified) ConceptMap.targetScope
 *
 * http://hl7.org/fhir/_targetScope
 */
export declare const _targetScope = "http://hl7.org/fhir/_targetScope";
/**
 * Parameter
 *
 * Transport.Parameter: Additional information that may be needed in the execution of the transport.
 *
 * http://hl7.org/fhir/Parameter
 */
export declare const Parameter = "http://hl7.org/fhir/Parameter";
/**
 * BiologicallyDerivedProduct
 *
 * A biological material originating from a biological entity intended to be transplanted or infused into another (possibly the same) biological entity.
 *
 * http://hl7.org/fhir/BiologicallyDerivedProduct
 */
export declare const BiologicallyDerivedProduct = "http://hl7.org/fhir/BiologicallyDerivedProduct";
/**
 * _GenomicStudy
 *
 * (Modified) GenomicStudy
 *
 * http://hl7.org/fhir/_GenomicStudy
 */
export declare const _GenomicStudy = "http://hl7.org/fhir/_GenomicStudy";
/**
 * _NutritionProduct
 *
 * (Modified) NutritionProduct
 *
 * http://hl7.org/fhir/_NutritionProduct
 */
export declare const _NutritionProduct = "http://hl7.org/fhir/_NutritionProduct";
/**
 * _additionalContext
 *
 * (Modified) SubscriptionStatus.notificationEvent.additionalContext
 *
 * http://hl7.org/fhir/_additionalContext
 */
export declare const _additionalContext = "http://hl7.org/fhir/_additionalContext";
/**
 * version
 *
 * Measure.version: The identifier that is used to identify this version of the measure when it is referenced in a specification, model, design or instance. This is an arbitrary value managed by the measure author and is not expected to be globally unique. For example, it might be a timestamp (e.g. yyyymmdd) if a managed version is not available. There is also no expectation that versions can be placed in a lexicographical sequence. To provide a version consistent with the Decision Support Service specification, use the format Major.Minor.Revision (e.g. 1.0.0). For more information on versioning knowledge assets, refer to the Decision Support Service specification. Note that a version is required for non-experimental active artifacts.
 *
 * http://hl7.org/fhir/version
 */
export declare const version = "http://hl7.org/fhir/version";
/**
 * detected
 *
 * AdverseEvent.detected: Estimated or actual date the AdverseEvent began, in the opinion of the reporter.
 *
 * http://hl7.org/fhir/detected
 */
export declare const detected = "http://hl7.org/fhir/detected";
/**
 * _statistic
 *
 * (Modified) Evidence.statistic
 *
 * http://hl7.org/fhir/_statistic
 */
export declare const _statistic = "http://hl7.org/fhir/_statistic";
/**
 * _bodyStructure
 *
 * (Modified) ServiceRequest.bodyStructure
 *
 * http://hl7.org/fhir/_bodyStructure
 */
export declare const _bodyStructure = "http://hl7.org/fhir/_bodyStructure";
/**
 * _definitionExpression
 *
 * (Modified) EvidenceVariable.characteristic.definitionByCombination.characteristic.definitionExpression
 *
 * http://hl7.org/fhir/_definitionExpression
 */
export declare const _definitionExpression = "http://hl7.org/fhir/_definitionExpression";
/**
 * translations
 *
 * TerminologyCapabilities.validateCode.translations: Whether translations are validated.
 *
 * http://hl7.org/fhir/translations
 */
export declare const translations = "http://hl7.org/fhir/translations";
/**
 * _targetProfile
 *
 * (Modified) OperationDefinition.parameter.part.targetProfile
 *
 * http://hl7.org/fhir/_targetProfile
 */
export declare const _targetProfile = "http://hl7.org/fhir/_targetProfile";
/**
 * _notPerformedReason
 *
 * (Modified) MedicationDispense.notPerformedReason
 *
 * http://hl7.org/fhir/_notPerformedReason
 */
export declare const _notPerformedReason = "http://hl7.org/fhir/_notPerformedReason";
/**
 * ArtifactAssessmentContentComponent
 *
 * ArtifactAssessmentContentComponent: A component comment, classifier, or rating of the artifact.
 *
 * http://hl7.org/fhir/ArtifactAssessmentContentComponent
 */
export declare const ArtifactAssessmentContentComponent = "http://hl7.org/fhir/ArtifactAssessmentContentComponent";
/**
 * cost
 *
 * MedicationKnowledge.packaging.cost.cost
 *
 * http://hl7.org/fhir/cost
 */
export declare const cost = "http://hl7.org/fhir/cost";
/**
 * CanonicalResource
 *
 * Common Interface declaration for conformance and knowledge artifact resources.
 *
 * http://hl7.org/fhir/CanonicalResource
 */
export declare const CanonicalResource = "http://hl7.org/fhir/CanonicalResource";
/**
 * _authorizationSupporting
 *
 * (Modified) CoverageEligibilityResponse.insurance.item.authorizationSupporting
 *
 * http://hl7.org/fhir/_authorizationSupporting
 */
export declare const _authorizationSupporting = "http://hl7.org/fhir/_authorizationSupporting";
/**
 * team
 *
 * ConditionDefinition.team: Appropriate team for this condition.
 *
 * http://hl7.org/fhir/team
 */
export declare const team = "http://hl7.org/fhir/team";
/**
 * actual
 *
 * Citation.statusDate.actual: Whether the status date is actual (has occurred) or expected (estimated or anticipated).
 *
 * http://hl7.org/fhir/actual
 */
export declare const actual = "http://hl7.org/fhir/actual";
/**
 * landmarkDescription
 *
 * BodyStructure.excludedStructure.bodyLandmarkOrientation.landmarkDescription: A description of a landmark on the body used as a reference to locate something else.
 *
 * http://hl7.org/fhir/landmarkDescription
 */
export declare const landmarkDescription = "http://hl7.org/fhir/landmarkDescription";
/**
 * typeCanonical
 *
 * RequestOrchestration.action.action.participant.typeCanonical: The type of participant in the action.
 *
 * http://hl7.org/fhir/typeCanonical
 */
export declare const typeCanonical = "http://hl7.org/fhir/typeCanonical";
/**
 * ArtifactAssessmentContentComponentContent
 *
 * If the informationType is container, the components of the content.
 *
 * http://hl7.org/fhir/ArtifactAssessmentContentComponentContent
 */
export declare const ArtifactAssessmentContentComponentContent = "http://hl7.org/fhir/ArtifactAssessmentContentComponentContent";
/**
 * _organizationReference
 *
 * (Modified) DeviceDefinition.packaging.packaging.distributor.organizationReference
 *
 * http://hl7.org/fhir/_organizationReference
 */
export declare const _organizationReference = "http://hl7.org/fhir/_organizationReference";
/**
 * _minimumVolume
 *
 * (Modified) SpecimenDefinition.typeTested.container.minimumVolume
 *
 * http://hl7.org/fhir/_minimumVolume
 */
export declare const _minimumVolume = "http://hl7.org/fhir/_minimumVolume";
/**
 * precedence
 *
 * ExplanationOfBenefit.precedence: This indicates the relative order of a series of EOBs related to different coverages for the same suite of services.
 *
 * http://hl7.org/fhir/precedence
 */
export declare const precedence = "http://hl7.org/fhir/precedence";
/**
 * CitationSummaryComponent
 *
 * CitationSummaryComponent: A human-readable display of key concepts to represent the citation.
 *
 * http://hl7.org/fhir/CitationSummaryComponent
 */
export declare const CitationSummaryComponent = "http://hl7.org/fhir/CitationSummaryComponent";
/**
 * decision
 *
 * ExplanationOfBenefit.decision: The result of the claim, predetermination, or preauthorization adjudication.
 *
 * http://hl7.org/fhir/decision
 */
export declare const decision = "http://hl7.org/fhir/decision";
/**
 * role
 *
 * CareTeam.participant.role: Indicates specific responsibility of an individual within the care team, such as "Primary care physician", "Trained social worker counselor", "Caregiver", etc.
 *
 * http://hl7.org/fhir/role
 */
export declare const role = "http://hl7.org/fhir/role";
/**
 * maternalOrganismId
 *
 * SubstanceSourceMaterial.organism.hybrid.maternalOrganismId: The identifier of the maternal species constituting the hybrid organism shall be specified based on a controlled vocabulary. For plants, the parents aren’t always known, and it is unlikely that it will be known which is maternal and which is paternal.
 *
 * http://hl7.org/fhir/maternalOrganismId
 */
export declare const maternalOrganismId = "http://hl7.org/fhir/maternalOrganismId";
/**
 * _triggeredBy
 *
 * (Modified) Observation.triggeredBy
 *
 * http://hl7.org/fhir/_triggeredBy
 */
export declare const _triggeredBy = "http://hl7.org/fhir/_triggeredBy";
/**
 * MedicationKnowledgeStorageGuidelineComponent
 *
 * MedicationKnowledgeStorageGuidelineComponent: Information on how the medication should be stored, for example, refrigeration temperatures and length of stability at a given temperature.
 *
 * http://hl7.org/fhir/MedicationKnowledgeStorageGuidelineComponent
 */
export declare const MedicationKnowledgeStorageGuidelineComponent = "http://hl7.org/fhir/MedicationKnowledgeStorageGuidelineComponent";
/**
 * dischargeDisposition
 *
 * Encounter.admission.dischargeDisposition: Category or kind of location after discharge.
 *
 * http://hl7.org/fhir/dischargeDisposition
 */
export declare const dischargeDisposition = "http://hl7.org/fhir/dischargeDisposition";
/**
 * _output
 *
 * (Modified) Transport.output
 *
 * http://hl7.org/fhir/_output
 */
export declare const _output = "http://hl7.org/fhir/_output";
/**
 * QuestionnaireItemComponent
 *
 * QuestionnaireItemComponent: A particular question, question grouping or display text that is part of the questionnaire.
 *
 * http://hl7.org/fhir/QuestionnaireItemComponent
 */
export declare const QuestionnaireItemComponent = "http://hl7.org/fhir/QuestionnaireItemComponent";
/**
 * _compareToSourcePath
 *
 * (Modified) TestScript.test.action.assert.compareToSourcePath
 *
 * http://hl7.org/fhir/_compareToSourcePath
 */
export declare const _compareToSourcePath = "http://hl7.org/fhir/_compareToSourcePath";
/**
 * traceNumber
 *
 * ExplanationOfBenefit.item.detail.traceNumber: Trace number for tracking purposes. May be defined at the jurisdiction level or between trading partners.
 *
 * http://hl7.org/fhir/traceNumber
 */
export declare const traceNumber = "http://hl7.org/fhir/traceNumber";
/**
 * InsurancePlanPlanComponent
 *
 * InsurancePlanPlanComponent: Details about an insurance plan.
 *
 * http://hl7.org/fhir/InsurancePlanPlanComponent
 */
export declare const InsurancePlanPlanComponent = "http://hl7.org/fhir/InsurancePlanPlanComponent";
/**
 * object
 *
 * TestPlan.testCase.assertion.object: The focus or object of the assertion i.e. a resource.
 *
 * http://hl7.org/fhir/object
 */
export declare const object = "http://hl7.org/fhir/object";
/**
 * statusReason
 *
 * Transport.statusReason: An explanation as to why this transport is held, failed, was refused, etc.
 *
 * http://hl7.org/fhir/statusReason
 */
export declare const statusReason = "http://hl7.org/fhir/statusReason";
/**
 * recall
 *
 * DeviceDefinition.correctiveAction.recall: Whether the last corrective action known for this device was a recall.
 *
 * http://hl7.org/fhir/recall
 */
export declare const recall = "http://hl7.org/fhir/recall";
/**
 * _codeSystem
 *
 * (Modified) TerminologyCapabilities.codeSystem
 *
 * http://hl7.org/fhir/_codeSystem
 */
export declare const _codeSystem = "http://hl7.org/fhir/_codeSystem";
/**
 * _processing
 *
 * (Modified) Specimen.processing
 *
 * http://hl7.org/fhir/_processing
 */
export declare const _processing = "http://hl7.org/fhir/_processing";
/**
 * gateway
 *
 * Device.gateway: The linked device acting as a communication controller, data collector, translator, or concentrator for the current device (e.g., mobile phone application that relays a blood pressure device's data).
 *
 * http://hl7.org/fhir/gateway
 */
export declare const gateway = "http://hl7.org/fhir/gateway";
/**
 * _performerType
 *
 * (Modified) Transport.performerType
 *
 * http://hl7.org/fhir/_performerType
 */
export declare const _performerType = "http://hl7.org/fhir/_performerType";
/**
 * _subcomponent
 *
 * (Modified) Evidence.certainty.subcomponent
 *
 * http://hl7.org/fhir/_subcomponent
 */
export declare const _subcomponent = "http://hl7.org/fhir/_subcomponent";
/**
 * postalCode
 *
 * Address.postalCode: A postal code designating a region defined by the postal service.
 *
 * http://hl7.org/fhir/postalCode
 */
export declare const postalCode = "http://hl7.org/fhir/postalCode";
/**
 * AddedItemDetail
 *
 * ExplanationOfBenefit.AddedItem.AddedItemDetail: The second-tier service adjudications for payor added services.
 *
 * http://hl7.org/fhir/AddedItemDetail
 */
export declare const AddedItemDetail = "http://hl7.org/fhir/AddedItemDetail";
/**
 * instance
 *
 * ChargeItemDefinition.instance: The defined billing details in this resource pertain to the given product instance(s).
 *
 * http://hl7.org/fhir/instance
 */
export declare const instance = "http://hl7.org/fhir/instance";
/**
 * _disposition
 *
 * (Modified) PaymentReconciliation.disposition
 *
 * http://hl7.org/fhir/_disposition
 */
export declare const _disposition = "http://hl7.org/fhir/_disposition";
/**
 * _statusDate
 *
 * (Modified) MedicinalProductDefinition.statusDate
 *
 * http://hl7.org/fhir/_statusDate
 */
export declare const _statusDate = "http://hl7.org/fhir/_statusDate";
/**
 * _facilityType
 *
 * (Modified) DocumentReference.facilityType
 *
 * http://hl7.org/fhir/_facilityType
 */
export declare const _facilityType = "http://hl7.org/fhir/_facilityType";
/**
 * _stratum
 *
 * (Modified) MeasureReport.group.stratifier.stratum
 *
 * http://hl7.org/fhir/_stratum
 */
export declare const _stratum = "http://hl7.org/fhir/_stratum";
/**
 * Payee
 *
 * Claim.Payee: The party to be reimbursed for cost of the products and services according to the terms of the policy.
 *
 * http://hl7.org/fhir/Payee
 */
export declare const Payee = "http://hl7.org/fhir/Payee";
/**
 * _measurementType
 *
 * (Modified) SubstanceDefinition.moiety.measurementType
 *
 * http://hl7.org/fhir/_measurementType
 */
export declare const _measurementType = "http://hl7.org/fhir/_measurementType";
/**
 * RelatedArtifact
 *
 * Related artifacts such as additional documentation, justification, or bibliographic references.
 *
 * http://hl7.org/fhir/RelatedArtifact
 */
export declare const RelatedArtifact = "http://hl7.org/fhir/RelatedArtifact";
/**
 * RequestOrchestrationActionDynamicValueComponent
 *
 * RequestOrchestrationActionComponentAction.RequestOrchestrationActionDynamicValueComponent: Customizations that should be applied to the statically defined resource. For example, if the dosage of a medication must be computed based on the patient's weight, a customization would be used to specify an expression that calculated the weight, and the path on the resource that would contain the result.
 *
 * http://hl7.org/fhir/RequestOrchestrationActionDynamicValueComponent
 */
export declare const RequestOrchestrationActionDynamicValueComponent = "http://hl7.org/fhir/RequestOrchestrationActionDynamicValueComponent";
/**
 * identity
 *
 * StructureDefinition.mapping.identity: An Internal id that is used to identify this mapping set when specific mappings are made.
 *
 * http://hl7.org/fhir/identity
 */
export declare const identity = "http://hl7.org/fhir/identity";
/**
 * subType
 *
 * Claim.subType: A finer grained suite of claim type codes which may convey additional information such as Inpatient vs Outpatient and/or a specialty service.
 *
 * http://hl7.org/fhir/subType
 */
export declare const subType = "http://hl7.org/fhir/subType";
/**
 * ValueSetExpansionContainsComponent
 *
 * ValueSetExpansionComponent.ValueSetExpansionContainsComponent: The codes that are contained in the value set expansion.
 *
 * http://hl7.org/fhir/ValueSetExpansionContainsComponent
 */
export declare const ValueSetExpansionContainsComponent = "http://hl7.org/fhir/ValueSetExpansionContainsComponent";
/**
 * MedicationKnowledgePackagingComponent
 *
 * MedicationKnowledgePackagingComponent: Information that only applies to packages (not products).
 *
 * http://hl7.org/fhir/MedicationKnowledgePackagingComponent
 */
export declare const MedicationKnowledgePackagingComponent = "http://hl7.org/fhir/MedicationKnowledgePackagingComponent";
/**
 * _display
 *
 * (Modified) ValueSet.expansion.contains.display
 *
 * http://hl7.org/fhir/_display
 */
export declare const _display = "http://hl7.org/fhir/_display";
/**
 * ImplementationGuideGlobalComponent
 *
 * ImplementationGuideGlobalComponent: A set of profiles that all resources covered by this implementation guide must conform to.
 *
 * http://hl7.org/fhir/ImplementationGuideGlobalComponent
 */
export declare const ImplementationGuideGlobalComponent = "http://hl7.org/fhir/ImplementationGuideGlobalComponent";
/**
 * _SubstanceNucleicAcid
 *
 * (Modified) SubstanceNucleicAcid
 *
 * http://hl7.org/fhir/_SubstanceNucleicAcid
 */
export declare const _SubstanceNucleicAcid = "http://hl7.org/fhir/_SubstanceNucleicAcid";
/**
 * TestScriptSetupActionOperationRequestHeaderComponent
 *
 * TestScriptTestComponent.TestActionOperation.TestScriptSetupActionOperationRequestHeaderComponent: Header elements would be used to set HTTP headers.
 *
 * http://hl7.org/fhir/TestScriptSetupActionOperationRequestHeaderComponent
 */
export declare const TestScriptSetupActionOperationRequestHeaderComponent = "http://hl7.org/fhir/TestScriptSetupActionOperationRequestHeaderComponent";
/**
 * targetItem
 *
 * PaymentReconciliation.allocation.targetItem
 *
 * http://hl7.org/fhir/targetItem
 */
export declare const targetItem = "http://hl7.org/fhir/targetItem";
/**
 * _dosingGuideline
 *
 * (Modified) MedicationKnowledge.indicationGuideline.dosingGuideline
 *
 * http://hl7.org/fhir/_dosingGuideline
 */
export declare const _dosingGuideline = "http://hl7.org/fhir/_dosingGuideline";
/**
 * _totalGross
 *
 * (Modified) Invoice.totalGross
 *
 * http://hl7.org/fhir/_totalGross
 */
export declare const _totalGross = "http://hl7.org/fhir/_totalGross";
/**
 * Reference
 *
 * A reference from one resource to another.
 *
 * http://hl7.org/fhir/Reference
 */
export declare const Reference = "http://hl7.org/fhir/Reference";
/**
 * _precheckBehavior
 *
 * (Modified) RequestOrchestration.action.action.precheckBehavior
 *
 * http://hl7.org/fhir/_precheckBehavior
 */
export declare const _precheckBehavior = "http://hl7.org/fhir/_precheckBehavior";
/**
 * _enableBehavior
 *
 * (Modified) Questionnaire.item.item.enableBehavior
 *
 * http://hl7.org/fhir/_enableBehavior
 */
export declare const _enableBehavior = "http://hl7.org/fhir/_enableBehavior";
/**
 * slot
 *
 * Appointment.slot: The slots from the participants' schedules that will be filled by the appointment.
 *
 * http://hl7.org/fhir/slot
 */
export declare const slot = "http://hl7.org/fhir/slot";
/**
 * groupDefinition
 *
 * Measure.group.stratifier.component.groupDefinition: A Group resource that defines this population as a set of characteristics.
 *
 * http://hl7.org/fhir/groupDefinition
 */
export declare const groupDefinition = "http://hl7.org/fhir/groupDefinition";
/**
 * _verifiedWith
 *
 * (Modified) Consent.verification.verifiedWith
 *
 * http://hl7.org/fhir/_verifiedWith
 */
export declare const _verifiedWith = "http://hl7.org/fhir/_verifiedWith";
/**
 * ResourceInteraction
 *
 * CapabilityStatementRestComponent.CapabilityStatementRestResourceComponent.ResourceInteraction: Identifies a restful operation supported by the solution.
 *
 * http://hl7.org/fhir/ResourceInteraction
 */
export declare const ResourceInteraction = "http://hl7.org/fhir/ResourceInteraction";
/**
 * _numberOfSubunits
 *
 * (Modified) SubstanceProtein.numberOfSubunits
 *
 * http://hl7.org/fhir/_numberOfSubunits
 */
export declare const _numberOfSubunits = "http://hl7.org/fhir/_numberOfSubunits";
/**
 * numberOfSeries
 *
 * ImagingStudy.numberOfSeries: Number of Series in the Study. This value given may be larger than the number of series elements this Resource contains due to resource availability, security, or other factors. This element should be present if any series elements are present.
 *
 * http://hl7.org/fhir/numberOfSeries
 */
export declare const numberOfSeries = "http://hl7.org/fhir/numberOfSeries";
/**
 * preAuthRefPeriod
 *
 * ExplanationOfBenefit.preAuthRefPeriod: The timeframe during which the supplied preauthorization reference may be quoted on claims to obtain the adjudication as provided.
 *
 * http://hl7.org/fhir/preAuthRefPeriod
 */
export declare const preAuthRefPeriod = "http://hl7.org/fhir/preAuthRefPeriod";
/**
 * _excludingRecurrenceId
 *
 * (Modified) Appointment.recurrenceTemplate.excludingRecurrenceId
 *
 * http://hl7.org/fhir/_excludingRecurrenceId
 */
export declare const _excludingRecurrenceId = "http://hl7.org/fhir/_excludingRecurrenceId";
/**
 * _baseCitation
 *
 * (Modified) Citation.citedArtifact.part.baseCitation
 *
 * http://hl7.org/fhir/_baseCitation
 */
export declare const _baseCitation = "http://hl7.org/fhir/_baseCitation";
/**
 * ContractAsset
 *
 * Contract.Term.ContractAsset: Contract Term Asset List.
 *
 * http://hl7.org/fhir/ContractAsset
 */
export declare const ContractAsset = "http://hl7.org/fhir/ContractAsset";
/**
 * ClinicalImpressionFindingComponent
 *
 * ClinicalImpressionFindingComponent: Specific findings or diagnoses that were considered likely or relevant to ongoing treatment.
 *
 * http://hl7.org/fhir/ClinicalImpressionFindingComponent
 */
export declare const ClinicalImpressionFindingComponent = "http://hl7.org/fhir/ClinicalImpressionFindingComponent";
/**
 * stopTestOnFail
 *
 * TestScript.test.action.assert.stopTestOnFail: Whether or not the current test execution will stop on failure for this assert.
 *
 * http://hl7.org/fhir/stopTestOnFail
 */
export declare const stopTestOnFail = "http://hl7.org/fhir/stopTestOnFail";
/**
 * _selectionBehavior
 *
 * (Modified) RequestOrchestration.action.action.selectionBehavior
 *
 * http://hl7.org/fhir/_selectionBehavior
 */
export declare const _selectionBehavior = "http://hl7.org/fhir/_selectionBehavior";
/**
 * _imports
 *
 * (Modified) CapabilityStatement.imports
 *
 * http://hl7.org/fhir/_imports
 */
export declare const _imports = "http://hl7.org/fhir/_imports";
/**
 * contextLinkId
 *
 * Contract.term.group.action.contextLinkId: Id [identifier??] of the clause or question text related to the requester of this action in the referenced form or QuestionnaireResponse.
 *
 * http://hl7.org/fhir/contextLinkId
 */
export declare const contextLinkId = "http://hl7.org/fhir/contextLinkId";
/**
 * _eye
 *
 * (Modified) VisionPrescription.lensSpecification.eye
 *
 * http://hl7.org/fhir/_eye
 */
export declare const _eye = "http://hl7.org/fhir/_eye";
/**
 * affiliation
 *
 * Citation.citedArtifact.contributorship.entry.affiliation: Organization affiliated with the contributor.
 *
 * http://hl7.org/fhir/affiliation
 */
export declare const affiliation = "http://hl7.org/fhir/affiliation";
/**
 * defaultValue
 *
 * TestScript.variable.defaultValue: A default, hard-coded, or user-defined value for this variable.
 *
 * http://hl7.org/fhir/defaultValue
 */
export declare const defaultValue = "http://hl7.org/fhir/defaultValue";
/**
 * MolecularSequence
 *
 * Representation of a molecular sequence.
 *
 * http://hl7.org/fhir/MolecularSequence
 */
export declare const MolecularSequence = "http://hl7.org/fhir/MolecularSequence";
/**
 * overload
 *
 * OperationDefinition.overload: Defines an appropriate combination of parameters to use when invoking this operation, to help code generators when generating overloaded parameter sets for this operation.
 *
 * http://hl7.org/fhir/overload
 */
export declare const overload = "http://hl7.org/fhir/overload";
/**
 * _productName
 *
 * (Modified) NutritionOrder.enteralFormula.additive.productName
 *
 * http://hl7.org/fhir/_productName
 */
export declare const _productName = "http://hl7.org/fhir/_productName";
/**
 * _comment
 *
 * (Modified) OperationDefinition.overload.comment
 *
 * http://hl7.org/fhir/_comment
 */
export declare const _comment = "http://hl7.org/fhir/_comment";
/**
 * _profile
 *
 * (Modified) Meta.profile
 *
 * http://hl7.org/fhir/_profile
 */
export declare const _profile = "http://hl7.org/fhir/_profile";
/**
 * _deleted
 *
 * (Modified) List.entry.deleted
 *
 * http://hl7.org/fhir/_deleted
 */
export declare const _deleted = "http://hl7.org/fhir/_deleted";
/**
 * _workflow
 *
 * (Modified) ExampleScenario.process.step.alternative.step.workflow
 *
 * http://hl7.org/fhir/_workflow
 */
export declare const _workflow = "http://hl7.org/fhir/_workflow";
/**
 * _attestationSignature
 *
 * (Modified) VerificationResult.validator.attestationSignature
 *
 * http://hl7.org/fhir/_attestationSignature
 */
export declare const _attestationSignature = "http://hl7.org/fhir/_attestationSignature";
/**
 * permittedDataType
 *
 * ObservationDefinition.component.permittedDataType: The data types allowed for the value element of the instance of this component observations.
 *
 * http://hl7.org/fhir/permittedDataType
 */
export declare const permittedDataType = "http://hl7.org/fhir/permittedDataType";
/**
 * gene
 *
 * SubstanceReferenceInformation.gene: Todo.
 *
 * http://hl7.org/fhir/gene
 */
export declare const gene = "http://hl7.org/fhir/gene";
/**
 * _prediction
 *
 * (Modified) RiskAssessment.prediction
 *
 * http://hl7.org/fhir/_prediction
 */
export declare const _prediction = "http://hl7.org/fhir/_prediction";
/**
 * exposureRoute
 *
 * AllergyIntolerance.reaction.exposureRoute: Identification of the route by which the subject was exposed to the substance.
 *
 * http://hl7.org/fhir/exposureRoute
 */
export declare const exposureRoute = "http://hl7.org/fhir/exposureRoute";
/**
 * height
 *
 * Attachment.height: Height of the image in pixels (photo/video).
 *
 * http://hl7.org/fhir/height
 */
export declare const height = "http://hl7.org/fhir/height";
/**
 * _entryClassifier
 *
 * (Modified) EvidenceReport.section.section.entryClassifier
 *
 * http://hl7.org/fhir/_entryClassifier
 */
export declare const _entryClassifier = "http://hl7.org/fhir/_entryClassifier";
/**
 * test
 *
 * TestScript.test: A test in this script.
 *
 * http://hl7.org/fhir/test
 */
export declare const test = "http://hl7.org/fhir/test";
/**
 * _previousAppointment
 *
 * (Modified) Appointment.previousAppointment
 *
 * http://hl7.org/fhir/_previousAppointment
 */
export declare const _previousAppointment = "http://hl7.org/fhir/_previousAppointment";
/**
 * implementationGuide
 *
 * CapabilityStatement.implementationGuide: A list of implementation guides that the server does (or should) support in their entirety.
 *
 * http://hl7.org/fhir/implementationGuide
 */
export declare const implementationGuide = "http://hl7.org/fhir/implementationGuide";
/**
 * UsageContext
 *
 * Specifies clinical/business/etc. metadata that can be used to retrieve, index and/or categorize an artifact. This metadata can either be specific to the applicable population (e.g., age category, DRG) or the specific context of care (e.g., venue, care setting, provider of care).
 *
 * http://hl7.org/fhir/UsageContext
 */
export declare const UsageContext = "http://hl7.org/fhir/UsageContext";
/**
 * EventDefinition
 *
 * The EventDefinition resource provides a reusable description of when a particular event can occur.
 *
 * http://hl7.org/fhir/EventDefinition
 */
export declare const EventDefinition = "http://hl7.org/fhir/EventDefinition";
/**
 * relatedIdentifier
 *
 * EvidenceReport.relatedIdentifier: A formal identifier that is used to identify things closely related to this EvidenceReport.
 *
 * http://hl7.org/fhir/relatedIdentifier
 */
export declare const relatedIdentifier = "http://hl7.org/fhir/relatedIdentifier";
/**
 * ImplementationGuideDependsOnComponent
 *
 * ImplementationGuideDependsOnComponent: Another implementation guide that this implementation depends on. Typically, an implementation guide uses value sets, profiles etc.defined in other implementation guides.
 *
 * http://hl7.org/fhir/ImplementationGuideDependsOnComponent
 */
export declare const ImplementationGuideDependsOnComponent = "http://hl7.org/fhir/ImplementationGuideDependsOnComponent";
/**
 * _procedureSequence
 *
 * (Modified) ExplanationOfBenefit.item.procedureSequence
 *
 * http://hl7.org/fhir/_procedureSequence
 */
export declare const _procedureSequence = "http://hl7.org/fhir/_procedureSequence";
/**
 * _copyrightLabel
 *
 * (Modified) ConceptMap.copyrightLabel
 *
 * http://hl7.org/fhir/_copyrightLabel
 */
export declare const _copyrightLabel = "http://hl7.org/fhir/_copyrightLabel";
/**
 * _navigationLinks
 *
 * (Modified) TestScript.test.action.assert.navigationLinks
 *
 * http://hl7.org/fhir/_navigationLinks
 */
export declare const _navigationLinks = "http://hl7.org/fhir/_navigationLinks";
/**
 * _generatedBy
 *
 * (Modified) GenomicStudy.analysis.input.generatedBy
 *
 * http://hl7.org/fhir/_generatedBy
 */
export declare const _generatedBy = "http://hl7.org/fhir/_generatedBy";
/**
 * administeredProduct
 *
 * Immunization.administeredProduct: An indication of which product was administered to the patient. This is typically a more detailed representation of the concept conveyed by the vaccineCode data element. If a Medication resource is referenced, it may be to a stand-alone resource or a contained resource within the Immunization resource.
 *
 * http://hl7.org/fhir/administeredProduct
 */
export declare const administeredProduct = "http://hl7.org/fhir/administeredProduct";
/**
 * validateProfileId
 *
 * TestScript.test.action.assert.validateProfileId: The ID of the Profile to validate against.
 *
 * http://hl7.org/fhir/validateProfileId
 */
export declare const validateProfileId = "http://hl7.org/fhir/validateProfileId";
/**
 * MedicationKnowledgeIndicationGuidelineComponent
 *
 * MedicationKnowledgeIndicationGuidelineComponent: Guidelines or protocols that are applicable for the administration of the medication based on indication.
 *
 * http://hl7.org/fhir/MedicationKnowledgeIndicationGuidelineComponent
 */
export declare const MedicationKnowledgeIndicationGuidelineComponent = "http://hl7.org/fhir/MedicationKnowledgeIndicationGuidelineComponent";
/**
 * intraspecificDescription
 *
 * SubstanceSourceMaterial.organism.intraspecificDescription: The intraspecific description of an organism shall be specified based on a controlled vocabulary. For Influenza Vaccine, the intraspecific description shall contain the syntax of the antigen in line with the WHO convention.
 *
 * http://hl7.org/fhir/intraspecificDescription
 */
export declare const intraspecificDescription = "http://hl7.org/fhir/intraspecificDescription";
/**
 * _protocolApplied
 *
 * (Modified) Immunization.protocolApplied
 *
 * http://hl7.org/fhir/_protocolApplied
 */
export declare const _protocolApplied = "http://hl7.org/fhir/_protocolApplied";
/**
 * _VerificationResult
 *
 * (Modified) VerificationResult
 *
 * http://hl7.org/fhir/_VerificationResult
 */
export declare const _VerificationResult = "http://hl7.org/fhir/_VerificationResult";
/**
 * monthInterval
 *
 * Appointment.recurrenceTemplate.monthlyTemplate.monthInterval: Indicates that recurring appointments should occur every nth month.
 *
 * http://hl7.org/fhir/monthInterval
 */
export declare const monthInterval = "http://hl7.org/fhir/monthInterval";
/**
 * expiry
 *
 * Substance.expiry: When the substance is no longer valid to use. For some substances, a single arbitrary date is used for expiry.
 *
 * http://hl7.org/fhir/expiry
 */
export declare const expiry = "http://hl7.org/fhir/expiry";
/**
 * versioning
 *
 * CapabilityStatement.rest.resource.versioning: This field is set to no-version to specify that the system does not support (server) or use (client) versioning for this resource type. If this has some other value, the server must at least correctly track and populate the versionId meta-property on resources. If the value is 'versioned-update', then the server supports all the versioning features, including using e-tags for version integrity in the API.
 *
 * http://hl7.org/fhir/versioning
 */
export declare const versioning = "http://hl7.org/fhir/versioning";
/**
 * pushTypeAvailable
 *
 * VerificationResult.primarySource.pushTypeAvailable: Type of alerts/updates the primary source can send (specific requested changes; any changes; as defined by source).
 *
 * http://hl7.org/fhir/pushTypeAvailable
 */
export declare const pushTypeAvailable = "http://hl7.org/fhir/pushTypeAvailable";
/**
 * CitationCitedArtifactStatusDateComponent
 *
 * CitationCitedArtifactComponent.CitationCitedArtifactStatusDateComponent: An effective date or period, historical or future, actual or expected, for a status of the cited artifact.
 *
 * http://hl7.org/fhir/CitationCitedArtifactStatusDateComponent
 */
export declare const CitationCitedArtifactStatusDateComponent = "http://hl7.org/fhir/CitationCitedArtifactStatusDateComponent";
/**
 * _assertion
 *
 * (Modified) TestPlan.testCase.assertion
 *
 * http://hl7.org/fhir/_assertion
 */
export declare const _assertion = "http://hl7.org/fhir/_assertion";
/**
 * diagnosis
 *
 * ExplanationOfBenefit.diagnosis.diagnosis
 *
 * http://hl7.org/fhir/diagnosis
 */
export declare const diagnosis = "http://hl7.org/fhir/diagnosis";
/**
 * _ifNoneExist
 *
 * (Modified) Bundle.entry.request.ifNoneExist
 *
 * http://hl7.org/fhir/_ifNoneExist
 */
export declare const _ifNoneExist = "http://hl7.org/fhir/_ifNoneExist";
/**
 * _low
 *
 * (Modified) SubstancePolymer.repeat.repeatUnit.degreeOfPolymerisation.low
 *
 * http://hl7.org/fhir/_low
 */
export declare const _low = "http://hl7.org/fhir/_low";
/**
 * undesirableEffect
 *
 * ClinicalUseDefinition.undesirableEffect: Describe the possible undesirable effects (negative outcomes) from the use of the medicinal product as treatment.
 *
 * http://hl7.org/fhir/undesirableEffect
 */
export declare const undesirableEffect = "http://hl7.org/fhir/undesirableEffect";
/**
 * _base
 *
 * (Modified) VisionPrescription.lensSpecification.prism.base
 *
 * http://hl7.org/fhir/_base
 */
export declare const _base = "http://hl7.org/fhir/_base";
/**
 * queryCriteria
 *
 * SubscriptionTopic.resourceTrigger.queryCriteria: The FHIR query based rules that the server should use to determine when to trigger a notification for this subscription topic.
 *
 * http://hl7.org/fhir/queryCriteria
 */
export declare const queryCriteria = "http://hl7.org/fhir/queryCriteria";
/**
 * _availableEndTime
 *
 * (Modified) Availability.availableTime.availableEndTime
 *
 * http://hl7.org/fhir/_availableEndTime
 */
export declare const _availableEndTime = "http://hl7.org/fhir/_availableEndTime";
/**
 * number
 *
 * ExampleScenario.process.step.process.step.alternative.step.number: The sequential number of the step, e.g. 1.2.5.
 *
 * http://hl7.org/fhir/number
 */
export declare const number = "http://hl7.org/fhir/number";
/**
 * spatialReference
 *
 * BodyStructure.excludedStructure.spatialReference: XY or XYZ-coordinate orientation for structure.
 *
 * http://hl7.org/fhir/spatialReference
 */
export declare const spatialReference = "http://hl7.org/fhir/spatialReference";
/**
 * conditionality
 *
 * Requirements.statement.conditionality: This boolean flag is set to true of the text of the requirement is conditional on something e.g. it includes lanauage like 'if x then y'. This conditionality flag is introduced for purposes of filtering and colour highlighting etc.
 *
 * http://hl7.org/fhir/conditionality
 */
export declare const conditionality = "http://hl7.org/fhir/conditionality";
/**
 * _codeFilter
 *
 * (Modified) DataRequirement.codeFilter
 *
 * http://hl7.org/fhir/_codeFilter
 */
export declare const _codeFilter = "http://hl7.org/fhir/_codeFilter";
/**
 * SubstanceDefinitionCharacterizationComponent
 *
 * SubstanceDefinitionCharacterizationComponent: General specifications for this substance.
 *
 * http://hl7.org/fhir/SubstanceDefinitionCharacterizationComponent
 */
export declare const SubstanceDefinitionCharacterizationComponent = "http://hl7.org/fhir/SubstanceDefinitionCharacterizationComponent";
/**
 * offsets
 *
 * SampledData.offsets: A series of data points which are decimal values separated by a single space (character u20).  The units in which the offsets are expressed are found in intervalUnit.  The absolute point at which the measurements begin SHALL be conveyed outside the scope of this datatype, e.g. Observation.effectiveDateTime for a timing offset.
 *
 * http://hl7.org/fhir/offsets
 */
export declare const offsets = "http://hl7.org/fhir/offsets";
/**
 * _orderedBy
 *
 * (Modified) List.orderedBy
 *
 * http://hl7.org/fhir/_orderedBy
 */
export declare const _orderedBy = "http://hl7.org/fhir/_orderedBy";
/**
 * _authorizationUrl
 *
 * (Modified) CoverageEligibilityResponse.insurance.item.authorizationUrl
 *
 * http://hl7.org/fhir/_authorizationUrl
 */
export declare const _authorizationUrl = "http://hl7.org/fhir/_authorizationUrl";
/**
 * _carrierAIDC
 *
 * (Modified) Device.udiCarrier.carrierAIDC
 *
 * http://hl7.org/fhir/_carrierAIDC
 */
export declare const _carrierAIDC = "http://hl7.org/fhir/_carrierAIDC";
/**
 * _episodeOfCare
 *
 * (Modified) Encounter.episodeOfCare
 *
 * http://hl7.org/fhir/_episodeOfCare
 */
export declare const _episodeOfCare = "http://hl7.org/fhir/_episodeOfCare";
/**
 * disabledDisplay
 *
 * Questionnaire.item.item.disabledDisplay: Indicates if and how items that are disabled (because enableWhen evaluates to 'false') should be displayed.
 *
 * http://hl7.org/fhir/disabledDisplay
 */
export declare const disabledDisplay = "http://hl7.org/fhir/disabledDisplay";
/**
 * DocumentReference
 *
 * A reference to a document of any kind for any purpose. While the term “document” implies a more narrow focus, for this resource this “document” encompasses *any* serialized object with a mime-type, it includes formal patient-centric documents (CDA), clinical notes, scanned paper, non-patient specific documents like policy text, as well as a photo, video, or audio recording acquired or used in healthcare.  The DocumentReference resource provides metadata about the document so that the document can be discovered and managed.  The actual content may be inline base64 encoded data or provided by direct reference.
 *
 * http://hl7.org/fhir/DocumentReference
 */
export declare const DocumentReference = "http://hl7.org/fhir/DocumentReference";
/**
 * compositeScoring
 *
 * Measure.compositeScoring: If this is a composite measure, the scoring method used to combine the component measures to determine the composite score.
 *
 * http://hl7.org/fhir/compositeScoring
 */
export declare const compositeScoring = "http://hl7.org/fhir/compositeScoring";
/**
 * _yearInterval
 *
 * (Modified) Appointment.recurrenceTemplate.yearlyTemplate.yearInterval
 *
 * http://hl7.org/fhir/_yearInterval
 */
export declare const _yearInterval = "http://hl7.org/fhir/_yearInterval";
/**
 * RelatedPersonCommunicationComponent
 *
 * RelatedPersonCommunicationComponent: A language which may be used to communicate with the related person about the patient's health.
 *
 * http://hl7.org/fhir/RelatedPersonCommunicationComponent
 */
export declare const RelatedPersonCommunicationComponent = "http://hl7.org/fhir/RelatedPersonCommunicationComponent";
/**
 * _displayName
 *
 * (Modified) Device.displayName
 *
 * http://hl7.org/fhir/_displayName
 */
export declare const _displayName = "http://hl7.org/fhir/_displayName";
/**
 * _monday
 *
 * (Modified) Appointment.recurrenceTemplate.weeklyTemplate.monday
 *
 * http://hl7.org/fhir/_monday
 */
export declare const _monday = "http://hl7.org/fhir/_monday";
/**
 * messaging
 *
 * CapabilityStatement.messaging: A description of the messaging capabilities of the solution.
 *
 * http://hl7.org/fhir/messaging
 */
export declare const messaging = "http://hl7.org/fhir/messaging";
/**
 * geneElement
 *
 * SubstanceReferenceInformation.geneElement: Todo.
 *
 * http://hl7.org/fhir/geneElement
 */
export declare const geneElement = "http://hl7.org/fhir/geneElement";
/**
 * exclude
 *
 * EvidenceVariable.characteristic.exclude: When true, this characteristic is an exclusion criterion. In other words, not matching this characteristic definition is equivalent to meeting this criterion.
 *
 * http://hl7.org/fhir/exclude
 */
export declare const exclude = "http://hl7.org/fhir/exclude";
/**
 * _itemSequence
 *
 * (Modified) ExplanationOfBenefit.addItem.itemSequence
 *
 * http://hl7.org/fhir/_itemSequence
 */
export declare const _itemSequence = "http://hl7.org/fhir/_itemSequence";
/**
 * _artifactAssessment
 *
 * (Modified) Citation.citedArtifact.classification.artifactAssessment
 *
 * http://hl7.org/fhir/_artifactAssessment
 */
export declare const _artifactAssessment = "http://hl7.org/fhir/_artifactAssessment";
/**
 * dispenseRequest
 *
 * MedicationRequest.dispenseRequest: Indicates the specific details for the dispense or medication supply part of a medication request (also known as a Medication Prescription or Medication Order).  Note that this information is not always sent with the order.  There may be in some settings (e.g. hospitals) institutional or system support for completing the dispense details in the pharmacy department.
 *
 * http://hl7.org/fhir/dispenseRequest
 */
export declare const dispenseRequest = "http://hl7.org/fhir/dispenseRequest";
/**
 * intendedJurisdiction
 *
 * MedicationKnowledge.intendedJurisdiction: Lists the jurisdictions that this medication knowledge was written for.
 *
 * http://hl7.org/fhir/intendedJurisdiction
 */
export declare const intendedJurisdiction = "http://hl7.org/fhir/intendedJurisdiction";
/**
 * _restriction
 *
 * (Modified) Transport.restriction
 *
 * http://hl7.org/fhir/_restriction
 */
export declare const _restriction = "http://hl7.org/fhir/_restriction";
/**
 * ImmunizationEvaluation
 *
 * Describes a comparison of an immunization event against published recommendations to determine if the administration is "valid" in relation to those  recommendations.
 *
 * http://hl7.org/fhir/ImmunizationEvaluation
 */
export declare const ImmunizationEvaluation = "http://hl7.org/fhir/ImmunizationEvaluation";
/**
 * Observation
 *
 * Measurements and simple assertions made about a patient, device or other subject.
 *
 * http://hl7.org/fhir/Observation
 */
export declare const Observation = "http://hl7.org/fhir/Observation";
/**
 * _supplier
 *
 * (Modified) SupplyRequest.supplier
 *
 * http://hl7.org/fhir/_supplier
 */
export declare const _supplier = "http://hl7.org/fhir/_supplier";
/**
 * NutritionIntakePerformerComponent
 *
 * NutritionIntakePerformerComponent: Who performed the intake and how they were involved.
 *
 * http://hl7.org/fhir/NutritionIntakePerformerComponent
 */
export declare const NutritionIntakePerformerComponent = "http://hl7.org/fhir/NutritionIntakePerformerComponent";
/**
 * CapabilityStatementRestComponentSearchParam
 *
 * Search parameters that are supported for searching all resources for implementations to support and/or make use of - either references to ones defined in the specification, or additional ones defined for/by the implementation. This is only for searches executed against the system-level endpoint.
 *
 * http://hl7.org/fhir/CapabilityStatementRestComponentSearchParam
 */
export declare const CapabilityStatementRestComponentSearchParam = "http://hl7.org/fhir/CapabilityStatementRestComponentSearchParam";
/**
 * _SubstanceReferenceInformation
 *
 * (Modified) SubstanceReferenceInformation
 *
 * http://hl7.org/fhir/_SubstanceReferenceInformation
 */
export declare const _SubstanceReferenceInformation = "http://hl7.org/fhir/_SubstanceReferenceInformation";
/**
 * _CarePlan
 *
 * (Modified) CarePlan
 *
 * http://hl7.org/fhir/_CarePlan
 */
export declare const _CarePlan = "http://hl7.org/fhir/_CarePlan";
/**
 * AdverseEventPreventiveActionComponent
 *
 * AdverseEventPreventiveActionComponent: Preventive actions that contributed to avoiding the adverse event.
 *
 * http://hl7.org/fhir/AdverseEventPreventiveActionComponent
 */
export declare const AdverseEventPreventiveActionComponent = "http://hl7.org/fhir/AdverseEventPreventiveActionComponent";
/**
 * outsideFoodAllowed
 *
 * NutritionOrder.outsideFoodAllowed: This modifier is used to convey whether a food item is allowed to be brought in by the patient and/or family.  If set to true, indicates that the receiving system does not need to supply the food item.
 *
 * http://hl7.org/fhir/outsideFoodAllowed
 */
export declare const outsideFoodAllowed = "http://hl7.org/fhir/outsideFoodAllowed";
/**
 * _maxVolumeToDeliver
 *
 * (Modified) NutritionOrder.enteralFormula.maxVolumeToDeliver
 *
 * http://hl7.org/fhir/_maxVolumeToDeliver
 */
export declare const _maxVolumeToDeliver = "http://hl7.org/fhir/_maxVolumeToDeliver";
/**
 * InventoryItemAssociationComponent
 *
 * InventoryItemAssociationComponent: Association with other items or products.
 *
 * http://hl7.org/fhir/InventoryItemAssociationComponent
 */
export declare const InventoryItemAssociationComponent = "http://hl7.org/fhir/InventoryItemAssociationComponent";
/**
 * deliverFor
 *
 * SupplyRequest.deliverFor: The patient to whom the supply will be given or for whom they will be used.
 *
 * http://hl7.org/fhir/deliverFor
 */
export declare const deliverFor = "http://hl7.org/fhir/deliverFor";
/**
 * ElementDefinitionExampleComponent
 *
 * ElementDefinitionExampleComponent: A sample value for this element demonstrating the type of information that would typically be found in the element.
 *
 * http://hl7.org/fhir/ElementDefinitionExampleComponent
 */
export declare const ElementDefinitionExampleComponent = "http://hl7.org/fhir/ElementDefinitionExampleComponent";
/**
 * _totalPriceComponent
 *
 * (Modified) Invoice.totalPriceComponent
 *
 * http://hl7.org/fhir/_totalPriceComponent
 */
export declare const _totalPriceComponent = "http://hl7.org/fhir/_totalPriceComponent";
/**
 * _carrierHRF
 *
 * (Modified) Device.udiCarrier.carrierHRF
 *
 * http://hl7.org/fhir/_carrierHRF
 */
export declare const _carrierHRF = "http://hl7.org/fhir/_carrierHRF";
/**
 * _subProperty
 *
 * (Modified) ValueSet.expansion.contains.contains.property.subProperty
 *
 * http://hl7.org/fhir/_subProperty
 */
export declare const _subProperty = "http://hl7.org/fhir/_subProperty";
/**
 * allowed
 *
 * MedicationRequest.substitution.allowed
 *
 * http://hl7.org/fhir/allowed
 */
export declare const allowed = "http://hl7.org/fhir/allowed";
/**
 * _searchType
 *
 * (Modified) OperationDefinition.parameter.part.searchType
 *
 * http://hl7.org/fhir/_searchType
 */
export declare const _searchType = "http://hl7.org/fhir/_searchType";
/**
 * List
 *
 * A List is a curated collection of resources, for things such as problem lists, allergy lists, facility list, organization list, etc.
 *
 * http://hl7.org/fhir/List
 */
export declare const List = "http://hl7.org/fhir/List";
/**
 * responseId
 *
 * TestScript.teardown.action.operation.responseId: The fixture id (maybe new) to map to the response.
 *
 * http://hl7.org/fhir/responseId
 */
export declare const responseId = "http://hl7.org/fhir/responseId";
/**
 * _defaultManualCompletion
 *
 * (Modified) TestScript.test.action.assert.defaultManualCompletion
 *
 * http://hl7.org/fhir/_defaultManualCompletion
 */
export declare const _defaultManualCompletion = "http://hl7.org/fhir/_defaultManualCompletion";
/**
 * _subscriberId
 *
 * (Modified) Coverage.subscriberId
 *
 * http://hl7.org/fhir/_subscriberId
 */
export declare const _subscriberId = "http://hl7.org/fhir/_subscriberId";
/**
 * _groupingId
 *
 * (Modified) ImplementationGuide.definition.resource.groupingId
 *
 * http://hl7.org/fhir/_groupingId
 */
export declare const _groupingId = "http://hl7.org/fhir/_groupingId";
/**
 * _protocolPerformed
 *
 * (Modified) GenomicStudy.analysis.protocolPerformed
 *
 * http://hl7.org/fhir/_protocolPerformed
 */
export declare const _protocolPerformed = "http://hl7.org/fhir/_protocolPerformed";
/**
 * subPotentReason
 *
 * MedicationAdministration.subPotentReason: The reason or reasons why the full dose was not administered.
 *
 * http://hl7.org/fhir/subPotentReason
 */
export declare const subPotentReason = "http://hl7.org/fhir/subPotentReason";
/**
 * maxValue
 *
 * ElementDefinition.maxValue
 *
 * http://hl7.org/fhir/maxValue
 */
export declare const maxValue = "http://hl7.org/fhir/maxValue";
/**
 * _data
 *
 * (Modified) TriggerDefinition.data
 *
 * http://hl7.org/fhir/_data
 */
export declare const _data = "http://hl7.org/fhir/_data";
/**
 * _disulfideLinkage
 *
 * (Modified) SubstanceProtein.disulfideLinkage
 *
 * http://hl7.org/fhir/_disulfideLinkage
 */
export declare const _disulfideLinkage = "http://hl7.org/fhir/_disulfideLinkage";
/**
 * metadata
 *
 * TestScript.metadata: The required capability must exist and are assumed to function correctly on the FHIR server being tested.
 *
 * http://hl7.org/fhir/metadata
 */
export declare const metadata = "http://hl7.org/fhir/metadata";
/**
 * ConditionParticipantComponent
 *
 * ConditionParticipantComponent: Indicates who or what participated in the activities related to the condition and how they were involved.
 *
 * http://hl7.org/fhir/ConditionParticipantComponent
 */
export declare const ConditionParticipantComponent = "http://hl7.org/fhir/ConditionParticipantComponent";
/**
 * rationale
 *
 * RiskAssessment.prediction.rationale: Additional information explaining the basis for the prediction.
 *
 * http://hl7.org/fhir/rationale
 */
export declare const rationale = "http://hl7.org/fhir/rationale";
/**
 * tax
 *
 * ClaimResponse.addItem.detail.tax: The total of taxes applicable for this product or service.
 *
 * http://hl7.org/fhir/tax
 */
export declare const tax = "http://hl7.org/fhir/tax";
/**
 * _line
 *
 * (Modified) Address.line
 *
 * http://hl7.org/fhir/_line
 */
export declare const _line = "http://hl7.org/fhir/_line";
/**
 * index
 *
 * TestScript.destination.index: Abstract name given to a destination server in this test script.  The name is provided as a number starting at 1.
 *
 * http://hl7.org/fhir/index
 */
export declare const index = "http://hl7.org/fhir/index";
/**
 * _firstPage
 *
 * (Modified) Citation.citedArtifact.publicationForm.firstPage
 *
 * http://hl7.org/fhir/_firstPage
 */
export declare const _firstPage = "http://hl7.org/fhir/_firstPage";
/**
 * verifiedBy
 *
 * Consent.verification.verifiedBy: The person who conducted the verification/validation of the Grantor decision.
 *
 * http://hl7.org/fhir/verifiedBy
 */
export declare const verifiedBy = "http://hl7.org/fhir/verifiedBy";
/**
 * _requestProvider
 *
 * (Modified) EnrollmentResponse.requestProvider
 *
 * http://hl7.org/fhir/_requestProvider
 */
export declare const _requestProvider = "http://hl7.org/fhir/_requestProvider";
/**
 * Diagnosis
 *
 * ExplanationOfBenefit.Diagnosis: Information about diagnoses relevant to the claim items.
 *
 * http://hl7.org/fhir/Diagnosis
 */
export declare const Diagnosis = "http://hl7.org/fhir/Diagnosis";
/**
 * _hybridType
 *
 * (Modified) SubstanceSourceMaterial.organism.hybrid.hybridType
 *
 * http://hl7.org/fhir/_hybridType
 */
export declare const _hybridType = "http://hl7.org/fhir/_hybridType";
/**
 * _abnormalCodedValueSet
 *
 * (Modified) ObservationDefinition.component.qualifiedValue.abnormalCodedValueSet
 *
 * http://hl7.org/fhir/_abnormalCodedValueSet
 */
export declare const _abnormalCodedValueSet = "http://hl7.org/fhir/_abnormalCodedValueSet";
/**
 * Encounter
 *
 * An interaction between healthcare provider(s), and/or patient(s) for the purpose of providing healthcare service(s) or assessing the health status of patient(s).
 *
 * http://hl7.org/fhir/Encounter
 */
export declare const Encounter = "http://hl7.org/fhir/Encounter";
/**
 * expression
 *
 * RequestOrchestration.action.condition.expression: An expression that returns true or false, indicating whether or not the condition is satisfied.
 *
 * http://hl7.org/fhir/expression
 */
export declare const expression = "http://hl7.org/fhir/expression";
/**
 * _current
 *
 * (Modified) SubscriptionTopic.resourceTrigger.queryCriteria.current
 *
 * http://hl7.org/fhir/_current
 */
export declare const _current = "http://hl7.org/fhir/_current";
/**
 * BackboneType
 *
 * Base definition for the few data types that are allowed to carry modifier extensions.
 *
 * http://hl7.org/fhir/BackboneType
 */
export declare const BackboneType = "http://hl7.org/fhir/BackboneType";
/**
 * collection
 *
 * SpecimenDefinition.collection: The action to be performed for collecting the specimen.
 *
 * http://hl7.org/fhir/collection
 */
export declare const collection = "http://hl7.org/fhir/collection";
/**
 * _family
 *
 * (Modified) SubstanceSourceMaterial.organism.family
 *
 * http://hl7.org/fhir/_family
 */
export declare const _family = "http://hl7.org/fhir/_family";
/**
 * _validated
 *
 * (Modified) TestScript.metadata.capability.validated
 *
 * http://hl7.org/fhir/_validated
 */
export declare const _validated = "http://hl7.org/fhir/_validated";
/**
 * question
 *
 * Questionnaire.item.item.enableWhen.question: The linkId for the question whose answer (or lack of answer) governs whether this item is enabled.
 *
 * http://hl7.org/fhir/question
 */
export declare const question = "http://hl7.org/fhir/question";
/**
 * _noMap
 *
 * (Modified) ConceptMap.group.element.noMap
 *
 * http://hl7.org/fhir/_noMap
 */
export declare const _noMap = "http://hl7.org/fhir/_noMap";
/**
 * _comparisonGroup
 *
 * (Modified) ResearchStudy.comparisonGroup
 *
 * http://hl7.org/fhir/_comparisonGroup
 */
export declare const _comparisonGroup = "http://hl7.org/fhir/_comparisonGroup";
/**
 * EnrollmentRequest
 *
 * This resource provides the insurance enrollment details to the insurer regarding a specified coverage.
 *
 * http://hl7.org/fhir/EnrollmentRequest
 */
export declare const EnrollmentRequest = "http://hl7.org/fhir/EnrollmentRequest";
/**
 * _surfaceOrientation
 *
 * (Modified) BodyStructure.excludedStructure.bodyLandmarkOrientation.surfaceOrientation
 *
 * http://hl7.org/fhir/_surfaceOrientation
 */
export declare const _surfaceOrientation = "http://hl7.org/fhir/_surfaceOrientation";
/**
 * prescription
 *
 * ExplanationOfBenefit.prescription: Prescription is the document/authorization given to the claim author for them to provide products and services for which consideration (reimbursement) is sought. Could be a RX for medications, an 'order' for oxygen or wheelchair or physiotherapy treatments.
 *
 * http://hl7.org/fhir/prescription
 */
export declare const prescription = "http://hl7.org/fhir/prescription";
/**
 * _contributorship
 *
 * (Modified) Citation.citedArtifact.contributorship
 *
 * http://hl7.org/fhir/_contributorship
 */
export declare const _contributorship = "http://hl7.org/fhir/_contributorship";
/**
 * synthesisType
 *
 * Evidence.synthesisType: The method to combine studies.
 *
 * http://hl7.org/fhir/synthesisType
 */
export declare const synthesisType = "http://hl7.org/fhir/synthesisType";
/**
 * _anchor
 *
 * (Modified) ImplementationGuide.manifest.page.anchor
 *
 * http://hl7.org/fhir/_anchor
 */
export declare const _anchor = "http://hl7.org/fhir/_anchor";
/**
 * _suppress
 *
 * (Modified) ElementDefinition.constraint.suppress
 *
 * http://hl7.org/fhir/_suppress
 */
export declare const _suppress = "http://hl7.org/fhir/_suppress";
/**
 * _other
 *
 * (Modified) Patient.link.other
 *
 * http://hl7.org/fhir/_other
 */
export declare const _other = "http://hl7.org/fhir/_other";
/**
 * variable
 *
 * StructureMap.group.rule.target.variable: Named context for field, if desired, and a field is specified.
 *
 * http://hl7.org/fhir/variable
 */
export declare const variable = "http://hl7.org/fhir/variable";
/**
 * MolecularSequenceRelativeComponent
 *
 * MolecularSequenceRelativeComponent: A sequence defined relative to another sequence.
 *
 * http://hl7.org/fhir/MolecularSequenceRelativeComponent
 */
export declare const MolecularSequenceRelativeComponent = "http://hl7.org/fhir/MolecularSequenceRelativeComponent";
/**
 * Ingredient
 *
 * An ingredient of a manufactured item or pharmaceutical product.
 *
 * http://hl7.org/fhir/Ingredient
 */
export declare const Ingredient = "http://hl7.org/fhir/Ingredient";
/**
 * _occurrenceDateTime
 *
 * (Modified) GuidanceResponse.occurrenceDateTime
 *
 * http://hl7.org/fhir/_occurrenceDateTime
 */
export declare const _occurrenceDateTime = "http://hl7.org/fhir/_occurrenceDateTime";
/**
 * Annotation
 *
 * A  text note which also  contains information about who made the statement and when.
 *
 * http://hl7.org/fhir/Annotation
 */
export declare const Annotation = "http://hl7.org/fhir/Annotation";
/**
 * SubstanceReferenceInformationGeneComponent
 *
 * SubstanceReferenceInformationGeneComponent: Todo.
 *
 * http://hl7.org/fhir/SubstanceReferenceInformationGeneComponent
 */
export declare const SubstanceReferenceInformationGeneComponent = "http://hl7.org/fhir/SubstanceReferenceInformationGeneComponent";
/**
 * _valueQuantity
 *
 * (Modified) Evidence.statistic.modelCharacteristic.variable.valueQuantity
 *
 * http://hl7.org/fhir/_valueQuantity
 */
export declare const _valueQuantity = "http://hl7.org/fhir/_valueQuantity";
/**
 * DeviceDefinitionCorrectiveActionComponent
 *
 * DeviceDefinitionCorrectiveActionComponent: Tracking of latest field safety corrective action.
 *
 * http://hl7.org/fhir/DeviceDefinitionCorrectiveActionComponent
 */
export declare const DeviceDefinitionCorrectiveActionComponent = "http://hl7.org/fhir/DeviceDefinitionCorrectiveActionComponent";
/**
 * OperationDefinitionParameterComponent
 *
 * OperationDefinitionParameterComponent: The parameters for the operation/query.
 *
 * http://hl7.org/fhir/OperationDefinitionParameterComponent
 */
export declare const OperationDefinitionParameterComponent = "http://hl7.org/fhir/OperationDefinitionParameterComponent";
/**
 * EvidenceVariableCharacteristicDefinitionByCombinationComponent
 *
 * EvidenceVariableCharacteristicComponent.EvidenceVariableCharacteristicDefinitionByCombinationComponent: Defines the characteristic as a combination of two or more characteristics.
 *
 * http://hl7.org/fhir/EvidenceVariableCharacteristicDefinitionByCombinationComponent
 */
export declare const EvidenceVariableCharacteristicDefinitionByCombinationComponent = "http://hl7.org/fhir/EvidenceVariableCharacteristicDefinitionByCombinationComponent";
/**
 * SpecimenDefinitionTypeTestedHandlingComponent
 *
 * SpecimenDefinitionTypeTestedComponent.SpecimenDefinitionTypeTestedHandlingComponent: Set of instructions for preservation/transport of the specimen at a defined temperature interval, prior the testing process.
 *
 * http://hl7.org/fhir/SpecimenDefinitionTypeTestedHandlingComponent
 */
export declare const SpecimenDefinitionTypeTestedHandlingComponent = "http://hl7.org/fhir/SpecimenDefinitionTypeTestedHandlingComponent";
/**
 * _testRun
 *
 * (Modified) TestPlan.testCase.testRun
 *
 * http://hl7.org/fhir/_testRun
 */
export declare const _testRun = "http://hl7.org/fhir/_testRun";
/**
 * compareToSourceId
 *
 * TestScript.test.action.assert.compareToSourceId: Id of the source fixture used as the contents to be evaluated by either the "source/expression" or "sourceId/path" definition.
 *
 * http://hl7.org/fhir/compareToSourceId
 */
export declare const compareToSourceId = "http://hl7.org/fhir/compareToSourceId";
/**
 * _definitional
 *
 * (Modified) MedicationKnowledge.definitional
 *
 * http://hl7.org/fhir/_definitional
 */
export declare const _definitional = "http://hl7.org/fhir/_definitional";
/**
 * _testCase
 *
 * (Modified) TestPlan.testCase
 *
 * http://hl7.org/fhir/_testCase
 */
export declare const _testCase = "http://hl7.org/fhir/_testCase";
/**
 * _PaymentReconciliation
 *
 * (Modified) PaymentReconciliation
 *
 * http://hl7.org/fhir/_PaymentReconciliation
 */
export declare const _PaymentReconciliation = "http://hl7.org/fhir/_PaymentReconciliation";
/**
 * valuedItem
 *
 * Contract.term.group.asset.valuedItem: Contract Valued Item List.
 *
 * http://hl7.org/fhir/valuedItem
 */
export declare const valuedItem = "http://hl7.org/fhir/valuedItem";
/**
 * relatedItem
 *
 * InventoryItem.association.relatedItem: The related item or product.
 *
 * http://hl7.org/fhir/relatedItem
 */
export declare const relatedItem = "http://hl7.org/fhir/relatedItem";
/**
 * consumedItem
 *
 * NutritionIntake.consumedItem: What food or fluid product or item was consumed.
 *
 * http://hl7.org/fhir/consumedItem
 */
export declare const consumedItem = "http://hl7.org/fhir/consumedItem";
/**
 * search
 *
 * CompartmentDefinition.search: Whether the search syntax is supported,.
 *
 * http://hl7.org/fhir/search
 */
export declare const search = "http://hl7.org/fhir/search";
/**
 * duration
 *
 * EvidenceVariable.characteristic.definitionByCombination.characteristic.duration
 *
 * http://hl7.org/fhir/duration
 */
export declare const duration = "http://hl7.org/fhir/duration";
/**
 * status
 *
 * PackagedProductDefinition.status: The status within the lifecycle of this item. A high level status, this is not intended to duplicate details carried elsewhere such as legal status, or authorization or marketing status.
 *
 * http://hl7.org/fhir/status
 */
export declare const status = "http://hl7.org/fhir/status";
/**
 * _context
 *
 * (Modified) Contract.term.group.asset.context
 *
 * http://hl7.org/fhir/_context
 */
export declare const _context = "http://hl7.org/fhir/_context";
/**
 * _requirements
 *
 * (Modified) ElementDefinition.constraint.requirements
 *
 * http://hl7.org/fhir/_requirements
 */
export declare const _requirements = "http://hl7.org/fhir/_requirements";
/**
 * _subjectType
 *
 * (Modified) Questionnaire.subjectType
 *
 * http://hl7.org/fhir/_subjectType
 */
export declare const _subjectType = "http://hl7.org/fhir/_subjectType";
/**
 * _use
 *
 * (Modified) OperationDefinition.parameter.use
 *
 * http://hl7.org/fhir/_use
 */
export declare const _use = "http://hl7.org/fhir/_use";
/**
 * udi
 *
 * ExplanationOfBenefit.item.detail.udi: Unique Device Identifiers associated with this line item.
 *
 * http://hl7.org/fhir/udi
 */
export declare const udi = "http://hl7.org/fhir/udi";
/**
 * nameType
 *
 * InventoryItem.name.nameType: The type of name e.g. 'brand-name', 'functional-name', 'common-name'.
 *
 * http://hl7.org/fhir/nameType
 */
export declare const nameType = "http://hl7.org/fhir/nameType";
/**
 * _producedFrom
 *
 * (Modified) AdministrableProductDefinition.producedFrom
 *
 * http://hl7.org/fhir/_producedFrom
 */
export declare const _producedFrom = "http://hl7.org/fhir/_producedFrom";
/**
 * _interval
 *
 * (Modified) SampledData.interval
 *
 * http://hl7.org/fhir/_interval
 */
export declare const _interval = "http://hl7.org/fhir/_interval";
/**
 * summary
 *
 * Citation.summary: A human-readable display of key concepts to represent the citation.
 *
 * http://hl7.org/fhir/summary
 */
export declare const summary = "http://hl7.org/fhir/summary";
/**
 * MedicinalProductDefinitionCharacteristicComponent
 *
 * MedicinalProductDefinitionCharacteristicComponent: Allows the key product features to be recorded, such as "sugar free", "modified release", "parallel import".
 *
 * http://hl7.org/fhir/MedicinalProductDefinitionCharacteristicComponent
 */
export declare const MedicinalProductDefinitionCharacteristicComponent = "http://hl7.org/fhir/MedicinalProductDefinitionCharacteristicComponent";
/**
 * sex
 *
 * FamilyMemberHistory.sex: The birth sex of the family member.
 *
 * http://hl7.org/fhir/sex
 */
export declare const sex = "http://hl7.org/fhir/sex";
/**
 * AdministrableProductDefinition
 *
 * A medicinal product in the final form which is suitable for administering to a patient (after any mixing of multiple components, dissolution etc. has been performed).
 *
 * http://hl7.org/fhir/AdministrableProductDefinition
 */
export declare const AdministrableProductDefinition = "http://hl7.org/fhir/AdministrableProductDefinition";
/**
 * SecurityLabel
 *
 * Contract.Term.SecurityLabel: Security labels that protect the handling of information about the term and its elements, which may be specifically identified.
 *
 * http://hl7.org/fhir/SecurityLabel
 */
export declare const SecurityLabel = "http://hl7.org/fhir/SecurityLabel";
/**
 * SubstanceDefinitionRelationshipComponent
 *
 * SubstanceDefinitionRelationshipComponent: A link between this substance and another, with details of the relationship.
 *
 * http://hl7.org/fhir/SubstanceDefinitionRelationshipComponent
 */
export declare const SubstanceDefinitionRelationshipComponent = "http://hl7.org/fhir/SubstanceDefinitionRelationshipComponent";
/**
 * knownAllergen
 *
 * NutritionProduct.knownAllergen: Allergens that are known or suspected to be a part of this nutrition product.
 *
 * http://hl7.org/fhir/knownAllergen
 */
export declare const knownAllergen = "http://hl7.org/fhir/knownAllergen";
/**
 * knownDataCount
 *
 * Evidence.statistic.sampleSize.knownDataCount: Number of participants with known results for measured variables.
 *
 * http://hl7.org/fhir/knownDataCount
 */
export declare const knownDataCount = "http://hl7.org/fhir/knownDataCount";
/**
 * observer
 *
 * AuditEvent.source.observer: Identifier of the source where the event was detected.
 *
 * http://hl7.org/fhir/observer
 */
export declare const observer = "http://hl7.org/fhir/observer";
/**
 * _subtitle
 *
 * (Modified) PlanDefinition.subtitle
 *
 * http://hl7.org/fhir/_subtitle
 */
export declare const _subtitle = "http://hl7.org/fhir/_subtitle";
/**
 * accessionNumber
 *
 * Citation.citedArtifact.publicationForm.accessionNumber: Entry number or identifier for inclusion in a database.
 *
 * http://hl7.org/fhir/accessionNumber
 */
export declare const accessionNumber = "http://hl7.org/fhir/accessionNumber";
/**
 * _finding
 *
 * (Modified) ClinicalImpression.finding
 *
 * http://hl7.org/fhir/_finding
 */
export declare const _finding = "http://hl7.org/fhir/_finding";
/**
 * _style
 *
 * (Modified) Citation.citedArtifact.contributorship.summary.style
 *
 * http://hl7.org/fhir/_style
 */
export declare const _style = "http://hl7.org/fhir/_style";
/**
 * relation
 *
 * DeviceDefinition.link.relation: The type indicates the relationship of the related device to the device instance.
 *
 * http://hl7.org/fhir/relation
 */
export declare const relation = "http://hl7.org/fhir/relation";
/**
 * priority
 *
 * Transport.priority: Indicates how quickly the Transport should be addressed with respect to other requests.
 *
 * http://hl7.org/fhir/priority
 */
export declare const priority = "http://hl7.org/fhir/priority";
/**
 * _requestId
 *
 * (Modified) TestScript.teardown.action.operation.requestId
 *
 * http://hl7.org/fhir/_requestId
 */
export declare const _requestId = "http://hl7.org/fhir/_requestId";
/**
 * ElementDefinitionBindingComponent
 *
 * ElementDefinitionBindingComponent: Binds to a value set if this element is coded (code, Coding, CodeableConcept, Quantity), or the data types (string, uri).
 *
 * http://hl7.org/fhir/ElementDefinitionBindingComponent
 */
export declare const ElementDefinitionBindingComponent = "http://hl7.org/fhir/ElementDefinitionBindingComponent";
/**
 * sequenceAttachment
 *
 * SubstanceProtein.subunit.sequenceAttachment: The sequence information shall be provided enumerating the amino acids from N- to C-terminal end using standard single-letter amino acid codes. Uppercase shall be used for L-amino acids and lowercase for D-amino acids. Transcribed SubstanceProteins will always be described using the translated sequence; for synthetic peptide containing amino acids that are not represented with a single letter code an X should be used within the sequence. The modified amino acids will be distinguished by their position in the sequence.
 *
 * http://hl7.org/fhir/sequenceAttachment
 */
export declare const sequenceAttachment = "http://hl7.org/fhir/sequenceAttachment";
/**
 * AddedItemBodySite
 *
 * ExplanationOfBenefit.AddedItem.AddedItemBodySite: Physical location where the service is performed or applies.
 *
 * http://hl7.org/fhir/AddedItemBodySite
 */
export declare const AddedItemBodySite = "http://hl7.org/fhir/AddedItemBodySite";
/**
 * _group
 *
 * (Modified) StructureMap.group
 *
 * http://hl7.org/fhir/_group
 */
export declare const _group = "http://hl7.org/fhir/_group";
/**
 * publisher
 *
 * ConditionDefinition.publisher: The name of the organization or individual responsible for the release and ongoing maintenance of the condition definition.
 *
 * http://hl7.org/fhir/publisher
 */
export declare const publisher = "http://hl7.org/fhir/publisher";
/**
 * consent
 *
 * ResearchSubject.consent: A record of the patient's informed agreement to participate in the study.
 *
 * http://hl7.org/fhir/consent
 */
export declare const consent = "http://hl7.org/fhir/consent";
/**
 * site
 *
 * ExplanationOfBenefit.item.bodySite.site: Physical service site on the patient (limb, tooth, etc.).
 *
 * http://hl7.org/fhir/site
 */
export declare const site = "http://hl7.org/fhir/site";
/**
 * canFilterBy
 *
 * SubscriptionTopic.canFilterBy: List of properties by which Subscriptions on the SubscriptionTopic can be filtered. May be defined Search Parameters (e.g., Encounter.patient) or parameters defined within this SubscriptionTopic context (e.g., hub.event).
 *
 * http://hl7.org/fhir/canFilterBy
 */
export declare const canFilterBy = "http://hl7.org/fhir/canFilterBy";
/**
 * TerminologyCapabilitiesValidateCodeComponent
 *
 * TerminologyCapabilitiesValidateCodeComponent: Information about the [ValueSet/$validate-code](valueset-operation-validate-code.html) operation.
 *
 * http://hl7.org/fhir/TerminologyCapabilitiesValidateCodeComponent
 */
export declare const TerminologyCapabilitiesValidateCodeComponent = "http://hl7.org/fhir/TerminologyCapabilitiesValidateCodeComponent";
/**
 * _isSubPotent
 *
 * (Modified) MedicationAdministration.isSubPotent
 *
 * http://hl7.org/fhir/_isSubPotent
 */
export declare const _isSubPotent = "http://hl7.org/fhir/_isSubPotent";
/**
 * EncounterParticipantComponent
 *
 * EncounterParticipantComponent: The list of people responsible for providing the service.
 *
 * http://hl7.org/fhir/EncounterParticipantComponent
 */
export declare const EncounterParticipantComponent = "http://hl7.org/fhir/EncounterParticipantComponent";
/**
 * _cancellationReason
 *
 * (Modified) Appointment.cancellationReason
 *
 * http://hl7.org/fhir/_cancellationReason
 */
export declare const _cancellationReason = "http://hl7.org/fhir/_cancellationReason";
/**
 * _repetitions
 *
 * (Modified) Transport.restriction.repetitions
 *
 * http://hl7.org/fhir/_repetitions
 */
export declare const _repetitions = "http://hl7.org/fhir/_repetitions";
/**
 * TestPlanTestCaseTestRunScriptComponent
 *
 * TestPlanTestCaseComponent.TestPlanTestCaseTestRunComponent.TestPlanTestCaseTestRunScriptComponent: The test cases in a structured language e.g. gherkin, Postman, or FHIR TestScript.
 *
 * http://hl7.org/fhir/TestPlanTestCaseTestRunScriptComponent
 */
export declare const TestPlanTestCaseTestRunScriptComponent = "http://hl7.org/fhir/TestPlanTestCaseTestRunScriptComponent";
/**
 * distributor
 *
 * DeviceDefinition.packaging.packaging.distributor: An organization that distributes the packaged device.
 *
 * http://hl7.org/fhir/distributor
 */
export declare const distributor = "http://hl7.org/fhir/distributor";
/**
 * _stopTestOnFail
 *
 * (Modified) TestScript.test.action.assert.stopTestOnFail
 *
 * http://hl7.org/fhir/_stopTestOnFail
 */
export declare const _stopTestOnFail = "http://hl7.org/fhir/_stopTestOnFail";
/**
 * organizationReference
 *
 * DeviceDefinition.packaging.packaging.distributor.organizationReference: Distributor as an Organization resource.
 *
 * http://hl7.org/fhir/organizationReference
 */
export declare const organizationReference = "http://hl7.org/fhir/organizationReference";
/**
 * residueSite
 *
 * SubstanceNucleicAcid.subunit.sugar.residueSite: The residues that contain a given sugar will be captured. The order of given residues will be captured in the 5‘-3‘direction consistent with the base sequences listed above.
 *
 * http://hl7.org/fhir/residueSite
 */
export declare const residueSite = "http://hl7.org/fhir/residueSite";
/**
 * guidance
 *
 * Measure.guidance: Additional guidance for the measure including how it can be used in a clinical context, and the intent of the measure.
 *
 * http://hl7.org/fhir/guidance
 */
export declare const guidance = "http://hl7.org/fhir/guidance";
/**
 * _originatingAppointment
 *
 * (Modified) Appointment.originatingAppointment
 *
 * http://hl7.org/fhir/_originatingAppointment
 */
export declare const _originatingAppointment = "http://hl7.org/fhir/_originatingAppointment";
/**
 * intended
 *
 * Evidence.variableDefinition.intended: Definition of the intended variable related to the Evidence.
 *
 * http://hl7.org/fhir/intended
 */
export declare const intended = "http://hl7.org/fhir/intended";
/**
 * _measurementFrequency
 *
 * (Modified) DeviceMetric.measurementFrequency
 *
 * http://hl7.org/fhir/_measurementFrequency
 */
export declare const _measurementFrequency = "http://hl7.org/fhir/_measurementFrequency";
/**
 * _variableRole
 *
 * (Modified) Evidence.variableDefinition.variableRole
 *
 * http://hl7.org/fhir/_variableRole
 */
export declare const _variableRole = "http://hl7.org/fhir/_variableRole";
/**
 * assurance
 *
 * Person.link.assurance: Level of assurance that this link is associated with the target resource.
 *
 * http://hl7.org/fhir/assurance
 */
export declare const assurance = "http://hl7.org/fhir/assurance";
/**
 * literal
 *
 * MolecularSequence.literal: Sequence that was observed.
 *
 * http://hl7.org/fhir/literal
 */
export declare const literal = "http://hl7.org/fhir/literal";
/**
 * _suppliedItem
 *
 * (Modified) SupplyDelivery.suppliedItem
 *
 * http://hl7.org/fhir/_suppliedItem
 */
export declare const _suppliedItem = "http://hl7.org/fhir/_suppliedItem";
/**
 * ProcedurePerformerComponent
 *
 * ProcedurePerformerComponent: Indicates who or what performed the procedure and how they were involved.
 *
 * http://hl7.org/fhir/ProcedurePerformerComponent
 */
export declare const ProcedurePerformerComponent = "http://hl7.org/fhir/ProcedurePerformerComponent";
/**
 * baseUnit
 *
 * InventoryItem.baseUnit: The base unit of measure - the unit in which the product is used or counted.
 *
 * http://hl7.org/fhir/baseUnit
 */
export declare const baseUnit = "http://hl7.org/fhir/baseUnit";
/**
 * _translation
 *
 * (Modified) TerminologyCapabilities.closure.translation
 *
 * http://hl7.org/fhir/_translation
 */
export declare const _translation = "http://hl7.org/fhir/_translation";
/**
 * StructureDefinitionSnapshotComponent
 *
 * StructureDefinitionSnapshotComponent: A snapshot view is expressed in a standalone form that can be used and interpreted without considering the base StructureDefinition.
 *
 * http://hl7.org/fhir/StructureDefinitionSnapshotComponent
 */
export declare const StructureDefinitionSnapshotComponent = "http://hl7.org/fhir/StructureDefinitionSnapshotComponent";
/**
 * _name
 *
 * (Modified) InventoryItem.name.name
 *
 * http://hl7.org/fhir/_name
 */
export declare const _name = "http://hl7.org/fhir/_name";
/**
 * MedicationRequestDispenseRequestInitialFillComponent
 *
 * MedicationRequestDispenseRequestComponent.MedicationRequestDispenseRequestInitialFillComponent: Indicates the quantity or duration for the first dispense of the medication.
 *
 * http://hl7.org/fhir/MedicationRequestDispenseRequestInitialFillComponent
 */
export declare const MedicationRequestDispenseRequestInitialFillComponent = "http://hl7.org/fhir/MedicationRequestDispenseRequestInitialFillComponent";
/**
 * _incidence
 *
 * (Modified) ClinicalUseDefinition.interaction.incidence
 *
 * http://hl7.org/fhir/_incidence
 */
export declare const _incidence = "http://hl7.org/fhir/_incidence";
/**
 * _during
 *
 * (Modified) Availability.notAvailableTime.during
 *
 * http://hl7.org/fhir/_during
 */
export declare const _during = "http://hl7.org/fhir/_during";
/**
 * _snapshot
 *
 * (Modified) StructureDefinition.snapshot
 *
 * http://hl7.org/fhir/_snapshot
 */
export declare const _snapshot = "http://hl7.org/fhir/_snapshot";
/**
 * SubstancePolymerRepeatRepeatUnitComponent
 *
 * SubstancePolymerRepeatComponent.SubstancePolymerRepeatRepeatUnitComponent: An SRU - Structural Repeat Unit.
 *
 * http://hl7.org/fhir/SubstancePolymerRepeatRepeatUnitComponent
 */
export declare const SubstancePolymerRepeatRepeatUnitComponent = "http://hl7.org/fhir/SubstancePolymerRepeatRepeatUnitComponent";
/**
 * _format
 *
 * (Modified) SubstancePolymer.repeat.repeatUnit.structuralRepresentation.format
 *
 * http://hl7.org/fhir/_format
 */
export declare const _format = "http://hl7.org/fhir/_format";
/**
 * PlanBenefit
 *
 * InsurancePlanPlanComponent.InsurancePlanPlanSpecificCostComponent.PlanBenefit: List of the specific benefits under this category of benefit.
 *
 * http://hl7.org/fhir/PlanBenefit
 */
export declare const PlanBenefit = "http://hl7.org/fhir/PlanBenefit";
/**
 * _foodPreferenceModifier
 *
 * (Modified) NutritionOrder.foodPreferenceModifier
 *
 * http://hl7.org/fhir/_foodPreferenceModifier
 */
export declare const _foodPreferenceModifier = "http://hl7.org/fhir/_foodPreferenceModifier";
/**
 * function
 *
 * ChargeItem.performer.function: Describes the type of performance or participation(e.g. primary surgeon, anesthesiologiest, etc.).
 * Note that `function` is a reserved Javascript keyword, and is therefore suffixed by `__workaround`.
 * For a list of reserved keywords, see https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Lexical_grammar#Keywords.
 *
 * http://hl7.org/fhir/function
 */
export declare const function__workaround = "http://hl7.org/fhir/function";
/**
 * environmentType
 *
 * Endpoint.environmentType: The type of environment(s) exposed at this endpoint (dev, prod, test, etc.).
 *
 * http://hl7.org/fhir/environmentType
 */
export declare const environmentType = "http://hl7.org/fhir/environmentType";
/**
 * SubscriptionTopicCanFilterByComponent
 *
 * SubscriptionTopicCanFilterByComponent: List of properties by which Subscriptions on the SubscriptionTopic can be filtered. May be defined Search Parameters (e.g., Encounter.patient) or parameters defined within this SubscriptionTopic context (e.g., hub.event).
 *
 * http://hl7.org/fhir/SubscriptionTopicCanFilterByComponent
 */
export declare const SubscriptionTopicCanFilterByComponent = "http://hl7.org/fhir/SubscriptionTopicCanFilterByComponent";
/**
 * occurrenceCount
 *
 * Appointment.recurrenceTemplate.occurrenceCount: How many appointments are planned in the recurrence.
 *
 * http://hl7.org/fhir/occurrenceCount
 */
export declare const occurrenceCount = "http://hl7.org/fhir/occurrenceCount";
/**
 * careTeamSequence
 *
 * ExplanationOfBenefit.item.careTeamSequence: Care team members related to this service or product.
 *
 * http://hl7.org/fhir/careTeamSequence
 */
export declare const careTeamSequence = "http://hl7.org/fhir/careTeamSequence";
/**
 * _notConsumedReason
 *
 * (Modified) NutritionIntake.consumedItem.notConsumedReason
 *
 * http://hl7.org/fhir/_notConsumedReason
 */
export declare const _notConsumedReason = "http://hl7.org/fhir/_notConsumedReason";
/**
 * _restoreDate
 *
 * (Modified) MarketingStatus.restoreDate
 *
 * http://hl7.org/fhir/_restoreDate
 */
export declare const _restoreDate = "http://hl7.org/fhir/_restoreDate";
/**
 * providedBy
 *
 * HealthcareService.providedBy: The organization that provides this healthcare service.
 *
 * http://hl7.org/fhir/providedBy
 */
export declare const providedBy = "http://hl7.org/fhir/providedBy";
/**
 * meta
 *
 * Resource.meta: The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.
 *
 * http://hl7.org/fhir/meta
 */
export declare const meta = "http://hl7.org/fhir/meta";
/**
 * _subDetailSequence
 *
 * (Modified) ExplanationOfBenefit.addItem.subDetailSequence
 *
 * http://hl7.org/fhir/_subDetailSequence
 */
export declare const _subDetailSequence = "http://hl7.org/fhir/_subDetailSequence";
/**
 * required
 *
 * Questionnaire.item.required: An indication, if true, that the item must be present in a "completed" QuestionnaireResponse.  If false, the item may be skipped when answering the questionnaire.
 *
 * http://hl7.org/fhir/required
 */
export declare const required = "http://hl7.org/fhir/required";
/**
 * _dateWritten
 *
 * (Modified) VisionPrescription.dateWritten
 *
 * http://hl7.org/fhir/_dateWritten
 */
export declare const _dateWritten = "http://hl7.org/fhir/_dateWritten";
/**
 * _deviceIdentifier
 *
 * (Modified) DeviceDefinition.packaging.packaging.udiDeviceIdentifier.deviceIdentifier
 *
 * http://hl7.org/fhir/_deviceIdentifier
 */
export declare const _deviceIdentifier = "http://hl7.org/fhir/_deviceIdentifier";
/**
 * referral
 *
 * ExplanationOfBenefit.referral: The referral information received by the claim author, it is not to be used when the author generates a referral for a patient. A copy of that referral may be provided as supporting information. Some insurers require proof of referral to pay for services or to pay specialist rates for services.
 *
 * http://hl7.org/fhir/referral
 */
export declare const referral = "http://hl7.org/fhir/referral";
/**
 * _conditionality
 *
 * (Modified) Requirements.statement.conditionality
 *
 * http://hl7.org/fhir/_conditionality
 */
export declare const _conditionality = "http://hl7.org/fhir/_conditionality";
/**
 * AuditEventSourceComponent
 *
 * AuditEventSourceComponent: The actor that is reporting the event.
 *
 * http://hl7.org/fhir/AuditEventSourceComponent
 */
export declare const AuditEventSourceComponent = "http://hl7.org/fhir/AuditEventSourceComponent";
/**
 * _component
 *
 * (Modified) DeviceDefinition.version.component
 *
 * http://hl7.org/fhir/_component
 */
export declare const _component = "http://hl7.org/fhir/_component";
/**
 * link
 *
 * TestScript.test.action.assert.requirement.link
 *
 * http://hl7.org/fhir/link
 */
export declare const link = "http://hl7.org/fhir/link";
/**
 * _hasStage
 *
 * (Modified) ConditionDefinition.hasStage
 *
 * http://hl7.org/fhir/_hasStage
 */
export declare const _hasStage = "http://hl7.org/fhir/_hasStage";
/**
 * _contentReference
 *
 * (Modified) ElementDefinition.contentReference
 *
 * http://hl7.org/fhir/_contentReference
 */
export declare const _contentReference = "http://hl7.org/fhir/_contentReference";
/**
 * program
 *
 * Immunization.programEligibility.program: Indicates which program the patient had their eligility evaluated for.
 *
 * http://hl7.org/fhir/program
 */
export declare const program = "http://hl7.org/fhir/program";
/**
 * OtherElement
 *
 * ConceptMapGroupComponent.SourceElement.TargetElement.OtherElement: A set of additional dependencies for this mapping to hold. This mapping is only applicable if the specified data attribute can be resolved, and it has the specified value.
 *
 * http://hl7.org/fhir/OtherElement
 */
export declare const OtherElement = "http://hl7.org/fhir/OtherElement";
/**
 * scoringUnit
 *
 * Measure.group.scoringUnit: Defines the expected units of measure for the measure score. This element SHOULD be specified as a UCUM unit.
 *
 * http://hl7.org/fhir/scoringUnit
 */
export declare const scoringUnit = "http://hl7.org/fhir/scoringUnit";
/**
 * _maxCount
 *
 * (Modified) Subscription.maxCount
 *
 * http://hl7.org/fhir/_maxCount
 */
export declare const _maxCount = "http://hl7.org/fhir/_maxCount";
/**
 * ExplanationOfBenefitEventComponent
 *
 * ExplanationOfBenefitEventComponent: Information code for an event with a corresponding date or period.
 *
 * http://hl7.org/fhir/ExplanationOfBenefitEventComponent
 */
export declare const ExplanationOfBenefitEventComponent = "http://hl7.org/fhir/ExplanationOfBenefitEventComponent";
/**
 * _ArtifactAssessment
 *
 * (Modified) ArtifactAssessment
 *
 * http://hl7.org/fhir/_ArtifactAssessment
 */
export declare const _ArtifactAssessment = "http://hl7.org/fhir/_ArtifactAssessment";
/**
 * scope
 *
 * Contract.term.group.asset.scope: Differentiates the kind of the asset .
 *
 * http://hl7.org/fhir/scope
 */
export declare const scope = "http://hl7.org/fhir/scope";
/**
 * inventoryListing
 *
 * InventoryReport.inventoryListing: An inventory listing section (grouped by any of the attributes).
 *
 * http://hl7.org/fhir/inventoryListing
 */
export declare const inventoryListing = "http://hl7.org/fhir/inventoryListing";
/**
 * concentration
 *
 * Ingredient.substance.strength.concentration
 *
 * http://hl7.org/fhir/concentration
 */
export declare const concentration = "http://hl7.org/fhir/concentration";
/**
 * _device
 *
 * (Modified) Specimen.collection.device
 *
 * http://hl7.org/fhir/_device
 */
export declare const _device = "http://hl7.org/fhir/_device";
/**
 * hierarchyMeaning
 *
 * CodeSystem.hierarchyMeaning: The meaning of the hierarchy of concepts as represented in this resource.
 *
 * http://hl7.org/fhir/hierarchyMeaning
 */
export declare const hierarchyMeaning = "http://hl7.org/fhir/hierarchyMeaning";
/**
 * CapabilityStatementRestComponentOperation
 *
 * Definition of an operation or a named query together with its parameters and their meaning and type.
 *
 * http://hl7.org/fhir/CapabilityStatementRestComponentOperation
 */
export declare const CapabilityStatementRestComponentOperation = "http://hl7.org/fhir/CapabilityStatementRestComponentOperation";
/**
 * otherMap
 *
 * ConceptMap.group.unmapped.otherMap: The canonical reference to an additional ConceptMap resource instance to use for mapping if this ConceptMap resource contains no matching mapping for the source concept.
 *
 * http://hl7.org/fhir/otherMap
 */
export declare const otherMap = "http://hl7.org/fhir/otherMap";
/**
 * answerConstraint
 *
 * Questionnaire.item.item.answerConstraint: For items that have a defined set of allowed answers (via answerOption or answerValueSet), indicates whether values *other* than those specified can be selected.
 *
 * http://hl7.org/fhir/answerConstraint
 */
export declare const answerConstraint = "http://hl7.org/fhir/answerConstraint";
/**
 * normalCodedValueSet
 *
 * ObservationDefinition.component.qualifiedValue.normalCodedValueSet: The set of normal coded results for qualitative observations  that match the criteria of this set of qualified values.
 *
 * http://hl7.org/fhir/normalCodedValueSet
 */
export declare const normalCodedValueSet = "http://hl7.org/fhir/normalCodedValueSet";
/**
 * global
 *
 * ImplementationGuide.global: A set of profiles that all resources covered by this implementation guide must conform to.
 *
 * http://hl7.org/fhir/global
 */
export declare const global = "http://hl7.org/fhir/global";
/**
 * excludingRecurrenceId
 *
 * Appointment.recurrenceTemplate.excludingRecurrenceId: Any dates, such as holidays, that should be excluded from the recurrence.
 *
 * http://hl7.org/fhir/excludingRecurrenceId
 */
export declare const excludingRecurrenceId = "http://hl7.org/fhir/excludingRecurrenceId";
/**
 * _SubstanceSourceMaterial
 *
 * (Modified) SubstanceSourceMaterial
 *
 * http://hl7.org/fhir/_SubstanceSourceMaterial
 */
export declare const _SubstanceSourceMaterial = "http://hl7.org/fhir/_SubstanceSourceMaterial";
/**
 * validity
 *
 * Permission.validity: The period in which the permission is active.
 *
 * http://hl7.org/fhir/validity
 */
export declare const validity = "http://hl7.org/fhir/validity";
/**
 * subjectReport
 *
 * MeasureReport.group.stratifier.stratum.population.subjectReport: A reference to an individual level MeasureReport resource for a member of the population.
 *
 * http://hl7.org/fhir/subjectReport
 */
export declare const subjectReport = "http://hl7.org/fhir/subjectReport";
/**
 * _any
 *
 * (Modified) ElementDefinition.binding.additional.any
 *
 * http://hl7.org/fhir/_any
 */
export declare const _any = "http://hl7.org/fhir/_any";
/**
 * _nextScheduled
 *
 * (Modified) VerificationResult.nextScheduled
 *
 * http://hl7.org/fhir/_nextScheduled
 */
export declare const _nextScheduled = "http://hl7.org/fhir/_nextScheduled";
/**
 * administration
 *
 * NutritionOrder.enteralFormula.administration: Formula administration instructions as structured data.  This repeating structure allows for changing the administration rate or volume over time for both bolus and continuous feeding.  An example of this would be an instruction to increase the rate of continuous feeding every 2 hours.
 *
 * http://hl7.org/fhir/administration
 */
export declare const administration = "http://hl7.org/fhir/administration";
/**
 * sort
 *
 * DataRequirement.sort: Specifies the order of the results to be returned.
 *
 * http://hl7.org/fhir/sort
 */
export declare const sort = "http://hl7.org/fhir/sort";
/**
 * ManufacturedItemDefinitionComponentComponentProperty
 *
 * General characteristics of this component.
 *
 * http://hl7.org/fhir/ManufacturedItemDefinitionComponentComponentProperty
 */
export declare const ManufacturedItemDefinitionComponentComponentProperty = "http://hl7.org/fhir/ManufacturedItemDefinitionComponentComponentProperty";
/**
 * _sent
 *
 * (Modified) Communication.sent
 *
 * http://hl7.org/fhir/_sent
 */
export declare const _sent = "http://hl7.org/fhir/_sent";
/**
 * _directnessMatch
 *
 * (Modified) Evidence.variableDefinition.directnessMatch
 *
 * http://hl7.org/fhir/_directnessMatch
 */
export declare const _directnessMatch = "http://hl7.org/fhir/_directnessMatch";
/**
 * _targetFormat
 *
 * (Modified) Signature.targetFormat
 *
 * http://hl7.org/fhir/_targetFormat
 */
export declare const _targetFormat = "http://hl7.org/fhir/_targetFormat";
/**
 * _used
 *
 * (Modified) Procedure.used
 *
 * http://hl7.org/fhir/_used
 */
export declare const _used = "http://hl7.org/fhir/_used";
/**
 * _occurence
 *
 * (Modified) MedicationAdministration.occurence
 *
 * http://hl7.org/fhir/_occurence
 */
export declare const _occurence = "http://hl7.org/fhir/_occurence";
/**
 * _partOf
 *
 * (Modified) Procedure.partOf
 *
 * http://hl7.org/fhir/_partOf
 */
export declare const _partOf = "http://hl7.org/fhir/_partOf";
/**
 * relativeRisk
 *
 * RiskAssessment.prediction.relativeRisk: Indicates the risk for this particular subject (with their specific characteristics) divided by the risk of the population in general.  (Numbers greater than 1 = higher risk than the population, numbers less than 1 = lower risk.).
 *
 * http://hl7.org/fhir/relativeRisk
 */
export declare const relativeRisk = "http://hl7.org/fhir/relativeRisk";
/**
 * supportedMessage
 *
 * CapabilityStatement.messaging.supportedMessage: References to message definitions for messages this system can send or receive.
 *
 * http://hl7.org/fhir/supportedMessage
 */
export declare const supportedMessage = "http://hl7.org/fhir/supportedMessage";
/**
 * _dateOfDiagnosis
 *
 * (Modified) Account.diagnosis.dateOfDiagnosis
 *
 * http://hl7.org/fhir/_dateOfDiagnosis
 */
export declare const _dateOfDiagnosis = "http://hl7.org/fhir/_dateOfDiagnosis";
/**
 * _seriesNumber
 *
 * (Modified) ImagingSelection.seriesNumber
 *
 * http://hl7.org/fhir/_seriesNumber
 */
export declare const _seriesNumber = "http://hl7.org/fhir/_seriesNumber";
/**
 * DataRequirementSortComponent
 *
 * DataRequirementSortComponent: Specifies the order of the results to be returned.
 *
 * http://hl7.org/fhir/DataRequirementSortComponent
 */
export declare const DataRequirementSortComponent = "http://hl7.org/fhir/DataRequirementSortComponent";
/**
 * ChargeItemDefinitionPropertyGroupComponentApplicability
 *
 * Expressions that describe applicability criteria for the priceComponent.
 *
 * http://hl7.org/fhir/ChargeItemDefinitionPropertyGroupComponentApplicability
 */
export declare const ChargeItemDefinitionPropertyGroupComponentApplicability = "http://hl7.org/fhir/ChargeItemDefinitionPropertyGroupComponentApplicability";
/**
 * codeSystem
 *
 * TerminologyCapabilities.codeSystem: Identifies a code system that is supported by the server. If there is a no code system URL, then this declares the general assumptions a client can make about support for any CodeSystem resource.
 *
 * http://hl7.org/fhir/codeSystem
 */
export declare const codeSystem = "http://hl7.org/fhir/codeSystem";
/**
 * processing
 *
 * Specimen.processing: Details concerning processing and processing steps for the specimen.
 *
 * http://hl7.org/fhir/processing
 */
export declare const processing = "http://hl7.org/fhir/processing";
/**
 * _ResearchSubject
 *
 * (Modified) ResearchSubject
 *
 * http://hl7.org/fhir/_ResearchSubject
 */
export declare const _ResearchSubject = "http://hl7.org/fhir/_ResearchSubject";
/**
 * _heartbeatPeriod
 *
 * (Modified) Subscription.heartbeatPeriod
 *
 * http://hl7.org/fhir/_heartbeatPeriod
 */
export declare const _heartbeatPeriod = "http://hl7.org/fhir/_heartbeatPeriod";
/**
 * ValueSetExpansionPropertyComponent
 *
 * ValueSetExpansionComponent.ValueSetExpansionPropertyComponent: A property defines an additional slot through which additional information can be provided about a concept.
 *
 * http://hl7.org/fhir/ValueSetExpansionPropertyComponent
 */
export declare const ValueSetExpansionPropertyComponent = "http://hl7.org/fhir/ValueSetExpansionPropertyComponent";
/**
 * orderDetail
 *
 * ServiceRequest.orderDetail: Additional details and instructions about the how the services are to be delivered.   For example, and order for a urinary catheter may have an order detail for an external or indwelling catheter, or an order for a bandage may require additional instructions specifying how the bandage should be applied.
 *
 * http://hl7.org/fhir/orderDetail
 */
export declare const orderDetail = "http://hl7.org/fhir/orderDetail";
/**
 * Group
 *
 * Represents a defined collection of entities that may be discussed or acted upon collectively but which are not expected to act collectively, and are not formally or legally recognized; i.e. a collection of entities that isn't an Organization.
 *
 * http://hl7.org/fhir/Group
 */
export declare const Group = "http://hl7.org/fhir/Group";
/**
 * statusDate
 *
 * VerificationResult.statusDate: When the validation status was updated.
 *
 * http://hl7.org/fhir/statusDate
 */
export declare const statusDate = "http://hl7.org/fhir/statusDate";
/**
 * uri
 *
 * ConceptMap.property.uri: Reference to the formal meaning of the property.
 *
 * http://hl7.org/fhir/uri
 */
export declare const uri = "http://hl7.org/fhir/uri";
/**
 * max
 *
 * StructureMap.group.rule.source.max: Specified maximum cardinality for the element - a number or a "*". This is optional; if present, it acts an implicit check on the input content (* just serves as documentation; it's the default value).
 *
 * http://hl7.org/fhir/max
 */
export declare const max = "http://hl7.org/fhir/max";
/**
 * _conformance
 *
 * (Modified) TestScript.scope.conformance
 *
 * http://hl7.org/fhir/_conformance
 */
export declare const _conformance = "http://hl7.org/fhir/_conformance";
/**
 * _unitPriceComponent
 *
 * (Modified) ChargeItem.unitPriceComponent
 *
 * http://hl7.org/fhir/_unitPriceComponent
 */
export declare const _unitPriceComponent = "http://hl7.org/fhir/_unitPriceComponent";
/**
 * _availabilityStatus
 *
 * (Modified) Device.availabilityStatus
 *
 * http://hl7.org/fhir/_availabilityStatus
 */
export declare const _availabilityStatus = "http://hl7.org/fhir/_availabilityStatus";
/**
 * _exitCriteria
 *
 * (Modified) TestPlan.exitCriteria
 *
 * http://hl7.org/fhir/_exitCriteria
 */
export declare const _exitCriteria = "http://hl7.org/fhir/_exitCriteria";
/**
 * Schedule
 *
 * A container for slots of time that may be available for booking appointments.
 *
 * http://hl7.org/fhir/Schedule
 */
export declare const Schedule = "http://hl7.org/fhir/Schedule";
/**
 * BiologicallyDerivedProductCollectionComponent
 *
 * BiologicallyDerivedProductCollectionComponent: How this product was collected.
 *
 * http://hl7.org/fhir/BiologicallyDerivedProductCollectionComponent
 */
export declare const BiologicallyDerivedProductCollectionComponent = "http://hl7.org/fhir/BiologicallyDerivedProductCollectionComponent";
/**
 * DomainResource
 *
 * A resource that includes narrative, extensions, and contained resources.
 *
 * http://hl7.org/fhir/DomainResource
 */
export declare const DomainResource = "http://hl7.org/fhir/DomainResource";
/**
 * _AdverseEvent
 *
 * (Modified) AdverseEvent
 *
 * http://hl7.org/fhir/_AdverseEvent
 */
export declare const _AdverseEvent = "http://hl7.org/fhir/_AdverseEvent";
/**
 * focalDevice
 *
 * Procedure.focalDevice: A device that is implanted, removed or otherwise manipulated (calibration, battery replacement, fitting a prosthesis, attaching a wound-vac, etc.) as a focal portion of the Procedure.
 *
 * http://hl7.org/fhir/focalDevice
 */
export declare const focalDevice = "http://hl7.org/fhir/focalDevice";
/**
 * _authorType
 *
 * (Modified) SubstanceSourceMaterial.organism.author.authorType
 *
 * http://hl7.org/fhir/_authorType
 */
export declare const _authorType = "http://hl7.org/fhir/_authorType";
/**
 * mode
 *
 * EvidenceReport.section.section.mode: How the entry list was prepared - whether it is a working list that is suitable for being maintained on an ongoing basis, or if it represents a snapshot of a list of items from another source, or whether it is a prepared list where items may be marked as added, modified or deleted.
 *
 * http://hl7.org/fhir/mode
 */
export declare const mode = "http://hl7.org/fhir/mode";
/**
 * observation
 *
 * Observation.triggeredBy.observation: Reference to the triggering observation.
 *
 * http://hl7.org/fhir/observation
 */
export declare const observation = "http://hl7.org/fhir/observation";
/**
 * _issuer
 *
 * (Modified) Device.udiCarrier.issuer
 *
 * http://hl7.org/fhir/_issuer
 */
export declare const _issuer = "http://hl7.org/fhir/_issuer";
/**
 * ClaimEventComponent
 *
 * ClaimEventComponent: Information code for an event with a corresponding date or period.
 *
 * http://hl7.org/fhir/ClaimEventComponent
 */
export declare const ClaimEventComponent = "http://hl7.org/fhir/ClaimEventComponent";
/**
 * FamilyMemberHistoryParticipantComponent
 *
 * FamilyMemberHistoryParticipantComponent: Indicates who or what participated in the activities related to the family member history and how they were involved.
 *
 * http://hl7.org/fhir/FamilyMemberHistoryParticipantComponent
 */
export declare const FamilyMemberHistoryParticipantComponent = "http://hl7.org/fhir/FamilyMemberHistoryParticipantComponent";
/**
 * _validationStatus
 *
 * (Modified) VerificationResult.primarySource.validationStatus
 *
 * http://hl7.org/fhir/_validationStatus
 */
export declare const _validationStatus = "http://hl7.org/fhir/_validationStatus";
/**
 * string
 *
 * A sequence of Unicode characters
 *
 * http://hl7.org/fhir/string
 */
export declare const string = "http://hl7.org/fhir/string";
/**
 * productCode
 *
 * BiologicallyDerivedProduct.productCode: A codified value that systematically supports characterization and classification of medical products of human origin inclusive of processing conditions such as additives, volumes and handling conditions.
 *
 * http://hl7.org/fhir/productCode
 */
export declare const productCode = "http://hl7.org/fhir/productCode";
/**
 * receiver
 *
 * ExampleScenario.process.step.process.step.operation.receiver: The system on which the action is invoked/receives the data.
 *
 * http://hl7.org/fhir/receiver
 */
export declare const receiver = "http://hl7.org/fhir/receiver";
/**
 * CitationCitedArtifactTitleComponent
 *
 * CitationCitedArtifactComponent.CitationCitedArtifactTitleComponent: The title details of the article or artifact.
 *
 * http://hl7.org/fhir/CitationCitedArtifactTitleComponent
 */
export declare const CitationCitedArtifactTitleComponent = "http://hl7.org/fhir/CitationCitedArtifactTitleComponent";
/**
 * totalGross
 *
 * Invoice.totalGross: Invoice total, tax included.
 *
 * http://hl7.org/fhir/totalGross
 */
export declare const totalGross = "http://hl7.org/fhir/totalGross";
/**
 * _outputProfile
 *
 * (Modified) OperationDefinition.outputProfile
 *
 * http://hl7.org/fhir/_outputProfile
 */
export declare const _outputProfile = "http://hl7.org/fhir/_outputProfile";
/**
 * conditionalDelete
 *
 * CapabilityStatement.rest.resource.conditionalDelete: A code that indicates how the server supports conditional delete.
 *
 * http://hl7.org/fhir/conditionalDelete
 */
export declare const conditionalDelete = "http://hl7.org/fhir/conditionalDelete";
/**
 * baseDefinition
 *
 * StructureDefinition.baseDefinition: An absolute URI that is the base structure from which this type is derived, either by specialization or constraint.
 *
 * http://hl7.org/fhir/baseDefinition
 */
export declare const baseDefinition = "http://hl7.org/fhir/baseDefinition";
/**
 * NutritionProductInstanceComponent
 *
 * NutritionProductInstanceComponent: Conveys instance-level information about this product item. One or several physical, countable instances or occurrences of the product.
 *
 * http://hl7.org/fhir/NutritionProductInstanceComponent
 */
export declare const NutritionProductInstanceComponent = "http://hl7.org/fhir/NutritionProductInstanceComponent";
/**
 * ClinicalUseDefinitionIndicationComponent
 *
 * ClinicalUseDefinitionIndicationComponent: Specifics for when this is an indication.
 *
 * http://hl7.org/fhir/ClinicalUseDefinitionIndicationComponent
 */
export declare const ClinicalUseDefinitionIndicationComponent = "http://hl7.org/fhir/ClinicalUseDefinitionIndicationComponent";
/**
 * relevantHistory
 *
 * Task.relevantHistory: Links to Provenance records for past versions of this Task that identify key state transitions or updates that are likely to be relevant to a user looking at the current version of the task.
 *
 * http://hl7.org/fhir/relevantHistory
 */
export declare const relevantHistory = "http://hl7.org/fhir/relevantHistory";
/**
 * referenceInformation
 *
 * SubstanceDefinition.referenceInformation: General information detailing this substance.
 *
 * http://hl7.org/fhir/referenceInformation
 */
export declare const referenceInformation = "http://hl7.org/fhir/referenceInformation";
/**
 * valueSet
 *
 * OperationDefinition.parameter.part.binding.valueSet: Points to the value set or external definition (e.g. implicit value set) that identifies the set of codes to be used.
 *
 * http://hl7.org/fhir/valueSet
 */
export declare const valueSet = "http://hl7.org/fhir/valueSet";
/**
 * library
 *
 * PlanDefinition.library: A reference to a Library resource containing any formal logic used by the plan definition.
 *
 * http://hl7.org/fhir/library
 */
export declare const library = "http://hl7.org/fhir/library";
/**
 * InventoryReportInventoryListingItemComponent
 *
 * InventoryReportInventoryListingComponent.InventoryReportInventoryListingItemComponent: The item or items in this listing.
 *
 * http://hl7.org/fhir/InventoryReportInventoryListingItemComponent
 */
export declare const InventoryReportInventoryListingItemComponent = "http://hl7.org/fhir/InventoryReportInventoryListingItemComponent";
/**
 * performedActivity
 *
 * CarePlan.activity.performedActivity: Identifies the activity that was performed. For example, an activity could be patient education, exercise, or a medication administration. The reference to an "event" resource, such as Procedure or Encounter or Observation, represents the activity that was performed. The requested activity can be conveyed using the CarePlan.activity.plannedActivityReference (a reference to a “request” resource).
 *
 * http://hl7.org/fhir/performedActivity
 */
export declare const performedActivity = "http://hl7.org/fhir/performedActivity";
/**
 * Coverage
 *
 * Financial instrument which may be used to reimburse or pay for health care products and services. Includes both insurance and self-payment.
 *
 * http://hl7.org/fhir/Coverage
 */
export declare const Coverage = "http://hl7.org/fhir/Coverage";
/**
 * probability
 *
 * RiskAssessment.prediction.probability
 *
 * http://hl7.org/fhir/probability
 */
export declare const probability = "http://hl7.org/fhir/probability";
/**
 * TerminologyCapabilitiesSoftwareComponent
 *
 * TerminologyCapabilitiesSoftwareComponent: Software that is covered by this terminology capability statement.  It is used when the statement describes the capabilities of a particular software version, independent of an installation.
 *
 * http://hl7.org/fhir/TerminologyCapabilitiesSoftwareComponent
 */
export declare const TerminologyCapabilitiesSoftwareComponent = "http://hl7.org/fhir/TerminologyCapabilitiesSoftwareComponent";
/**
 * _activity
 *
 * (Modified) Provenance.activity
 *
 * http://hl7.org/fhir/_activity
 */
export declare const _activity = "http://hl7.org/fhir/_activity";
/**
 * prediction
 *
 * RiskAssessment.prediction: Describes the expected outcome for the subject.
 *
 * http://hl7.org/fhir/prediction
 */
export declare const prediction = "http://hl7.org/fhir/prediction";
/**
 * _mimeType
 *
 * (Modified) Endpoint.payload.mimeType
 *
 * http://hl7.org/fhir/_mimeType
 */
export declare const _mimeType = "http://hl7.org/fhir/_mimeType";
/**
 * exception
 *
 * Coverage.costToBeneficiary.exception: A suite of codes indicating exceptions or reductions to patient costs and their effective periods.
 *
 * http://hl7.org/fhir/exception
 */
export declare const exception = "http://hl7.org/fhir/exception";
/**
 * ImplementationGuideDefinitionTemplateComponent
 *
 * ImplementationGuideDefinitionComponent.ImplementationGuideDefinitionTemplateComponent: A template for building resources.
 *
 * http://hl7.org/fhir/ImplementationGuideDefinitionTemplateComponent
 */
export declare const ImplementationGuideDefinitionTemplateComponent = "http://hl7.org/fhir/ImplementationGuideDefinitionTemplateComponent";
/**
 * _edit
 *
 * (Modified) MolecularSequence.relative.edit
 *
 * http://hl7.org/fhir/_edit
 */
export declare const _edit = "http://hl7.org/fhir/_edit";
/**
 * _usage
 *
 * (Modified) NamingSystem.usage
 *
 * http://hl7.org/fhir/_usage
 */
export declare const _usage = "http://hl7.org/fhir/_usage";
/**
 * proposedNewTime
 *
 * AppointmentResponse.proposedNewTime: Indicates that the response is proposing a different time that was initially requested.  The new proposed time will be indicated in the start and end properties.
 *
 * http://hl7.org/fhir/proposedNewTime
 */
export declare const proposedNewTime = "http://hl7.org/fhir/proposedNewTime";
/**
 * security
 *
 * Permission.rule.data.security: The data in scope are those with the given codes present in that data .meta.security element.
 *
 * http://hl7.org/fhir/security
 */
export declare const security = "http://hl7.org/fhir/security";
/**
 * _parameter
 *
 * (Modified) ValueSet.expansion.parameter
 *
 * http://hl7.org/fhir/_parameter
 */
export declare const _parameter = "http://hl7.org/fhir/_parameter";
/**
 * InventoryItemDescriptionComponent
 *
 * InventoryItemDescriptionComponent: The descriptive characteristics of the inventory item.
 *
 * http://hl7.org/fhir/InventoryItemDescriptionComponent
 */
export declare const InventoryItemDescriptionComponent = "http://hl7.org/fhir/InventoryItemDescriptionComponent";
/**
 * ConditionDefinitionPreconditionComponent
 *
 * ConditionDefinitionPreconditionComponent: An observation that suggests that this condition applies.
 *
 * http://hl7.org/fhir/ConditionDefinitionPreconditionComponent
 */
export declare const ConditionDefinitionPreconditionComponent = "http://hl7.org/fhir/ConditionDefinitionPreconditionComponent";
/**
 * LocationPositionComponent
 *
 * LocationPositionComponent: The absolute geographic location of the Location, expressed using the WGS84 datum (This is the same co-ordinate system used in KML).
 *
 * http://hl7.org/fhir/LocationPositionComponent
 */
export declare const LocationPositionComponent = "http://hl7.org/fhir/LocationPositionComponent";
/**
 * sequenceRange
 *
 * MolecularSequence.relative.sequenceRange: Indicates the nucleotide range in the composed sequence when multiple 'relative' elements are used together.
 *
 * http://hl7.org/fhir/sequenceRange
 */
export declare const sequenceRange = "http://hl7.org/fhir/sequenceRange";
/**
 * policyBasis
 *
 * Consent.policyBasis: A Reference or URL used to uniquely identify the policy the organization will enforce for this Consent. This Reference or URL should be specific to the version of the policy and should be dereferencable to a computable policy of some form.
 *
 * http://hl7.org/fhir/policyBasis
 */
export declare const policyBasis = "http://hl7.org/fhir/policyBasis";
/**
 * _inputParameters
 *
 * (Modified) MeasureReport.inputParameters
 *
 * http://hl7.org/fhir/_inputParameters
 */
export declare const _inputParameters = "http://hl7.org/fhir/_inputParameters";
/**
 * _dateRange
 *
 * (Modified) MarketingStatus.dateRange
 *
 * http://hl7.org/fhir/_dateRange
 */
export declare const _dateRange = "http://hl7.org/fhir/_dateRange";
/**
 * _cost
 *
 * (Modified) MedicationKnowledge.packaging.cost
 *
 * http://hl7.org/fhir/_cost
 */
export declare const _cost = "http://hl7.org/fhir/_cost";
/**
 * Timing
 *
 * Specifies an event that may occur multiple times. Timing schedules are used to record when things are planned, expected or requested to occur. The most common usage is in dosage instructions for medications. They are also used when planning care of various kinds, and may be used for reporting the schedule to which past regular activities were carried out.
 *
 * http://hl7.org/fhir/Timing
 */
export declare const Timing = "http://hl7.org/fhir/Timing";
/**
 * _team
 *
 * (Modified) ConditionDefinition.team
 *
 * http://hl7.org/fhir/_team
 */
export declare const _team = "http://hl7.org/fhir/_team";
/**
 * _paternalOrganismId
 *
 * (Modified) SubstanceSourceMaterial.organism.hybrid.paternalOrganismId
 *
 * http://hl7.org/fhir/_paternalOrganismId
 */
export declare const _paternalOrganismId = "http://hl7.org/fhir/_paternalOrganismId";
/**
 * _statusChanged
 *
 * (Modified) MedicationRequest.statusChanged
 *
 * http://hl7.org/fhir/_statusChanged
 */
export declare const _statusChanged = "http://hl7.org/fhir/_statusChanged";
/**
 * ActivityDefinitionDynamicValueComponent
 *
 * ActivityDefinitionDynamicValueComponent: Dynamic values that will be evaluated to produce values for elements of the resulting resource. For example, if the dosage of a medication must be computed based on the patient's weight, a dynamic value would be used to specify an expression that calculated the weight, and the path on the request resource that would contain the result.
 *
 * http://hl7.org/fhir/ActivityDefinitionDynamicValueComponent
 */
export declare const ActivityDefinitionDynamicValueComponent = "http://hl7.org/fhir/ActivityDefinitionDynamicValueComponent";
/**
 * processor
 *
 * PaymentReconciliation.processor: The name of the card processor, etf processor, bank for checks.
 *
 * http://hl7.org/fhir/processor
 */
export declare const processor = "http://hl7.org/fhir/processor";
/**
 * _constraint
 *
 * (Modified) SearchParameter.constraint
 *
 * http://hl7.org/fhir/_constraint
 */
export declare const _constraint = "http://hl7.org/fhir/_constraint";
/**
 * _sampleSize
 *
 * (Modified) Evidence.statistic.sampleSize
 *
 * http://hl7.org/fhir/_sampleSize
 */
export declare const _sampleSize = "http://hl7.org/fhir/_sampleSize";
/**
 * ClinicalUseDefinitionContraindicationComponent
 *
 * ClinicalUseDefinitionContraindicationComponent: Specifics for when this is a contraindication.
 *
 * http://hl7.org/fhir/ClinicalUseDefinitionContraindicationComponent
 */
export declare const ClinicalUseDefinitionContraindicationComponent = "http://hl7.org/fhir/ClinicalUseDefinitionContraindicationComponent";
/**
 * _comorbidity
 *
 * (Modified) ClinicalUseDefinition.indication.comorbidity
 *
 * http://hl7.org/fhir/_comorbidity
 */
export declare const _comorbidity = "http://hl7.org/fhir/_comorbidity";
/**
 * _knownDataCount
 *
 * (Modified) Evidence.statistic.sampleSize.knownDataCount
 *
 * http://hl7.org/fhir/_knownDataCount
 */
export declare const _knownDataCount = "http://hl7.org/fhir/_knownDataCount";
/**
 * template
 *
 * ImplementationGuide.definition.template: A template for building resources.
 *
 * http://hl7.org/fhir/template
 */
export declare const template = "http://hl7.org/fhir/template";
/**
 * codeFilter
 *
 * DataRequirement.codeFilter: Code filters specify additional constraints on the data, specifying the value set of interest for a particular element of the data. Each code filter defines an additional constraint on the data, i.e. code filters are AND'ed, not OR'ed.
 *
 * http://hl7.org/fhir/codeFilter
 */
export declare const codeFilter = "http://hl7.org/fhir/codeFilter";
/**
 * dateAccessed
 *
 * Citation.citedArtifact.dateAccessed: When the cited artifact was accessed.
 *
 * http://hl7.org/fhir/dateAccessed
 */
export declare const dateAccessed = "http://hl7.org/fhir/dateAccessed";
/**
 * _organization
 *
 * (Modified) MedicinalProductDefinition.operation.organization
 *
 * http://hl7.org/fhir/_organization
 */
export declare const _organization = "http://hl7.org/fhir/_organization";
/**
 * _ifModifiedSince
 *
 * (Modified) Bundle.entry.request.ifModifiedSince
 *
 * http://hl7.org/fhir/_ifModifiedSince
 */
export declare const _ifModifiedSince = "http://hl7.org/fhir/_ifModifiedSince";
/**
 * _lastRevisionDate
 *
 * (Modified) Citation.citedArtifact.publicationForm.lastRevisionDate
 *
 * http://hl7.org/fhir/_lastRevisionDate
 */
export declare const _lastRevisionDate = "http://hl7.org/fhir/_lastRevisionDate";
/**
 * _strength
 *
 * (Modified) OperationDefinition.parameter.part.binding.strength
 *
 * http://hl7.org/fhir/_strength
 */
export declare const _strength = "http://hl7.org/fhir/_strength";
/**
 * numerator
 *
 * Ratio.numerator: The value of the numerator.
 *
 * http://hl7.org/fhir/numerator
 */
export declare const numerator = "http://hl7.org/fhir/numerator";
/**
 * _altitude
 *
 * (Modified) Location.position.altitude
 *
 * http://hl7.org/fhir/_altitude
 */
export declare const _altitude = "http://hl7.org/fhir/_altitude";
/**
 * _countingDateTime
 *
 * (Modified) InventoryReport.inventoryListing.countingDateTime
 *
 * http://hl7.org/fhir/_countingDateTime
 */
export declare const _countingDateTime = "http://hl7.org/fhir/_countingDateTime";
/**
 * MedicationDispense
 *
 * Indicates that a medication product is to be or has been dispensed for a named person/patient.  This includes a description of the medication product (supply) provided and the instructions for administering the medication.  The medication dispense is the result of a pharmacy system responding to a medication order.
 *
 * http://hl7.org/fhir/MedicationDispense
 */
export declare const MedicationDispense = "http://hl7.org/fhir/MedicationDispense";
/**
 * _maxDuration
 *
 * (Modified) SpecimenDefinition.typeTested.handling.maxDuration
 *
 * http://hl7.org/fhir/_maxDuration
 */
export declare const _maxDuration = "http://hl7.org/fhir/_maxDuration";
/**
 * requirement
 *
 * RequestOrchestration.action.input.requirement: Defines the data that is to be provided as input to the action.
 *
 * http://hl7.org/fhir/requirement
 */
export declare const requirement = "http://hl7.org/fhir/requirement";
/**
 * SubstanceProteinSubunitComponent
 *
 * SubstanceProteinSubunitComponent: This subclause refers to the description of each subunit constituting the SubstanceProtein. A subunit is a linear sequence of amino acids linked through peptide bonds. The Subunit information shall be provided when the finished SubstanceProtein is a complex of multiple sequences; subunits are not used to delineate domains within a single sequence. Subunits are listed in order of decreasing length; sequences of the same length will be ordered by decreasing molecular weight; subunits that have identical sequences will be repeated multiple times.
 *
 * http://hl7.org/fhir/SubstanceProteinSubunitComponent
 */
export declare const SubstanceProteinSubunitComponent = "http://hl7.org/fhir/SubstanceProteinSubunitComponent";
/**
 * _abatement
 *
 * (Modified) Condition.abatement
 *
 * http://hl7.org/fhir/_abatement
 */
export declare const _abatement = "http://hl7.org/fhir/_abatement";
/**
 * reportingPeriod
 *
 * InventoryReport.reportingPeriod: The period the report refers to.
 *
 * http://hl7.org/fhir/reportingPeriod
 */
export declare const reportingPeriod = "http://hl7.org/fhir/reportingPeriod";
/**
 * dosage
 *
 * MedicationKnowledge.indicationGuideline.dosingGuideline.dosage: Dosage for the medication for the specific guidelines.
 *
 * http://hl7.org/fhir/dosage
 */
export declare const dosage = "http://hl7.org/fhir/dosage";
/**
 * _supplement
 *
 * (Modified) NutritionOrder.supplement
 *
 * http://hl7.org/fhir/_supplement
 */
export declare const _supplement = "http://hl7.org/fhir/_supplement";
/**
 * _treatmentIntent
 *
 * (Modified) MedicationKnowledge.indicationGuideline.dosingGuideline.treatmentIntent
 *
 * http://hl7.org/fhir/_treatmentIntent
 */
export declare const _treatmentIntent = "http://hl7.org/fhir/_treatmentIntent";
/**
 * performingOrganization
 *
 * ChargeItem.performingOrganization: The organization performing the service.
 *
 * http://hl7.org/fhir/performingOrganization
 */
export declare const performingOrganization = "http://hl7.org/fhir/performingOrganization";
/**
 * _what
 *
 * (Modified) Provenance.entity.what
 *
 * http://hl7.org/fhir/_what
 */
export declare const _what = "http://hl7.org/fhir/_what";
/**
 * intervalUnit
 *
 * SampledData.intervalUnit: The measurement unit in which the sample interval is expressed.
 *
 * http://hl7.org/fhir/intervalUnit
 */
export declare const intervalUnit = "http://hl7.org/fhir/intervalUnit";
/**
 * preAuthPeriod
 *
 * ClaimResponse.item.detail.subDetail.reviewOutcome.preAuthPeriod: The time frame during which this authorization is effective.
 *
 * http://hl7.org/fhir/preAuthPeriod
 */
export declare const preAuthPeriod = "http://hl7.org/fhir/preAuthPeriod";
/**
 * fhirPathCriteria
 *
 * SubscriptionTopic.resourceTrigger.fhirPathCriteria: The FHIRPath based rules that the server should use to determine when to trigger a notification for this topic.
 *
 * http://hl7.org/fhir/fhirPathCriteria
 */
export declare const fhirPathCriteria = "http://hl7.org/fhir/fhirPathCriteria";
/**
 * administeredBy
 *
 * InsurancePlan.administeredBy: An organization which administer other services such as underwriting, customer service and/or claims processing on behalf of the health insurance product owner.
 *
 * http://hl7.org/fhir/administeredBy
 */
export declare const administeredBy = "http://hl7.org/fhir/administeredBy";
/**
 * factor
 *
 * ClaimResponse.addItem.factor: A real number that represents a multiplier used in determining the overall value of services delivered and/or goods received. The concept of a Factor allows for a discount or surcharge multiplier to be applied to a monetary amount.
 *
 * http://hl7.org/fhir/factor
 */
export declare const factor = "http://hl7.org/fhir/factor";
/**
 * ContactPoint
 *
 * Details for all kinds of technology mediated contact points for a person or organization, including telephone, email, etc.
 *
 * http://hl7.org/fhir/ContactPoint
 */
export declare const ContactPoint = "http://hl7.org/fhir/ContactPoint";
/**
 * appointmentType
 *
 * Slot.appointmentType: The style of appointment or patient that may be booked in the slot (not service type).
 *
 * http://hl7.org/fhir/appointmentType
 */
export declare const appointmentType = "http://hl7.org/fhir/appointmentType";
/**
 * _collector
 *
 * (Modified) Specimen.collection.collector
 *
 * http://hl7.org/fhir/_collector
 */
export declare const _collector = "http://hl7.org/fhir/_collector";
/**
 * answerValueSet
 *
 * Questionnaire.item.item.answerValueSet: A reference to a value set containing a list of values representing permitted answers for a question.
 *
 * http://hl7.org/fhir/answerValueSet
 */
export declare const answerValueSet = "http://hl7.org/fhir/answerValueSet";
/**
 * _achievementStatus
 *
 * (Modified) Goal.achievementStatus
 *
 * http://hl7.org/fhir/_achievementStatus
 */
export declare const _achievementStatus = "http://hl7.org/fhir/_achievementStatus";
/**
 * carrierHRF
 *
 * Device.udiCarrier.carrierHRF: The full UDI carrier as the human readable form (HRF) representation of the barcode string as printed on the packaging of the device.
 *
 * http://hl7.org/fhir/carrierHRF
 */
export declare const carrierHRF = "http://hl7.org/fhir/carrierHRF";
/**
 * _evaluatedResource
 *
 * (Modified) MeasureReport.evaluatedResource
 *
 * http://hl7.org/fhir/_evaluatedResource
 */
export declare const _evaluatedResource = "http://hl7.org/fhir/_evaluatedResource";
/**
 * signer
 *
 * Contract.signer: Parties with legal standing in the Contract, including the principal parties, the grantor(s) and grantee(s), which are any person or organization bound by the contract, and any ancillary parties, which facilitate the execution of the contract such as a notary or witness.
 *
 * http://hl7.org/fhir/signer
 */
export declare const signer = "http://hl7.org/fhir/signer";
/**
 * _usageReason
 *
 * (Modified) DeviceUsage.usageReason
 *
 * http://hl7.org/fhir/_usageReason
 */
export declare const _usageReason = "http://hl7.org/fhir/_usageReason";
/**
 * variableDefinition
 *
 * Evidence.statistic.modelCharacteristic.variable.variableDefinition: Description of the variable.
 *
 * http://hl7.org/fhir/variableDefinition
 */
export declare const variableDefinition = "http://hl7.org/fhir/variableDefinition";
/**
 * manifestation
 *
 * Immunization.reaction.manifestation: Details of the reaction.
 *
 * http://hl7.org/fhir/manifestation
 */
export declare const manifestation = "http://hl7.org/fhir/manifestation";
/**
 * searchType
 *
 * OperationDefinition.parameter.part.searchType: How the parameter is understood if/when it used as search parameter. This is only used if the parameter is a string.
 *
 * http://hl7.org/fhir/searchType
 */
export declare const searchType = "http://hl7.org/fhir/searchType";
/**
 * PaymentReconciliation
 *
 * This resource provides the details including amount of a payment and allocates the payment items being paid.
 *
 * http://hl7.org/fhir/PaymentReconciliation
 */
export declare const PaymentReconciliation = "http://hl7.org/fhir/PaymentReconciliation";
/**
 * _modelNumber
 *
 * (Modified) DeviceDefinition.modelNumber
 *
 * http://hl7.org/fhir/_modelNumber
 */
export declare const _modelNumber = "http://hl7.org/fhir/_modelNumber";
/**
 * groupingId
 *
 * ImplementationGuide.definition.resource.groupingId: Reference to the id of the grouping this resource appears in.
 *
 * http://hl7.org/fhir/groupingId
 */
export declare const groupingId = "http://hl7.org/fhir/groupingId";
/**
 * _VisionPrescription
 *
 * (Modified) VisionPrescription
 *
 * http://hl7.org/fhir/_VisionPrescription
 */
export declare const _VisionPrescription = "http://hl7.org/fhir/_VisionPrescription";
/**
 * performerLinkId
 *
 * Contract.term.group.action.performerLinkId: Id [identifier??] of the clause or question text related to the reason type or reference of this  action in the referenced form or QuestionnaireResponse.
 *
 * http://hl7.org/fhir/performerLinkId
 */
export declare const performerLinkId = "http://hl7.org/fhir/performerLinkId";
/**
 * procedure
 *
 * ExplanationOfBenefit.procedure: Procedures performed on the patient relevant to the billing items with the claim.
 *
 * http://hl7.org/fhir/procedure
 */
export declare const procedure = "http://hl7.org/fhir/procedure";
/**
 * implicitRules
 *
 * Resource.implicitRules: A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.
 *
 * http://hl7.org/fhir/implicitRules
 */
export declare const implicitRules = "http://hl7.org/fhir/implicitRules";
/**
 * query
 *
 * AuditEvent.entity.query: The query parameters for a query-type entities.
 *
 * http://hl7.org/fhir/query
 */
export declare const query = "http://hl7.org/fhir/query";
/**
 * Items
 *
 * CoverageEligibilityResponse.Insurance.Items: Benefits and optionally current balances, and authorization details by category or service.
 *
 * http://hl7.org/fhir/Items
 */
export declare const Items = "http://hl7.org/fhir/Items";
/**
 * _slot
 *
 * (Modified) Appointment.slot
 *
 * http://hl7.org/fhir/_slot
 */
export declare const _slot = "http://hl7.org/fhir/_slot";
/**
 * _conditionalCreate
 *
 * (Modified) CapabilityStatement.rest.resource.conditionalCreate
 *
 * http://hl7.org/fhir/_conditionalCreate
 */
export declare const _conditionalCreate = "http://hl7.org/fhir/_conditionalCreate";
/**
 * PatientCommunicationComponent
 *
 * PatientCommunicationComponent: A language which may be used to communicate with the patient about his or her health.
 *
 * http://hl7.org/fhir/PatientCommunicationComponent
 */
export declare const PatientCommunicationComponent = "http://hl7.org/fhir/PatientCommunicationComponent";
/**
 * ConditionDefinitionMedicationComponent
 *
 * ConditionDefinitionMedicationComponent: Medications particularly relevant for this condition.
 *
 * http://hl7.org/fhir/ConditionDefinitionMedicationComponent
 */
export declare const ConditionDefinitionMedicationComponent = "http://hl7.org/fhir/ConditionDefinitionMedicationComponent";
/**
 * documentation
 *
 * ActorDefinition.documentation: Documentation about the functionality of the actor.
 *
 * http://hl7.org/fhir/documentation
 */
export declare const documentation = "http://hl7.org/fhir/documentation";
/**
 * maxDosePerTreatmentPeriod
 *
 * AdministrableProductDefinition.routeOfAdministration.maxDosePerTreatmentPeriod: The maximum dose per treatment period that can be administered.
 *
 * http://hl7.org/fhir/maxDosePerTreatmentPeriod
 */
export declare const maxDosePerTreatmentPeriod = "http://hl7.org/fhir/maxDosePerTreatmentPeriod";
/**
 * example
 *
 * ElementDefinition.example: A sample value for this element demonstrating the type of information that would typically be found in the element.
 *
 * http://hl7.org/fhir/example
 */
export declare const example = "http://hl7.org/fhir/example";
/**
 * _sessionKey
 *
 * (Modified) VirtualServiceDetail.sessionKey
 *
 * http://hl7.org/fhir/_sessionKey
 */
export declare const _sessionKey = "http://hl7.org/fhir/_sessionKey";
/**
 * lastPage
 *
 * Citation.citedArtifact.publicationForm.lastPage: Used for isolated representation of last page.
 *
 * http://hl7.org/fhir/lastPage
 */
export declare const lastPage = "http://hl7.org/fhir/lastPage";
/**
 * hybridType
 *
 * SubstanceSourceMaterial.organism.hybrid.hybridType: The hybrid type of an organism shall be specified.
 *
 * http://hl7.org/fhir/hybridType
 */
export declare const hybridType = "http://hl7.org/fhir/hybridType";
/**
 * field
 *
 * TestScript.teardown.action.operation.requestHeader.field: The HTTP header field e.g. "Accept".
 *
 * http://hl7.org/fhir/field
 */
export declare const field = "http://hl7.org/fhir/field";
/**
 * maxDosePerPeriod
 *
 * Dosage.maxDosePerPeriod: Upper limit on medication per unit of time.
 *
 * http://hl7.org/fhir/maxDosePerPeriod
 */
export declare const maxDosePerPeriod = "http://hl7.org/fhir/maxDosePerPeriod";
/**
 * _excludedStructure
 *
 * (Modified) BodyStructure.excludedStructure
 *
 * http://hl7.org/fhir/_excludedStructure
 */
export declare const _excludedStructure = "http://hl7.org/fhir/_excludedStructure";
/**
 * _script
 *
 * (Modified) TestPlan.testCase.testRun.script
 *
 * http://hl7.org/fhir/_script
 */
export declare const _script = "http://hl7.org/fhir/_script";
/**
 * acceptLanguage
 *
 * CapabilityStatement.acceptLanguage: A list of the languages supported by this implementation that are usefully supported in the ```Accept-Language``` header.
 *
 * http://hl7.org/fhir/acceptLanguage
 */
export declare const acceptLanguage = "http://hl7.org/fhir/acceptLanguage";
/**
 * practiceSetting
 *
 * DocumentReference.practiceSetting: This property may convey specifics about the practice setting where the content was created, often reflecting the clinical specialty.
 *
 * http://hl7.org/fhir/practiceSetting
 */
export declare const practiceSetting = "http://hl7.org/fhir/practiceSetting";
/**
 * brand
 *
 * VisionPrescription.lensSpecification.brand: Brand recommendations or restrictions.
 *
 * http://hl7.org/fhir/brand
 */
export declare const brand = "http://hl7.org/fhir/brand";
/**
 * _attributeEstimate
 *
 * (Modified) Evidence.statistic.modelCharacteristic.attributeEstimate
 *
 * http://hl7.org/fhir/_attributeEstimate
 */
export declare const _attributeEstimate = "http://hl7.org/fhir/_attributeEstimate";
/**
 * _end
 *
 * (Modified) Subscription.end
 *
 * http://hl7.org/fhir/_end
 */
export declare const _end = "http://hl7.org/fhir/_end";
/**
 * diagnosisSequence
 *
 * ExplanationOfBenefit.item.diagnosisSequence: Diagnoses applicable for this service or product.
 *
 * http://hl7.org/fhir/diagnosisSequence
 */
export declare const diagnosisSequence = "http://hl7.org/fhir/diagnosisSequence";
/**
 * _specification
 *
 * (Modified) DeviceDefinition.conformsTo.specification
 *
 * http://hl7.org/fhir/_specification
 */
export declare const _specification = "http://hl7.org/fhir/_specification";
/**
 * _test
 *
 * (Modified) TestScript.test
 *
 * http://hl7.org/fhir/_test
 */
export declare const _test = "http://hl7.org/fhir/_test";
/**
 * _durationMax
 *
 * (Modified) Timing.repeat.durationMax
 *
 * http://hl7.org/fhir/_durationMax
 */
export declare const _durationMax = "http://hl7.org/fhir/_durationMax";
/**
 * impurity
 *
 * MedicinalProductDefinition.impurity: Any component of the drug product which is not the chemical entity defined as the drug substance, or an excipient in the drug product. This includes process-related impurities and contaminants, product-related impurities including degradation products.
 *
 * http://hl7.org/fhir/impurity
 */
export declare const impurity = "http://hl7.org/fhir/impurity";
/**
 * _Practitioner
 *
 * (Modified) Practitioner
 *
 * http://hl7.org/fhir/_Practitioner
 */
export declare const _Practitioner = "http://hl7.org/fhir/_Practitioner";
/**
 * SubstanceIngredientComponent
 *
 * SubstanceIngredientComponent: A substance can be composed of other substances.
 *
 * http://hl7.org/fhir/SubstanceIngredientComponent
 */
export declare const SubstanceIngredientComponent = "http://hl7.org/fhir/SubstanceIngredientComponent";
/**
 * control
 *
 * Contract.term.group.securityLabel.control: Security label privacy tag that specifies the manner in which term and/or term elements are to be protected.
 *
 * http://hl7.org/fhir/control
 */
export declare const control = "http://hl7.org/fhir/control";
/**
 * _enterer
 *
 * (Modified) PaymentReconciliation.enterer
 *
 * http://hl7.org/fhir/_enterer
 */
export declare const _enterer = "http://hl7.org/fhir/_enterer";
/**
 * TransportOutputComponent
 *
 * TransportOutputComponent: Outputs produced by the Transport.
 *
 * http://hl7.org/fhir/TransportOutputComponent
 */
export declare const TransportOutputComponent = "http://hl7.org/fhir/TransportOutputComponent";
/**
 * _retentionTime
 *
 * (Modified) SpecimenDefinition.typeTested.retentionTime
 *
 * http://hl7.org/fhir/_retentionTime
 */
export declare const _retentionTime = "http://hl7.org/fhir/_retentionTime";
/**
 * _encodeRequestUrl
 *
 * (Modified) TestScript.teardown.action.operation.encodeRequestUrl
 *
 * http://hl7.org/fhir/_encodeRequestUrl
 */
export declare const _encodeRequestUrl = "http://hl7.org/fhir/_encodeRequestUrl";
/**
 * countMax
 *
 * Timing.repeat.countMax: If present, indicates that the count is a range - so to perform the action between [count] and [countMax] times.
 *
 * http://hl7.org/fhir/countMax
 */
export declare const countMax = "http://hl7.org/fhir/countMax";
/**
 * _netContent
 *
 * (Modified) InventoryItem.netContent
 *
 * http://hl7.org/fhir/_netContent
 */
export declare const _netContent = "http://hl7.org/fhir/_netContent";
/**
 * AccountBalanceComponent
 *
 * AccountBalanceComponent: The calculated account balances - these are calculated and processed by the finance system.

The balances with a `term` that is not current are usually generated/updated by an invoicing or similar process.
 *
 * http://hl7.org/fhir/AccountBalanceComponent
 */
export declare const AccountBalanceComponent = "http://hl7.org/fhir/AccountBalanceComponent";
/**
 * _sequenceAttachment
 *
 * (Modified) SubstanceProtein.subunit.sequenceAttachment
 *
 * http://hl7.org/fhir/_sequenceAttachment
 */
export declare const _sequenceAttachment = "http://hl7.org/fhir/_sequenceAttachment";
/**
 * requestedLocation
 *
 * Transport.requestedLocation: The desired or final location for the transport.
 *
 * http://hl7.org/fhir/requestedLocation
 */
export declare const requestedLocation = "http://hl7.org/fhir/requestedLocation";
/**
 * DeviceDefinitionRegulatoryIdentifierComponent
 *
 * DeviceDefinitionRegulatoryIdentifierComponent: Identifier associated with the regulatory documentation (certificates, technical documentation, post-market surveillance documentation and reports) of a set of device models sharing the same intended purpose, risk class and essential design and manufacturing characteristics. One example is the Basic UDI-DI in Europe.
 *
 * http://hl7.org/fhir/DeviceDefinitionRegulatoryIdentifierComponent
 */
export declare const DeviceDefinitionRegulatoryIdentifierComponent = "http://hl7.org/fhir/DeviceDefinitionRegulatoryIdentifierComponent";
/**
 * _target
 *
 * (Modified) ConceptMap.group.element.target
 *
 * http://hl7.org/fhir/_target
 */
export declare const _target = "http://hl7.org/fhir/_target";
/**
 * _implicated
 *
 * (Modified) DetectedIssue.implicated
 *
 * http://hl7.org/fhir/_implicated
 */
export declare const _implicated = "http://hl7.org/fhir/_implicated";
/**
 * _administration
 *
 * (Modified) NutritionOrder.enteralFormula.administration
 *
 * http://hl7.org/fhir/_administration
 */
export declare const _administration = "http://hl7.org/fhir/_administration";
/**
 * _flag
 *
 * (Modified) List.entry.flag
 *
 * http://hl7.org/fhir/_flag
 */
export declare const _flag = "http://hl7.org/fhir/_flag";
/**
 * _party
 *
 * (Modified) Coverage.paymentBy.party
 *
 * http://hl7.org/fhir/_party
 */
export declare const _party = "http://hl7.org/fhir/_party";
/**
 * _version
 *
 * (Modified) ValueSet.expansion.contains.version
 *
 * http://hl7.org/fhir/_version
 */
export declare const _version = "http://hl7.org/fhir/_version";
/**
 * provision
 *
 * Consent.provision.provision.provision: Provisions which provide exceptions to the base provision or subprovisions.
 *
 * http://hl7.org/fhir/provision
 */
export declare const provision = "http://hl7.org/fhir/provision";
/**
 * patientPaid
 *
 * Claim.item.patientPaid: The amount paid by the patient, in total at the claim claim level or specifically for the item and detail level, to the provider for goods and services.
 *
 * http://hl7.org/fhir/patientPaid
 */
export declare const patientPaid = "http://hl7.org/fhir/patientPaid";
/**
 * referenceNumber
 *
 * PaymentReconciliation.referenceNumber: The check number, eft reference, car processor reference.
 *
 * http://hl7.org/fhir/referenceNumber
 */
export declare const referenceNumber = "http://hl7.org/fhir/referenceNumber";
/**
 * manifest
 *
 * ImplementationGuide.manifest: Information about an assembled implementation guide, created by the publication tooling.
 *
 * http://hl7.org/fhir/manifest
 */
export declare const manifest = "http://hl7.org/fhir/manifest";
/**
 * Account
 *
 * A financial tool for tracking value accrued for a particular purpose.  In the healthcare field, used to track charges for a patient, cost centers, etc.
 *
 * http://hl7.org/fhir/Account
 */
export declare const Account = "http://hl7.org/fhir/Account";
/**
 * _goal
 *
 * (Modified) RequestOrchestration.action.action.goal
 *
 * http://hl7.org/fhir/_goal
 */
export declare const _goal = "http://hl7.org/fhir/_goal";
/**
 * _basis
 *
 * (Modified) RiskAssessment.basis
 *
 * http://hl7.org/fhir/_basis
 */
export declare const _basis = "http://hl7.org/fhir/_basis";
/**
 * MessageSource
 *
 * MessageHeader.MessageSource: The source application from which this message originated.
 *
 * http://hl7.org/fhir/MessageSource
 */
export declare const MessageSource = "http://hl7.org/fhir/MessageSource";
/**
 * _formCode
 *
 * (Modified) PaymentReconciliation.formCode
 *
 * http://hl7.org/fhir/_formCode
 */
export declare const _formCode = "http://hl7.org/fhir/_formCode";
/**
 * _disclaimer
 *
 * (Modified) Measure.disclaimer
 *
 * http://hl7.org/fhir/_disclaimer
 */
export declare const _disclaimer = "http://hl7.org/fhir/_disclaimer";
/**
 * _definitionByCombination
 *
 * (Modified) EvidenceVariable.characteristic.definitionByCombination.characteristic.definitionByCombination
 *
 * http://hl7.org/fhir/_definitionByCombination
 */
export declare const _definitionByCombination = "http://hl7.org/fhir/_definitionByCombination";
/**
 * step
 *
 * ExampleScenario.process.step.process.step.alternative.step.alternative.step: Indicates the operation, sub-process or scenario that happens if the alternative option is selected.
 *
 * http://hl7.org/fhir/step
 */
export declare const step = "http://hl7.org/fhir/step";
/**
 * fractionDescription
 *
 * SubstanceSourceMaterial.fractionDescription: Many complex materials are fractions of parts of plants, animals, or minerals. Fraction elements are often necessary to define both Substances and Specified Group 1 Substances. For substances derived from Plants, fraction information will be captured at the Substance information level ( . Oils, Juices and Exudates). Additional information for Extracts, such as extraction solvent composition, will be captured at the Specified Substance Group 1 information level. For plasma-derived products fraction information will be captured at the Substance and the Specified Substance Group 1 levels.
 *
 * http://hl7.org/fhir/fractionDescription
 */
export declare const fractionDescription = "http://hl7.org/fhir/fractionDescription";
/**
 * valueCategory
 *
 * Evidence.statistic.modelCharacteristic.variable.valueCategory: Description for grouping of ordinal or polychotomous variables.
 *
 * http://hl7.org/fhir/valueCategory
 */
export declare const valueCategory = "http://hl7.org/fhir/valueCategory";
/**
 * requestMethod
 *
 * TestScript.test.action.assert.requestMethod: The request method or HTTP operation code to compare against that used by the client system under test.
 *
 * http://hl7.org/fhir/requestMethod
 */
export declare const requestMethod = "http://hl7.org/fhir/requestMethod";
/**
 * BodySite
 *
 * Claim.Item.BodySite: Physical location where the service is performed or applies.
 *
 * http://hl7.org/fhir/BodySite
 */
export declare const BodySite = "http://hl7.org/fhir/BodySite";
/**
 * etag
 *
 * Bundle.entry.response.etag: The Etag for the resource, if the operation for the entry produced a versioned resource (see [Resource Metadata and Versioning](http.html#versioning) and [Managing Resource Contention](http.html#concurrency)).
 *
 * http://hl7.org/fhir/etag
 */
export declare const etag = "http://hl7.org/fhir/etag";
/**
 * specimenQuantity
 *
 * Specimen.container.specimenQuantity: The quantity of specimen in the container; may be volume, dimensions, or other appropriate measurements, depending on the specimen type.
 *
 * http://hl7.org/fhir/specimenQuantity
 */
export declare const specimenQuantity = "http://hl7.org/fhir/specimenQuantity";
/**
 * comprisedOf
 *
 * MedicinalProductDefinition.comprisedOf: Types of medicinal manufactured items and/or devices that this product consists of, such as tablets, capsule, or syringes. Used as a direct link when the item's packaging is not being recorded (see also PackagedProductDefinition.package.containedItem.item).
 *
 * http://hl7.org/fhir/comprisedOf
 */
export declare const comprisedOf = "http://hl7.org/fhir/comprisedOf";
/**
 * _pediatricUseIndicator
 *
 * (Modified) MedicinalProductDefinition.pediatricUseIndicator
 *
 * http://hl7.org/fhir/_pediatricUseIndicator
 */
export declare const _pediatricUseIndicator = "http://hl7.org/fhir/_pediatricUseIndicator";
/**
 * _destination
 *
 * (Modified) TestScript.metadata.capability.destination
 *
 * http://hl7.org/fhir/_destination
 */
export declare const _destination = "http://hl7.org/fhir/_destination";
/**
 * _evaluationMessage
 *
 * (Modified) GuidanceResponse.evaluationMessage
 *
 * http://hl7.org/fhir/_evaluationMessage
 */
export declare const _evaluationMessage = "http://hl7.org/fhir/_evaluationMessage";
/**
 * ResearchStudyComparisonGroupComponent
 *
 * ResearchStudyComparisonGroupComponent: Describes an expected event or sequence of events for one of the subjects of a study. E.g. for a living subject: exposure to drug A, wash-out, exposure to drug B, wash-out, follow-up. E.g. for a stability study: {store sample from lot A at 25 degrees for 1 month}, {store sample from lot A at 40 degrees for 1 month}.
 *
 * http://hl7.org/fhir/ResearchStudyComparisonGroupComponent
 */
export declare const ResearchStudyComparisonGroupComponent = "http://hl7.org/fhir/ResearchStudyComparisonGroupComponent";
/**
 * _DomainResource
 *
 * http://hl7.org/fhir/_DomainResource
 */
export declare const _DomainResource = "http://hl7.org/fhir/_DomainResource";
/**
 * CitationCitedArtifactWebLocationComponent
 *
 * CitationCitedArtifactComponent.CitationCitedArtifactWebLocationComponent: Used for any URL for the article or artifact cited.
 *
 * http://hl7.org/fhir/CitationCitedArtifactWebLocationComponent
 */
export declare const CitationCitedArtifactWebLocationComponent = "http://hl7.org/fhir/CitationCitedArtifactWebLocationComponent";
/**
 * beneficiary
 *
 * Coverage.beneficiary: The party who benefits from the insurance coverage; the patient when products and/or services are provided.
 *
 * http://hl7.org/fhir/beneficiary
 */
export declare const beneficiary = "http://hl7.org/fhir/beneficiary";
/**
 * prefix
 *
 * Questionnaire.item.item.prefix: A short label for a particular group, question or set of display text within the questionnaire used for reference by the individual completing the questionnaire.
 *
 * http://hl7.org/fhir/prefix
 */
export declare const prefix = "http://hl7.org/fhir/prefix";
/**
 * effectiveTime
 *
 * Contract.term.group.asset.valuedItem.effectiveTime: Indicates the time during which this Contract ValuedItem information is effective.
 *
 * http://hl7.org/fhir/effectiveTime
 */
export declare const effectiveTime = "http://hl7.org/fhir/effectiveTime";
/**
 * RegulatedAuthorizationCaseComponent
 *
 * RegulatedAuthorizationCaseComponent: The case or regulatory procedure for granting or amending a regulated authorization. An authorization is granted in response to submissions/applications by those seeking authorization. A case is the administrative process that deals with the application(s) that relate to this and assesses them. Note: This area is subject to ongoing review and the workgroup is seeking implementer feedback on its use (see link at bottom of page).
 *
 * http://hl7.org/fhir/RegulatedAuthorizationCaseComponent
 */
export declare const RegulatedAuthorizationCaseComponent = "http://hl7.org/fhir/RegulatedAuthorizationCaseComponent";
/**
 * AccountProcedureComponent
 *
 * AccountProcedureComponent: When using an account for billing a specific Encounter the set of procedures that are relevant for billing are stored here on the account where they are able to be sequenced appropriately prior to processing to produce claim(s).
 *
 * http://hl7.org/fhir/AccountProcedureComponent
 */
export declare const AccountProcedureComponent = "http://hl7.org/fhir/AccountProcedureComponent";
/**
 * doseStatusReason
 *
 * ImmunizationEvaluation.doseStatusReason: Provides an explanation as to why the vaccine administration event is valid or not relative to the published recommendations.
 *
 * http://hl7.org/fhir/doseStatusReason
 */
export declare const doseStatusReason = "http://hl7.org/fhir/doseStatusReason";
/**
 * ResearchStudyAssociatedPartyComponent
 *
 * ResearchStudyAssociatedPartyComponent: Sponsors, collaborators, and other parties.
 *
 * http://hl7.org/fhir/ResearchStudyAssociatedPartyComponent
 */
export declare const ResearchStudyAssociatedPartyComponent = "http://hl7.org/fhir/ResearchStudyAssociatedPartyComponent";
/**
 * reason
 *
 * Procedure.reason: The coded reason or reference why the procedure was performed. This may be a coded entity of some type, be present as text, or be a reference to one of several resources that justify the procedure.
 *
 * http://hl7.org/fhir/reason
 */
export declare const reason = "http://hl7.org/fhir/reason";
/**
 * _precondition
 *
 * (Modified) ConditionDefinition.precondition
 *
 * http://hl7.org/fhir/_precondition
 */
export declare const _precondition = "http://hl7.org/fhir/_precondition";
/**
 * criteria
 *
 * Measure.supplementalData.criteria: The criteria for the supplemental data. This is typically the name of a valid expression defined within a referenced library, but it may also be a path to a specific data element. The criteria defines the data to be returned for this element.
 *
 * http://hl7.org/fhir/criteria
 */
export declare const criteria = "http://hl7.org/fhir/criteria";
/**
 * MedicationAdministrationDosageComponent
 *
 * MedicationAdministrationDosageComponent: Describes the medication dosage information details e.g. dose, rate, site, route, etc.
 *
 * http://hl7.org/fhir/MedicationAdministrationDosageComponent
 */
export declare const MedicationAdministrationDosageComponent = "http://hl7.org/fhir/MedicationAdministrationDosageComponent";
/**
 * latitude
 *
 * Location.position.latitude: Latitude. The value domain and the interpretation are the same as for the text of the latitude element in KML (see notes on Location main page).
 *
 * http://hl7.org/fhir/latitude
 */
export declare const latitude = "http://hl7.org/fhir/latitude";
/**
 * IngredientSubstanceStrengthReferenceStrengthComponent
 *
 * IngredientSubstanceComponent.IngredientSubstanceStrengthComponent.IngredientSubstanceStrengthReferenceStrengthComponent: Strength expressed in terms of a reference substance. For when the ingredient strength is additionally expressed as equivalent to the strength of some other closely related substance (e.g. salt vs. base). Reference strength represents the strength (quantitative composition) of the active moiety of the active substance. There are situations when the active substance and active moiety are different, therefore both a strength and a reference strength are needed.
 *
 * http://hl7.org/fhir/IngredientSubstanceStrengthReferenceStrengthComponent
 */
export declare const IngredientSubstanceStrengthReferenceStrengthComponent = "http://hl7.org/fhir/IngredientSubstanceStrengthReferenceStrengthComponent";
/**
 * _thursday
 *
 * (Modified) Appointment.recurrenceTemplate.weeklyTemplate.thursday
 *
 * http://hl7.org/fhir/_thursday
 */
export declare const _thursday = "http://hl7.org/fhir/_thursday";
/**
 * securityContext
 *
 * Binary.securityContext: This element identifies another resource that can be used as a proxy of the security sensitivity to use when deciding and enforcing access control rules for the Binary resource. Given that the Binary resource contains very few elements that can be used to determine the sensitivity of the data and relationships to individuals, the referenced resource stands in as a proxy equivalent for this purpose. This referenced resource may be related to the Binary (e.g. DocumentReference), or may be some non-related Resource purely as a security proxy. E.g. to identify that the binary resource relates to a patient, and access should only be granted to applications that have access to the patient.
 *
 * http://hl7.org/fhir/securityContext
 */
export declare const securityContext = "http://hl7.org/fhir/securityContext";
/**
 * _baseDefinition
 *
 * (Modified) StructureDefinition.baseDefinition
 *
 * http://hl7.org/fhir/_baseDefinition
 */
export declare const _baseDefinition = "http://hl7.org/fhir/_baseDefinition";
/**
 * _publicationStatus
 *
 * (Modified) Contract.contentDefinition.publicationStatus
 *
 * http://hl7.org/fhir/_publicationStatus
 */
export declare const _publicationStatus = "http://hl7.org/fhir/_publicationStatus";
/**
 * relatedArtifact
 *
 * Measure.relatedArtifact: Related artifacts such as additional documentation, justification, or bibliographic references.
 *
 * http://hl7.org/fhir/relatedArtifact
 */
export declare const relatedArtifact = "http://hl7.org/fhir/relatedArtifact";
/**
 * safety
 *
 * DeviceDefinition.safety: Safety characteristics of the device.
 *
 * http://hl7.org/fhir/safety
 */
export declare const safety = "http://hl7.org/fhir/safety";
/**
 * stereochemistry
 *
 * SubstanceDefinition.structure.stereochemistry: Stereochemistry type.
 *
 * http://hl7.org/fhir/stereochemistry
 */
export declare const stereochemistry = "http://hl7.org/fhir/stereochemistry";
/**
 * _timeout
 *
 * (Modified) Subscription.timeout
 *
 * http://hl7.org/fhir/_timeout
 */
export declare const _timeout = "http://hl7.org/fhir/_timeout";
/**
 * primarySource
 *
 * VerificationResult.primarySource: Information about the primary source(s) involved in validation.
 *
 * http://hl7.org/fhir/primarySource
 */
export declare const primarySource = "http://hl7.org/fhir/primarySource";
/**
 * NutritionOrderOralDietNutrientComponent
 *
 * NutritionOrderOralDietComponent.NutritionOrderOralDietNutrientComponent: Class that defines the quantity and type of nutrient modifications (for example carbohydrate, fiber or sodium) required for the oral diet.
 *
 * http://hl7.org/fhir/NutritionOrderOralDietNutrientComponent
 */
export declare const NutritionOrderOralDietNutrientComponent = "http://hl7.org/fhir/NutritionOrderOralDietNutrientComponent";
/**
 * responseCode
 *
 * TestScript.test.action.assert.responseCode: The value of the HTTP response code to be tested.
 *
 * http://hl7.org/fhir/responseCode
 */
export declare const responseCode = "http://hl7.org/fhir/responseCode";
/**
 * eventHistory
 *
 * DeviceDispense.eventHistory: A summary of the events of interest that have occurred, such as when the dispense was verified.
 *
 * http://hl7.org/fhir/eventHistory
 */
export declare const eventHistory = "http://hl7.org/fhir/eventHistory";
/**
 * _doseForm
 *
 * (Modified) MedicationKnowledge.definitional.doseForm
 *
 * http://hl7.org/fhir/_doseForm
 */
export declare const _doseForm = "http://hl7.org/fhir/_doseForm";
/**
 * _allowedResponse
 *
 * (Modified) MessageDefinition.allowedResponse
 *
 * http://hl7.org/fhir/_allowedResponse
 */
export declare const _allowedResponse = "http://hl7.org/fhir/_allowedResponse";
/**
 * _storageGuideline
 *
 * (Modified) MedicationKnowledge.storageGuideline
 *
 * http://hl7.org/fhir/_storageGuideline
 */
export declare const _storageGuideline = "http://hl7.org/fhir/_storageGuideline";
/**
 * timezone
 *
 * Appointment.recurrenceTemplate.timezone: The timezone of the recurring appointment occurrences.
 *
 * http://hl7.org/fhir/timezone
 */
export declare const timezone = "http://hl7.org/fhir/timezone";
/**
 * copolymerConnectivity
 *
 * SubstancePolymer.copolymerConnectivity: Descrtibes the copolymer sequence type (polymer connectivity).
 *
 * http://hl7.org/fhir/copolymerConnectivity
 */
export declare const copolymerConnectivity = "http://hl7.org/fhir/copolymerConnectivity";
/**
 * GenomicStudyAnalysisOutputComponent
 *
 * GenomicStudyAnalysisComponent.GenomicStudyAnalysisOutputComponent: Outputs for the analysis event.
 *
 * http://hl7.org/fhir/GenomicStudyAnalysisOutputComponent
 */
export declare const GenomicStudyAnalysisOutputComponent = "http://hl7.org/fhir/GenomicStudyAnalysisOutputComponent";
/**
 * _molecularWeight
 *
 * (Modified) SubstanceDefinition.structure.molecularWeight
 *
 * http://hl7.org/fhir/_molecularWeight
 */
export declare const _molecularWeight = "http://hl7.org/fhir/_molecularWeight";
/**
 * ObservationDefinition
 *
 * Set of definitional characteristics for a kind of observation or measurement produced or consumed by an orderable health care service.
 *
 * http://hl7.org/fhir/ObservationDefinition
 */
export declare const ObservationDefinition = "http://hl7.org/fhir/ObservationDefinition";
/**
 * ifNoneMatch
 *
 * Bundle.entry.request.ifNoneMatch: If the ETag values match, return a 304 Not Modified status. See the API documentation for ["Conditional Read"](http.html#cread).
 *
 * http://hl7.org/fhir/ifNoneMatch
 */
export declare const ifNoneMatch = "http://hl7.org/fhir/ifNoneMatch";
/**
 * _notConsumed
 *
 * (Modified) NutritionIntake.consumedItem.notConsumed
 *
 * http://hl7.org/fhir/_notConsumed
 */
export declare const _notConsumed = "http://hl7.org/fhir/_notConsumed";
/**
 * grade
 *
 * SubstanceDefinition.grade: The quality standard, established benchmark, to which substance complies (e.g. USP/NF, Ph. Eur, JP, BP, Company Standard).
 *
 * http://hl7.org/fhir/grade
 */
export declare const grade = "http://hl7.org/fhir/grade";
/**
 * OralDietSchedule
 *
 * NutritionOrderOralDietComponent.OralDietSchedule: Schedule information for an oral diet.
 *
 * http://hl7.org/fhir/OralDietSchedule
 */
export declare const OralDietSchedule = "http://hl7.org/fhir/OralDietSchedule";
/**
 * _diagnosis
 *
 * (Modified) Encounter.diagnosis
 *
 * http://hl7.org/fhir/_diagnosis
 */
export declare const _diagnosis = "http://hl7.org/fhir/_diagnosis";
/**
 * _channelType
 *
 * (Modified) Subscription.channelType
 *
 * http://hl7.org/fhir/_channelType
 */
export declare const _channelType = "http://hl7.org/fhir/_channelType";
/**
 * _encounter
 *
 * (Modified) ServiceRequest.encounter
 *
 * http://hl7.org/fhir/_encounter
 */
export declare const _encounter = "http://hl7.org/fhir/_encounter";
/**
 * SubstancePolymerMonomerSetStartingMaterialComponent
 *
 * SubstancePolymerMonomerSetComponent.SubstancePolymerMonomerSetStartingMaterialComponent: The starting materials - monomer(s) used in the synthesis of the polymer.
 *
 * http://hl7.org/fhir/SubstancePolymerMonomerSetStartingMaterialComponent
 */
export declare const SubstancePolymerMonomerSetStartingMaterialComponent = "http://hl7.org/fhir/SubstancePolymerMonomerSetStartingMaterialComponent";
/**
 * statisticType
 *
 * Evidence.statistic.statisticType: Type of statistic, e.g., relative risk.
 *
 * http://hl7.org/fhir/statisticType
 */
export declare const statisticType = "http://hl7.org/fhir/statisticType";
/**
 * _webLocation
 *
 * (Modified) Citation.citedArtifact.webLocation
 *
 * http://hl7.org/fhir/_webLocation
 */
export declare const _webLocation = "http://hl7.org/fhir/_webLocation";
/**
 * SubstanceSourceMaterialOrganismOrganismGeneralComponent
 *
 * SubstanceSourceMaterialOrganismComponent.SubstanceSourceMaterialOrganismOrganismGeneralComponent: 4.9.13.7.1 Kingdom (Conditional).
 *
 * http://hl7.org/fhir/SubstanceSourceMaterialOrganismOrganismGeneralComponent
 */
export declare const SubstanceSourceMaterialOrganismOrganismGeneralComponent = "http://hl7.org/fhir/SubstanceSourceMaterialOrganismOrganismGeneralComponent";
/**
 * textConcentration
 *
 * Ingredient.substance.strength.textConcentration: A textual represention of either the whole of the concentration strength or a part of it - with the rest being in Strength.concentration as a ratio.
 *
 * http://hl7.org/fhir/textConcentration
 */
export declare const textConcentration = "http://hl7.org/fhir/textConcentration";
/**
 * _multipleAnd
 *
 * (Modified) SearchParameter.multipleAnd
 *
 * http://hl7.org/fhir/_multipleAnd
 */
export declare const _multipleAnd = "http://hl7.org/fhir/_multipleAnd";
/**
 * _freeToShare
 *
 * (Modified) ArtifactAssessment.content.component.freeToShare
 *
 * http://hl7.org/fhir/_freeToShare
 */
export declare const _freeToShare = "http://hl7.org/fhir/_freeToShare";
/**
 * _contributionInstance
 *
 * (Modified) Citation.citedArtifact.contributorship.entry.contributionInstance
 *
 * http://hl7.org/fhir/_contributionInstance
 */
export declare const _contributionInstance = "http://hl7.org/fhir/_contributionInstance";
/**
 * MedicationStatementAdherenceComponent
 *
 * MedicationStatementAdherenceComponent: Indicates whether the medication is or is not being consumed or administered.
 *
 * http://hl7.org/fhir/MedicationStatementAdherenceComponent
 */
export declare const MedicationStatementAdherenceComponent = "http://hl7.org/fhir/MedicationStatementAdherenceComponent";
/**
 * _onAdmission
 *
 * (Modified) ExplanationOfBenefit.diagnosis.onAdmission
 *
 * http://hl7.org/fhir/_onAdmission
 */
export declare const _onAdmission = "http://hl7.org/fhir/_onAdmission";
/**
 * output
 *
 * GenomicStudy.analysis.output: Outputs for the analysis event.
 *
 * http://hl7.org/fhir/output
 */
export declare const output = "http://hl7.org/fhir/output";
/**
 * _indication
 *
 * (Modified) RegulatedAuthorization.indication
 *
 * http://hl7.org/fhir/_indication
 */
export declare const _indication = "http://hl7.org/fhir/_indication";
/**
 * DeviceDefinitionChargeItemComponent
 *
 * DeviceDefinitionChargeItemComponent: Billing code or reference associated with the device.
 *
 * http://hl7.org/fhir/DeviceDefinitionChargeItemComponent
 */
export declare const DeviceDefinitionChargeItemComponent = "http://hl7.org/fhir/DeviceDefinitionChargeItemComponent";
/**
 * location
 *
 * InventoryItem.instance.location: The location that the item is associated with.
 *
 * http://hl7.org/fhir/location
 */
export declare const location = "http://hl7.org/fhir/location";
/**
 * generalCost
 *
 * InsurancePlan.plan.generalCost: Overall costs associated with the plan.
 *
 * http://hl7.org/fhir/generalCost
 */
export declare const generalCost = "http://hl7.org/fhir/generalCost";
/**
 * _plannedActivityReference
 *
 * (Modified) CarePlan.activity.plannedActivityReference
 *
 * http://hl7.org/fhir/_plannedActivityReference
 */
export declare const _plannedActivityReference = "http://hl7.org/fhir/_plannedActivityReference";
/**
 * rules
 *
 * ElementDefinition.slicing.rules: Whether additional slices are allowed or not. When the slices are ordered, profile authors can also say that additional slices are only allowed at the end.
 *
 * http://hl7.org/fhir/rules
 */
export declare const rules = "http://hl7.org/fhir/rules";
/**
 * reported
 *
 * Procedure.reported
 *
 * http://hl7.org/fhir/reported
 */
export declare const reported = "http://hl7.org/fhir/reported";
/**
 * maxDosePerDay
 *
 * AdministrableProductDefinition.routeOfAdministration.maxDosePerDay: The maximum dose per day (maximum dose quantity to be administered in any one 24-h period) that can be administered.
 *
 * http://hl7.org/fhir/maxDosePerDay
 */
export declare const maxDosePerDay = "http://hl7.org/fhir/maxDosePerDay";
/**
 * NutritionOrderOralDietTextureComponent
 *
 * NutritionOrderOralDietComponent.NutritionOrderOralDietTextureComponent: Class that describes any texture modifications required for the patient to safely consume various types of solid foods.
 *
 * http://hl7.org/fhir/NutritionOrderOralDietTextureComponent
 */
export declare const NutritionOrderOralDietTextureComponent = "http://hl7.org/fhir/NutritionOrderOralDietTextureComponent";
/**
 * _definitionByTypeAndValue
 *
 * (Modified) EvidenceVariable.characteristic.definitionByCombination.characteristic.definitionByTypeAndValue
 *
 * http://hl7.org/fhir/_definitionByTypeAndValue
 */
export declare const _definitionByTypeAndValue = "http://hl7.org/fhir/_definitionByTypeAndValue";
/**
 * GroupMemberComponent
 *
 * GroupMemberComponent: Identifies the resource instances that are members of the group.
 *
 * http://hl7.org/fhir/GroupMemberComponent
 */
export declare const GroupMemberComponent = "http://hl7.org/fhir/GroupMemberComponent";
/**
 * _verificationType
 *
 * (Modified) Consent.verification.verificationType
 *
 * http://hl7.org/fhir/_verificationType
 */
export declare const _verificationType = "http://hl7.org/fhir/_verificationType";
/**
 * _supportingInformation
 *
 * (Modified) MedicationAdministration.supportingInformation
 *
 * http://hl7.org/fhir/_supportingInformation
 */
export declare const _supportingInformation = "http://hl7.org/fhir/_supportingInformation";
/**
 * kingdom
 *
 * SubstanceSourceMaterial.organism.organismGeneral.kingdom: The kingdom of an organism shall be specified.
 *
 * http://hl7.org/fhir/kingdom
 */
export declare const kingdom = "http://hl7.org/fhir/kingdom";
/**
 * sourceMaterialClass
 *
 * SubstanceSourceMaterial.sourceMaterialClass: General high level classification of the source material specific to the origin of the material.
 *
 * http://hl7.org/fhir/sourceMaterialClass
 */
export declare const sourceMaterialClass = "http://hl7.org/fhir/sourceMaterialClass";
/**
 * _polymer
 *
 * (Modified) SubstanceDefinition.polymer
 *
 * http://hl7.org/fhir/_polymer
 */
export declare const _polymer = "http://hl7.org/fhir/_polymer";
/**
 * insurance
 *
 * Transport.insurance: Insurance plans, coverage extensions, pre-authorizations and/or pre-determinations that may be relevant to the Transport.
 *
 * http://hl7.org/fhir/insurance
 */
export declare const insurance = "http://hl7.org/fhir/insurance";
/**
 * _handling
 *
 * (Modified) SpecimenDefinition.typeTested.handling
 *
 * http://hl7.org/fhir/_handling
 */
export declare const _handling = "http://hl7.org/fhir/_handling";
/**
 * supportingInfo
 *
 * AdverseEvent.supportingInfo: Supporting information relevant to the event.
 *
 * http://hl7.org/fhir/supportingInfo
 */
export declare const supportingInfo = "http://hl7.org/fhir/supportingInfo";
/**
 * lifecycleStatus
 *
 * Goal.lifecycleStatus: The state of the goal throughout its lifecycle.
 *
 * http://hl7.org/fhir/lifecycleStatus
 */
export declare const lifecycleStatus = "http://hl7.org/fhir/lifecycleStatus";
/**
 * _symptomConditionEffect
 *
 * (Modified) ClinicalUseDefinition.undesirableEffect.symptomConditionEffect
 *
 * http://hl7.org/fhir/_symptomConditionEffect
 */
export declare const _symptomConditionEffect = "http://hl7.org/fhir/_symptomConditionEffect";
/**
 * _fraction
 *
 * (Modified) SubstanceSourceMaterial.fractionDescription.fraction
 *
 * http://hl7.org/fhir/_fraction
 */
export declare const _fraction = "http://hl7.org/fhir/_fraction";
/**
 * language
 *
 * RelatedPerson.communication.language: The ISO-639-1 alpha 2 code in lower case for the language, optionally followed by a hyphen and the ISO-3166-1 alpha 2 code for the region in upper case; e.g. "en" for English, or "en-US" for American English versus "en-AU" for Australian English.
 *
 * http://hl7.org/fhir/language
 */
export declare const language = "http://hl7.org/fhir/language";
/**
 * combining
 *
 * Permission.combining: Defines a procedure for arriving at an access decision given the set of rules.
 *
 * http://hl7.org/fhir/combining
 */
export declare const combining = "http://hl7.org/fhir/combining";
/**
 * country
 *
 * Address.country: Country - a nation as commonly understood or generally accepted.
 *
 * http://hl7.org/fhir/country
 */
export declare const country = "http://hl7.org/fhir/country";
/**
 * isExample
 *
 * ImplementationGuide.manifest.resource.isExample: If true, indicates the resource is an example instance.
 *
 * http://hl7.org/fhir/isExample
 */
export declare const isExample = "http://hl7.org/fhir/isExample";
/**
 * _readHistory
 *
 * (Modified) CapabilityStatement.rest.resource.readHistory
 *
 * http://hl7.org/fhir/_readHistory
 */
export declare const _readHistory = "http://hl7.org/fhir/_readHistory";
/**
 * BundleLinkComponent
 *
 * BundleLinkComponent: A series of links that provide context to this bundle.
 *
 * http://hl7.org/fhir/BundleLinkComponent
 */
export declare const BundleLinkComponent = "http://hl7.org/fhir/BundleLinkComponent";
/**
 * currentLocation
 *
 * Transport.currentLocation: The current location for the entity to be transported.
 *
 * http://hl7.org/fhir/currentLocation
 */
export declare const currentLocation = "http://hl7.org/fhir/currentLocation";
/**
 * official
 *
 * SubstanceDefinition.name.official: Details of the official nature of this name.
 *
 * http://hl7.org/fhir/official
 */
export declare const official = "http://hl7.org/fhir/official";
/**
 * _EncounterHistory
 *
 * (Modified) EncounterHistory
 *
 * http://hl7.org/fhir/_EncounterHistory
 */
export declare const _EncounterHistory = "http://hl7.org/fhir/_EncounterHistory";
/**
 * EvidenceVariableCategoryComponent
 *
 * EvidenceVariableCategoryComponent: A grouping for ordinal or polychotomous variables.
 *
 * http://hl7.org/fhir/EvidenceVariableCategoryComponent
 */
export declare const EvidenceVariableCategoryComponent = "http://hl7.org/fhir/EvidenceVariableCategoryComponent";
/**
 * _administeredBy
 *
 * (Modified) InsurancePlan.administeredBy
 *
 * http://hl7.org/fhir/_administeredBy
 */
export declare const _administeredBy = "http://hl7.org/fhir/_administeredBy";
/**
 * _ProductShelfLife
 *
 * (Modified) ProductShelfLife
 *
 * http://hl7.org/fhir/_ProductShelfLife
 */
export declare const _ProductShelfLife = "http://hl7.org/fhir/_ProductShelfLife";
/**
 * SubstanceDefinitionMolecularWeightComponent
 *
 * SubstanceDefinitionMolecularWeightComponent: The average mass of a molecule of a compound compared to 1/12 the mass of carbon 12 and calculated as the sum of the atomic weights of the constituent atoms.
 *
 * http://hl7.org/fhir/SubstanceDefinitionMolecularWeightComponent
 */
export declare const SubstanceDefinitionMolecularWeightComponent = "http://hl7.org/fhir/SubstanceDefinitionMolecularWeightComponent";
/**
 * affectsState
 *
 * OperationDefinition.affectsState: Whether the operation affects state. Side effects such as producing audit trail entries do not count as 'affecting  state'.
 *
 * http://hl7.org/fhir/affectsState
 */
export declare const affectsState = "http://hl7.org/fhir/affectsState";
/**
 * notificationShape
 *
 * SubscriptionTopic.notificationShape: List of properties to describe the shape (e.g., resources) included in notifications from this Subscription Topic.
 *
 * http://hl7.org/fhir/notificationShape
 */
export declare const notificationShape = "http://hl7.org/fhir/notificationShape";
/**
 * descriptionSummary
 *
 * ResearchStudy.descriptionSummary: A brief text for explaining the study.
 *
 * http://hl7.org/fhir/descriptionSummary
 */
export declare const descriptionSummary = "http://hl7.org/fhir/descriptionSummary";
/**
 * _answerValueSet
 *
 * (Modified) Questionnaire.item.item.answerValueSet
 *
 * http://hl7.org/fhir/_answerValueSet
 */
export declare const _answerValueSet = "http://hl7.org/fhir/_answerValueSet";
/**
 * PractitionerRole
 *
 * A specific set of Roles/Locations/specialties/services that a practitioner may perform, or has performed at an organization during a period of time.
 *
 * http://hl7.org/fhir/PractitionerRole
 */
export declare const PractitionerRole = "http://hl7.org/fhir/PractitionerRole";
/**
 * _rationale
 *
 * (Modified) RiskAssessment.prediction.rationale
 *
 * http://hl7.org/fhir/_rationale
 */
export declare const _rationale = "http://hl7.org/fhir/_rationale";
/**
 * _ChargeItem
 *
 * (Modified) ChargeItem
 *
 * http://hl7.org/fhir/_ChargeItem
 */
export declare const _ChargeItem = "http://hl7.org/fhir/_ChargeItem";
/**
 * _offer
 *
 * (Modified) Contract.term.group.offer
 *
 * http://hl7.org/fhir/_offer
 */
export declare const _offer = "http://hl7.org/fhir/_offer";
/**
 * OperationDefinitionParameterReferencedFromComponent
 *
 * OperationDefinitionParameterComponent.OperationDefinitionParameterReferencedFromComponent: Identifies other resource parameters within the operation invocation that are expected to resolve to this resource.
 *
 * http://hl7.org/fhir/OperationDefinitionParameterReferencedFromComponent
 */
export declare const OperationDefinitionParameterReferencedFromComponent = "http://hl7.org/fhir/OperationDefinitionParameterReferencedFromComponent";
/**
 * singleUse
 *
 * SpecimenDefinition.typeTested.singleUse: Specimen can be used by only one test or panel if the value is "true".
 *
 * http://hl7.org/fhir/singleUse
 */
export declare const singleUse = "http://hl7.org/fhir/singleUse";
/**
 * _exclude
 *
 * (Modified) ValueSet.compose.exclude
 *
 * http://hl7.org/fhir/_exclude
 */
export declare const _exclude = "http://hl7.org/fhir/_exclude";
/**
 * fhirVersion
 *
 * ImplementationGuide.fhirVersion: The version(s) of the FHIR specification that this ImplementationGuide targets - e.g. describes how to use. The value of this element is the formal version of the specification, without the revision number, e.g. [publication].[major].[minor], which is 4.6.0. for this version.
 *
 * http://hl7.org/fhir/fhirVersion
 */
export declare const fhirVersion = "http://hl7.org/fhir/fhirVersion";
/**
 * _nucleicAcid
 *
 * (Modified) SubstanceDefinition.nucleicAcid
 *
 * http://hl7.org/fhir/_nucleicAcid
 */
export declare const _nucleicAcid = "http://hl7.org/fhir/_nucleicAcid";
/**
 * CodeableConcept
 *
 * A concept that may be defined by a formal reference to a terminology or ontology or may be provided by text.
 *
 * http://hl7.org/fhir/CodeableConcept
 */
export declare const CodeableConcept = "http://hl7.org/fhir/CodeableConcept";
/**
 * _Claim
 *
 * (Modified) Claim
 *
 * http://hl7.org/fhir/_Claim
 */
export declare const _Claim = "http://hl7.org/fhir/_Claim";
/**
 * _site
 *
 * (Modified) ExplanationOfBenefit.item.bodySite.site
 *
 * http://hl7.org/fhir/_site
 */
export declare const _site = "http://hl7.org/fhir/_site";
/**
 * targetScope
 *
 * ConceptMap.targetScope
 *
 * http://hl7.org/fhir/targetScope
 */
export declare const targetScope = "http://hl7.org/fhir/targetScope";
/**
 * _monthInterval
 *
 * (Modified) Appointment.recurrenceTemplate.monthlyTemplate.monthInterval
 *
 * http://hl7.org/fhir/_monthInterval
 */
export declare const _monthInterval = "http://hl7.org/fhir/_monthInterval";
/**
 * _monitoringProgram
 *
 * (Modified) MedicationKnowledge.monitoringProgram
 *
 * http://hl7.org/fhir/_monitoringProgram
 */
export declare const _monitoringProgram = "http://hl7.org/fhir/_monitoringProgram";
/**
 * mustHaveValue
 *
 * ElementDefinition.mustHaveValue: Specifies for a primitive data type that the value of the data type cannot be replaced by an extension.
 *
 * http://hl7.org/fhir/mustHaveValue
 */
export declare const mustHaveValue = "http://hl7.org/fhir/mustHaveValue";
/**
 * _interpreter
 *
 * (Modified) GenomicStudy.interpreter
 *
 * http://hl7.org/fhir/_interpreter
 */
export declare const _interpreter = "http://hl7.org/fhir/_interpreter";
/**
 * SubscriptionStatus
 *
 * The SubscriptionStatus resource describes the state of a Subscription during notifications. It is not persisted.
 *
 * http://hl7.org/fhir/SubscriptionStatus
 */
export declare const SubscriptionStatus = "http://hl7.org/fhir/SubscriptionStatus";
/**
 * _productOrServiceEnd
 *
 * (Modified) ClaimResponse.addItem.detail.productOrServiceEnd
 *
 * http://hl7.org/fhir/_productOrServiceEnd
 */
export declare const _productOrServiceEnd = "http://hl7.org/fhir/_productOrServiceEnd";
/**
 * doseQuantity
 *
 * Immunization.doseQuantity: The quantity of vaccine product that was administered.
 *
 * http://hl7.org/fhir/doseQuantity
 */
export declare const doseQuantity = "http://hl7.org/fhir/doseQuantity";
/**
 * _prism
 *
 * (Modified) VisionPrescription.lensSpecification.prism
 *
 * http://hl7.org/fhir/_prism
 */
export declare const _prism = "http://hl7.org/fhir/_prism";
/**
 * highNumerator
 *
 * RatioRange.highNumerator: The value of the high limit numerator.
 *
 * http://hl7.org/fhir/highNumerator
 */
export declare const highNumerator = "http://hl7.org/fhir/highNumerator";
/**
 * contentDefinition
 *
 * Contract.contentDefinition: Precusory content developed with a focus and intent of supporting the formation a Contract instance, which may be associated with and transformable into a Contract.
 *
 * http://hl7.org/fhir/contentDefinition
 */
export declare const contentDefinition = "http://hl7.org/fhir/contentDefinition";
/**
 * due
 *
 * PlanDefinition.goal.target.due: Indicates the timeframe after the start of the goal in which the goal should be met.
 *
 * http://hl7.org/fhir/due
 */
export declare const due = "http://hl7.org/fhir/due";
/**
 * structureProfile
 *
 * ExampleScenario.instance.structureProfile
 *
 * http://hl7.org/fhir/structureProfile
 */
export declare const structureProfile = "http://hl7.org/fhir/structureProfile";
/**
 * _acceptLanguage
 *
 * (Modified) CapabilityStatement.acceptLanguage
 *
 * http://hl7.org/fhir/_acceptLanguage
 */
export declare const _acceptLanguage = "http://hl7.org/fhir/_acceptLanguage";
/**
 * _RegulatedAuthorization
 *
 * (Modified) RegulatedAuthorization
 *
 * http://hl7.org/fhir/_RegulatedAuthorization
 */
export declare const _RegulatedAuthorization = "http://hl7.org/fhir/_RegulatedAuthorization";
/**
 * authorType
 *
 * SubstanceSourceMaterial.organism.author.authorType: The type of author of an organism species shall be specified. The parenthetical author of an organism species refers to the first author who published the plant/animal name (of any rank). The primary author of an organism species refers to the first author(s), who validly published the plant/animal name.
 *
 * http://hl7.org/fhir/authorType
 */
export declare const authorType = "http://hl7.org/fhir/authorType";
/**
 * paymentIssuer
 *
 * PaymentReconciliation.paymentIssuer: The party who generated the payment.
 *
 * http://hl7.org/fhir/paymentIssuer
 */
export declare const paymentIssuer = "http://hl7.org/fhir/paymentIssuer";
/**
 * clinicalTrial
 *
 * MedicinalProductDefinition.clinicalTrial: Clinical trials or studies that this product is involved in.
 *
 * http://hl7.org/fhir/clinicalTrial
 */
export declare const clinicalTrial = "http://hl7.org/fhir/clinicalTrial";
/**
 * _parentSubstanceName
 *
 * (Modified) SubstanceSourceMaterial.parentSubstanceName
 *
 * http://hl7.org/fhir/_parentSubstanceName
 */
export declare const _parentSubstanceName = "http://hl7.org/fhir/_parentSubstanceName";
/**
 * _high
 *
 * (Modified) SubstancePolymer.repeat.repeatUnit.degreeOfPolymerisation.high
 *
 * http://hl7.org/fhir/_high
 */
export declare const _high = "http://hl7.org/fhir/_high";
/**
 * actorId
 *
 * PlanDefinition.action.action.participant.actorId: A reference to the id element of the actor who will participate in this action.
 *
 * http://hl7.org/fhir/actorId
 */
export declare const actorId = "http://hl7.org/fhir/actorId";
/**
 * _document
 *
 * (Modified) SubstanceDefinition.structure.representation.document
 *
 * http://hl7.org/fhir/_document
 */
export declare const _document = "http://hl7.org/fhir/_document";
/**
 * _marketPeriod
 *
 * (Modified) DeviceDefinition.packaging.packaging.udiDeviceIdentifier.marketDistribution.marketPeriod
 *
 * http://hl7.org/fhir/_marketPeriod
 */
export declare const _marketPeriod = "http://hl7.org/fhir/_marketPeriod";
/**
 * _denominator
 *
 * (Modified) RatioRange.denominator
 *
 * http://hl7.org/fhir/_denominator
 */
export declare const _denominator = "http://hl7.org/fhir/_denominator";
/**
 * accessionIdentifier
 *
 * Specimen.accessionIdentifier: The identifier assigned by the lab when accessioning specimen(s). This is not necessarily the same as the specimen identifier, depending on local lab procedures.
 *
 * http://hl7.org/fhir/accessionIdentifier
 */
export declare const accessionIdentifier = "http://hl7.org/fhir/accessionIdentifier";
/**
 * VerificationResultPrimarySourceComponent
 *
 * VerificationResultPrimarySourceComponent: Information about the primary source(s) involved in validation.
 *
 * http://hl7.org/fhir/VerificationResultPrimarySourceComponent
 */
export declare const VerificationResultPrimarySourceComponent = "http://hl7.org/fhir/VerificationResultPrimarySourceComponent";
/**
 * authored
 *
 * QuestionnaireResponse.authored: The date and/or time that this questionnaire response was last modified by the user - e.g. changing answers or revising status.
 *
 * http://hl7.org/fhir/authored
 */
export declare const authored = "http://hl7.org/fhir/authored";
/**
 * serialNumber
 *
 * Device.serialNumber: The serial number assigned by the organization when the device was manufactured.
 *
 * http://hl7.org/fhir/serialNumber
 */
export declare const serialNumber = "http://hl7.org/fhir/serialNumber";
/**
 * Consent
 *
 * A record of a healthcare consumer’s  choices  or choices made on their behalf by a third party, which permits or denies identified recipient(s) or recipient role(s) to perform one or more actions within a given policy context, for specific purposes and periods of time.
 *
 * http://hl7.org/fhir/Consent
 */
export declare const Consent = "http://hl7.org/fhir/Consent";
/**
 * _resourceType
 *
 * (Modified) Subscription.filterBy.resourceType
 *
 * http://hl7.org/fhir/_resourceType
 */
export declare const _resourceType = "http://hl7.org/fhir/_resourceType";
/**
 * outcomeMeasure
 *
 * ResearchStudy.outcomeMeasure: An "outcome measure", "endpoint", "effect measure" or "measure of effect" is a specific measurement or observation used to quantify the effect of experimental variables on the participants in a study, or for observational studies, to describe patterns of diseases or traits or associations with exposures, risk factors or treatment.
 *
 * http://hl7.org/fhir/outcomeMeasure
 */
export declare const outcomeMeasure = "http://hl7.org/fhir/outcomeMeasure";
/**
 * purpose
 *
 * Requirements.purpose: Explanation of why this Requirements is needed and why it has been designed as it has.
 *
 * http://hl7.org/fhir/purpose
 */
export declare const purpose = "http://hl7.org/fhir/purpose";
/**
 * DiagnosticReportSupportingInfoComponent
 *
 * DiagnosticReportSupportingInfoComponent: This backbone element contains supporting information that was used in the creation of the report not included in the results already included in the report.
 *
 * http://hl7.org/fhir/DiagnosticReportSupportingInfoComponent
 */
export declare const DiagnosticReportSupportingInfoComponent = "http://hl7.org/fhir/DiagnosticReportSupportingInfoComponent";
/**
 * Citation
 *
 * The Citation Resource enables reference to any knowledge artifact for purposes of identification and attribution. The Citation Resource supports existing reference structures and developing publication practices such as versioning, expressing complex contributorship roles, and referencing computable resources.
 *
 * http://hl7.org/fhir/Citation
 */
export declare const Citation = "http://hl7.org/fhir/Citation";
/**
 * _serviced
 *
 * (Modified) Invoice.lineItem.serviced
 *
 * http://hl7.org/fhir/_serviced
 */
export declare const _serviced = "http://hl7.org/fhir/_serviced";
/**
 * performer
 *
 * Procedure.performer: Indicates who or what performed the procedure and how they were involved.
 *
 * http://hl7.org/fhir/performer
 */
export declare const performer = "http://hl7.org/fhir/performer";
/**
 * _stratifier
 *
 * (Modified) MeasureReport.group.stratifier
 *
 * http://hl7.org/fhir/_stratifier
 */
export declare const _stratifier = "http://hl7.org/fhir/_stratifier";
/**
 * InvoiceParticipantComponent
 *
 * InvoiceParticipantComponent: Indicates who or what performed or participated in the charged service.
 *
 * http://hl7.org/fhir/InvoiceParticipantComponent
 */
export declare const InvoiceParticipantComponent = "http://hl7.org/fhir/InvoiceParticipantComponent";
/**
 * requiredBehavior
 *
 * PlanDefinition.action.requiredBehavior: Defines the required behavior for the action.
 *
 * http://hl7.org/fhir/requiredBehavior
 */
export declare const requiredBehavior = "http://hl7.org/fhir/requiredBehavior";
/**
 * _oralDiet
 *
 * (Modified) NutritionOrder.oralDiet
 *
 * http://hl7.org/fhir/_oralDiet
 */
export declare const _oralDiet = "http://hl7.org/fhir/_oralDiet";
/**
 * monday
 *
 * Appointment.recurrenceTemplate.weeklyTemplate.monday: Indicates that recurring appointments should occur on Mondays.
 *
 * http://hl7.org/fhir/monday
 */
export declare const monday = "http://hl7.org/fhir/monday";
/**
 * MedicationRequestDispenseRequestComponent
 *
 * MedicationRequestDispenseRequestComponent: Indicates the specific details for the dispense or medication supply part of a medication request (also known as a Medication Prescription or Medication Order).  Note that this information is not always sent with the order.  There may be in some settings (e.g. hospitals) institutional or system support for completing the dispense details in the pharmacy department.
 *
 * http://hl7.org/fhir/MedicationRequestDispenseRequestComponent
 */
export declare const MedicationRequestDispenseRequestComponent = "http://hl7.org/fhir/MedicationRequestDispenseRequestComponent";
/**
 * _subJurisdiction
 *
 * (Modified) DeviceDefinition.packaging.packaging.udiDeviceIdentifier.marketDistribution.subJurisdiction
 *
 * http://hl7.org/fhir/_subJurisdiction
 */
export declare const _subJurisdiction = "http://hl7.org/fhir/_subJurisdiction";
/**
 * _interactant
 *
 * (Modified) ClinicalUseDefinition.interaction.interactant
 *
 * http://hl7.org/fhir/_interactant
 */
export declare const _interactant = "http://hl7.org/fhir/_interactant";
/**
 * _admitSource
 *
 * (Modified) Encounter.admission.admitSource
 *
 * http://hl7.org/fhir/_admitSource
 */
export declare const _admitSource = "http://hl7.org/fhir/_admitSource";
/**
 * TargetElement
 *
 * ConceptMapGroupComponent.SourceElement.TargetElement: A concept from the target value set that this concept maps to.
 *
 * http://hl7.org/fhir/TargetElement
 */
export declare const TargetElement = "http://hl7.org/fhir/TargetElement";
/**
 * _given
 *
 * (Modified) HumanName.given
 *
 * http://hl7.org/fhir/_given
 */
export declare const _given = "http://hl7.org/fhir/_given";
/**
 * _recorder
 *
 * (Modified) Procedure.recorder
 *
 * http://hl7.org/fhir/_recorder
 */
export declare const _recorder = "http://hl7.org/fhir/_recorder";
/**
 * hasPart
 *
 * DeviceDefinition.hasPart: A device that is part (for example a component) of the present device.
 *
 * http://hl7.org/fhir/hasPart
 */
export declare const hasPart = "http://hl7.org/fhir/hasPart";
/**
 * _cancellationDate
 *
 * (Modified) Appointment.cancellationDate
 *
 * http://hl7.org/fhir/_cancellationDate
 */
export declare const _cancellationDate = "http://hl7.org/fhir/_cancellationDate";
/**
 * supplements
 *
 * CodeSystem.supplements: The canonical URL of the code system that this code system supplement is adding designations and properties to.
 *
 * http://hl7.org/fhir/supplements
 */
export declare const supplements = "http://hl7.org/fhir/supplements";
/**
 * constraint
 *
 * SearchParameter.constraint: FHIRPath expression that defines/sets a complex constraint for when this SearchParameter is applicable.
 *
 * http://hl7.org/fhir/constraint
 */
export declare const constraint = "http://hl7.org/fhir/constraint";
/**
 * total
 *
 * ValueSet.expansion.total: The total number of concepts in the expansion. If the number of concept nodes in this resource is less than the stated number, then the server can return more using the offset parameter.
 *
 * http://hl7.org/fhir/total
 */
export declare const total = "http://hl7.org/fhir/total";
/**
 * outcome
 *
 * Goal.outcome: Identifies the change (or lack of change) at the point when the status of the goal is assessed.
 *
 * http://hl7.org/fhir/outcome
 */
export declare const outcome = "http://hl7.org/fhir/outcome";
/**
 * sampleSize
 *
 * Evidence.statistic.sampleSize: Number of samples in the statistic.
 *
 * http://hl7.org/fhir/sampleSize
 */
export declare const sampleSize = "http://hl7.org/fhir/sampleSize";
/**
 * ContributorshipSummary
 *
 * CitationCitedArtifactComponent.CitationCitedArtifactContributorshipComponent.ContributorshipSummary: Used to record a display of the author/contributor list without separate data element for each list member.
 *
 * http://hl7.org/fhir/ContributorshipSummary
 */
export declare const ContributorshipSummary = "http://hl7.org/fhir/ContributorshipSummary";
/**
 * PrimitiveType
 *
 * The base type for all re-useable types defined that have a simple property.
 *
 * http://hl7.org/fhir/PrimitiveType
 */
export declare const PrimitiveType = "http://hl7.org/fhir/PrimitiveType";
/**
 * caloricDensity
 *
 * NutritionOrder.enteralFormula.caloricDensity: The amount of energy (calories) that the formula should provide per specified volume, typically per mL or fluid oz.  For example, an infant may require a formula that provides 24 calories per fluid ounce or an adult may require an enteral formula that provides 1.5 calorie/mL.
 *
 * http://hl7.org/fhir/caloricDensity
 */
export declare const caloricDensity = "http://hl7.org/fhir/caloricDensity";
/**
 * MedicationKnowledgeStorageGuidelineEnvironmentalSettingComponent
 *
 * MedicationKnowledgeStorageGuidelineComponent.MedicationKnowledgeStorageGuidelineEnvironmentalSettingComponent: Describes a setting/value on the environment for the adequate storage of the medication and other substances.  Environment settings may involve temperature, humidity, or exposure to light.
 *
 * http://hl7.org/fhir/MedicationKnowledgeStorageGuidelineEnvironmentalSettingComponent
 */
export declare const MedicationKnowledgeStorageGuidelineEnvironmentalSettingComponent = "http://hl7.org/fhir/MedicationKnowledgeStorageGuidelineEnvironmentalSettingComponent";
/**
 * _clinicalUseIssue
 *
 * (Modified) MedicationKnowledge.clinicalUseIssue
 *
 * http://hl7.org/fhir/_clinicalUseIssue
 */
export declare const _clinicalUseIssue = "http://hl7.org/fhir/_clinicalUseIssue";
/**
 * LinkageItemComponent
 *
 * LinkageItemComponent: Identifies which record considered as the reference to the same real-world occurrence as well as how the items should be evaluated within the collection of linked items.
 *
 * http://hl7.org/fhir/LinkageItemComponent
 */
export declare const LinkageItemComponent = "http://hl7.org/fhir/LinkageItemComponent";
/**
 * AdministrableProductDefinitionRouteOfAdministrationComponent
 *
 * AdministrableProductDefinitionRouteOfAdministrationComponent: The path by which the product is taken into or makes contact with the body. In some regions this is referred to as the licenced or approved route. RouteOfAdministration cannot be used when the 'formOf' product already uses MedicinalProductDefinition.route (and vice versa).
 *
 * http://hl7.org/fhir/AdministrableProductDefinitionRouteOfAdministrationComponent
 */
export declare const AdministrableProductDefinitionRouteOfAdministrationComponent = "http://hl7.org/fhir/AdministrableProductDefinitionRouteOfAdministrationComponent";
/**
 * _conditionalUpdate
 *
 * (Modified) CapabilityStatement.rest.resource.conditionalUpdate
 *
 * http://hl7.org/fhir/_conditionalUpdate
 */
export declare const _conditionalUpdate = "http://hl7.org/fhir/_conditionalUpdate";
/**
 * _publisher
 *
 * (Modified) ImplementationGuide.publisher
 *
 * http://hl7.org/fhir/_publisher
 */
export declare const _publisher = "http://hl7.org/fhir/_publisher";
/**
 * MolecularSequenceRelativeStartingSequenceComponent
 *
 * MolecularSequenceRelativeComponent.MolecularSequenceRelativeStartingSequenceComponent: A sequence that is used as a starting sequence to describe variants that are present in a sequence analyzed.
 *
 * http://hl7.org/fhir/MolecularSequenceRelativeStartingSequenceComponent
 */
export declare const MolecularSequenceRelativeStartingSequenceComponent = "http://hl7.org/fhir/MolecularSequenceRelativeStartingSequenceComponent";
/**
 * _validator
 *
 * (Modified) VerificationResult.validator
 *
 * http://hl7.org/fhir/_validator
 */
export declare const _validator = "http://hl7.org/fhir/_validator";
/**
 * _inactive
 *
 * (Modified) ValueSet.expansion.contains.contains.inactive
 *
 * http://hl7.org/fhir/_inactive
 */
export declare const _inactive = "http://hl7.org/fhir/_inactive";
/**
 * AppointmentResponse
 *
 * A reply to an appointment request for a patient and/or practitioner(s), such as a confirmation or rejection.
 *
 * http://hl7.org/fhir/AppointmentResponse
 */
export declare const AppointmentResponse = "http://hl7.org/fhir/AppointmentResponse";
/**
 * _molecularFormula
 *
 * (Modified) SubstanceDefinition.structure.molecularFormula
 *
 * http://hl7.org/fhir/_molecularFormula
 */
export declare const _molecularFormula = "http://hl7.org/fhir/_molecularFormula";
/**
 * payload
 *
 * Endpoint.payload: The set of payloads that are provided/available at this endpoint.
 *
 * http://hl7.org/fhir/payload
 */
export declare const payload = "http://hl7.org/fhir/payload";
/**
 * subSite
 *
 * ExplanationOfBenefit.addItem.bodySite.subSite: A region or surface of the bodySite, e.g. limb region or tooth surface(s).
 *
 * http://hl7.org/fhir/subSite
 */
export declare const subSite = "http://hl7.org/fhir/subSite";
/**
 * _sort
 *
 * (Modified) DataRequirement.sort
 *
 * http://hl7.org/fhir/_sort
 */
export declare const _sort = "http://hl7.org/fhir/_sort";
/**
 * TestScriptOriginComponent
 *
 * TestScriptOriginComponent: An abstract server used in operations within this test script in the origin element.
 *
 * http://hl7.org/fhir/TestScriptOriginComponent
 */
export declare const TestScriptOriginComponent = "http://hl7.org/fhir/TestScriptOriginComponent";
/**
 * _allergyIntolerance
 *
 * (Modified) NutritionOrder.allergyIntolerance
 *
 * http://hl7.org/fhir/_allergyIntolerance
 */
export declare const _allergyIntolerance = "http://hl7.org/fhir/_allergyIntolerance";
/**
 * _identityCertificate
 *
 * (Modified) VerificationResult.validator.identityCertificate
 *
 * http://hl7.org/fhir/_identityCertificate
 */
export declare const _identityCertificate = "http://hl7.org/fhir/_identityCertificate";
/**
 * _additional
 *
 * (Modified) ElementDefinition.binding.additional
 *
 * http://hl7.org/fhir/_additional
 */
export declare const _additional = "http://hl7.org/fhir/_additional";
/**
 * _assurance
 *
 * (Modified) Person.link.assurance
 *
 * http://hl7.org/fhir/_assurance
 */
export declare const _assurance = "http://hl7.org/fhir/_assurance";
/**
 * _careManager
 *
 * (Modified) EpisodeOfCare.careManager
 *
 * http://hl7.org/fhir/_careManager
 */
export declare const _careManager = "http://hl7.org/fhir/_careManager";
/**
 * ImageRegion2D
 *
 * ImagingSelectionInstanceComponent.ImageRegion2D: Each imaging selection instance or frame list might includes an image region, specified by a region type and a set of 2D coordinates.
 *        If the parent imagingSelection.instance contains a subset element of type frame, the image region applies to all frames in the subset list.
 *
 * http://hl7.org/fhir/ImageRegion2D
 */
export declare const ImageRegion2D = "http://hl7.org/fhir/ImageRegion2D";
/**
 * forecastReason
 *
 * ImmunizationRecommendation.recommendation.forecastReason: The reason for the assigned forecast status.
 *
 * http://hl7.org/fhir/forecastReason
 */
export declare const forecastReason = "http://hl7.org/fhir/forecastReason";
/**
 * supplement
 *
 * NutritionOrder.supplement: Oral nutritional products given in order to add further nutritional value to the patient's diet.
 *
 * http://hl7.org/fhir/supplement
 */
export declare const supplement = "http://hl7.org/fhir/supplement";
/**
 * _nutrient
 *
 * (Modified) NutritionProduct.nutrient
 *
 * http://hl7.org/fhir/_nutrient
 */
export declare const _nutrient = "http://hl7.org/fhir/_nutrient";
/**
 * _sugar
 *
 * (Modified) SubstanceNucleicAcid.subunit.sugar
 *
 * http://hl7.org/fhir/_sugar
 */
export declare const _sugar = "http://hl7.org/fhir/_sugar";
/**
 * entryReference
 *
 * EvidenceReport.section.section.entryReference: A reference to the actual resource from which the narrative in the section is derived.
 *
 * http://hl7.org/fhir/entryReference
 */
export declare const entryReference = "http://hl7.org/fhir/entryReference";
/**
 * _citedMedium
 *
 * (Modified) Citation.citedArtifact.publicationForm.citedMedium
 *
 * http://hl7.org/fhir/_citedMedium
 */
export declare const _citedMedium = "http://hl7.org/fhir/_citedMedium";
/**
 * MeasureSupplementalDataComponent
 *
 * MeasureSupplementalDataComponent: The supplemental data criteria for the measure report, specified as either the name of a valid CQL expression within a referenced library, or a valid FHIR Resource Path.
 *
 * http://hl7.org/fhir/MeasureSupplementalDataComponent
 */
export declare const MeasureSupplementalDataComponent = "http://hl7.org/fhir/MeasureSupplementalDataComponent";
/**
 * input
 *
 * StructureMap.group.input: A name assigned to an instance of data. The instance must be provided when the mapping is invoked.
 *
 * http://hl7.org/fhir/input
 */
export declare const input = "http://hl7.org/fhir/input";
/**
 * ManufacturedItemDefinition
 *
 * The definition and characteristics of a medicinal manufactured item, such as a tablet or capsule, as contained in a packaged medicinal product.
 *
 * http://hl7.org/fhir/ManufacturedItemDefinition
 */
export declare const ManufacturedItemDefinition = "http://hl7.org/fhir/ManufacturedItemDefinition";
/**
 * Prism
 *
 * VisionPrescriptionLensSpecificationComponent.Prism: Allows for adjustment on two axis.
 *
 * http://hl7.org/fhir/Prism
 */
export declare const Prism = "http://hl7.org/fhir/Prism";
/**
 * GroupCharacteristicComponent
 *
 * GroupCharacteristicComponent: Identifies traits whose presence r absence is shared by members of the group.
 *
 * http://hl7.org/fhir/GroupCharacteristicComponent
 */
export declare const GroupCharacteristicComponent = "http://hl7.org/fhir/GroupCharacteristicComponent";
/**
 * _qualifier
 *
 * (Modified) BodyStructure.excludedStructure.qualifier
 *
 * http://hl7.org/fhir/_qualifier
 */
export declare const _qualifier = "http://hl7.org/fhir/_qualifier";
/**
 * GraphDefinition
 *
 * A formal computable definition of a graph of resources - that is, a coherent set of resources that form a graph by following references. The Graph Definition resource defines a set and makes rules about the set.
 *
 * http://hl7.org/fhir/GraphDefinition
 */
export declare const GraphDefinition = "http://hl7.org/fhir/GraphDefinition";
/**
 * _BiologicallyDerivedProduct
 *
 * (Modified) BiologicallyDerivedProduct
 *
 * http://hl7.org/fhir/_BiologicallyDerivedProduct
 */
export declare const _BiologicallyDerivedProduct = "http://hl7.org/fhir/_BiologicallyDerivedProduct";
/**
 * _Procedure
 *
 * (Modified) Procedure
 *
 * http://hl7.org/fhir/_Procedure
 */
export declare const _Procedure = "http://hl7.org/fhir/_Procedure";
/**
 * _receivedTime
 *
 * (Modified) Specimen.receivedTime
 *
 * http://hl7.org/fhir/_receivedTime
 */
export declare const _receivedTime = "http://hl7.org/fhir/_receivedTime";
/**
 * quantity
 *
 * ArtifactAssessment.content.component.quantity: A quantitative rating of the artifact.
 *
 * http://hl7.org/fhir/quantity
 */
export declare const quantity = "http://hl7.org/fhir/quantity";
/**
 * _linkId
 *
 * (Modified) Contract.term.offer.linkId
 *
 * http://hl7.org/fhir/_linkId
 */
export declare const _linkId = "http://hl7.org/fhir/_linkId";
/**
 * ManufacturedItemDefinitionComponentComponentComponentComponent
 *
 * A component that this component contains or is made from.
 *
 * http://hl7.org/fhir/ManufacturedItemDefinitionComponentComponentComponentComponent
 */
export declare const ManufacturedItemDefinitionComponentComponentComponentComponent = "http://hl7.org/fhir/ManufacturedItemDefinitionComponentComponentComponentComponent";
/**
 * _prescriber
 *
 * (Modified) VisionPrescription.prescriber
 *
 * http://hl7.org/fhir/_prescriber
 */
export declare const _prescriber = "http://hl7.org/fhir/_prescriber";
/**
 * EvidenceReportSubjectCharacteristicComponent
 *
 * EvidenceReportSubjectComponent.EvidenceReportSubjectCharacteristicComponent: Characteristic.
 *
 * http://hl7.org/fhir/EvidenceReportSubjectCharacteristicComponent
 */
export declare const EvidenceReportSubjectCharacteristicComponent = "http://hl7.org/fhir/EvidenceReportSubjectCharacteristicComponent";
/**
 * hasSeverity
 *
 * ConditionDefinition.hasSeverity: Whether Severity is appropriate to collect for this condition.
 *
 * http://hl7.org/fhir/hasSeverity
 */
export declare const hasSeverity = "http://hl7.org/fhir/hasSeverity";
/**
 * _estimate
 *
 * (Modified) Account.balance.estimate
 *
 * http://hl7.org/fhir/_estimate
 */
export declare const _estimate = "http://hl7.org/fhir/_estimate";
/**
 * certainty
 *
 * Evidence.certainty: Assessment of certainty, confidence in the estimates, or quality of the evidence.
 *
 * http://hl7.org/fhir/certainty
 */
export declare const certainty = "http://hl7.org/fhir/certainty";
/**
 * _billingStatus
 *
 * (Modified) Account.billingStatus
 *
 * http://hl7.org/fhir/_billingStatus
 */
export declare const _billingStatus = "http://hl7.org/fhir/_billingStatus";
/**
 * ContactDetail
 *
 * Specifies contact information for a person or organization.
 *
 * http://hl7.org/fhir/ContactDetail
 */
export declare const ContactDetail = "http://hl7.org/fhir/ContactDetail";
/**
 * sessionKey
 *
 * VirtualServiceDetail.sessionKey: Session Key required by the virtual service.
 *
 * http://hl7.org/fhir/sessionKey
 */
export declare const sessionKey = "http://hl7.org/fhir/sessionKey";
/**
 * calibration
 *
 * DeviceMetric.calibration: Describes the calibrations that have been performed or that are required to be performed.
 *
 * http://hl7.org/fhir/calibration
 */
export declare const calibration = "http://hl7.org/fhir/calibration";
/**
 * _literal
 *
 * (Modified) MolecularSequence.literal
 *
 * http://hl7.org/fhir/_literal
 */
export declare const _literal = "http://hl7.org/fhir/_literal";
/**
 * ConditionDefinitionQuestionnaireComponent
 *
 * ConditionDefinitionQuestionnaireComponent: Questionnaire for this condition.
 *
 * http://hl7.org/fhir/ConditionDefinitionQuestionnaireComponent
 */
export declare const ConditionDefinitionQuestionnaireComponent = "http://hl7.org/fhir/ConditionDefinitionQuestionnaireComponent";
/**
 * _dateTime
 *
 * (Modified) NutritionOrder.dateTime
 *
 * http://hl7.org/fhir/_dateTime
 */
export declare const _dateTime = "http://hl7.org/fhir/_dateTime";
/**
 * CoverageEligibilityRequest
 *
 * The CoverageEligibilityRequest provides patient and insurance coverage information to an insurer for them to respond, in the form of an CoverageEligibilityResponse, with information regarding whether the stated coverage is valid and in-force and optionally to provide the insurance details of the policy.
 *
 * http://hl7.org/fhir/CoverageEligibilityRequest
 */
export declare const CoverageEligibilityRequest = "http://hl7.org/fhir/CoverageEligibilityRequest";
/**
 * _repeatUnitAmountType
 *
 * (Modified) SubstancePolymer.repeat.repeatUnitAmountType
 *
 * http://hl7.org/fhir/_repeatUnitAmountType
 */
export declare const _repeatUnitAmountType = "http://hl7.org/fhir/_repeatUnitAmountType";
/**
 * pediatricUseIndicator
 *
 * MedicinalProductDefinition.pediatricUseIndicator: If authorised for use in children, or infants, neonates etc.
 *
 * http://hl7.org/fhir/pediatricUseIndicator
 */
export declare const pediatricUseIndicator = "http://hl7.org/fhir/pediatricUseIndicator";
/**
 * SampledData
 *
 * A series of measurements taken by a device, with upper and lower limits. There may be more than one dimension in the data.
 *
 * http://hl7.org/fhir/SampledData
 */
export declare const SampledData = "http://hl7.org/fhir/SampledData";
/**
 * attester
 *
 * DocumentReference.attester: A participant who has authenticated the accuracy of the document.
 *
 * http://hl7.org/fhir/attester
 */
export declare const attester = "http://hl7.org/fhir/attester";
/**
 * originatingAppointment
 *
 * Appointment.originatingAppointment: The originating appointment in a recurring set of related appointments.
 *
 * http://hl7.org/fhir/originatingAppointment
 */
export declare const originatingAppointment = "http://hl7.org/fhir/originatingAppointment";
/**
 * progress
 *
 * ResearchSubject.progress: The current state (status) of the subject and resons for status change where appropriate.
 *
 * http://hl7.org/fhir/progress
 */
export declare const progress = "http://hl7.org/fhir/progress";
/**
 * _frequencyMax
 *
 * (Modified) Timing.repeat.frequencyMax
 *
 * http://hl7.org/fhir/_frequencyMax
 */
export declare const _frequencyMax = "http://hl7.org/fhir/_frequencyMax";
/**
 * measureScore
 *
 * MeasureReport.group.stratifier.stratum.measureScore
 *
 * http://hl7.org/fhir/measureScore
 */
export declare const measureScore = "http://hl7.org/fhir/measureScore";
/**
 * InsurancePlanCoverageComponent
 *
 * InsurancePlanCoverageComponent: Details about the coverage offered by the insurance product.
 *
 * http://hl7.org/fhir/InsurancePlanCoverageComponent
 */
export declare const InsurancePlanCoverageComponent = "http://hl7.org/fhir/InsurancePlanCoverageComponent";
/**
 * Evidence
 *
 * The Evidence Resource provides a machine-interpretable expression of an evidence concept including the evidence variables (e.g., population, exposures/interventions, comparators, outcomes, measured variables, confounding variables), the statistics, and the certainty of this evidence.
 *
 * http://hl7.org/fhir/Evidence
 */
export declare const Evidence = "http://hl7.org/fhir/Evidence";
/**
 * _operationalStatus
 *
 * (Modified) Location.operationalStatus
 *
 * http://hl7.org/fhir/_operationalStatus
 */
export declare const _operationalStatus = "http://hl7.org/fhir/_operationalStatus";
/**
 * ImagingSelectionPerformerComponent
 *
 * ImagingSelectionPerformerComponent: Selector of the instances – human or machine.
 *
 * http://hl7.org/fhir/ImagingSelectionPerformerComponent
 */
export declare const ImagingSelectionPerformerComponent = "http://hl7.org/fhir/ImagingSelectionPerformerComponent";
/**
 * restriction
 *
 * Transport.restriction: If the Transport.focus is a request resource and the transport is seeking fulfillment (i.e. is asking for the request to be actioned), this element identifies any limitations on what parts of the referenced request should be actioned.
 *
 * http://hl7.org/fhir/restriction
 */
export declare const restriction = "http://hl7.org/fhir/restriction";
/**
 * _issues
 *
 * (Modified) Bundle.issues
 *
 * http://hl7.org/fhir/_issues
 */
export declare const _issues = "http://hl7.org/fhir/_issues";
/**
 * dose
 *
 * MedicationAdministration.dosage.dose: The amount of the medication given at one administration event.   Use this value when the administration is essentially an instantaneous event such as a swallowing a tablet or giving an injection.
 *
 * http://hl7.org/fhir/dose
 */
export declare const dose = "http://hl7.org/fhir/dose";
/**
 * _updateCreate
 *
 * (Modified) CapabilityStatement.rest.resource.updateCreate
 *
 * http://hl7.org/fhir/_updateCreate
 */
export declare const _updateCreate = "http://hl7.org/fhir/_updateCreate";
/**
 * _supportingInfo
 *
 * (Modified) Procedure.supportingInfo
 *
 * http://hl7.org/fhir/_supportingInfo
 */
export declare const _supportingInfo = "http://hl7.org/fhir/_supportingInfo";
/**
 * warningOnly
 *
 * TestScript.test.action.assert.warningOnly: Whether or not the test execution will produce a warning only on error for this assert.
 *
 * http://hl7.org/fhir/warningOnly
 */
export declare const warningOnly = "http://hl7.org/fhir/warningOnly";
/**
 * _coverage
 *
 * (Modified) Account.coverage.coverage
 *
 * http://hl7.org/fhir/_coverage
 */
export declare const _coverage = "http://hl7.org/fhir/_coverage";
/**
 * informationSequence
 *
 * ExplanationOfBenefit.item.informationSequence: Exceptions, special conditions and supporting information applicable for this service or product.
 *
 * http://hl7.org/fhir/informationSequence
 */
export declare const informationSequence = "http://hl7.org/fhir/informationSequence";
/**
 * netContent
 *
 * InventoryItem.netContent: Net content or amount present in the item.
 *
 * http://hl7.org/fhir/netContent
 */
export declare const netContent = "http://hl7.org/fhir/netContent";
/**
 * representation
 *
 * SubstanceDefinition.structure.representation: A depiction of the structure of the substance.
 *
 * http://hl7.org/fhir/representation
 */
export declare const representation = "http://hl7.org/fhir/representation";
/**
 * _typeMode
 *
 * (Modified) StructureMap.group.typeMode
 *
 * http://hl7.org/fhir/_typeMode
 */
export declare const _typeMode = "http://hl7.org/fhir/_typeMode";
/**
 * subProperty
 *
 * ValueSet.expansion.contains.contains.property.subProperty: A subproperty value for this concept.
 *
 * http://hl7.org/fhir/subProperty
 */
export declare const subProperty = "http://hl7.org/fhir/subProperty";
/**
 * _subscription
 *
 * (Modified) SubscriptionStatus.subscription
 *
 * http://hl7.org/fhir/_subscription
 */
export declare const _subscription = "http://hl7.org/fhir/_subscription";
/**
 * Library
 *
 * The Library resource is a general-purpose container for knowledge asset definitions. It can be used to describe and expose existing knowledge assets such as logic libraries and information model descriptions, as well as to describe a collection of knowledge assets.
 *
 * http://hl7.org/fhir/Library
 */
export declare const Library = "http://hl7.org/fhir/Library";
/**
 * DeviceMetricCalibrationComponent
 *
 * DeviceMetricCalibrationComponent: Describes the calibrations that have been performed or that are required to be performed.
 *
 * http://hl7.org/fhir/DeviceMetricCalibrationComponent
 */
export declare const DeviceMetricCalibrationComponent = "http://hl7.org/fhir/DeviceMetricCalibrationComponent";
/**
 * implicated
 *
 * DetectedIssue.implicated: Indicates the resource representing the current activity or proposed activity that is potentially problematic.
 *
 * http://hl7.org/fhir/implicated
 */
export declare const implicated = "http://hl7.org/fhir/implicated";
/**
 * _actualGroup
 *
 * (Modified) ResearchStudy.recruitment.actualGroup
 *
 * http://hl7.org/fhir/_actualGroup
 */
export declare const _actualGroup = "http://hl7.org/fhir/_actualGroup";
/**
 * _SubstanceProtein
 *
 * (Modified) SubstanceProtein
 *
 * http://hl7.org/fhir/_SubstanceProtein
 */
export declare const _SubstanceProtein = "http://hl7.org/fhir/_SubstanceProtein";
/**
 * _capabilities
 *
 * (Modified) TestScript.metadata.capability.capabilities
 *
 * http://hl7.org/fhir/_capabilities
 */
export declare const _capabilities = "http://hl7.org/fhir/_capabilities";
/**
 * _associatedParty
 *
 * (Modified) ResearchStudy.associatedParty
 *
 * http://hl7.org/fhir/_associatedParty
 */
export declare const _associatedParty = "http://hl7.org/fhir/_associatedParty";
/**
 * _supplementalData
 *
 * (Modified) MeasureReport.supplementalData
 *
 * http://hl7.org/fhir/_supplementalData
 */
export declare const _supplementalData = "http://hl7.org/fhir/_supplementalData";
/**
 * _program
 *
 * (Modified) Immunization.programEligibility.program
 *
 * http://hl7.org/fhir/_program
 */
export declare const _program = "http://hl7.org/fhir/_program";
/**
 * offeredIn
 *
 * HealthcareService.offeredIn: When the HealthcareService is representing a specific, schedulable service, the availableIn property can refer to a generic service.
 *
 * http://hl7.org/fhir/offeredIn
 */
export declare const offeredIn = "http://hl7.org/fhir/offeredIn";
/**
 * TerminologyCapabilitiesCodeSystemComponent
 *
 * TerminologyCapabilitiesCodeSystemComponent: Identifies a code system that is supported by the server. If there is a no code system URL, then this declares the general assumptions a client can make about support for any CodeSystem resource.
 *
 * http://hl7.org/fhir/TerminologyCapabilitiesCodeSystemComponent
 */
export declare const TerminologyCapabilitiesCodeSystemComponent = "http://hl7.org/fhir/TerminologyCapabilitiesCodeSystemComponent";
/**
 * multipleBirth
 *
 * Patient.multipleBirth
 *
 * http://hl7.org/fhir/multipleBirth
 */
export declare const multipleBirth = "http://hl7.org/fhir/multipleBirth";
/**
 * _replacedSequence
 *
 * (Modified) MolecularSequence.relative.edit.replacedSequence
 *
 * http://hl7.org/fhir/_replacedSequence
 */
export declare const _replacedSequence = "http://hl7.org/fhir/_replacedSequence";
/**
 * disclaimer
 *
 * Measure.disclaimer: Notices and disclaimers regarding the use of the measure or related to intellectual property (such as code systems) referenced by the measure.
 *
 * http://hl7.org/fhir/disclaimer
 */
export declare const disclaimer = "http://hl7.org/fhir/disclaimer";
/**
 * InsurancePlan
 *
 * Details of a Health Insurance product/plan provided by an organization.
 *
 * http://hl7.org/fhir/InsurancePlan
 */
export declare const InsurancePlan = "http://hl7.org/fhir/InsurancePlan";
/**
 * _installDate
 *
 * (Modified) Device.version.installDate
 *
 * http://hl7.org/fhir/_installDate
 */
export declare const _installDate = "http://hl7.org/fhir/_installDate";
/**
 * _extends
 *
 * (Modified) StructureMap.group.extends
 *
 * http://hl7.org/fhir/_extends
 */
export declare const _extends = "http://hl7.org/fhir/_extends";
/**
 * fundsReserve
 *
 * ExplanationOfBenefit.fundsReserve: A code, used only on a response to a preauthorization, to indicate whether the benefits payable have been reserved and for whom.
 *
 * http://hl7.org/fhir/fundsReserve
 */
export declare const fundsReserve = "http://hl7.org/fhir/fundsReserve";
/**
 * assigner
 *
 * Identifier.assigner: Organization that issued/manages the identifier.
 *
 * http://hl7.org/fhir/assigner
 */
export declare const assigner = "http://hl7.org/fhir/assigner";
/**
 * SpecimenProcessingComponent
 *
 * SpecimenProcessingComponent: Details concerning processing and processing steps for the specimen.
 *
 * http://hl7.org/fhir/SpecimenProcessingComponent
 */
export declare const SpecimenProcessingComponent = "http://hl7.org/fhir/SpecimenProcessingComponent";
/**
 * occurred
 *
 * Provenance.occurred
 *
 * http://hl7.org/fhir/occurred
 */
export declare const occurred = "http://hl7.org/fhir/occurred";
/**
 * _lockedDate
 *
 * (Modified) ValueSet.compose.lockedDate
 *
 * http://hl7.org/fhir/_lockedDate
 */
export declare const _lockedDate = "http://hl7.org/fhir/_lockedDate";
/**
 * GenomicStudyAnalysisPerformerComponent
 *
 * GenomicStudyAnalysisComponent.GenomicStudyAnalysisPerformerComponent: Performer for the analysis event.
 *
 * http://hl7.org/fhir/GenomicStudyAnalysisPerformerComponent
 */
export declare const GenomicStudyAnalysisPerformerComponent = "http://hl7.org/fhir/GenomicStudyAnalysisPerformerComponent";
/**
 * _lowNumerator
 *
 * (Modified) RatioRange.lowNumerator
 *
 * http://hl7.org/fhir/_lowNumerator
 */
export declare const _lowNumerator = "http://hl7.org/fhir/_lowNumerator";
/**
 * _classifier
 *
 * (Modified) ResearchStudy.classifier
 *
 * http://hl7.org/fhir/_classifier
 */
export declare const _classifier = "http://hl7.org/fhir/_classifier";
/**
 * resultsInterpreter
 *
 * DiagnosticReport.resultsInterpreter: The practitioner or organization that is responsible for the report's conclusions and interpretations.
 *
 * http://hl7.org/fhir/resultsInterpreter
 */
export declare const resultsInterpreter = "http://hl7.org/fhir/resultsInterpreter";
/**
 * _limit
 *
 * (Modified) Permission.rule.limit
 *
 * http://hl7.org/fhir/_limit
 */
export declare const _limit = "http://hl7.org/fhir/_limit";
/**
 * _serviceProvider
 *
 * (Modified) Encounter.serviceProvider
 *
 * http://hl7.org/fhir/_serviceProvider
 */
export declare const _serviceProvider = "http://hl7.org/fhir/_serviceProvider";
/**
 * patientInstruction
 *
 * ServiceRequest.patientInstruction: Instructions in terms that are understood by the patient or consumer.
 *
 * http://hl7.org/fhir/patientInstruction
 */
export declare const patientInstruction = "http://hl7.org/fhir/patientInstruction";
/**
 * binding
 *
 * OperationDefinition.parameter.part.binding: Binds to a value set if this parameter is coded (code, Coding, CodeableConcept).
 *
 * http://hl7.org/fhir/binding
 */
export declare const binding = "http://hl7.org/fhir/binding";
/**
 * recurrenceType
 *
 * Appointment.recurrenceTemplate.recurrenceType: How often the appointment series should recur.
 *
 * http://hl7.org/fhir/recurrenceType
 */
export declare const recurrenceType = "http://hl7.org/fhir/recurrenceType";
/**
 * during
 *
 * Availability.notAvailableTime.during: Service not available during this period.
 *
 * http://hl7.org/fhir/during
 */
export declare const during = "http://hl7.org/fhir/during";
/**
 * capability
 *
 * TestScript.metadata.capability: Capabilities that must exist and are assumed to function correctly on the FHIR server being tested.
 *
 * http://hl7.org/fhir/capability
 */
export declare const capability = "http://hl7.org/fhir/capability";
/**
 * Substance
 *
 * A homogeneous material with a definite composition.
 *
 * http://hl7.org/fhir/Substance
 */
export declare const Substance = "http://hl7.org/fhir/Substance";
/**
 * suspectEntity
 *
 * AdverseEvent.suspectEntity: Describes the entity that is suspected to have caused the adverse event.
 *
 * http://hl7.org/fhir/suspectEntity
 */
export declare const suspectEntity = "http://hl7.org/fhir/suspectEntity";
/**
 * QuestionnaireItemInitialComponent
 *
 * QuestionnaireItemComponentItem.QuestionnaireItemInitialComponent: One or more values that should be pre-populated in the answer when initially rendering the questionnaire for user input.
 *
 * http://hl7.org/fhir/QuestionnaireItemInitialComponent
 */
export declare const QuestionnaireItemInitialComponent = "http://hl7.org/fhir/QuestionnaireItemInitialComponent";
/**
 * occurrenceDate
 *
 * AppointmentResponse.occurrenceDate: The original date within a recurring request. This could be used in place of the recurrenceId to be more direct (or where the template is provided through the simple list of dates in `Appointment.occurrenceDate`).
 *
 * http://hl7.org/fhir/occurrenceDate
 */
export declare const occurrenceDate = "http://hl7.org/fhir/occurrenceDate";
/**
 * monthlyTemplate
 *
 * Appointment.recurrenceTemplate.monthlyTemplate: Information about monthly recurring appointments.
 *
 * http://hl7.org/fhir/monthlyTemplate
 */
export declare const monthlyTemplate = "http://hl7.org/fhir/monthlyTemplate";
/**
 * supportingInformation
 *
 * DeviceDispense.supportingInformation: Additional information that supports the device being dispensed.
 *
 * http://hl7.org/fhir/supportingInformation
 */
export declare const supportingInformation = "http://hl7.org/fhir/supportingInformation";
/**
 * authorizationRequired
 *
 * CoverageEligibilityResponse.insurance.item.authorizationRequired: A boolean flag indicating whether a preauthorization is required prior to actual service delivery.
 *
 * http://hl7.org/fhir/authorizationRequired
 */
export declare const authorizationRequired = "http://hl7.org/fhir/authorizationRequired";
/**
 * _versionReference
 *
 * (Modified) ExampleScenario.process.step.process.step.operation.request.versionReference
 *
 * http://hl7.org/fhir/_versionReference
 */
export declare const _versionReference = "http://hl7.org/fhir/_versionReference";
/**
 * ImmunizationRecommendationRecommendationComponent
 *
 * ImmunizationRecommendationRecommendationComponent: Vaccine administration recommendations.
 *
 * http://hl7.org/fhir/ImmunizationRecommendationRecommendationComponent
 */
export declare const ImmunizationRecommendationRecommendationComponent = "http://hl7.org/fhir/ImmunizationRecommendationRecommendationComponent";
/**
 * _measurementPoint
 *
 * (Modified) Ingredient.substance.strength.referenceStrength.measurementPoint
 *
 * http://hl7.org/fhir/_measurementPoint
 */
export declare const _measurementPoint = "http://hl7.org/fhir/_measurementPoint";
/**
 * batch
 *
 * Medication.batch: Information that only applies to packages (not products).
 *
 * http://hl7.org/fhir/batch
 */
export declare const batch = "http://hl7.org/fhir/batch";
/**
 * _include
 *
 * (Modified) ValueSet.compose.include
 *
 * http://hl7.org/fhir/_include
 */
export declare const _include = "http://hl7.org/fhir/_include";
/**
 * ValueSetComposeIncludeFilterComponent
 *
 * ValueSetComposeComponentInclude.ValueSetComposeIncludeFilterComponent: Select concepts by specifying a matching criterion based on the properties (including relationships) defined by the system, or on filters defined by the system. If multiple filters are specified within the include, they SHALL all be true.
 *
 * http://hl7.org/fhir/ValueSetComposeIncludeFilterComponent
 */
export declare const ValueSetComposeIncludeFilterComponent = "http://hl7.org/fhir/ValueSetComposeIncludeFilterComponent";
/**
 * subcomponent
 *
 * Evidence.certainty.subcomponent: A domain or subdomain of certainty.
 *
 * http://hl7.org/fhir/subcomponent
 */
export declare const subcomponent = "http://hl7.org/fhir/subcomponent";
/**
 * _DetectedIssue
 *
 * (Modified) DetectedIssue
 *
 * http://hl7.org/fhir/_DetectedIssue
 */
export declare const _DetectedIssue = "http://hl7.org/fhir/_DetectedIssue";
/**
 * _GuidanceResponse
 *
 * (Modified) GuidanceResponse
 *
 * http://hl7.org/fhir/_GuidanceResponse
 */
export declare const _GuidanceResponse = "http://hl7.org/fhir/_GuidanceResponse";
/**
 * _participantType
 *
 * (Modified) AppointmentResponse.participantType
 *
 * http://hl7.org/fhir/_participantType
 */
export declare const _participantType = "http://hl7.org/fhir/_participantType";
/**
 * _division
 *
 * (Modified) BiologicallyDerivedProduct.division
 *
 * http://hl7.org/fhir/_division
 */
export declare const _division = "http://hl7.org/fhir/_division";
/**
 * _section
 *
 * (Modified) EvidenceReport.section.section
 *
 * http://hl7.org/fhir/_section
 */
export declare const _section = "http://hl7.org/fhir/_section";
/**
 * _MedicationAdministration
 *
 * (Modified) MedicationAdministration
 *
 * http://hl7.org/fhir/_MedicationAdministration
 */
export declare const _MedicationAdministration = "http://hl7.org/fhir/_MedicationAdministration";
/**
 * _outcomeMeasure
 *
 * (Modified) ResearchStudy.outcomeMeasure
 *
 * http://hl7.org/fhir/_outcomeMeasure
 */
export declare const _outcomeMeasure = "http://hl7.org/fhir/_outcomeMeasure";
/**
 * PackagingDistributor
 *
 * DeviceDefinitionPackagingComponentPackaging.PackagingDistributor: An organization that distributes the packaged device.
 *
 * http://hl7.org/fhir/PackagingDistributor
 */
export declare const PackagingDistributor = "http://hl7.org/fhir/PackagingDistributor";
/**
 * _serviceType
 *
 * (Modified) Slot.serviceType
 *
 * http://hl7.org/fhir/_serviceType
 */
export declare const _serviceType = "http://hl7.org/fhir/_serviceType";
/**
 * _subjectReport
 *
 * (Modified) MeasureReport.group.stratifier.stratum.population.subjectReport
 *
 * http://hl7.org/fhir/_subjectReport
 */
export declare const _subjectReport = "http://hl7.org/fhir/_subjectReport";
/**
 * _initialFill
 *
 * (Modified) MedicationRequest.dispenseRequest.initialFill
 *
 * http://hl7.org/fhir/_initialFill
 */
export declare const _initialFill = "http://hl7.org/fhir/_initialFill";
/**
 * _administrableDoseForm
 *
 * (Modified) AdministrableProductDefinition.administrableDoseForm
 *
 * http://hl7.org/fhir/_administrableDoseForm
 */
export declare const _administrableDoseForm = "http://hl7.org/fhir/_administrableDoseForm";
/**
 * areaOfHybridisation
 *
 * SubstanceNucleicAcid.areaOfHybridisation: The area of hybridisation shall be described if applicable for double stranded RNA or DNA. The number associated with the subunit followed by the number associated to the residue shall be specified in increasing order. The underscore “” shall be used as separator as follows: “Subunitnumber Residue”.
 *
 * http://hl7.org/fhir/areaOfHybridisation
 */
export declare const areaOfHybridisation = "http://hl7.org/fhir/areaOfHybridisation";
/**
 * subjectType
 *
 * Questionnaire.subjectType: The types of subjects that can be the subject of responses created for the questionnaire.
 *
 * http://hl7.org/fhir/subjectType
 */
export declare const subjectType = "http://hl7.org/fhir/subjectType";
/**
 * device
 *
 * Specimen.container.device: The device resource for the the container holding the specimen. If the container is in a holder then the referenced device will point to a parent device.
 *
 * http://hl7.org/fhir/device
 */
export declare const device = "http://hl7.org/fhir/device";
/**
 * AddedItem
 *
 * ExplanationOfBenefit.AddedItem: The first-tier service adjudications for payor added product or service lines.
 *
 * http://hl7.org/fhir/AddedItem
 */
export declare const AddedItem = "http://hl7.org/fhir/AddedItem";
/**
 * _region
 *
 * (Modified) ResearchStudy.region
 *
 * http://hl7.org/fhir/_region
 */
export declare const _region = "http://hl7.org/fhir/_region";
/**
 * MedicationKnowledgeRegulatorySubstitutionComponent
 *
 * MedicationKnowledgeRegulatoryComponent.MedicationKnowledgeRegulatorySubstitutionComponent: Specifies if changes are allowed when dispensing a medication from a regulatory perspective.
 *
 * http://hl7.org/fhir/MedicationKnowledgeRegulatorySubstitutionComponent
 */
export declare const MedicationKnowledgeRegulatorySubstitutionComponent = "http://hl7.org/fhir/MedicationKnowledgeRegulatorySubstitutionComponent";
/**
 * MeasureReportGroupComponent
 *
 * MeasureReportGroupComponent: The results of the calculation, one for each population group in the measure.
 *
 * http://hl7.org/fhir/MeasureReportGroupComponent
 */
export declare const MeasureReportGroupComponent = "http://hl7.org/fhir/MeasureReportGroupComponent";
/**
 * _accident
 *
 * (Modified) ExplanationOfBenefit.accident
 *
 * http://hl7.org/fhir/_accident
 */
export declare const _accident = "http://hl7.org/fhir/_accident";
/**
 * endRelationship
 *
 * RequestOrchestration.action.relatedAction.endRelationship: The relationship of the end of this action to the related action.
 *
 * http://hl7.org/fhir/endRelationship
 */
export declare const endRelationship = "http://hl7.org/fhir/endRelationship";
/**
 * structure
 *
 * SubstanceDefinition.structure: Structural information.
 *
 * http://hl7.org/fhir/structure
 */
export declare const structure = "http://hl7.org/fhir/structure";
/**
 * _library
 *
 * (Modified) PlanDefinition.library
 *
 * http://hl7.org/fhir/_library
 */
export declare const _library = "http://hl7.org/fhir/_library";
/**
 * _descriptionSummary
 *
 * (Modified) ResearchStudy.descriptionSummary
 *
 * http://hl7.org/fhir/_descriptionSummary
 */
export declare const _descriptionSummary = "http://hl7.org/fhir/_descriptionSummary";
/**
 * baseCitation
 *
 * Citation.citedArtifact.part.baseCitation: The citation for the full article or artifact.
 *
 * http://hl7.org/fhir/baseCitation
 */
export declare const baseCitation = "http://hl7.org/fhir/baseCitation";
/**
 * definitionId
 *
 * EvidenceVariable.characteristic.definitionByCombination.characteristic.definitionId: Defines the characteristic using id.
 *
 * http://hl7.org/fhir/definitionId
 */
export declare const definitionId = "http://hl7.org/fhir/definitionId";
/**
 * _coordinateSystem
 *
 * (Modified) MolecularSequence.relative.coordinateSystem
 *
 * http://hl7.org/fhir/_coordinateSystem
 */
export declare const _coordinateSystem = "http://hl7.org/fhir/_coordinateSystem";
/**
 * characteristicType
 *
 * InventoryItem.characteristic.characteristicType: The type of characteristic that is being defined.
 *
 * http://hl7.org/fhir/characteristicType
 */
export declare const characteristicType = "http://hl7.org/fhir/characteristicType";
/**
 * _entry
 *
 * (Modified) List.entry
 *
 * http://hl7.org/fhir/_entry
 */
export declare const _entry = "http://hl7.org/fhir/_entry";
/**
 * imageRegion2D
 *
 * ImagingSelection.instance.imageRegion2D: Each imaging selection instance or frame list might includes an image region, specified by a region type and a set of 2D coordinates.
 *        If the parent imagingSelection.instance contains a subset element of type frame, the image region applies to all frames in the subset list.
 *
 * http://hl7.org/fhir/imageRegion2D
 */
export declare const imageRegion2D = "http://hl7.org/fhir/imageRegion2D";
/**
 * _DeviceDefinition
 *
 * (Modified) DeviceDefinition
 *
 * http://hl7.org/fhir/_DeviceDefinition
 */
export declare const _DeviceDefinition = "http://hl7.org/fhir/_DeviceDefinition";
/**
 * conclusionCode
 *
 * DiagnosticReport.conclusionCode: One or more codes that represent the summary conclusion (interpretation/impression) of the diagnostic report.
 *
 * http://hl7.org/fhir/conclusionCode
 */
export declare const conclusionCode = "http://hl7.org/fhir/conclusionCode";
/**
 * BiologicallyDerivedProductDispensePerformerComponent
 *
 * BiologicallyDerivedProductDispensePerformerComponent: Indicates who or what performed an action.
 *
 * http://hl7.org/fhir/BiologicallyDerivedProductDispensePerformerComponent
 */
export declare const BiologicallyDerivedProductDispensePerformerComponent = "http://hl7.org/fhir/BiologicallyDerivedProductDispensePerformerComponent";
/**
 * _caloricDensity
 *
 * (Modified) NutritionOrder.enteralFormula.caloricDensity
 *
 * http://hl7.org/fhir/_caloricDensity
 */
export declare const _caloricDensity = "http://hl7.org/fhir/_caloricDensity";
/**
 * ManufacturedItemDefinitionComponentComponent
 *
 * ManufacturedItemDefinitionComponentComponent: Physical parts of the manufactured item, that it is intrisically made from. This is distinct from the ingredients that are part of its chemical makeup.
 *
 * http://hl7.org/fhir/ManufacturedItemDefinitionComponentComponent
 */
export declare const ManufacturedItemDefinitionComponentComponent = "http://hl7.org/fhir/ManufacturedItemDefinitionComponentComponent";
/**
 * _focal
 *
 * (Modified) ExplanationOfBenefit.insurance.focal
 *
 * http://hl7.org/fhir/_focal
 */
export declare const _focal = "http://hl7.org/fhir/_focal";
/**
 * indication
 *
 * MedicinalProductDefinition.indication: Description of indication(s) for this product, used when structured indications are not required. In cases where structured indications are required, they are captured using the ClinicalUseDefinition resource. An indication is a medical situation for which using the product is appropriate.
 *
 * http://hl7.org/fhir/indication
 */
export declare const indication = "http://hl7.org/fhir/indication";
/**
 * _AllergyIntolerance
 *
 * (Modified) AllergyIntolerance
 *
 * http://hl7.org/fhir/_AllergyIntolerance
 */
export declare const _AllergyIntolerance = "http://hl7.org/fhir/_AllergyIntolerance";
/**
 * _publishedIn
 *
 * (Modified) Citation.citedArtifact.publicationForm.publishedIn
 *
 * http://hl7.org/fhir/_publishedIn
 */
export declare const _publishedIn = "http://hl7.org/fhir/_publishedIn";
/**
 * partOf
 *
 * BiologicallyDerivedProductDispense.partOf: A larger event of which this particular event is a component.
 *
 * http://hl7.org/fhir/partOf
 */
export declare const partOf = "http://hl7.org/fhir/partOf";
/**
 * _initialSelected
 *
 * (Modified) Questionnaire.item.item.answerOption.initialSelected
 *
 * http://hl7.org/fhir/_initialSelected
 */
export declare const _initialSelected = "http://hl7.org/fhir/_initialSelected";
/**
 * _key
 *
 * (Modified) Requirements.statement.key
 *
 * http://hl7.org/fhir/_key
 */
export declare const _key = "http://hl7.org/fhir/_key";
/**
 * backCurve
 *
 * VisionPrescription.lensSpecification.backCurve: Back curvature measured in millimetres.
 *
 * http://hl7.org/fhir/backCurve
 */
export declare const backCurve = "http://hl7.org/fhir/backCurve";
/**
 * _path
 *
 * (Modified) RequestOrchestration.action.dynamicValue.path
 *
 * http://hl7.org/fhir/_path
 */
export declare const _path = "http://hl7.org/fhir/_path";
/**
 * definitionUri
 *
 * ChargeItem.definitionUri: References the (external) source of pricing information, rules of application for the code this ChargeItem uses.
 *
 * http://hl7.org/fhir/definitionUri
 */
export declare const definitionUri = "http://hl7.org/fhir/definitionUri";
/**
 * ExplanationOfBenefitItemReviewOutcomeComponent
 *
 * ExplanationOfBenefit.Item.ExplanationOfBenefitItemReviewOutcomeComponent: The high-level results of the adjudication if adjudication has been performed.
 *
 * http://hl7.org/fhir/ExplanationOfBenefitItemReviewOutcomeComponent
 */
export declare const ExplanationOfBenefitItemReviewOutcomeComponent = "http://hl7.org/fhir/ExplanationOfBenefitItemReviewOutcomeComponent";
/**
 * DetectedIssueMitigationComponent
 *
 * DetectedIssueMitigationComponent: Indicates an action that has been taken or is committed to reduce or eliminate the likelihood of the risk identified by the detected issue from manifesting.  Can also reflect an observation of known mitigating factors that may reduce/eliminate the need for any action.
 *
 * http://hl7.org/fhir/DetectedIssueMitigationComponent
 */
export declare const DetectedIssueMitigationComponent = "http://hl7.org/fhir/DetectedIssueMitigationComponent";
/**
 * _lastOccurrenceDate
 *
 * (Modified) Appointment.recurrenceTemplate.lastOccurrenceDate
 *
 * http://hl7.org/fhir/_lastOccurrenceDate
 */
export declare const _lastOccurrenceDate = "http://hl7.org/fhir/_lastOccurrenceDate";
/**
 * _enableWhen
 *
 * (Modified) Questionnaire.item.item.enableWhen
 *
 * http://hl7.org/fhir/_enableWhen
 */
export declare const _enableWhen = "http://hl7.org/fhir/_enableWhen";
/**
 * time
 *
 * DocumentReference.attester.time: When the document was attested by the party.
 *
 * http://hl7.org/fhir/time
 */
export declare const time = "http://hl7.org/fhir/time";
/**
 * MedicinalProductDefinitionNameUsageComponent
 *
 * MedicinalProductDefinitionNameComponent.MedicinalProductDefinitionNameUsageComponent: Country and jurisdiction where the name applies, and associated language.
 *
 * http://hl7.org/fhir/MedicinalProductDefinitionNameUsageComponent
 */
export declare const MedicinalProductDefinitionNameUsageComponent = "http://hl7.org/fhir/MedicinalProductDefinitionNameUsageComponent";
/**
 * ChargeItemDefinitionApplicabilityComponent
 *
 * ChargeItemDefinitionApplicabilityComponent: Expressions that describe applicability criteria for the billing code.
 *
 * http://hl7.org/fhir/ChargeItemDefinitionApplicabilityComponent
 */
export declare const ChargeItemDefinitionApplicabilityComponent = "http://hl7.org/fhir/ChargeItemDefinitionApplicabilityComponent";
/**
 * InventoryItemCharacteristicComponent
 *
 * InventoryItemCharacteristicComponent: The descriptive or identifying characteristics of the item.
 *
 * http://hl7.org/fhir/InventoryItemCharacteristicComponent
 */
export declare const InventoryItemCharacteristicComponent = "http://hl7.org/fhir/InventoryItemCharacteristicComponent";
/**
 * _dischargeDisposition
 *
 * (Modified) Encounter.admission.dischargeDisposition
 *
 * http://hl7.org/fhir/_dischargeDisposition
 */
export declare const _dischargeDisposition = "http://hl7.org/fhir/_dischargeDisposition";
/**
 * isModifierReason
 *
 * ElementDefinition.isModifierReason: Explains how that element affects the interpretation of the resource or element that contains it.
 *
 * http://hl7.org/fhir/isModifierReason
 */
export declare const isModifierReason = "http://hl7.org/fhir/isModifierReason";
/**
 * StructureDefinitionContextComponent
 *
 * StructureDefinitionContextComponent: Identifies the types of resource or data type elements to which the extension can be applied. For more guidance on using the 'context' element, see the [defining extensions page](defining-extensions.html#context).
 *
 * http://hl7.org/fhir/StructureDefinitionContextComponent
 */
export declare const StructureDefinitionContextComponent = "http://hl7.org/fhir/StructureDefinitionContextComponent";
/**
 * _forecastReason
 *
 * (Modified) ImmunizationRecommendation.recommendation.forecastReason
 *
 * http://hl7.org/fhir/_forecastReason
 */
export declare const _forecastReason = "http://hl7.org/fhir/_forecastReason";
/**
 * SubstanceDefinitionMoietyComponent
 *
 * SubstanceDefinitionMoietyComponent: Moiety, for structural modifications.
 *
 * http://hl7.org/fhir/SubstanceDefinitionMoietyComponent
 */
export declare const SubstanceDefinitionMoietyComponent = "http://hl7.org/fhir/SubstanceDefinitionMoietyComponent";
/**
 * _step
 *
 * (Modified) ExampleScenario.process.step.alternative.step
 *
 * http://hl7.org/fhir/_step
 */
export declare const _step = "http://hl7.org/fhir/_step";
/**
 * rest
 *
 * CapabilityStatement.rest: A definition of the restful capabilities of the solution, if any.
 *
 * http://hl7.org/fhir/rest
 */
export declare const rest = "http://hl7.org/fhir/rest";
/**
 * issuer
 *
 * DeviceDefinition.packaging.packaging.udiDeviceIdentifier.issuer: The organization that assigns the identifier algorithm.
 *
 * http://hl7.org/fhir/issuer
 */
export declare const issuer = "http://hl7.org/fhir/issuer";
/**
 * _nutritionProduct
 *
 * (Modified) NutritionIntake.consumedItem.nutritionProduct
 *
 * http://hl7.org/fhir/_nutritionProduct
 */
export declare const _nutritionProduct = "http://hl7.org/fhir/_nutritionProduct";
/**
 * SubstancePolymer
 *
 * Properties of a substance specific to it being a polymer.
 *
 * http://hl7.org/fhir/SubstancePolymer
 */
export declare const SubstancePolymer = "http://hl7.org/fhir/SubstancePolymer";
/**
 * ValueSetComposeComponent
 *
 * ValueSetComposeComponent: A set of criteria that define the contents of the value set by including or excluding codes selected from the specified code system(s) that the value set draws from. This is also known as the Content Logical Definition (CLD).
 *
 * http://hl7.org/fhir/ValueSetComposeComponent
 */
export declare const ValueSetComposeComponent = "http://hl7.org/fhir/ValueSetComposeComponent";
/**
 * _doseNumber
 *
 * (Modified) ImmunizationRecommendation.recommendation.doseNumber
 *
 * http://hl7.org/fhir/_doseNumber
 */
export declare const _doseNumber = "http://hl7.org/fhir/_doseNumber";
/**
 * SubstanceDefinitionNameComponent
 *
 * SubstanceDefinitionNameComponent: Names applicable to this substance.
 *
 * http://hl7.org/fhir/SubstanceDefinitionNameComponent
 */
export declare const SubstanceDefinitionNameComponent = "http://hl7.org/fhir/SubstanceDefinitionNameComponent";
/**
 * derivedFromUri
 *
 * SpecimenDefinition.derivedFromUri: The URL pointing to an externally-defined type of specimen, guideline or other definition that is adhered to in whole or in part by this definition.
 *
 * http://hl7.org/fhir/derivedFromUri
 */
export declare const derivedFromUri = "http://hl7.org/fhir/derivedFromUri";
/**
 * _startParam
 *
 * (Modified) CompartmentDefinition.resource.startParam
 *
 * http://hl7.org/fhir/_startParam
 */
export declare const _startParam = "http://hl7.org/fhir/_startParam";
/**
 * _attribute
 *
 * (Modified) ConceptMap.group.element.target.product.attribute
 *
 * http://hl7.org/fhir/_attribute
 */
export declare const _attribute = "http://hl7.org/fhir/_attribute";
/**
 * _extraDetails
 *
 * (Modified) HealthcareService.extraDetails
 *
 * http://hl7.org/fhir/_extraDetails
 */
export declare const _extraDetails = "http://hl7.org/fhir/_extraDetails";
/**
 * _accessionIdentifier
 *
 * (Modified) Specimen.accessionIdentifier
 *
 * http://hl7.org/fhir/_accessionIdentifier
 */
export declare const _accessionIdentifier = "http://hl7.org/fhir/_accessionIdentifier";
/**
 * _entryReference
 *
 * (Modified) EvidenceReport.section.section.entryReference
 *
 * http://hl7.org/fhir/_entryReference
 */
export declare const _entryReference = "http://hl7.org/fhir/_entryReference";
/**
 * Parameters
 *
 * This resource is used to pass information into and back from an operation (whether invoked directly from REST or within a messaging environment).  It is not persisted or allowed to be referenced by other resources except as described in the definition of the Parameters resource.
 *
 * http://hl7.org/fhir/Parameters
 */
export declare const Parameters = "http://hl7.org/fhir/Parameters";
/**
 * ChargeItem
 *
 * The resource ChargeItem describes the provision of healthcare provider products for a certain patient, therefore referring not only to the product, but containing in addition details of the provision, like date, time, amounts and participating organizations and persons. Main Usage of the ChargeItem is to enable the billing process and internal cost allocation.
 *
 * http://hl7.org/fhir/ChargeItem
 */
export declare const ChargeItem = "http://hl7.org/fhir/ChargeItem";
/**
 * _uid
 *
 * (Modified) ImagingStudy.series.instance.uid
 *
 * http://hl7.org/fhir/_uid
 */
export declare const _uid = "http://hl7.org/fhir/_uid";
/**
 * chain
 *
 * SearchParameter.chain: Contains the names of any search parameters which may be chained to the containing search parameter. Chained parameters may be added to search parameters of type reference and specify that resources will only be returned if they contain a reference to a resource which matches the chained parameter value. Values for this field should be drawn from SearchParameter.code for a parameter on the target resource type.
 *
 * http://hl7.org/fhir/chain
 */
export declare const chain = "http://hl7.org/fhir/chain";
/**
 * _bodySite
 *
 * (Modified) Claim.item.bodySite
 *
 * http://hl7.org/fhir/_bodySite
 */
export declare const _bodySite = "http://hl7.org/fhir/_bodySite";
/**
 * qualification
 *
 * Practitioner.qualification: The official qualifications, certifications, accreditations, training, licenses (and other types of educations/skills/capabilities) that authorize or otherwise pertain to the provision of care by the practitioner.

For example, a medical license issued by a medical board of licensure authorizing the practitioner to practice medicine within a certain locality.
 *
 * http://hl7.org/fhir/qualification
 */
export declare const qualification = "http://hl7.org/fhir/qualification";
/**
 * yearInterval
 *
 * Appointment.recurrenceTemplate.yearlyTemplate.yearInterval: Appointment recurs every nth year.
 *
 * http://hl7.org/fhir/yearInterval
 */
export declare const yearInterval = "http://hl7.org/fhir/yearInterval";
/**
 * _developmentStage
 *
 * (Modified) SubstanceSourceMaterial.developmentStage
 *
 * http://hl7.org/fhir/_developmentStage
 */
export declare const _developmentStage = "http://hl7.org/fhir/_developmentStage";
/**
 * riskAdjustment
 *
 * Measure.riskAdjustment: A description of the risk adjustment factors that may impact the resulting score for the measure and how they may be accounted for when computing and reporting measure results.
 *
 * http://hl7.org/fhir/riskAdjustment
 */
export declare const riskAdjustment = "http://hl7.org/fhir/riskAdjustment";
/**
 * _estimatedAge
 *
 * (Modified) FamilyMemberHistory.estimatedAge
 *
 * http://hl7.org/fhir/_estimatedAge
 */
export declare const _estimatedAge = "http://hl7.org/fhir/_estimatedAge";
/**
 * RequirementsStatementComponent
 *
 * RequirementsStatementComponent: The actual statement of requirement, in markdown format.
 *
 * http://hl7.org/fhir/RequirementsStatementComponent
 */
export declare const RequirementsStatementComponent = "http://hl7.org/fhir/RequirementsStatementComponent";
/**
 * _intendedRoute
 *
 * (Modified) MedicationKnowledge.definitional.intendedRoute
 *
 * http://hl7.org/fhir/_intendedRoute
 */
export declare const _intendedRoute = "http://hl7.org/fhir/_intendedRoute";
/**
 * score
 *
 * TestReport.score: The final score (percentage of tests passed) resulting from the execution of the TestScript.
 *
 * http://hl7.org/fhir/score
 */
export declare const score = "http://hl7.org/fhir/score";
/**
 * DeviceRequestParameterComponent
 *
 * DeviceRequestParameterComponent: Specific parameters for the ordered item.  For example, the prism value for lenses.
 *
 * http://hl7.org/fhir/DeviceRequestParameterComponent
 */
export declare const DeviceRequestParameterComponent = "http://hl7.org/fhir/DeviceRequestParameterComponent";
/**
 * _diseaseSymptomProcedure
 *
 * (Modified) ClinicalUseDefinition.indication.diseaseSymptomProcedure
 *
 * http://hl7.org/fhir/_diseaseSymptomProcedure
 */
export declare const _diseaseSymptomProcedure = "http://hl7.org/fhir/_diseaseSymptomProcedure";
/**
 * _validationProcess
 *
 * (Modified) VerificationResult.validationProcess
 *
 * http://hl7.org/fhir/_validationProcess
 */
export declare const _validationProcess = "http://hl7.org/fhir/_validationProcess";
/**
 * ExampleScenarioProcessComponent
 *
 * ExampleScenarioProcessComponent: A group of operations that represents a significant step within a scenario.
 *
 * http://hl7.org/fhir/ExampleScenarioProcessComponent
 */
export declare const ExampleScenarioProcessComponent = "http://hl7.org/fhir/ExampleScenarioProcessComponent";
/**
 * _timestamp
 *
 * (Modified) ValueSet.expansion.timestamp
 *
 * http://hl7.org/fhir/_timestamp
 */
export declare const _timestamp = "http://hl7.org/fhir/_timestamp";
/**
 * supportedProfile
 *
 * CapabilityStatement.rest.resource.supportedProfile: A list of profiles representing different use cases the system hosts/produces. A supported profile is a statement about the functionality of the data and services provided by the server (or the client) for supported use cases. For example, a system can define and declare multiple Observation profiles for laboratory observations, vital sign observations, etc. By declaring supported profiles, systems provide a way to determine whether individual resources are conformant. See further discussion in [Using Profiles](profiling.html#profile-uses).
 *
 * http://hl7.org/fhir/supportedProfile
 */
export declare const supportedProfile = "http://hl7.org/fhir/supportedProfile";
/**
 * TestReportSetupActionAssertComponent
 *
 * TestReportSetupComponent.SetupAction.TestReportSetupActionAssertComponent: The results of the assertion performed on the previous operations.
 *
 * http://hl7.org/fhir/TestReportSetupActionAssertComponent
 */
export declare const TestReportSetupActionAssertComponent = "http://hl7.org/fhir/TestReportSetupActionAssertComponent";
/**
 * _label
 *
 * (Modified) Citation.citedArtifact.relatesTo.label
 *
 * http://hl7.org/fhir/_label
 */
export declare const _label = "http://hl7.org/fhir/_label";
/**
 * _preparationInstruction
 *
 * (Modified) MedicationKnowledge.preparationInstruction
 *
 * http://hl7.org/fhir/_preparationInstruction
 */
export declare const _preparationInstruction = "http://hl7.org/fhir/_preparationInstruction";
/**
 * InventoryItemResponsibleOrganizationComponent
 *
 * InventoryItemResponsibleOrganizationComponent: Organization(s) responsible for the product.
 *
 * http://hl7.org/fhir/InventoryItemResponsibleOrganizationComponent
 */
export declare const InventoryItemResponsibleOrganizationComponent = "http://hl7.org/fhir/InventoryItemResponsibleOrganizationComponent";
/**
 * informationType
 *
 * ArtifactAssessment.content.component.informationType: The type of information this component of the content represents.
 *
 * http://hl7.org/fhir/informationType
 */
export declare const informationType = "http://hl7.org/fhir/informationType";
/**
 * BodyStructureIncludedStructure
 *
 * The anatomical location(s) or region(s) not occupied or represented by the specimen, lesion, or body structure.
 *
 * http://hl7.org/fhir/BodyStructureIncludedStructure
 */
export declare const BodyStructureIncludedStructure = "http://hl7.org/fhir/BodyStructureIncludedStructure";
/**
 * _requesterLinkId
 *
 * (Modified) Contract.term.group.action.requesterLinkId
 *
 * http://hl7.org/fhir/_requesterLinkId
 */
export declare const _requesterLinkId = "http://hl7.org/fhir/_requesterLinkId";
/**
 * PlanDefinition
 *
 * This resource allows for the definition of various types of plans as a sharable, consumable, and executable artifact. The resource is general enough to support the description of a broad range of clinical and non-clinical artifacts such as clinical decision support rules, order sets, protocols, and drug quality specifications.
 *
 * http://hl7.org/fhir/PlanDefinition
 */
export declare const PlanDefinition = "http://hl7.org/fhir/PlanDefinition";
/**
 * postConditions
 *
 * ExampleScenario.process.step.alternative.step.process.postConditions: Description of the final state of the actors, environment and data after the process has been successfully completed.
 *
 * http://hl7.org/fhir/postConditions
 */
export declare const postConditions = "http://hl7.org/fhir/postConditions";
/**
 * EvidenceVariableDefinitionComponent
 *
 * EvidenceVariableDefinitionComponent: Evidence variable such as population, exposure, or outcome.
 *
 * http://hl7.org/fhir/EvidenceVariableDefinitionComponent
 */
export declare const EvidenceVariableDefinitionComponent = "http://hl7.org/fhir/EvidenceVariableDefinitionComponent";
/**
 * _meaningWhenMissing
 *
 * (Modified) ElementDefinition.meaningWhenMissing
 *
 * http://hl7.org/fhir/_meaningWhenMissing
 */
export declare const _meaningWhenMissing = "http://hl7.org/fhir/_meaningWhenMissing";
/**
 * DeviceDispense
 *
 * Indicates that a device is to be or has been dispensed for a named person/patient.  This includes a description of the product (supply) provided and the instructions for using the device.
 *
 * http://hl7.org/fhir/DeviceDispense
 */
export declare const DeviceDispense = "http://hl7.org/fhir/DeviceDispense";
/**
 * _modelCharacteristic
 *
 * (Modified) Evidence.statistic.modelCharacteristic
 *
 * http://hl7.org/fhir/_modelCharacteristic
 */
export declare const _modelCharacteristic = "http://hl7.org/fhir/_modelCharacteristic";
/**
 * SetupAction
 *
 * TestScriptSetupComponent.SetupAction: Action would contain either an operation or an assertion.
 *
 * http://hl7.org/fhir/SetupAction
 */
export declare const SetupAction = "http://hl7.org/fhir/SetupAction";
/**
 * _studyDesign
 *
 * (Modified) ResearchStudy.studyDesign
 *
 * http://hl7.org/fhir/_studyDesign
 */
export declare const _studyDesign = "http://hl7.org/fhir/_studyDesign";
/**
 * _analysis
 *
 * (Modified) GenomicStudy.analysis
 *
 * http://hl7.org/fhir/_analysis
 */
export declare const _analysis = "http://hl7.org/fhir/_analysis";
/**
 * insurancePlan
 *
 * Coverage.insurancePlan: The insurance plan details, benefits and costs, which constitute this insurance coverage.
 *
 * http://hl7.org/fhir/insurancePlan
 */
export declare const insurancePlan = "http://hl7.org/fhir/insurancePlan";
/**
 * communicationRequest
 *
 * ClaimResponse.communicationRequest: Request for additional supporting or authorizing information.
 *
 * http://hl7.org/fhir/communicationRequest
 */
export declare const communicationRequest = "http://hl7.org/fhir/communicationRequest";
/**
 * specialty
 *
 * Appointment.specialty: The specialty of a practitioner that would be required to perform the service requested in this appointment.
 *
 * http://hl7.org/fhir/specialty
 */
export declare const specialty = "http://hl7.org/fhir/specialty";
/**
 * _artifact
 *
 * (Modified) TestScript.scope.artifact
 *
 * http://hl7.org/fhir/_artifact
 */
export declare const _artifact = "http://hl7.org/fhir/_artifact";
/**
 * chargeItemCode
 *
 * DeviceDefinition.chargeItem.chargeItemCode: The code or reference for the charge item.
 *
 * http://hl7.org/fhir/chargeItemCode
 */
export declare const chargeItemCode = "http://hl7.org/fhir/chargeItemCode";
/**
 * actuality
 *
 * AdverseEvent.actuality: Whether the event actually happened or was a near miss. Note that this is independent of whether anyone was affected or harmed or how severely.
 *
 * http://hl7.org/fhir/actuality
 */
export declare const actuality = "http://hl7.org/fhir/actuality";
/**
 * _maxParticipants
 *
 * (Modified) VirtualServiceDetail.maxParticipants
 *
 * http://hl7.org/fhir/_maxParticipants
 */
export declare const _maxParticipants = "http://hl7.org/fhir/_maxParticipants";
/**
 * _Basic
 *
 * (Modified) Basic
 *
 * http://hl7.org/fhir/_Basic
 */
export declare const _Basic = "http://hl7.org/fhir/_Basic";
/**
 * _example
 *
 * (Modified) ElementDefinition.example
 *
 * http://hl7.org/fhir/_example
 */
export declare const _example = "http://hl7.org/fhir/_example";
/**
 * _representation
 *
 * (Modified) SubstancePolymer.repeat.repeatUnit.structuralRepresentation.representation
 *
 * http://hl7.org/fhir/_representation
 */
export declare const _representation = "http://hl7.org/fhir/_representation";
/**
 * telecom
 *
 * ContactDetail.telecom: The contact details for the individual (if a name was provided) or the organization.
 *
 * http://hl7.org/fhir/telecom
 */
export declare const telecom = "http://hl7.org/fhir/telecom";
/**
 * EvidenceCertaintyComponentCertaintyCertainty
 *
 * A domain or subdomain of certainty.
 *
 * http://hl7.org/fhir/EvidenceCertaintyComponentCertaintyCertainty
 */
export declare const EvidenceCertaintyComponentCertaintyCertainty = "http://hl7.org/fhir/EvidenceCertaintyComponentCertaintyCertainty";
/**
 * _lastPerformed
 *
 * (Modified) VerificationResult.lastPerformed
 *
 * http://hl7.org/fhir/_lastPerformed
 */
export declare const _lastPerformed = "http://hl7.org/fhir/_lastPerformed";
/**
 * _legalState
 *
 * (Modified) Contract.legalState
 *
 * http://hl7.org/fhir/_legalState
 */
export declare const _legalState = "http://hl7.org/fhir/_legalState";
/**
 * _preAuthPeriod
 *
 * (Modified) ExplanationOfBenefit.item.detail.reviewOutcome.preAuthPeriod
 *
 * http://hl7.org/fhir/_preAuthPeriod
 */
export declare const _preAuthPeriod = "http://hl7.org/fhir/_preAuthPeriod";
/**
 * GraphDefinitionLinkComponent
 *
 * GraphDefinitionLinkComponent: Links this graph makes rules about.
 *
 * http://hl7.org/fhir/GraphDefinitionLinkComponent
 */
export declare const GraphDefinitionLinkComponent = "http://hl7.org/fhir/GraphDefinitionLinkComponent";
/**
 * workflow
 *
 * ExampleScenario.process.step.alternative.step.process.step.workflow: Indicates that the step is defined by a seaparate scenario instance.
 *
 * http://hl7.org/fhir/workflow
 */
export declare const workflow = "http://hl7.org/fhir/workflow";
/**
 * _incomplete
 *
 * (Modified) TerminologyCapabilities.expansion.incomplete
 *
 * http://hl7.org/fhir/_incomplete
 */
export declare const _incomplete = "http://hl7.org/fhir/_incomplete";
/**
 * _sphere
 *
 * (Modified) VisionPrescription.lensSpecification.sphere
 *
 * http://hl7.org/fhir/_sphere
 */
export declare const _sphere = "http://hl7.org/fhir/_sphere";
/**
 * _substanceDefinition
 *
 * (Modified) SubstanceDefinition.relationship.substanceDefinition
 *
 * http://hl7.org/fhir/_substanceDefinition
 */
export declare const _substanceDefinition = "http://hl7.org/fhir/_substanceDefinition";
/**
 * informationSource
 *
 * Immunization.informationSource: Typically the source of the data when the report of the immunization event is not based on information from the person who administered the vaccine.
 *
 * http://hl7.org/fhir/informationSource
 */
export declare const informationSource = "http://hl7.org/fhir/informationSource";
/**
 * _periodUnit
 *
 * (Modified) Timing.repeat.periodUnit
 *
 * http://hl7.org/fhir/_periodUnit
 */
export declare const _periodUnit = "http://hl7.org/fhir/_periodUnit";
/**
 * paymentIdentifier
 *
 * PaymentReconciliation.paymentIdentifier: Issuer's unique identifier for the payment instrument.
 *
 * http://hl7.org/fhir/paymentIdentifier
 */
export declare const paymentIdentifier = "http://hl7.org/fhir/paymentIdentifier";
/**
 * stratifier
 *
 * MeasureReport.group.stratifier: When a measure includes multiple stratifiers, there will be a stratifier group for each stratifier defined by the measure.
 *
 * http://hl7.org/fhir/stratifier
 */
export declare const stratifier = "http://hl7.org/fhir/stratifier";
/**
 * pause
 *
 * ExampleScenario.process.step.process.step.alternative.step.pause: If true, indicates that, following this step, there is a pause in the flow and the subsequent step will occur at some later time (triggered by some event).
 *
 * http://hl7.org/fhir/pause
 */
export declare const pause = "http://hl7.org/fhir/pause";
/**
 * _isActive
 *
 * (Modified) Medication.ingredient.isActive
 *
 * http://hl7.org/fhir/_isActive
 */
export declare const _isActive = "http://hl7.org/fhir/_isActive";
/**
 * _synonym
 *
 * (Modified) SubstanceDefinition.name.translation.synonym
 *
 * http://hl7.org/fhir/_synonym
 */
export declare const _synonym = "http://hl7.org/fhir/_synonym";
/**
 * _manifestation
 *
 * (Modified) Immunization.reaction.manifestation
 *
 * http://hl7.org/fhir/_manifestation
 */
export declare const _manifestation = "http://hl7.org/fhir/_manifestation";
/**
 * _control
 *
 * (Modified) Contract.term.group.securityLabel.control
 *
 * http://hl7.org/fhir/_control
 */
export declare const _control = "http://hl7.org/fhir/_control";
/**
 * RegulatedAuthorizationCaseComponentCase
 *
 * A regulatory submission from an organization to a regulator, as part of an assessing case. Multiple applications may occur over time, with more or different information to support or modify the submission or the authorization. The applications can be considered as steps within the longer running case or procedure for this authorization process.
 *
 * http://hl7.org/fhir/RegulatedAuthorizationCaseComponentCase
 */
export declare const RegulatedAuthorizationCaseComponentCase = "http://hl7.org/fhir/RegulatedAuthorizationCaseComponentCase";
/**
 * dosageInstruction
 *
 * MedicationRequest.dosageInstruction: Specific instructions for how the medication is to be used by the patient.
 *
 * http://hl7.org/fhir/dosageInstruction
 */
export declare const dosageInstruction = "http://hl7.org/fhir/dosageInstruction";
/**
 * _implicitRules
 *
 * (Modified) Resource.implicitRules
 *
 * http://hl7.org/fhir/_implicitRules
 */
export declare const _implicitRules = "http://hl7.org/fhir/_implicitRules";
/**
 * AvailabilityAvailableTimeComponent
 *
 * AvailabilityAvailableTimeComponent: Times the {item} is available.
 *
 * http://hl7.org/fhir/AvailabilityAvailableTimeComponent
 */
export declare const AvailabilityAvailableTimeComponent = "http://hl7.org/fhir/AvailabilityAvailableTimeComponent";
/**
 * SpecimenCollectionComponent
 *
 * SpecimenCollectionComponent: Details concerning the specimen collection.
 *
 * http://hl7.org/fhir/SpecimenCollectionComponent
 */
export declare const SpecimenCollectionComponent = "http://hl7.org/fhir/SpecimenCollectionComponent";
/**
 * regulatoryAuthority
 *
 * MedicationKnowledge.regulatory.regulatoryAuthority: The authority that is specifying the regulations.
 *
 * http://hl7.org/fhir/regulatoryAuthority
 */
export declare const regulatoryAuthority = "http://hl7.org/fhir/regulatoryAuthority";
/**
 * _EnrollmentRequest
 *
 * (Modified) EnrollmentRequest
 *
 * http://hl7.org/fhir/_EnrollmentRequest
 */
export declare const _EnrollmentRequest = "http://hl7.org/fhir/_EnrollmentRequest";
/**
 * hash
 *
 * Attachment.hash: The calculated hash of the data using SHA-1. Represented using base64.
 *
 * http://hl7.org/fhir/hash
 */
export declare const hash = "http://hl7.org/fhir/hash";
/**
 * marketDistribution
 *
 * DeviceDefinition.packaging.packaging.udiDeviceIdentifier.marketDistribution: Indicates where and when the device is available on the market.
 *
 * http://hl7.org/fhir/marketDistribution
 */
export declare const marketDistribution = "http://hl7.org/fhir/marketDistribution";
/**
 * countType
 *
 * InventoryReport.countType: Whether the report is about the current inventory count (snapshot) or a differential change in inventory (change).
 *
 * http://hl7.org/fhir/countType
 */
export declare const countType = "http://hl7.org/fhir/countType";
/**
 * _documentation
 *
 * (Modified) ParameterDefinition.documentation
 *
 * http://hl7.org/fhir/_documentation
 */
export declare const _documentation = "http://hl7.org/fhir/_documentation";
/**
 * association
 *
 * InventoryItem.association: Association with other items or products.
 *
 * http://hl7.org/fhir/association
 */
export declare const association = "http://hl7.org/fhir/association";
/**
 * _intendedJurisdiction
 *
 * (Modified) MedicationKnowledge.intendedJurisdiction
 *
 * http://hl7.org/fhir/_intendedJurisdiction
 */
export declare const _intendedJurisdiction = "http://hl7.org/fhir/_intendedJurisdiction";
/**
 * _recurrenceType
 *
 * (Modified) Appointment.recurrenceTemplate.recurrenceType
 *
 * http://hl7.org/fhir/_recurrenceType
 */
export declare const _recurrenceType = "http://hl7.org/fhir/_recurrenceType";
/**
 * when
 *
 * RiskAssessment.prediction.when
 *
 * http://hl7.org/fhir/when
 */
export declare const when = "http://hl7.org/fhir/when";
/**
 * form
 *
 * ClaimResponse.form: The actual form, by reference or inclusion, for printing the content or an EOB.
 *
 * http://hl7.org/fhir/form
 */
export declare const form = "http://hl7.org/fhir/form";
/**
 * _complete
 *
 * (Modified) Citation.citedArtifact.contributorship.complete
 *
 * http://hl7.org/fhir/_complete
 */
export declare const _complete = "http://hl7.org/fhir/_complete";
/**
 * _shortDoco
 *
 * (Modified) ElementDefinition.binding.additional.shortDoco
 *
 * http://hl7.org/fhir/_shortDoco
 */
export declare const _shortDoco = "http://hl7.org/fhir/_shortDoco";
/**
 * differential
 *
 * StructureDefinition.differential: A differential view is expressed relative to the base StructureDefinition - a statement of differences that it applies.
 *
 * http://hl7.org/fhir/differential
 */
export declare const differential = "http://hl7.org/fhir/differential";
/**
 * _occurrenceDate
 *
 * (Modified) AppointmentResponse.occurrenceDate
 *
 * http://hl7.org/fhir/_occurrenceDate
 */
export declare const _occurrenceDate = "http://hl7.org/fhir/_occurrenceDate";
/**
 * additional
 *
 * ElementDefinition.binding.additional: Additional bindings that help applications implementing this element. Additional bindings do not replace the main binding but provide more information and/or context.
 *
 * http://hl7.org/fhir/additional
 */
export declare const additional = "http://hl7.org/fhir/additional";
/**
 * canonical
 *
 * A URI that is a reference to a canonical URL on a FHIR resource
 *
 * http://hl7.org/fhir/canonical
 */
export declare const canonical = "http://hl7.org/fhir/canonical";
/**
 * _actualComparisonGroup
 *
 * (Modified) ResearchSubject.actualComparisonGroup
 *
 * http://hl7.org/fhir/_actualComparisonGroup
 */
export declare const _actualComparisonGroup = "http://hl7.org/fhir/_actualComparisonGroup";
/**
 * _requestor
 *
 * (Modified) PaymentReconciliation.requestor
 *
 * http://hl7.org/fhir/_requestor
 */
export declare const _requestor = "http://hl7.org/fhir/_requestor";
/**
 * CommunicationPayloadComponent
 *
 * CommunicationPayloadComponent: Text, attachment(s), or resource(s) that was communicated to the recipient.
 *
 * http://hl7.org/fhir/CommunicationPayloadComponent
 */
export declare const CommunicationPayloadComponent = "http://hl7.org/fhir/CommunicationPayloadComponent";
/**
 * AccountDiagnosisComponent
 *
 * AccountDiagnosisComponent: When using an account for billing a specific Encounter the set of diagnoses that are relevant for billing are stored here on the account where they are able to be sequenced appropriately prior to processing to produce claim(s).
 *
 * http://hl7.org/fhir/AccountDiagnosisComponent
 */
export declare const AccountDiagnosisComponent = "http://hl7.org/fhir/AccountDiagnosisComponent";
/**
 * _doseStatus
 *
 * (Modified) ImmunizationEvaluation.doseStatus
 *
 * http://hl7.org/fhir/_doseStatus
 */
export declare const _doseStatus = "http://hl7.org/fhir/_doseStatus";
/**
 * TestScriptTestComponent
 *
 * TestScriptTestComponent: A test in this script.
 *
 * http://hl7.org/fhir/TestScriptTestComponent
 */
export declare const TestScriptTestComponent = "http://hl7.org/fhir/TestScriptTestComponent";
/**
 * TaskOutputComponent
 *
 * TaskOutputComponent: Outputs produced by the Task.
 *
 * http://hl7.org/fhir/TaskOutputComponent
 */
export declare const TaskOutputComponent = "http://hl7.org/fhir/TaskOutputComponent";
/**
 * MeasureReport
 *
 * The MeasureReport resource contains the results of the calculation of a measure; and optionally a reference to the resources involved in that calculation.
 *
 * http://hl7.org/fhir/MeasureReport
 */
export declare const MeasureReport = "http://hl7.org/fhir/MeasureReport";
/**
 * producedFrom
 *
 * AdministrableProductDefinition.producedFrom: Indicates the specific manufactured items that are part of the 'formOf' product that are used in the preparation of this specific administrable form.  In some cases, an administrable form might use all of the items from the overall product (or there might only be one item), while in other cases, an administrable form might use only a subset of the items available in the overall product.  For example, an administrable form might involve combining a liquid and a powder available as part of an overall product, but not involve applying the also supplied cream.
 *
 * http://hl7.org/fhir/producedFrom
 */
export declare const producedFrom = "http://hl7.org/fhir/producedFrom";
/**
 * tuesday
 *
 * Appointment.recurrenceTemplate.weeklyTemplate.tuesday: Indicates that recurring appointments should occur on Tuesdays.
 *
 * http://hl7.org/fhir/tuesday
 */
export declare const tuesday = "http://hl7.org/fhir/tuesday";
/**
 * _sourceReference
 *
 * (Modified) Consent.sourceReference
 *
 * http://hl7.org/fhir/_sourceReference
 */
export declare const _sourceReference = "http://hl7.org/fhir/_sourceReference";
/**
 * crossReference
 *
 * MedicinalProductDefinition.crossReference: Reference to another product, e.g. for linking authorised to investigational product, or a virtual product.
 *
 * http://hl7.org/fhir/crossReference
 */
export declare const crossReference = "http://hl7.org/fhir/crossReference";
/**
 * _Composition
 *
 * (Modified) Composition
 *
 * http://hl7.org/fhir/_Composition
 */
export declare const _Composition = "http://hl7.org/fhir/_Composition";
/**
 * subdetailSequence
 *
 * ClaimResponse.addItem.subdetailSequence: The sequence number of the sub-details within the details within the claim item which this line is intended to replace.
 *
 * http://hl7.org/fhir/subdetailSequence
 */
export declare const subdetailSequence = "http://hl7.org/fhir/subdetailSequence";
/**
 * _definitionReference
 *
 * (Modified) EvidenceVariable.characteristic.definitionByCombination.characteristic.definitionReference
 *
 * http://hl7.org/fhir/_definitionReference
 */
export declare const _definitionReference = "http://hl7.org/fhir/_definitionReference";
/**
 * supplier
 *
 * SubstanceDefinition.supplier: An entity that is the source for the substance. It may be different from the manufacturer. Supplier is synonymous to a distributor.
 *
 * http://hl7.org/fhir/supplier
 */
export declare const supplier = "http://hl7.org/fhir/supplier";
/**
 * inputPopulationId
 *
 * Measure.group.population.inputPopulationId: The id of a population element in this measure that provides the input for this population criteria. In most cases, the scoring structure of the measure implies specific relationships (e.g. the Numerator uses the Denominator as the source in a proportion scoring). In some cases, however, multiple possible choices exist and must be resolved explicitly. For example in a ratio measure with multiple initial populations, the denominator must specify which population should be used as the starting point.
 *
 * http://hl7.org/fhir/inputPopulationId
 */
export declare const inputPopulationId = "http://hl7.org/fhir/inputPopulationId";
/**
 * CarePlan
 *
 * Describes the intention of how one or more practitioners intend to deliver care for a particular patient, group or community for a period of time, possibly limited to care for a specific condition or set of conditions.
 *
 * http://hl7.org/fhir/CarePlan
 */
export declare const CarePlan = "http://hl7.org/fhir/CarePlan";
/**
 * clinicalStatus
 *
 * Condition.clinicalStatus: The clinical status of the condition.
 *
 * http://hl7.org/fhir/clinicalStatus
 */
export declare const clinicalStatus = "http://hl7.org/fhir/clinicalStatus";
/**
 * measurementType
 *
 * SubstanceDefinition.moiety.measurementType: The measurement type of the quantitative value. In capturing the actual relative amounts of substances or molecular fragments it may be necessary to indicate whether the amount refers to, for example, a mole ratio or weight ratio.
 *
 * http://hl7.org/fhir/measurementType
 */
export declare const measurementType = "http://hl7.org/fhir/measurementType";
/**
 * ImplementationGuideDefinitionGroupingComponent
 *
 * ImplementationGuideDefinitionComponent.ImplementationGuideDefinitionGroupingComponent: A logical group of resources. Logical groups can be used when building pages.
 *
 * http://hl7.org/fhir/ImplementationGuideDefinitionGroupingComponent
 */
export declare const ImplementationGuideDefinitionGroupingComponent = "http://hl7.org/fhir/ImplementationGuideDefinitionGroupingComponent";
/**
 * _fundingSource
 *
 * (Modified) Immunization.fundingSource
 *
 * http://hl7.org/fhir/_fundingSource
 */
export declare const _fundingSource = "http://hl7.org/fhir/_fundingSource";
/**
 * _immunizationEvent
 *
 * (Modified) ImmunizationEvaluation.immunizationEvent
 *
 * http://hl7.org/fhir/_immunizationEvent
 */
export declare const _immunizationEvent = "http://hl7.org/fhir/_immunizationEvent";
/**
 * ClaimResponseEventComponent
 *
 * ClaimResponseEventComponent: Information code for an event with a corresponding date or period.
 *
 * http://hl7.org/fhir/ClaimResponseEventComponent
 */
export declare const ClaimResponseEventComponent = "http://hl7.org/fhir/ClaimResponseEventComponent";
/**
 * statement
 *
 * Requirements.statement: The actual statement of requirement, in markdown format.
 *
 * http://hl7.org/fhir/statement
 */
export declare const statement = "http://hl7.org/fhir/statement";
/**
 * ImageRegion3D
 *
 * ImagingSelectionInstanceComponent.ImageRegion3D: Each imaging selection might includes a 3D image region, specified by a region type and a set of 3D coordinates.
 *
 * http://hl7.org/fhir/ImageRegion3D
 */
export declare const ImageRegion3D = "http://hl7.org/fhir/ImageRegion3D";
/**
 * _item
 *
 * (Modified) Linkage.item
 *
 * http://hl7.org/fhir/_item
 */
export declare const _item = "http://hl7.org/fhir/_item";
/**
 * _repeatUnit
 *
 * (Modified) SubstancePolymer.repeat.repeatUnit
 *
 * http://hl7.org/fhir/_repeatUnit
 */
export declare const _repeatUnit = "http://hl7.org/fhir/_repeatUnit";
/**
 * startingMaterial
 *
 * SubstancePolymer.monomerSet.startingMaterial: The starting materials - monomer(s) used in the synthesis of the polymer.
 *
 * http://hl7.org/fhir/startingMaterial
 */
export declare const startingMaterial = "http://hl7.org/fhir/startingMaterial";
/**
 * _temperatureQualifier
 *
 * (Modified) SpecimenDefinition.typeTested.handling.temperatureQualifier
 *
 * http://hl7.org/fhir/_temperatureQualifier
 */
export declare const _temperatureQualifier = "http://hl7.org/fhir/_temperatureQualifier";
/**
 * dosingGuideline
 *
 * MedicationKnowledge.indicationGuideline.dosingGuideline: The guidelines for the dosage of the medication for the indication.
 *
 * http://hl7.org/fhir/dosingGuideline
 */
export declare const dosingGuideline = "http://hl7.org/fhir/dosingGuideline";
/**
 * _serviceCategory
 *
 * (Modified) Slot.serviceCategory
 *
 * http://hl7.org/fhir/_serviceCategory
 */
export declare const _serviceCategory = "http://hl7.org/fhir/_serviceCategory";
/**
 * _rate
 *
 * (Modified) NutritionOrder.enteralFormula.administration.rate
 *
 * http://hl7.org/fhir/_rate
 */
export declare const _rate = "http://hl7.org/fhir/_rate";
/**
 * _filterDefinition
 *
 * (Modified) SubscriptionTopic.canFilterBy.filterDefinition
 *
 * http://hl7.org/fhir/_filterDefinition
 */
export declare const _filterDefinition = "http://hl7.org/fhir/_filterDefinition";
/**
 * prescriber
 *
 * VisionPrescription.prescriber: The healthcare professional responsible for authorizing the prescription.
 *
 * http://hl7.org/fhir/prescriber
 */
export declare const prescriber = "http://hl7.org/fhir/prescriber";
/**
 * oid
 *
 * An OID represented as a URI
 *
 * http://hl7.org/fhir/oid
 */
export declare const oid = "http://hl7.org/fhir/oid";
/**
 * _attachment
 *
 * (Modified) SubstancePolymer.repeat.repeatUnit.structuralRepresentation.attachment
 *
 * http://hl7.org/fhir/_attachment
 */
export declare const _attachment = "http://hl7.org/fhir/_attachment";
/**
 * _sourceAttachment
 *
 * (Modified) Consent.sourceAttachment
 *
 * http://hl7.org/fhir/_sourceAttachment
 */
export declare const _sourceAttachment = "http://hl7.org/fhir/_sourceAttachment";
/**
 * _materialType
 *
 * (Modified) SubstanceSourceMaterial.fractionDescription.materialType
 *
 * http://hl7.org/fhir/_materialType
 */
export declare const _materialType = "http://hl7.org/fhir/_materialType";
/**
 * target
 *
 * VerificationResult.target: A resource that was validated.
 *
 * http://hl7.org/fhir/target
 */
export declare const target = "http://hl7.org/fhir/target";
/**
 * _valueCategory
 *
 * (Modified) Evidence.statistic.modelCharacteristic.variable.valueCategory
 *
 * http://hl7.org/fhir/_valueCategory
 */
export declare const _valueCategory = "http://hl7.org/fhir/_valueCategory";
/**
 * _requestMethod
 *
 * (Modified) TestScript.test.action.assert.requestMethod
 *
 * http://hl7.org/fhir/_requestMethod
 */
export declare const _requestMethod = "http://hl7.org/fhir/_requestMethod";
/**
 * linkage
 *
 * SubstanceNucleicAcid.subunit.linkage: The linkages between sugar residues will also be captured.
 *
 * http://hl7.org/fhir/linkage
 */
export declare const linkage = "http://hl7.org/fhir/linkage";
/**
 * DeviceUdiCarrierComponent
 *
 * DeviceUdiCarrierComponent: Unique device identifier (UDI) assigned to device label or package.  Note that the Device may include multiple udiCarriers as it either may include just the udiCarrier for the jurisdiction it is sold, or for multiple jurisdictions it could have been sold.
 *
 * http://hl7.org/fhir/DeviceUdiCarrierComponent
 */
export declare const DeviceUdiCarrierComponent = "http://hl7.org/fhir/DeviceUdiCarrierComponent";
/**
 * TerminologyCapabilitiesClosureComponent
 *
 * TerminologyCapabilitiesClosureComponent: Whether the $closure operation is supported.
 *
 * http://hl7.org/fhir/TerminologyCapabilitiesClosureComponent
 */
export declare const TerminologyCapabilitiesClosureComponent = "http://hl7.org/fhir/TerminologyCapabilitiesClosureComponent";
/**
 * _conclusionCode
 *
 * (Modified) DiagnosticReport.conclusionCode
 *
 * http://hl7.org/fhir/_conclusionCode
 */
export declare const _conclusionCode = "http://hl7.org/fhir/_conclusionCode";
/**
 * _div
 *
 * (Modified) Narrative.div
 *
 * http://hl7.org/fhir/_div
 */
export declare const _div = "http://hl7.org/fhir/_div";
/**
 * processingMode
 *
 * SearchParameter.processingMode: How the search parameter relates to the set of elements returned by evaluating the expression query.
 *
 * http://hl7.org/fhir/processingMode
 */
export declare const processingMode = "http://hl7.org/fhir/processingMode";
/**
 * _rule
 *
 * (Modified) StructureMap.group.rule.rule
 *
 * http://hl7.org/fhir/_rule
 */
export declare const _rule = "http://hl7.org/fhir/_rule";
/**
 * StructureMap
 *
 * A Map of relationships between 2 structures that can be used to transform data.
 *
 * http://hl7.org/fhir/StructureMap
 */
export declare const StructureMap = "http://hl7.org/fhir/StructureMap";
/**
 * _molecularFormulaByMoiety
 *
 * (Modified) SubstanceDefinition.structure.molecularFormulaByMoiety
 *
 * http://hl7.org/fhir/_molecularFormulaByMoiety
 */
export declare const _molecularFormulaByMoiety = "http://hl7.org/fhir/_molecularFormulaByMoiety";
/**
 * firstDose
 *
 * AdministrableProductDefinition.routeOfAdministration.firstDose: The first dose (dose quantity) administered can be specified for the product, using a numerical value and its unit of measurement.
 *
 * http://hl7.org/fhir/firstDose
 */
export declare const firstDose = "http://hl7.org/fhir/firstDose";
/**
 * BundleEntryResponseComponent
 *
 * BundleEntryComponent.BundleEntryResponseComponent: Indicates the results of processing the corresponding 'request' entry in the batch or transaction being responded to or what the results of an operation where when returning history.
 *
 * http://hl7.org/fhir/BundleEntryResponseComponent
 */
export declare const BundleEntryResponseComponent = "http://hl7.org/fhir/BundleEntryResponseComponent";
/**
 * structureVersion
 *
 * ExampleScenario.instance.structureVersion: Conveys the version of the data structure instantiated.  I.e. what release of FHIR, X12, OpenEHR, etc. is instance compliant with.
 *
 * http://hl7.org/fhir/structureVersion
 */
export declare const structureVersion = "http://hl7.org/fhir/structureVersion";
/**
 * alias
 *
 * InsurancePlan.alias: A list of alternate names that the product is known as, or was known as in the past.
 *
 * http://hl7.org/fhir/alias
 */
export declare const alias = "http://hl7.org/fhir/alias";
/**
 * _programCode
 *
 * (Modified) ExplanationOfBenefit.item.detail.subDetail.programCode
 *
 * http://hl7.org/fhir/_programCode
 */
export declare const _programCode = "http://hl7.org/fhir/_programCode";
/**
 * _resultForDelete
 *
 * (Modified) SubscriptionTopic.resourceTrigger.queryCriteria.resultForDelete
 *
 * http://hl7.org/fhir/_resultForDelete
 */
export declare const _resultForDelete = "http://hl7.org/fhir/_resultForDelete";
/**
 * grantee
 *
 * Consent.grantee: The entity responsible for complying with the Consent Directive, including any obligations or limitations on authorizations and enforcement of prohibitions.
 *
 * http://hl7.org/fhir/grantee
 */
export declare const grantee = "http://hl7.org/fhir/grantee";
/**
 * _effectiveTime
 *
 * (Modified) Contract.term.group.asset.valuedItem.effectiveTime
 *
 * http://hl7.org/fhir/_effectiveTime
 */
export declare const _effectiveTime = "http://hl7.org/fhir/_effectiveTime";
/**
 * definitionCodeableConcept
 *
 * EvidenceVariable.characteristic.definitionByCombination.characteristic.definitionCodeableConcept: Defines the characteristic using CodeableConcept.
 *
 * http://hl7.org/fhir/definitionCodeableConcept
 */
export declare const definitionCodeableConcept = "http://hl7.org/fhir/definitionCodeableConcept";
/**
 * Property
 *
 * ConceptMap.Property: A property defines a slot through which additional information can be provided about a map from source -> target.
 *
 * http://hl7.org/fhir/Property
 */
export declare const Property = "http://hl7.org/fhir/Property";
/**
 * entryClassifier
 *
 * EvidenceReport.section.section.entryClassifier: Specifies any type of classification of the evidence report.
 *
 * http://hl7.org/fhir/entryClassifier
 */
export declare const entryClassifier = "http://hl7.org/fhir/entryClassifier";
/**
 * _combining
 *
 * (Modified) Permission.combining
 *
 * http://hl7.org/fhir/_combining
 */
export declare const _combining = "http://hl7.org/fhir/_combining";
/**
 * paternalOrganismName
 *
 * SubstanceSourceMaterial.organism.hybrid.paternalOrganismName: The name of the paternal species constituting the hybrid organism shall be specified.
 *
 * http://hl7.org/fhir/paternalOrganismName
 */
export declare const paternalOrganismName = "http://hl7.org/fhir/paternalOrganismName";
/**
 * _asset
 *
 * (Modified) Contract.term.group.asset
 *
 * http://hl7.org/fhir/_asset
 */
export declare const _asset = "http://hl7.org/fhir/_asset";
/**
 * PaymentReconciliationAllocationComponent
 *
 * PaymentReconciliationAllocationComponent: Distribution of the payment amount for a previously acknowledged payable.
 *
 * http://hl7.org/fhir/PaymentReconciliationAllocationComponent
 */
export declare const PaymentReconciliationAllocationComponent = "http://hl7.org/fhir/PaymentReconciliationAllocationComponent";
/**
 * _part
 *
 * (Modified) OperationDefinition.parameter.part
 *
 * http://hl7.org/fhir/_part
 */
export declare const _part = "http://hl7.org/fhir/_part";
/**
 * actor
 *
 * Schedule.actor: Slots that reference this schedule resource provide the availability details to these referenced resource(s).
 *
 * http://hl7.org/fhir/actor
 */
export declare const actor = "http://hl7.org/fhir/actor";
/**
 * _isExample
 *
 * (Modified) ImplementationGuide.manifest.resource.isExample
 *
 * http://hl7.org/fhir/_isExample
 */
export declare const _isExample = "http://hl7.org/fhir/_isExample";
/**
 * navigationLinks
 *
 * TestScript.test.action.assert.navigationLinks: Whether or not the test execution performs validation on the bundle navigation links.
 *
 * http://hl7.org/fhir/navigationLinks
 */
export declare const navigationLinks = "http://hl7.org/fhir/navigationLinks";
/**
 * availability
 *
 * PractitionerRole.availability: A collection of times the practitioner is available or performing this role at the location and/or healthcareservice.
 *
 * http://hl7.org/fhir/availability
 */
export declare const availability = "http://hl7.org/fhir/availability";
/**
 * _specimen
 *
 * (Modified) ServiceRequest.specimen
 *
 * http://hl7.org/fhir/_specimen
 */
export declare const _specimen = "http://hl7.org/fhir/_specimen";
/**
 * term
 *
 * Contract.term: One or more Contract Provisions, which may be related and conveyed as a group, and may contain nested groups.
 *
 * http://hl7.org/fhir/term
 */
export declare const term = "http://hl7.org/fhir/term";
/**
 * notAvailableTime
 *
 * Availability.notAvailableTime: Not available during this time due to provided reason.
 *
 * http://hl7.org/fhir/notAvailableTime
 */
export declare const notAvailableTime = "http://hl7.org/fhir/notAvailableTime";
/**
 * specimenRequirement
 *
 * ActivityDefinition.specimenRequirement: Defines specimen requirements for the action to be performed, such as required specimens for a lab test.
 *
 * http://hl7.org/fhir/specimenRequirement
 */
export declare const specimenRequirement = "http://hl7.org/fhir/specimenRequirement";
/**
 * answer
 *
 * Contract.term.offer.answer: Response to offer text.
 *
 * http://hl7.org/fhir/answer
 */
export declare const answer = "http://hl7.org/fhir/answer";
/**
 * _citation
 *
 * (Modified) Citation.citedArtifact.relatesTo.citation
 *
 * http://hl7.org/fhir/_citation
 */
export declare const _citation = "http://hl7.org/fhir/_citation";
/**
 * patient
 *
 * CoverageEligibilityRequest.patient: The party who is the beneficiary of the supplied coverage and for whom eligibility is sought.
 *
 * http://hl7.org/fhir/patient
 */
export declare const patient = "http://hl7.org/fhir/patient";
/**
 * suppress
 *
 * ElementDefinition.constraint.suppress: If true, indicates that the warning or best practice guideline should be suppressed.
 *
 * http://hl7.org/fhir/suppress
 */
export declare const suppress = "http://hl7.org/fhir/suppress";
/**
 * additionalUse
 *
 * CodeSystem.concept.concept.designation.additionalUse: Additional codes that detail how this designation would be used, if there is more than one use.
 *
 * http://hl7.org/fhir/additionalUse
 */
export declare const additionalUse = "http://hl7.org/fhir/additionalUse";
/**
 * _maxDosePerLifetime
 *
 * (Modified) Dosage.maxDosePerLifetime
 *
 * http://hl7.org/fhir/_maxDosePerLifetime
 */
export declare const _maxDosePerLifetime = "http://hl7.org/fhir/_maxDosePerLifetime";
/**
 * Distance
 *
 * A length - a value with a unit that is a physical distance.
 *
 * http://hl7.org/fhir/Distance
 */
export declare const Distance = "http://hl7.org/fhir/Distance";
/**
 * _primarySource
 *
 * (Modified) VerificationResult.primarySource
 *
 * http://hl7.org/fhir/_primarySource
 */
export declare const _primarySource = "http://hl7.org/fhir/_primarySource";
/**
 * _opticalActivity
 *
 * (Modified) SubstanceDefinition.structure.opticalActivity
 *
 * http://hl7.org/fhir/_opticalActivity
 */
export declare const _opticalActivity = "http://hl7.org/fhir/_opticalActivity";
/**
 * _multipleOr
 *
 * (Modified) SearchParameter.multipleOr
 *
 * http://hl7.org/fhir/_multipleOr
 */
export declare const _multipleOr = "http://hl7.org/fhir/_multipleOr";
/**
 * _specialMeasures
 *
 * (Modified) MedicinalProductDefinition.specialMeasures
 *
 * http://hl7.org/fhir/_specialMeasures
 */
export declare const _specialMeasures = "http://hl7.org/fhir/_specialMeasures";
/**
 * usageReason
 *
 * DeviceUsage.usageReason: The reason for asserting the usage status - for example forgot, lost, stolen, broken.
 *
 * http://hl7.org/fhir/usageReason
 */
export declare const usageReason = "http://hl7.org/fhir/usageReason";
/**
 * GoalTargetComponent
 *
 * GoalTargetComponent: Indicates what should be done by when.
 *
 * http://hl7.org/fhir/GoalTargetComponent
 */
export declare const GoalTargetComponent = "http://hl7.org/fhir/GoalTargetComponent";
/**
 * measure
 *
 * MeasureReport.measure: A reference to the Measure that was calculated to produce this report.
 *
 * http://hl7.org/fhir/measure
 */
export declare const measure = "http://hl7.org/fhir/measure";
/**
 * contributionType
 *
 * Citation.citedArtifact.contributorship.entry.contributionType: This element identifies the specific nature of an individual’s contribution with respect to the cited work.
 *
 * http://hl7.org/fhir/contributionType
 */
export declare const contributionType = "http://hl7.org/fhir/contributionType";
/**
 * modelNumber
 *
 * DeviceDefinition.modelNumber: The model number for the device for example as defined by the manufacturer or labeler, or other agency.
 *
 * http://hl7.org/fhir/modelNumber
 */
export declare const modelNumber = "http://hl7.org/fhir/modelNumber";
/**
 * _derivedFromUri
 *
 * (Modified) SpecimenDefinition.derivedFromUri
 *
 * http://hl7.org/fhir/_derivedFromUri
 */
export declare const _derivedFromUri = "http://hl7.org/fhir/_derivedFromUri";
/**
 * _method
 *
 * (Modified) MedicationAdministration.dosage.method
 *
 * http://hl7.org/fhir/_method
 */
export declare const _method = "http://hl7.org/fhir/_method";
/**
 * effectiveDate
 *
 * MedicinalProductDefinition.operation.effectiveDate: Date range of applicability.
 *
 * http://hl7.org/fhir/effectiveDate
 */
export declare const effectiveDate = "http://hl7.org/fhir/effectiveDate";
/**
 * _servicePeriod
 *
 * (Modified) Account.servicePeriod
 *
 * http://hl7.org/fhir/_servicePeriod
 */
export declare const _servicePeriod = "http://hl7.org/fhir/_servicePeriod";
/**
 * asNeededFor
 *
 * DeviceRequest.asNeededFor: The reason for using the device.
 *
 * http://hl7.org/fhir/asNeededFor
 */
export declare const asNeededFor = "http://hl7.org/fhir/asNeededFor";
/**
 * ExplanationOfBenefit
 *
 * This resource provides: the claim details; adjudication details from the processing of a Claim; and optionally account balance information, for informing the subscriber of the benefits provided.
 *
 * http://hl7.org/fhir/ExplanationOfBenefit
 */
export declare const ExplanationOfBenefit = "http://hl7.org/fhir/ExplanationOfBenefit";
/**
 * _add
 *
 * (Modified) VisionPrescription.lensSpecification.add
 *
 * http://hl7.org/fhir/_add
 */
export declare const _add = "http://hl7.org/fhir/_add";
/**
 * _cancelledReason
 *
 * (Modified) Invoice.cancelledReason
 *
 * http://hl7.org/fhir/_cancelledReason
 */
export declare const _cancelledReason = "http://hl7.org/fhir/_cancelledReason";
/**
 * orderMeaning
 *
 * ElementDefinition.orderMeaning: If present, indicates that the order of the repeating element has meaning and describes what that meaning is.  If absent, it means that the order of the element has no meaning.
 *
 * http://hl7.org/fhir/orderMeaning
 */
export declare const orderMeaning = "http://hl7.org/fhir/orderMeaning";
/**
 * testCase
 *
 * TestPlan.testCase: The individual test cases that are part of this plan, when they they are made explicit.
 *
 * http://hl7.org/fhir/testCase
 */
export declare const testCase = "http://hl7.org/fhir/testCase";
/**
 * net
 *
 * ExplanationOfBenefit.addItem.detail.net: The total amount claimed for the group (if a grouper) or the addItem.detail. Net = unit price * quantity * factor.
 *
 * http://hl7.org/fhir/net
 */
export declare const net = "http://hl7.org/fhir/net";
/**
 * VerificationResultAttestationComponent
 *
 * VerificationResultAttestationComponent: Information about the entity attesting to information.
 *
 * http://hl7.org/fhir/VerificationResultAttestationComponent
 */
export declare const VerificationResultAttestationComponent = "http://hl7.org/fhir/VerificationResultAttestationComponent";
/**
 * _class
 *
 * (Modified) SubstanceSourceMaterial.organism.organismGeneral.class
 *
 * http://hl7.org/fhir/_class
 */
export declare const _class = "http://hl7.org/fhir/_class";
/**
 * claim
 *
 * ExplanationOfBenefit.related.claim: Reference to a related claim.
 *
 * http://hl7.org/fhir/claim
 */
export declare const claim = "http://hl7.org/fhir/claim";
/**
 * Flag
 *
 * Prospective warnings of potential issues when providing care to the patient.
 *
 * http://hl7.org/fhir/Flag
 */
export declare const Flag = "http://hl7.org/fhir/Flag";
/**
 * _riskAdjustment
 *
 * (Modified) Measure.riskAdjustment
 *
 * http://hl7.org/fhir/_riskAdjustment
 */
export declare const _riskAdjustment = "http://hl7.org/fhir/_riskAdjustment";
/**
 * _compareToSourceExpression
 *
 * (Modified) TestScript.test.action.assert.compareToSourceExpression
 *
 * http://hl7.org/fhir/_compareToSourceExpression
 */
export declare const _compareToSourceExpression = "http://hl7.org/fhir/_compareToSourceExpression";
/**
 * _notificationEvent
 *
 * (Modified) SubscriptionStatus.notificationEvent
 *
 * http://hl7.org/fhir/_notificationEvent
 */
export declare const _notificationEvent = "http://hl7.org/fhir/_notificationEvent";
/**
 * guideline
 *
 * DeviceDefinition.guideline: Information aimed at providing directions for the usage of this model of device.
 *
 * http://hl7.org/fhir/guideline
 */
export declare const guideline = "http://hl7.org/fhir/guideline";
/**
 * amount
 *
 * ExplanationOfBenefit.total.amount: Monetary total amount associated with the category.
 *
 * http://hl7.org/fhir/amount
 */
export declare const amount = "http://hl7.org/fhir/amount";
/**
 * _dateFilter
 *
 * (Modified) DataRequirement.dateFilter
 *
 * http://hl7.org/fhir/_dateFilter
 */
export declare const _dateFilter = "http://hl7.org/fhir/_dateFilter";
/**
 * _statisticType
 *
 * (Modified) Evidence.statistic.statisticType
 *
 * http://hl7.org/fhir/_statisticType
 */
export declare const _statisticType = "http://hl7.org/fhir/_statisticType";
/**
 * genus
 *
 * SubstanceSourceMaterial.organism.genus: The genus of an organism shall be specified; refers to the Latin epithet of the genus element of the plant/animal scientific name; it is present in names for genera, species and infraspecies.
 *
 * http://hl7.org/fhir/genus
 */
export declare const genus = "http://hl7.org/fhir/genus";
/**
 * _MessageHeader
 *
 * (Modified) MessageHeader
 *
 * http://hl7.org/fhir/_MessageHeader
 */
export declare const _MessageHeader = "http://hl7.org/fhir/_MessageHeader";
/**
 * _administrationTreatment
 *
 * (Modified) MedicationKnowledge.indicationGuideline.dosingGuideline.administrationTreatment
 *
 * http://hl7.org/fhir/_administrationTreatment
 */
export declare const _administrationTreatment = "http://hl7.org/fhir/_administrationTreatment";
/**
 * _country
 *
 * (Modified) MedicinalProductDefinition.name.usage.country
 *
 * http://hl7.org/fhir/_country
 */
export declare const _country = "http://hl7.org/fhir/_country";
/**
 * insurer
 *
 * Claim.insurer: The Insurer who is target of the request.
 *
 * http://hl7.org/fhir/insurer
 */
export declare const insurer = "http://hl7.org/fhir/insurer";
/**
 * DeviceDefinitionLinkComponent
 *
 * DeviceDefinitionLinkComponent: An associated device, attached to, used with, communicating with or linking a previous or new device model to the focal device.
 *
 * http://hl7.org/fhir/DeviceDefinitionLinkComponent
 */
export declare const DeviceDefinitionLinkComponent = "http://hl7.org/fhir/DeviceDefinitionLinkComponent";
/**
 * container
 *
 * SpecimenDefinition.typeTested.container: The specimen's container.
 *
 * http://hl7.org/fhir/container
 */
export declare const container = "http://hl7.org/fhir/container";
/**
 * _params
 *
 * (Modified) TestScript.teardown.action.operation.params
 *
 * http://hl7.org/fhir/_params
 */
export declare const _params = "http://hl7.org/fhir/_params";
/**
 * Goal
 *
 * Describes the intended objective(s) for a patient, group or organization care, for example, weight loss, restoring an activity of daily living, obtaining herd immunity via immunization, meeting a process improvement objective, etc.
 *
 * http://hl7.org/fhir/Goal
 */
export declare const Goal = "http://hl7.org/fhir/Goal";
/**
 * lockedDate
 *
 * ValueSet.compose.lockedDate: The Locked Date is  the effective date that is used to determine the version of all referenced Code Systems and Value Set Definitions included in the compose that are not already tied to a specific version.
 *
 * http://hl7.org/fhir/lockedDate
 */
export declare const lockedDate = "http://hl7.org/fhir/lockedDate";
/**
 * symptomConditionEffect
 *
 * ClinicalUseDefinition.undesirableEffect.symptomConditionEffect: The situation in which the undesirable effect may manifest.
 *
 * http://hl7.org/fhir/symptomConditionEffect
 */
export declare const symptomConditionEffect = "http://hl7.org/fhir/symptomConditionEffect";
/**
 * referenceStrength
 *
 * Ingredient.substance.strength.referenceStrength: Strength expressed in terms of a reference substance. For when the ingredient strength is additionally expressed as equivalent to the strength of some other closely related substance (e.g. salt vs. base). Reference strength represents the strength (quantitative composition) of the active moiety of the active substance. There are situations when the active substance and active moiety are different, therefore both a strength and a reference strength are needed.
 *
 * http://hl7.org/fhir/referenceStrength
 */
export declare const referenceStrength = "http://hl7.org/fhir/referenceStrength";
/**
 * interval
 *
 * SampledData.interval: Amount of intervalUnits between samples, e.g. milliseconds for time-based sampling.
 *
 * http://hl7.org/fhir/interval
 */
export declare const interval = "http://hl7.org/fhir/interval";
/**
 * _compartment
 *
 * (Modified) GraphDefinition.link.compartment
 *
 * http://hl7.org/fhir/_compartment
 */
export declare const _compartment = "http://hl7.org/fhir/_compartment";
/**
 * classifier
 *
 * Citation.classification.classifier: The specific classification value.
 *
 * http://hl7.org/fhir/classifier
 */
export declare const classifier = "http://hl7.org/fhir/classifier";
/**
 * PackagedProductDefinitionPackagingPropertyComponent
 *
 * PackagedProductDefinitionPackagingComponent.PackagedProductDefinitionPackagingPropertyComponent: General characteristics of this item.
 *
 * http://hl7.org/fhir/PackagedProductDefinitionPackagingPropertyComponent
 */
export declare const PackagedProductDefinitionPackagingPropertyComponent = "http://hl7.org/fhir/PackagedProductDefinitionPackagingPropertyComponent";
/**
 * setup
 *
 * TestScript.setup: A series of required setup operations before tests are executed.
 *
 * http://hl7.org/fhir/setup
 */
export declare const setup = "http://hl7.org/fhir/setup";
/**
 * _areaOfHybridisation
 *
 * (Modified) SubstanceNucleicAcid.areaOfHybridisation
 *
 * http://hl7.org/fhir/_areaOfHybridisation
 */
export declare const _areaOfHybridisation = "http://hl7.org/fhir/_areaOfHybridisation";
/**
 * maxLength
 *
 * Questionnaire.item.item.maxLength: The maximum number of characters that are permitted in the answer to be considered a "valid" QuestionnaireResponse.
 *
 * http://hl7.org/fhir/maxLength
 */
export declare const maxLength = "http://hl7.org/fhir/maxLength";
/**
 * publisherLocation
 *
 * Citation.citedArtifact.publicationForm.publishedIn.publisherLocation: Geographic location of the publisher.
 *
 * http://hl7.org/fhir/publisherLocation
 */
export declare const publisherLocation = "http://hl7.org/fhir/publisherLocation";
/**
 * RelatedPerson
 *
 * Information about a person that is involved in a patient's health or the care for a patient, but who is not the target of healthcare, nor has a formal responsibility in the care process.
 *
 * http://hl7.org/fhir/RelatedPerson
 */
export declare const RelatedPerson = "http://hl7.org/fhir/RelatedPerson";
/**
 * _storageTempRequirements
 *
 * (Modified) BiologicallyDerivedProduct.storageTempRequirements
 *
 * http://hl7.org/fhir/_storageTempRequirements
 */
export declare const _storageTempRequirements = "http://hl7.org/fhir/_storageTempRequirements";
/**
 * _Organization
 *
 * (Modified) Organization
 *
 * http://hl7.org/fhir/_Organization
 */
export declare const _Organization = "http://hl7.org/fhir/_Organization";
/**
 * _postConditions
 *
 * (Modified) ExampleScenario.process.step.alternative.step.process.postConditions
 *
 * http://hl7.org/fhir/_postConditions
 */
export declare const _postConditions = "http://hl7.org/fhir/_postConditions";
/**
 * _DeviceDispense
 *
 * (Modified) DeviceDispense
 *
 * http://hl7.org/fhir/_DeviceDispense
 */
export declare const _DeviceDispense = "http://hl7.org/fhir/_DeviceDispense";
/**
 * state
 *
 * ResearchStudy.progressStatus.state: Label for status or state (e.g. recruitment status).
 *
 * http://hl7.org/fhir/state
 */
export declare const state = "http://hl7.org/fhir/state";
/**
 * SubstanceDefinitionSourceMaterialComponent
 *
 * SubstanceDefinitionSourceMaterialComponent: Material or taxonomic/anatomical source for the substance.
 *
 * http://hl7.org/fhir/SubstanceDefinitionSourceMaterialComponent
 */
export declare const SubstanceDefinitionSourceMaterialComponent = "http://hl7.org/fhir/SubstanceDefinitionSourceMaterialComponent";
/**
 * _aggregate
 *
 * (Modified) Account.balance.aggregate
 *
 * http://hl7.org/fhir/_aggregate
 */
export declare const _aggregate = "http://hl7.org/fhir/_aggregate";
/**
 * fluidConsistencyType
 *
 * NutritionOrder.oralDiet.fluidConsistencyType: The required consistency (e.g. honey-thick, nectar-thick, thin, thickened.) of liquids or fluids served to the patient.
 *
 * http://hl7.org/fhir/fluidConsistencyType
 */
export declare const fluidConsistencyType = "http://hl7.org/fhir/fluidConsistencyType";
/**
 * MoneyQuantity
 *
 * There SHALL be a code if there is a value and it SHALL be an expression of currency.  If system is present, it SHALL be ISO 4217 (system = "urn:iso:std:iso:4217" - currency).
 *
 * http://hl7.org/fhir/MoneyQuantity
 */
export declare const MoneyQuantity = "http://hl7.org/fhir/MoneyQuantity";
/**
 * _specificCost
 *
 * (Modified) InsurancePlan.plan.specificCost
 *
 * http://hl7.org/fhir/_specificCost
 */
export declare const _specificCost = "http://hl7.org/fhir/_specificCost";
/**
 * _organismId
 *
 * (Modified) SubstanceSourceMaterial.organismId
 *
 * http://hl7.org/fhir/_organismId
 */
export declare const _organismId = "http://hl7.org/fhir/_organismId";
/**
 * StructureMapGroupInputComponent
 *
 * StructureMapGroupComponent.StructureMapGroupInputComponent: A name assigned to an instance of data. The instance must be provided when the mapping is invoked.
 *
 * http://hl7.org/fhir/StructureMapGroupInputComponent
 */
export declare const StructureMapGroupInputComponent = "http://hl7.org/fhir/StructureMapGroupInputComponent";
/**
 * _check
 *
 * (Modified) StructureMap.group.rule.rule.source.check
 *
 * http://hl7.org/fhir/_check
 */
export declare const _check = "http://hl7.org/fhir/_check";
/**
 * _chargeItemCode
 *
 * (Modified) DeviceDefinition.chargeItem.chargeItemCode
 *
 * http://hl7.org/fhir/_chargeItemCode
 */
export declare const _chargeItemCode = "http://hl7.org/fhir/_chargeItemCode";
/**
 * ownedBy
 *
 * InsurancePlan.ownedBy: The entity that is providing  the health insurance product and underwriting the risk.  This is typically an insurance carriers, other third-party payers, or health plan sponsors comonly referred to as 'payers'.
 *
 * http://hl7.org/fhir/ownedBy
 */
export declare const ownedBy = "http://hl7.org/fhir/ownedBy";
/**
 * _participantStatus
 *
 * (Modified) AppointmentResponse.participantStatus
 *
 * http://hl7.org/fhir/_participantStatus
 */
export declare const _participantStatus = "http://hl7.org/fhir/_participantStatus";
/**
 * _baseFormulaType
 *
 * (Modified) NutritionOrder.enteralFormula.baseFormulaType
 *
 * http://hl7.org/fhir/_baseFormulaType
 */
export declare const _baseFormulaType = "http://hl7.org/fhir/_baseFormulaType";
/**
 * shelfLifeStorage
 *
 * PackagedProductDefinition.packaging.packaging.shelfLifeStorage: Shelf Life and storage information.
 *
 * http://hl7.org/fhir/shelfLifeStorage
 */
export declare const shelfLifeStorage = "http://hl7.org/fhir/shelfLifeStorage";
/**
 * authorizingPrescription
 *
 * MedicationDispense.authorizingPrescription: Indicates the medication order that is being dispensed against.
 *
 * http://hl7.org/fhir/authorizingPrescription
 */
export declare const authorizingPrescription = "http://hl7.org/fhir/authorizingPrescription";
/**
 * protein
 *
 * SubstanceDefinition.protein: Data items specific to proteins.
 *
 * http://hl7.org/fhir/protein
 */
export declare const protein = "http://hl7.org/fhir/protein";
/**
 * connectivity
 *
 * SubstanceNucleicAcid.subunit.linkage.connectivity: The entity that links the sugar residues together should also be captured for nearly all naturally occurring nucleic acid the linkage is a phosphate group. For many synthetic oligonucleotides phosphorothioate linkages are often seen. Linkage connectivity is assumed to be 3’-5’. If the linkage is either 3’-3’ or 5’-5’ this should be specified.
 *
 * http://hl7.org/fhir/connectivity
 */
export declare const connectivity = "http://hl7.org/fhir/connectivity";
/**
 * information
 *
 * CoverageEligibilityRequest.supportingInfo.information: Additional data or information such as resources, documents, images etc. including references to the data or the actual inclusion of the data.
 *
 * http://hl7.org/fhir/information
 */
export declare const information = "http://hl7.org/fhir/information";
/**
 * DeviceDefinitionVersionComponent
 *
 * DeviceDefinitionVersionComponent: The version of the device or software.
 *
 * http://hl7.org/fhir/DeviceDefinitionVersionComponent
 */
export declare const DeviceDefinitionVersionComponent = "http://hl7.org/fhir/DeviceDefinitionVersionComponent";
/**
 * AdverseEvent
 *
 * An event (i.e. any change to current patient status) that may be related to unintended effects on a patient or research participant. The unintended effects may require additional monitoring, treatment, hospitalization, or may result in death. The AdverseEvent resource also extends to potential or avoided events that could have had such effects. There are two major domains where the AdverseEvent resource is expected to be used. One is in clinical care reported adverse events and the other is in reporting adverse events in clinical  research trial management.  Adverse events can be reported by healthcare providers, patients, caregivers or by medical products manufacturers.  Given the differences between these two concepts, we recommend consulting the domain specific implementation guides when implementing the AdverseEvent Resource. The implementation guides include specific extensions, value sets and constraints.
 *
 * http://hl7.org/fhir/AdverseEvent
 */
export declare const AdverseEvent = "http://hl7.org/fhir/AdverseEvent";
/**
 * _originRelationshipType
 *
 * (Modified) BiologicallyDerivedProductDispense.originRelationshipType
 *
 * http://hl7.org/fhir/_originRelationshipType
 */
export declare const _originRelationshipType = "http://hl7.org/fhir/_originRelationshipType";
/**
 * definitionExpression
 *
 * EvidenceVariable.characteristic.definitionByCombination.characteristic.definitionExpression: Defines the characteristic using Expression.
 *
 * http://hl7.org/fhir/definitionExpression
 */
export declare const definitionExpression = "http://hl7.org/fhir/definitionExpression";
/**
 * ServiceRequestOrderDetailParameterComponent
 *
 * ServiceRequestOrderDetailComponent.ServiceRequestOrderDetailParameterComponent: The parameter details for the service being requested.
 *
 * http://hl7.org/fhir/ServiceRequestOrderDetailParameterComponent
 */
export declare const ServiceRequestOrderDetailParameterComponent = "http://hl7.org/fhir/ServiceRequestOrderDetailParameterComponent";
/**
 * TestPlan
 *
 * A plan for executing testing on an artifact or specifications
 *
 * http://hl7.org/fhir/TestPlan
 */
export declare const TestPlan = "http://hl7.org/fhir/TestPlan";
/**
 * requestProvider
 *
 * EnrollmentResponse.requestProvider: The practitioner who is responsible for the services rendered to the patient.
 *
 * http://hl7.org/fhir/requestProvider
 */
export declare const requestProvider = "http://hl7.org/fhir/requestProvider";
/**
 * _formatted
 *
 * (Modified) MolecularSequence.formatted
 *
 * http://hl7.org/fhir/_formatted
 */
export declare const _formatted = "http://hl7.org/fhir/_formatted";
/**
 * NutritionProduct
 *
 * A food or supplement that is consumed by patients.
 *
 * http://hl7.org/fhir/NutritionProduct
 */
export declare const NutritionProduct = "http://hl7.org/fhir/NutritionProduct";
/**
 * ActorDefinition
 *
 * The ActorDefinition resource is used to describe an actor - a human or an application that plays a role in data exchange, and that may have obligations associated with the role the actor plays.
 *
 * http://hl7.org/fhir/ActorDefinition
 */
export declare const ActorDefinition = "http://hl7.org/fhir/ActorDefinition";
/**
 * RegulatedAuthorization
 *
 * Regulatory approval, clearance or licencing related to a regulated product, treatment, facility or activity that is cited in a guidance, regulation, rule or legislative act. An example is Market Authorization relating to a Medicinal Product.
 *
 * http://hl7.org/fhir/RegulatedAuthorization
 */
export declare const RegulatedAuthorization = "http://hl7.org/fhir/RegulatedAuthorization";
/**
 * _facility
 *
 * (Modified) ExplanationOfBenefit.facility
 *
 * http://hl7.org/fhir/_facility
 */
export declare const _facility = "http://hl7.org/fhir/_facility";
/**
 * sourceDocument
 *
 * SubstanceDefinition.structure.sourceDocument: The source of information about the structure.
 *
 * http://hl7.org/fhir/sourceDocument
 */
export declare const sourceDocument = "http://hl7.org/fhir/sourceDocument";
/**
 * _morphology
 *
 * (Modified) BodyStructure.morphology
 *
 * http://hl7.org/fhir/_morphology
 */
export declare const _morphology = "http://hl7.org/fhir/_morphology";
/**
 * _kind
 *
 * (Modified) Coverage.kind
 *
 * http://hl7.org/fhir/_kind
 */
export declare const _kind = "http://hl7.org/fhir/_kind";
/**
 * color
 *
 * VisionPrescription.lensSpecification.color: Special color or pattern.
 *
 * http://hl7.org/fhir/color
 */
export declare const color = "http://hl7.org/fhir/color";
/**
 * _bounds
 *
 * (Modified) Timing.repeat.bounds
 *
 * http://hl7.org/fhir/_bounds
 */
export declare const _bounds = "http://hl7.org/fhir/_bounds";
/**
 * snapshot
 *
 * StructureDefinition.snapshot: A snapshot view is expressed in a standalone form that can be used and interpreted without considering the base StructureDefinition.
 *
 * http://hl7.org/fhir/snapshot
 */
export declare const snapshot = "http://hl7.org/fhir/snapshot";
/**
 * SpecimenContainerComponent
 *
 * SpecimenContainerComponent: The container holding the specimen.  The recursive nature of containers; i.e. blood in tube in tray in rack is not addressed here.
 *
 * http://hl7.org/fhir/SpecimenContainerComponent
 */
export declare const SpecimenContainerComponent = "http://hl7.org/fhir/SpecimenContainerComponent";
/**
 * unsignedInt
 *
 * An integer with a value that is not negative (e.g. >= 0)
 *
 * http://hl7.org/fhir/unsignedInt
 */
export declare const unsignedInt = "http://hl7.org/fhir/unsignedInt";
/**
 * MedicationKnowledgeMedicineClassificationComponent
 *
 * MedicationKnowledgeMedicineClassificationComponent: Categorization of the medication within a formulary or classification system.
 *
 * http://hl7.org/fhir/MedicationKnowledgeMedicineClassificationComponent
 */
export declare const MedicationKnowledgeMedicineClassificationComponent = "http://hl7.org/fhir/MedicationKnowledgeMedicineClassificationComponent";
/**
 * ImmunizationProgramEligibilityComponent
 *
 * ImmunizationProgramEligibilityComponent: Indicates a patient's eligibility for a funding program.
 *
 * http://hl7.org/fhir/ImmunizationProgramEligibilityComponent
 */
export declare const ImmunizationProgramEligibilityComponent = "http://hl7.org/fhir/ImmunizationProgramEligibilityComponent";
/**
 * _dose
 *
 * (Modified) MedicationAdministration.dosage.dose
 *
 * http://hl7.org/fhir/_dose
 */
export declare const _dose = "http://hl7.org/fhir/_dose";
/**
 * useBy
 *
 * NutritionProduct.instance.useBy: The time after which the product is no longer expected to be in proper condition, or its use is not advised or not allowed.
 *
 * http://hl7.org/fhir/useBy
 */
export declare const useBy = "http://hl7.org/fhir/useBy";
/**
 * _start
 *
 * (Modified) Period.start
 *
 * http://hl7.org/fhir/_start
 */
export declare const _start = "http://hl7.org/fhir/_start";
/**
 * _import
 *
 * (Modified) StructureMap.import
 *
 * http://hl7.org/fhir/_import
 */
export declare const _import = "http://hl7.org/fhir/_import";
/**
 * TaskPerformerComponent
 *
 * TaskPerformerComponent: The entity who performed the requested task.
 *
 * http://hl7.org/fhir/TaskPerformerComponent
 */
export declare const TaskPerformerComponent = "http://hl7.org/fhir/TaskPerformerComponent";
/**
 * grantor
 *
 * Consent.grantor: The entity responsible for granting the rights listed in a Consent Directive.
 *
 * http://hl7.org/fhir/grantor
 */
export declare const grantor = "http://hl7.org/fhir/grantor";
/**
 * _purpose
 *
 * (Modified) CanonicalResource.purpose
 *
 * http://hl7.org/fhir/_purpose
 */
export declare const _purpose = "http://hl7.org/fhir/_purpose";
/**
 * benefit
 *
 * InsurancePlan.plan.specificCost.benefit: List of the specific benefits under this category of benefit.
 *
 * http://hl7.org/fhir/benefit
 */
export declare const benefit = "http://hl7.org/fhir/benefit";
/**
 * contributorship
 *
 * Citation.citedArtifact.contributorship: This element is used to list authors and other contributors, their contact information, specific contributions, and summary statements.
 *
 * http://hl7.org/fhir/contributorship
 */
export declare const contributorship = "http://hl7.org/fhir/contributorship";
/**
 * PlanDefinitionActionDynamicValueComponent
 *
 * PlanDefinitionActionComponent.PlanDefinitionActionDynamicValueComponent: Customizations that should be applied to the statically defined resource. For example, if the dosage of a medication must be computed based on the patient's weight, a customization would be used to specify an expression that calculated the weight, and the path on the resource that would contain the result.
 *
 * http://hl7.org/fhir/PlanDefinitionActionDynamicValueComponent
 */
export declare const PlanDefinitionActionDynamicValueComponent = "http://hl7.org/fhir/PlanDefinitionActionDynamicValueComponent";
/**
 * ImagingStudySeriesComponent
 *
 * ImagingStudySeriesComponent: Each study has one or more series of images or other content.
 *
 * http://hl7.org/fhir/ImagingStudySeriesComponent
 */
export declare const ImagingStudySeriesComponent = "http://hl7.org/fhir/ImagingStudySeriesComponent";
/**
 * programStatus
 *
 * Immunization.programEligibility.programStatus: Indicates the patient's eligility status for for a specific payment program.
 *
 * http://hl7.org/fhir/programStatus
 */
export declare const programStatus = "http://hl7.org/fhir/programStatus";
/**
 * _evidence
 *
 * (Modified) Permission.justification.evidence
 *
 * http://hl7.org/fhir/_evidence
 */
export declare const _evidence = "http://hl7.org/fhir/_evidence";
/**
 * ClinicalUseDefinitionInteractionInteractantComponent
 *
 * ClinicalUseDefinitionInteractionComponent.ClinicalUseDefinitionInteractionInteractantComponent: The specific medication, product, food, substance etc. or laboratory test that interacts.
 *
 * http://hl7.org/fhir/ClinicalUseDefinitionInteractionInteractantComponent
 */
export declare const ClinicalUseDefinitionInteractionInteractantComponent = "http://hl7.org/fhir/ClinicalUseDefinitionInteractionInteractantComponent";
/**
 * _highNumerator
 *
 * (Modified) RatioRange.highNumerator
 *
 * http://hl7.org/fhir/_highNumerator
 */
export declare const _highNumerator = "http://hl7.org/fhir/_highNumerator";
/**
 * ChargeItemDefinitionPropertyGroupComponent
 *
 * ChargeItemDefinitionPropertyGroupComponent: Group of properties which are applicable under the same conditions. If no applicability rules are established for the group, then all properties always apply.
 *
 * http://hl7.org/fhir/ChargeItemDefinitionPropertyGroupComponent
 */
export declare const ChargeItemDefinitionPropertyGroupComponent = "http://hl7.org/fhir/ChargeItemDefinitionPropertyGroupComponent";
/**
 * boolean
 *
 * Value of "true" or "false"
 *
 * http://hl7.org/fhir/boolean
 */
export declare const boolean = "http://hl7.org/fhir/boolean";
/**
 * PackagedProductDefinitionProperty
 *
 * Allows the key features to be recorded, such as "hospital pack", "nurse prescribable", "calendar pack".
 *
 * http://hl7.org/fhir/PackagedProductDefinitionProperty
 */
export declare const PackagedProductDefinitionProperty = "http://hl7.org/fhir/PackagedProductDefinitionProperty";
/**
 * _Group
 *
 * (Modified) Group
 *
 * http://hl7.org/fhir/_Group
 */
export declare const _Group = "http://hl7.org/fhir/_Group";
/**
 * _media
 *
 * (Modified) DiagnosticReport.media
 *
 * http://hl7.org/fhir/_media
 */
export declare const _media = "http://hl7.org/fhir/_media";
/**
 * hasStage
 *
 * ConditionDefinition.hasStage: Whether stage is appropriate to collect for this condition.
 *
 * http://hl7.org/fhir/hasStage
 */
export declare const hasStage = "http://hl7.org/fhir/hasStage";
/**
 * TestReportSetupActionAssertRequirementComponent
 *
 * TestReportTestComponent.TestActionAssert.TestReportSetupActionAssertRequirementComponent: Links or references providing traceability to the testing requirements for this assert.
 *
 * http://hl7.org/fhir/TestReportSetupActionAssertRequirementComponent
 */
export declare const TestReportSetupActionAssertRequirementComponent = "http://hl7.org/fhir/TestReportSetupActionAssertRequirementComponent";
/**
 * _onBehalfOf
 *
 * (Modified) VerificationResult.attestation.onBehalfOf
 *
 * http://hl7.org/fhir/_onBehalfOf
 */
export declare const _onBehalfOf = "http://hl7.org/fhir/_onBehalfOf";
/**
 * SubstanceReferenceInformationGeneElementComponent
 *
 * SubstanceReferenceInformationGeneElementComponent: Todo.
 *
 * http://hl7.org/fhir/SubstanceReferenceInformationGeneElementComponent
 */
export declare const SubstanceReferenceInformationGeneElementComponent = "http://hl7.org/fhir/SubstanceReferenceInformationGeneElementComponent";
/**
 * maxCount
 *
 * Subscription.maxCount: If present, the maximum number of events that will be included in a notification bundle. Note that this is not a strict limit on the number of entries in a bundle, as dependent resources can be included.
 *
 * http://hl7.org/fhir/maxCount
 */
export declare const maxCount = "http://hl7.org/fhir/maxCount";
/**
 * enableWhen
 *
 * Questionnaire.item.item.enableWhen: A constraint indicating that this item should only be enabled (displayed/allow answers to be captured) when the specified condition is true.
 *
 * http://hl7.org/fhir/enableWhen
 */
export declare const enableWhen = "http://hl7.org/fhir/enableWhen";
/**
 * regulator
 *
 * RegulatedAuthorization.regulator: The regulatory authority or authorizing body granting the authorization. For example, European Medicines Agency (EMA), Food and Drug Administration (FDA), Health Canada (HC), etc.
 *
 * http://hl7.org/fhir/regulator
 */
export declare const regulator = "http://hl7.org/fhir/regulator";
/**
 * _medicineClassification
 *
 * (Modified) MedicationKnowledge.medicineClassification
 *
 * http://hl7.org/fhir/_medicineClassification
 */
export declare const _medicineClassification = "http://hl7.org/fhir/_medicineClassification";
/**
 * imageRegion3D
 *
 * ImagingSelection.instance.imageRegion3D: Each imaging selection might includes a 3D image region, specified by a region type and a set of 3D coordinates.
 *
 * http://hl7.org/fhir/imageRegion3D
 */
export declare const imageRegion3D = "http://hl7.org/fhir/imageRegion3D";
/**
 * _source
 *
 * (Modified) SubstanceDefinition.name.translation.source
 *
 * http://hl7.org/fhir/_source
 */
export declare const _source = "http://hl7.org/fhir/_source";
/**
 * _hoursOfOperation
 *
 * (Modified) Location.hoursOfOperation
 *
 * http://hl7.org/fhir/_hoursOfOperation
 */
export declare const _hoursOfOperation = "http://hl7.org/fhir/_hoursOfOperation";
/**
 * admission
 *
 * Encounter.admission: Details about the stay during which a healthcare service is provided.

This does not describe the event of admitting the patient, but rather any information that is relevant from the time of admittance until the time of discharge.
 *
 * http://hl7.org/fhir/admission
 */
export declare const admission = "http://hl7.org/fhir/admission";
/**
 * extension
 *
 * DomainResource.extension: May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and managable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.
 *
 * http://hl7.org/fhir/extension
 */
export declare const extension = "http://hl7.org/fhir/extension";
/**
 * _reAdmission
 *
 * (Modified) Encounter.admission.reAdmission
 *
 * http://hl7.org/fhir/_reAdmission
 */
export declare const _reAdmission = "http://hl7.org/fhir/_reAdmission";
/**
 * integer64
 *
 * A very large whole number
 *
 * http://hl7.org/fhir/integer64
 */
export declare const integer64 = "http://hl7.org/fhir/integer64";
/**
 * _Task
 *
 * (Modified) Task
 *
 * http://hl7.org/fhir/_Task
 */
export declare const _Task = "http://hl7.org/fhir/_Task";
/**
 * HealthcareService
 *
 * The details of a healthcare service available at a location or in a catalog.  In the case where there is a hierarchy of services (for example, Lab -> Pathology -> Wound Cultures), this can be represented using a set of linked HealthcareServices.
 *
 * http://hl7.org/fhir/HealthcareService
 */
export declare const HealthcareService = "http://hl7.org/fhir/HealthcareService";
/**
 * _Appointment
 *
 * (Modified) Appointment
 *
 * http://hl7.org/fhir/_Appointment
 */
export declare const _Appointment = "http://hl7.org/fhir/_Appointment";
/**
 * _crossReference
 *
 * (Modified) MedicinalProductDefinition.crossReference
 *
 * http://hl7.org/fhir/_crossReference
 */
export declare const _crossReference = "http://hl7.org/fhir/_crossReference";
/**
 * _hasPart
 *
 * (Modified) DeviceDefinition.hasPart
 *
 * http://hl7.org/fhir/_hasPart
 */
export declare const _hasPart = "http://hl7.org/fhir/_hasPart";
/**
 * _executionPeriod
 *
 * (Modified) Task.executionPeriod
 *
 * http://hl7.org/fhir/_executionPeriod
 */
export declare const _executionPeriod = "http://hl7.org/fhir/_executionPeriod";
/**
 * Expression
 *
 * A expression that is evaluated in a specified context and returns a value. The context of use of the expression must specify the context in which the expression is evaluated, and how the result of the expression is used.
 *
 * http://hl7.org/fhir/Expression
 */
export declare const Expression = "http://hl7.org/fhir/Expression";
/**
 * Class
 *
 * Coverage.Class: A suite of underwriter specific classifiers.
 *
 * http://hl7.org/fhir/Class
 */
export declare const Class = "http://hl7.org/fhir/Class";
/**
 * _operation
 *
 * (Modified) TestScript.test.action.operation
 *
 * http://hl7.org/fhir/_operation
 */
export declare const _operation = "http://hl7.org/fhir/_operation";
/**
 * _adjustmentReason
 *
 * (Modified) ExplanationOfBenefit.payment.adjustmentReason
 *
 * http://hl7.org/fhir/_adjustmentReason
 */
export declare const _adjustmentReason = "http://hl7.org/fhir/_adjustmentReason";
/**
 * notConsumed
 *
 * NutritionIntake.consumedItem.notConsumed: Indicator when a patient is in a setting where it is helpful to know if food was not consumed, such as it was refused, held (as in tube feedings), or otherwise not provided. If a consumption is being recorded from an app, such as MyFitnessPal, this indicator will likely not be used.
 *
 * http://hl7.org/fhir/notConsumed
 */
export declare const notConsumed = "http://hl7.org/fhir/notConsumed";
/**
 * relativePath
 *
 * ImplementationGuide.manifest.resource.relativePath: The relative path for primary page for this resource within the IG.
 *
 * http://hl7.org/fhir/relativePath
 */
export declare const relativePath = "http://hl7.org/fhir/relativePath";
/**
 * ImplementationGuideDefinitionComponent
 *
 * ImplementationGuideDefinitionComponent: The information needed by an IG publisher tool to publish the whole implementation guide.
 *
 * http://hl7.org/fhir/ImplementationGuideDefinitionComponent
 */
export declare const ImplementationGuideDefinitionComponent = "http://hl7.org/fhir/ImplementationGuideDefinitionComponent";
/**
 * geneSequenceOrigin
 *
 * SubstanceReferenceInformation.gene.geneSequenceOrigin: Todo.
 *
 * http://hl7.org/fhir/geneSequenceOrigin
 */
export declare const geneSequenceOrigin = "http://hl7.org/fhir/geneSequenceOrigin";
/**
 * level
 *
 * Evidence.statistic.modelCharacteristic.attributeEstimate.level: Use 95 for a 95% confidence interval.
 *
 * http://hl7.org/fhir/level
 */
export declare const level = "http://hl7.org/fhir/level";
/**
 * TestReportTestComponent
 *
 * TestReportTestComponent: A test executed from the test script.
 *
 * http://hl7.org/fhir/TestReportTestComponent
 */
export declare const TestReportTestComponent = "http://hl7.org/fhir/TestReportTestComponent";
/**
 * doseNumber
 *
 * ImmunizationRecommendation.recommendation.doseNumber: Nominal position of the recommended dose in a series as determined by the evaluation and forecasting process (e.g. dose 2 is the next recommended dose).
 *
 * http://hl7.org/fhir/doseNumber
 */
export declare const doseNumber = "http://hl7.org/fhir/doseNumber";
/**
 * ParametersParameterComponentParameterParameter
 *
 * A named part of a multi-part parameter.
 *
 * http://hl7.org/fhir/ParametersParameterComponentParameterParameter
 */
export declare const ParametersParameterComponentParameterParameter = "http://hl7.org/fhir/ParametersParameterComponentParameterParameter";
/**
 * age
 *
 * FamilyMemberHistory.age
 *
 * http://hl7.org/fhir/age
 */
export declare const age = "http://hl7.org/fhir/age";
/**
 * _payload
 *
 * (Modified) Endpoint.payload
 *
 * http://hl7.org/fhir/_payload
 */
export declare const _payload = "http://hl7.org/fhir/_payload";
/**
 * entityRelatedness
 *
 * AdverseEvent.suspectEntity.causality.entityRelatedness: The result of the assessment regarding the relatedness of the suspected entity to the event.
 *
 * http://hl7.org/fhir/entityRelatedness
 */
export declare const entityRelatedness = "http://hl7.org/fhir/entityRelatedness";
/**
 * startParam
 *
 * CompartmentDefinition.resource.startParam: Search Parameter for mapping requests made with $everything.start (e.g. on [Patient.$everything](patient-operation-everything.html)).
 *
 * http://hl7.org/fhir/startParam
 */
export declare const startParam = "http://hl7.org/fhir/startParam";
/**
 * _intraspecificDescription
 *
 * (Modified) SubstanceSourceMaterial.organism.intraspecificDescription
 *
 * http://hl7.org/fhir/_intraspecificDescription
 */
export declare const _intraspecificDescription = "http://hl7.org/fhir/_intraspecificDescription";
/**
 * _clinicalStatus
 *
 * (Modified) Condition.clinicalStatus
 *
 * http://hl7.org/fhir/_clinicalStatus
 */
export declare const _clinicalStatus = "http://hl7.org/fhir/_clinicalStatus";
/**
 * _compositeScoring
 *
 * (Modified) Measure.compositeScoring
 *
 * http://hl7.org/fhir/_compositeScoring
 */
export declare const _compositeScoring = "http://hl7.org/fhir/_compositeScoring";
/**
 * jurisdiction
 *
 * SubstanceDefinition.name.synonym.jurisdiction: The jurisdiction where this name applies.
 *
 * http://hl7.org/fhir/jurisdiction
 */
export declare const jurisdiction = "http://hl7.org/fhir/jurisdiction";
/**
 * Exemption
 *
 * Coverage.CostToBeneficiary.Exemption: A suite of codes indicating exceptions or reductions to patient costs and their effective periods.
 *
 * http://hl7.org/fhir/Exemption
 */
export declare const Exemption = "http://hl7.org/fhir/Exemption";
/**
 * _requestHeader
 *
 * (Modified) TestScript.teardown.action.operation.requestHeader
 *
 * http://hl7.org/fhir/_requestHeader
 */
export declare const _requestHeader = "http://hl7.org/fhir/_requestHeader";
/**
 * _certainty
 *
 * (Modified) Evidence.certainty
 *
 * http://hl7.org/fhir/_certainty
 */
export declare const _certainty = "http://hl7.org/fhir/_certainty";
/**
 * connectionType
 *
 * Endpoint.connectionType: A coded value that represents the technical details of the usage of this endpoint, such as what WSDLs should be used in what way. (e.g. XDS.b/DICOM/cds-hook).
 *
 * http://hl7.org/fhir/connectionType
 */
export declare const connectionType = "http://hl7.org/fhir/connectionType";
/**
 * _groupingBehavior
 *
 * (Modified) RequestOrchestration.action.action.groupingBehavior
 *
 * http://hl7.org/fhir/_groupingBehavior
 */
export declare const _groupingBehavior = "http://hl7.org/fhir/_groupingBehavior";
/**
 * _translations
 *
 * (Modified) TerminologyCapabilities.validateCode.translations
 *
 * http://hl7.org/fhir/_translations
 */
export declare const _translations = "http://hl7.org/fhir/_translations";
/**
 * photo
 *
 * Person.photo: An image that can be displayed as a thumbnail of the person to enhance the identification of the individual.
 *
 * http://hl7.org/fhir/photo
 */
export declare const photo = "http://hl7.org/fhir/photo";
/**
 * multipleAnd
 *
 * SearchParameter.multipleAnd: Whether multiple parameters are allowed - e.g. more than one parameter with the same name. The search matches if all the parameters match.
 *
 * http://hl7.org/fhir/multipleAnd
 */
export declare const multipleAnd = "http://hl7.org/fhir/multipleAnd";
/**
 * _gender
 *
 * (Modified) RelatedPerson.gender
 *
 * http://hl7.org/fhir/_gender
 */
export declare const _gender = "http://hl7.org/fhir/_gender";
/**
 * _coding
 *
 * (Modified) CodeableConcept.coding
 *
 * http://hl7.org/fhir/_coding
 */
export declare const _coding = "http://hl7.org/fhir/_coding";
/**
 * _system
 *
 * (Modified) Coding.system
 *
 * http://hl7.org/fhir/_system
 */
export declare const _system = "http://hl7.org/fhir/_system";
/**
 * _Slot
 *
 * (Modified) Slot
 *
 * http://hl7.org/fhir/_Slot
 */
export declare const _Slot = "http://hl7.org/fhir/_Slot";
/**
 * freeToShare
 *
 * ArtifactAssessment.content.component.freeToShare: Acceptable to publicly share the comment, classifier or rating.
 *
 * http://hl7.org/fhir/freeToShare
 */
export declare const freeToShare = "http://hl7.org/fhir/freeToShare";
/**
 * ElementDefinitionMappingComponent
 *
 * ElementDefinitionMappingComponent: Identifies a concept from an external specification that roughly corresponds to this element.
 *
 * http://hl7.org/fhir/ElementDefinitionMappingComponent
 */
export declare const ElementDefinitionMappingComponent = "http://hl7.org/fhir/ElementDefinitionMappingComponent";
/**
 * copackagedIndicator
 *
 * PackagedProductDefinition.copackagedIndicator: Identifies if the package contains different items, such as when a drug product is supplied with another item e.g. a diluent or adjuvant.
 *
 * http://hl7.org/fhir/copackagedIndicator
 */
export declare const copackagedIndicator = "http://hl7.org/fhir/copackagedIndicator";
/**
 * precheckBehavior
 *
 * RequestOrchestration.action.action.precheckBehavior: Defines whether the action should usually be preselected.
 *
 * http://hl7.org/fhir/precheckBehavior
 */
export declare const precheckBehavior = "http://hl7.org/fhir/precheckBehavior";
/**
 * map
 *
 * ElementDefinition.mapping.map: Expresses what part of the target specification corresponds to this element.
 *
 * http://hl7.org/fhir/map
 */
export declare const map = "http://hl7.org/fhir/map";
/**
 * additionalInfo
 *
 * VirtualServiceDetail.additionalInfo: Address to see alternative connection details.
 *
 * http://hl7.org/fhir/additionalInfo
 */
export declare const additionalInfo = "http://hl7.org/fhir/additionalInfo";
/**
 * preConditions
 *
 * ExampleScenario.process.step.alternative.step.process.preConditions: Description of the initial state of the actors, environment and data before the process starts.
 *
 * http://hl7.org/fhir/preConditions
 */
export declare const preConditions = "http://hl7.org/fhir/preConditions";
/**
 * numberOfSubunits
 *
 * SubstanceProtein.numberOfSubunits: Number of linear sequences of amino acids linked through peptide bonds. The number of subunits constituting the SubstanceProtein shall be described. It is possible that the number of subunits can be variable.
 *
 * http://hl7.org/fhir/numberOfSubunits
 */
export declare const numberOfSubunits = "http://hl7.org/fhir/numberOfSubunits";
/**
 * numberOfEvents
 *
 * Evidence.statistic.numberOfEvents: The number of events associated with the statistic, where the unit of analysis is different from numberAffected, sampleSize.knownDataCount and sampleSize.numberOfParticipants.
 *
 * http://hl7.org/fhir/numberOfEvents
 */
export declare const numberOfEvents = "http://hl7.org/fhir/numberOfEvents";
/**
 * _sender
 *
 * (Modified) MessageHeader.sender
 *
 * http://hl7.org/fhir/_sender
 */
export declare const _sender = "http://hl7.org/fhir/_sender";
/**
 * _validCodedValueSet
 *
 * (Modified) ObservationDefinition.component.qualifiedValue.validCodedValueSet
 *
 * http://hl7.org/fhir/_validCodedValueSet
 */
export declare const _validCodedValueSet = "http://hl7.org/fhir/_validCodedValueSet";
/**
 * _referenceInformation
 *
 * (Modified) SubstanceDefinition.referenceInformation
 *
 * http://hl7.org/fhir/_referenceInformation
 */
export declare const _referenceInformation = "http://hl7.org/fhir/_referenceInformation";
/**
 * longitude
 *
 * Location.position.longitude: Longitude. The value domain and the interpretation are the same as for the text of the longitude element in KML (see notes on Location main page).
 *
 * http://hl7.org/fhir/longitude
 */
export declare const longitude = "http://hl7.org/fhir/longitude";
/**
 * _contentDerivative
 *
 * (Modified) Contract.contentDerivative
 *
 * http://hl7.org/fhir/_contentDerivative
 */
export declare const _contentDerivative = "http://hl7.org/fhir/_contentDerivative";
/**
 * _reportedDateTime
 *
 * (Modified) InventoryReport.reportedDateTime
 *
 * http://hl7.org/fhir/_reportedDateTime
 */
export declare const _reportedDateTime = "http://hl7.org/fhir/_reportedDateTime";
/**
 * Primitive
 *
 * Types with only a value and no additional elements as children
 *
 * http://hl7.org/fhir/Primitive
 */
export declare const Primitive = "http://hl7.org/fhir/Primitive";
/**
 * _processingMode
 *
 * (Modified) SearchParameter.processingMode
 *
 * http://hl7.org/fhir/_processingMode
 */
export declare const _processingMode = "http://hl7.org/fhir/_processingMode";
/**
 * _composition
 *
 * (Modified) DiagnosticReport.composition
 *
 * http://hl7.org/fhir/_composition
 */
export declare const _composition = "http://hl7.org/fhir/_composition";
/**
 * _width
 *
 * (Modified) Attachment.width
 *
 * http://hl7.org/fhir/_width
 */
export declare const _width = "http://hl7.org/fhir/_width";
/**
 * _valueAlternatives
 *
 * (Modified) ElementDefinition.valueAlternatives
 *
 * http://hl7.org/fhir/_valueAlternatives
 */
export declare const _valueAlternatives = "http://hl7.org/fhir/_valueAlternatives";
/**
 * hint
 *
 * TestScript.variable.hint: Displayable text string with hint help information to the user when entering a default value.
 *
 * http://hl7.org/fhir/hint
 */
export declare const hint = "http://hl7.org/fhir/hint";
/**
 * license
 *
 * ImplementationGuide.license: The license that applies to this Implementation Guide, using an SPDX license code, or 'not-open-source'.
 *
 * http://hl7.org/fhir/license
 */
export declare const license = "http://hl7.org/fhir/license";
/**
 * created
 *
 * ExplanationOfBenefit.created: The date this resource was created.
 *
 * http://hl7.org/fhir/created
 */
export declare const created = "http://hl7.org/fhir/created";
/**
 * expectedInResearchStudy
 *
 * AdverseEvent.expectedInResearchStudy: Considered likely or probable or anticipated in the research study.  Whether the reported event matches any of the outcomes for the patient that are considered by the study as known or likely.
 *
 * http://hl7.org/fhir/expectedInResearchStudy
 */
export declare const expectedInResearchStudy = "http://hl7.org/fhir/expectedInResearchStudy";
/**
 * originalPrescription
 *
 * ExplanationOfBenefit.originalPrescription: Original prescription which has been superseded by this prescription to support the dispensing of pharmacy services, medications or products.
 *
 * http://hl7.org/fhir/originalPrescription
 */
export declare const originalPrescription = "http://hl7.org/fhir/originalPrescription";
/**
 * scoring
 *
 * MeasureReport.scoring: Indicates how the calculation is performed for the measure, including proportion, ratio, continuous-variable, and cohort. The value set is extensible, allowing additional measure scoring types to be represented. It is expected to be the same as the scoring element on the referenced Measure.
 *
 * http://hl7.org/fhir/scoring
 */
export declare const scoring = "http://hl7.org/fhir/scoring";
/**
 * ClinicalUseDefinitionInteractionComponent
 *
 * ClinicalUseDefinitionInteractionComponent: Specifics for when this is an interaction.
 *
 * http://hl7.org/fhir/ClinicalUseDefinitionInteractionComponent
 */
export declare const ClinicalUseDefinitionInteractionComponent = "http://hl7.org/fhir/ClinicalUseDefinitionInteractionComponent";
/**
 * PlanDefinitionActorComponent
 *
 * PlanDefinitionActorComponent: Actors represent the individuals or groups involved in the execution of the defined set of activities.
 *
 * http://hl7.org/fhir/PlanDefinitionActorComponent
 */
export declare const PlanDefinitionActorComponent = "http://hl7.org/fhir/PlanDefinitionActorComponent";
/**
 * subjectStatus
 *
 * EncounterHistory.subjectStatus: The subjectStatus value can be used to track the patient's status within the encounter. It details whether the patient has arrived or departed, has been triaged or is currently in a waiting status.
 *
 * http://hl7.org/fhir/subjectStatus
 */
export declare const subjectStatus = "http://hl7.org/fhir/subjectStatus";
/**
 * _qualitativeRisk
 *
 * (Modified) RiskAssessment.prediction.qualitativeRisk
 *
 * http://hl7.org/fhir/_qualitativeRisk
 */
export declare const _qualitativeRisk = "http://hl7.org/fhir/_qualitativeRisk";
/**
 * _header
 *
 * (Modified) Endpoint.header
 *
 * http://hl7.org/fhir/_header
 */
export declare const _header = "http://hl7.org/fhir/_header";
/**
 * recurrenceId
 *
 * AppointmentResponse.recurrenceId: The recurrence ID (sequence number) of the specific appointment when responding to a recurring request.
 *
 * http://hl7.org/fhir/recurrenceId
 */
export declare const recurrenceId = "http://hl7.org/fhir/recurrenceId";
/**
 * _author
 *
 * (Modified) EvidenceReport.section.section.author
 *
 * http://hl7.org/fhir/_author
 */
export declare const _author = "http://hl7.org/fhir/_author";
/**
 * responsibleOrganization
 *
 * InventoryItem.responsibleOrganization: Organization(s) responsible for the product.
 *
 * http://hl7.org/fhir/responsibleOrganization
 */
export declare const responsibleOrganization = "http://hl7.org/fhir/responsibleOrganization";
/**
 * TriggerDefinition
 *
 * A description of a triggering event. Triggering events can be named events, data events, or periodic, as determined by the type element.
 *
 * http://hl7.org/fhir/TriggerDefinition
 */
export declare const TriggerDefinition = "http://hl7.org/fhir/TriggerDefinition";
/**
 * _BackboneElement
 *
 * http://hl7.org/fhir/_BackboneElement
 */
export declare const _BackboneElement = "http://hl7.org/fhir/_BackboneElement";
/**
 * _offeredIn
 *
 * (Modified) HealthcareService.offeredIn
 *
 * http://hl7.org/fhir/_offeredIn
 */
export declare const _offeredIn = "http://hl7.org/fhir/_offeredIn";
/**
 * _accessionNumber
 *
 * (Modified) Citation.citedArtifact.publicationForm.accessionNumber
 *
 * http://hl7.org/fhir/_accessionNumber
 */
export declare const _accessionNumber = "http://hl7.org/fhir/_accessionNumber";
/**
 * legalState
 *
 * Contract.legalState: Legal states of the formation of a legal instrument, which is a formally executed written document that can be formally attributed to its author, records and formally expresses a legally enforceable act, process, or contractual duty, obligation, or right, and therefore evidences that act, process, or agreement.
 *
 * http://hl7.org/fhir/legalState
 */
export declare const legalState = "http://hl7.org/fhir/legalState";
/**
 * incomplete
 *
 * TerminologyCapabilities.expansion.incomplete: True if requests for incomplete expansions are allowed.
 *
 * http://hl7.org/fhir/incomplete
 */
export declare const incomplete = "http://hl7.org/fhir/incomplete";
/**
 * CodeableReference
 *
 * A reference to a resource (by instance), or instead, a reference to a concept defined in a terminology or ontology (by class).
 *
 * http://hl7.org/fhir/CodeableReference
 */
export declare const CodeableReference = "http://hl7.org/fhir/CodeableReference";
/**
 * activity
 *
 * Citation.citedArtifact.statusDate.activity: A definition of the status associated with a date or period.
 *
 * http://hl7.org/fhir/activity
 */
export declare const activity = "http://hl7.org/fhir/activity";
/**
 * availableEndTime
 *
 * Availability.availableTime.availableEndTime: Closing time of day (ignored if allDay = true).
 *
 * http://hl7.org/fhir/availableEndTime
 */
export declare const availableEndTime = "http://hl7.org/fhir/availableEndTime";
/**
 * mimeType
 *
 * Endpoint.payload.mimeType: The mime type to send the payload in - e.g. application/fhir+xml, application/fhir+json. If the mime type is not specified, then the sender could send any content (including no content depending on the connectionType).
 *
 * http://hl7.org/fhir/mimeType
 */
export declare const mimeType = "http://hl7.org/fhir/mimeType";
/**
 * NutritionOrderEnteralFormulaAdministrationComponent
 *
 * NutritionOrderEnteralFormulaComponent.NutritionOrderEnteralFormulaAdministrationComponent: Formula administration instructions as structured data.  This repeating structure allows for changing the administration rate or volume over time for both bolus and continuous feeding.  An example of this would be an instruction to increase the rate of continuous feeding every 2 hours.
 *
 * http://hl7.org/fhir/NutritionOrderEnteralFormulaAdministrationComponent
 */
export declare const NutritionOrderEnteralFormulaAdministrationComponent = "http://hl7.org/fhir/NutritionOrderEnteralFormulaAdministrationComponent";
/**
 * periodUnit
 *
 * Timing.repeat.periodUnit: The units of time for the period in UCUM units
 * Normal practice is to use the 'mo' code as a calendar month when calculating the next occurrence.
 *
 * http://hl7.org/fhir/periodUnit
 */
export declare const periodUnit = "http://hl7.org/fhir/periodUnit";
/**
 * EvidenceReportRelatesToComponent
 *
 * EvidenceReportRelatesToComponent: Relationships that this composition has with other compositions or documents that already exist.
 *
 * http://hl7.org/fhir/EvidenceReportRelatesToComponent
 */
export declare const EvidenceReportRelatesToComponent = "http://hl7.org/fhir/EvidenceReportRelatesToComponent";
/**
 * SubstanceDefinition
 *
 * The detailed description of a substance, typically at a level beyond what is used for prescribing.
 *
 * http://hl7.org/fhir/SubstanceDefinition
 */
export declare const SubstanceDefinition = "http://hl7.org/fhir/SubstanceDefinition";
/**
 * _useContext
 *
 * (Modified) Library.useContext
 *
 * http://hl7.org/fhir/_useContext
 */
export declare const _useContext = "http://hl7.org/fhir/_useContext";
/**
 * _instantiatesUri
 *
 * (Modified) Transport.instantiatesUri
 *
 * http://hl7.org/fhir/_instantiatesUri
 */
export declare const _instantiatesUri = "http://hl7.org/fhir/_instantiatesUri";
/**
 * authorizationUrl
 *
 * CoverageEligibilityResponse.insurance.item.authorizationUrl: A web location for obtaining requirements or descriptive information regarding the preauthorization.
 *
 * http://hl7.org/fhir/authorizationUrl
 */
export declare const authorizationUrl = "http://hl7.org/fhir/authorizationUrl";
/**
 * contributedToDeath
 *
 * FamilyMemberHistory.procedure.contributedToDeath: This procedure contributed to the cause of death of the related person. If contributedToDeath is not populated, then it is unknown.
 *
 * http://hl7.org/fhir/contributedToDeath
 */
export declare const contributedToDeath = "http://hl7.org/fhir/contributedToDeath";
/**
 * confidentialityIndicator
 *
 * MedicinalProductDefinition.operation.confidentialityIndicator: Specifies whether this particular business or manufacturing process is considered proprietary or confidential.
 *
 * http://hl7.org/fhir/confidentialityIndicator
 */
export declare const confidentialityIndicator = "http://hl7.org/fhir/confidentialityIndicator";
/**
 * _diagnosisSequence
 *
 * (Modified) ExplanationOfBenefit.item.diagnosisSequence
 *
 * http://hl7.org/fhir/_diagnosisSequence
 */
export declare const _diagnosisSequence = "http://hl7.org/fhir/_diagnosisSequence";
/**
 * selectionBehavior
 *
 * PlanDefinition.action.action.selectionBehavior: Defines the selection behavior for the action and its children.
 *
 * http://hl7.org/fhir/selectionBehavior
 */
export declare const selectionBehavior = "http://hl7.org/fhir/selectionBehavior";
/**
 * _time
 *
 * (Modified) Specimen.processing.time
 *
 * http://hl7.org/fhir/_time
 */
export declare const _time = "http://hl7.org/fhir/_time";
/**
 * addresses
 *
 * Goal.addresses: The identified conditions and other health record elements that are intended to be addressed by the goal.
 *
 * http://hl7.org/fhir/addresses
 */
export declare const addresses = "http://hl7.org/fhir/addresses";
/**
 * _dataRequirement
 *
 * (Modified) Library.dataRequirement
 *
 * http://hl7.org/fhir/_dataRequirement
 */
export declare const _dataRequirement = "http://hl7.org/fhir/_dataRequirement";
/**
 * CapabilityStatementRestResourceComponent
 *
 * CapabilityStatementRestComponent.CapabilityStatementRestResourceComponent: A specification of the restful capabilities of the solution for a specific resource type.
 *
 * http://hl7.org/fhir/CapabilityStatementRestResourceComponent
 */
export declare const CapabilityStatementRestResourceComponent = "http://hl7.org/fhir/CapabilityStatementRestResourceComponent";
/**
 * _lineItem
 *
 * (Modified) Invoice.lineItem
 *
 * http://hl7.org/fhir/_lineItem
 */
export declare const _lineItem = "http://hl7.org/fhir/_lineItem";
/**
 * _InventoryReport
 *
 * (Modified) InventoryReport
 *
 * http://hl7.org/fhir/_InventoryReport
 */
export declare const _InventoryReport = "http://hl7.org/fhir/_InventoryReport";
/**
 * _copyright
 *
 * (Modified) ArtifactAssessment.copyright
 *
 * http://hl7.org/fhir/_copyright
 */
export declare const _copyright = "http://hl7.org/fhir/_copyright";
/**
 * _Substance
 *
 * (Modified) Substance
 *
 * http://hl7.org/fhir/_Substance
 */
export declare const _Substance = "http://hl7.org/fhir/_Substance";
/**
 * _timing
 *
 * (Modified) PlanDefinition.action.timing
 *
 * http://hl7.org/fhir/_timing
 */
export declare const _timing = "http://hl7.org/fhir/_timing";
/**
 * wasSubstituted
 *
 * MedicationDispense.substitution.wasSubstituted: True if the dispenser dispensed a different drug or product from what was prescribed.
 *
 * http://hl7.org/fhir/wasSubstituted
 */
export declare const wasSubstituted = "http://hl7.org/fhir/wasSubstituted";
/**
 * aggregation
 *
 * ElementDefinition.type.aggregation: If the type is a reference to another resource, how the resource is or can be aggregated - is it a contained resource, or a reference, and if the context is a bundle, is it included in the bundle.
 *
 * http://hl7.org/fhir/aggregation
 */
export declare const aggregation = "http://hl7.org/fhir/aggregation";
/**
 * _authorDescription
 *
 * (Modified) SubstanceSourceMaterial.organism.author.authorDescription
 *
 * http://hl7.org/fhir/_authorDescription
 */
export declare const _authorDescription = "http://hl7.org/fhir/_authorDescription";
/**
 * _filter
 *
 * (Modified) ValueSet.compose.exclude.filter
 *
 * http://hl7.org/fhir/_filter
 */
export declare const _filter = "http://hl7.org/fhir/_filter";
/**
 * MedicinalProductDefinitionOperationComponent
 *
 * MedicinalProductDefinitionOperationComponent: A manufacturing or administrative process or step associated with (or performed on) the medicinal product.
 *
 * http://hl7.org/fhir/MedicinalProductDefinitionOperationComponent
 */
export declare const MedicinalProductDefinitionOperationComponent = "http://hl7.org/fhir/MedicinalProductDefinitionOperationComponent";
/**
 * _defaultValue
 *
 * (Modified) TestScript.variable.defaultValue
 *
 * http://hl7.org/fhir/_defaultValue
 */
export declare const _defaultValue = "http://hl7.org/fhir/_defaultValue";
/**
 * StructureMapStructureComponent
 *
 * StructureMapStructureComponent: A structure definition used by this map. The structure definition may describe instances that are converted, or the instances that are produced.
 *
 * http://hl7.org/fhir/StructureMapStructureComponent
 */
export declare const StructureMapStructureComponent = "http://hl7.org/fhir/StructureMapStructureComponent";
/**
 * recipient
 *
 * Task.restriction.recipient: For requests that are targeted to more than one potential recipient/target, to identify who is fulfillment is sought for.
 *
 * http://hl7.org/fhir/recipient
 */
export declare const recipient = "http://hl7.org/fhir/recipient";
/**
 * _lotNumber
 *
 * (Modified) NutritionProduct.instance.lotNumber
 *
 * http://hl7.org/fhir/_lotNumber
 */
export declare const _lotNumber = "http://hl7.org/fhir/_lotNumber";
/**
 * QuestionnaireItemAnswerOptionComponent
 *
 * QuestionnaireItemComponentItem.QuestionnaireItemAnswerOptionComponent: One of the permitted answers for the question.
 *
 * http://hl7.org/fhir/QuestionnaireItemAnswerOptionComponent
 */
export declare const QuestionnaireItemAnswerOptionComponent = "http://hl7.org/fhir/QuestionnaireItemAnswerOptionComponent";
/**
 * applies
 *
 * Contract.applies: Relevant time or time-period when this Contract is applicable.
 *
 * http://hl7.org/fhir/applies
 */
export declare const applies = "http://hl7.org/fhir/applies";
/**
 * caseSensitive
 *
 * CodeSystem.caseSensitive: If code comparison is case sensitive when codes within this system are compared to each other.
 *
 * http://hl7.org/fhir/caseSensitive
 */
export declare const caseSensitive = "http://hl7.org/fhir/caseSensitive";
/**
 * subtype
 *
 * Contract.term.group.asset.subtype: May be a subtype or part of an offered asset.
 *
 * http://hl7.org/fhir/subtype
 */
export declare const subtype = "http://hl7.org/fhir/subtype";
/**
 * _field
 *
 * (Modified) TestScript.teardown.action.operation.requestHeader.field
 *
 * http://hl7.org/fhir/_field
 */
export declare const _field = "http://hl7.org/fhir/_field";
/**
 * _hasIngredient
 *
 * (Modified) ManufacturedItemDefinition.component.component.constituent.hasIngredient
 *
 * http://hl7.org/fhir/_hasIngredient
 */
export declare const _hasIngredient = "http://hl7.org/fhir/_hasIngredient";
/**
 * strength
 *
 * OperationDefinition.parameter.part.binding.strength: Indicates the degree of conformance expectations associated with this binding - that is, the degree to which the provided value set must be adhered to in the instances.
 *
 * http://hl7.org/fhir/strength
 */
export declare const strength = "http://hl7.org/fhir/strength";
/**
 * linkId
 *
 * ResearchStudy.comparisonGroup.linkId: Allows the comparisonGroup for the study and the comparisonGroup for the subject to be linked easily.
 *
 * http://hl7.org/fhir/linkId
 */
export declare const linkId = "http://hl7.org/fhir/linkId";
/**
 * StructureMapGroupRuleTargetComponent
 *
 * StructureMapGroupComponent.StructureMapGroupRuleComponentRule.StructureMapGroupRuleTargetComponent: Content to create because of this mapping rule.
 *
 * http://hl7.org/fhir/StructureMapGroupRuleTargetComponent
 */
export declare const StructureMapGroupRuleTargetComponent = "http://hl7.org/fhir/StructureMapGroupRuleTargetComponent";
/**
 * _resultingEffect
 *
 * (Modified) AdverseEvent.resultingEffect
 *
 * http://hl7.org/fhir/_resultingEffect
 */
export declare const _resultingEffect = "http://hl7.org/fhir/_resultingEffect";
/**
 * altitude
 *
 * Location.position.altitude: Altitude. The value domain and the interpretation are the same as for the text of the altitude element in KML (see notes on Location main page).
 *
 * http://hl7.org/fhir/altitude
 */
export declare const altitude = "http://hl7.org/fhir/altitude";
/**
 * phase
 *
 * TestScript.scope.phase: The phase of testing for this artifact: unit - development / implementation phase, integration - internal system to system phase, production - live system to system phase (Note, this may involve pii/phi data).
 *
 * http://hl7.org/fhir/phase
 */
export declare const phase = "http://hl7.org/fhir/phase";
/**
 * _numberOfRepeatsAllowed
 *
 * (Modified) MedicationRequest.dispenseRequest.numberOfRepeatsAllowed
 *
 * http://hl7.org/fhir/_numberOfRepeatsAllowed
 */
export declare const _numberOfRepeatsAllowed = "http://hl7.org/fhir/_numberOfRepeatsAllowed";
/**
 * groupSize
 *
 * InsurancePlan.plan.generalCost.groupSize: Number of participants enrolled in the plan.
 *
 * http://hl7.org/fhir/groupSize
 */
export declare const groupSize = "http://hl7.org/fhir/groupSize";
/**
 * _oligoNucleotideType
 *
 * (Modified) SubstanceNucleicAcid.oligoNucleotideType
 *
 * http://hl7.org/fhir/_oligoNucleotideType
 */
export declare const _oligoNucleotideType = "http://hl7.org/fhir/_oligoNucleotideType";
/**
 * doseStatus
 *
 * ImmunizationEvaluation.doseStatus: Indicates if the dose is valid or not valid with respect to the published recommendations.
 *
 * http://hl7.org/fhir/doseStatus
 */
export declare const doseStatus = "http://hl7.org/fhir/doseStatus";
/**
 * directnessMatch
 *
 * Evidence.variableDefinition.directnessMatch: Indication of quality of match between intended variable to actual variable.
 *
 * http://hl7.org/fhir/directnessMatch
 */
export declare const directnessMatch = "http://hl7.org/fhir/directnessMatch";
/**
 * AppointmentParticipantComponent
 *
 * AppointmentParticipantComponent: List of participants involved in the appointment.
 *
 * http://hl7.org/fhir/AppointmentParticipantComponent
 */
export declare const AppointmentParticipantComponent = "http://hl7.org/fhir/AppointmentParticipantComponent";
/**
 * _continuous
 *
 * (Modified) Goal.continuous
 *
 * http://hl7.org/fhir/_continuous
 */
export declare const _continuous = "http://hl7.org/fhir/_continuous";
/**
 * _dispenseInterval
 *
 * (Modified) MedicationRequest.dispenseRequest.dispenseInterval
 *
 * http://hl7.org/fhir/_dispenseInterval
 */
export declare const _dispenseInterval = "http://hl7.org/fhir/_dispenseInterval";
/**
 * stage
 *
 * ConditionDefinition.stage: Clinical stage or grade of a condition. May include formal severity assessments.
 *
 * http://hl7.org/fhir/stage
 */
export declare const stage = "http://hl7.org/fhir/stage";
/**
 * associatedMedication
 *
 * MedicationKnowledge.associatedMedication: Links to associated medications that could be prescribed, dispensed or administered.
 *
 * http://hl7.org/fhir/associatedMedication
 */
export declare const associatedMedication = "http://hl7.org/fhir/associatedMedication";
/**
 * dateOfDiagnosis
 *
 * Account.diagnosis.dateOfDiagnosis: Ranking of the diagnosis (for each type).
 *
 * http://hl7.org/fhir/dateOfDiagnosis
 */
export declare const dateOfDiagnosis = "http://hl7.org/fhir/dateOfDiagnosis";
/**
 * _actualPeriod
 *
 * (Modified) EncounterHistory.actualPeriod
 *
 * http://hl7.org/fhir/_actualPeriod
 */
export declare const _actualPeriod = "http://hl7.org/fhir/_actualPeriod";
/**
 * ValueSet
 *
 * A ValueSet resource instance specifies a set of codes drawn from one or more code systems, intended for use in a particular context. Value sets link between [[[CodeSystem]]] definitions and their use in [coded elements](terminologies.html).
 *
 * http://hl7.org/fhir/ValueSet
 */
export declare const ValueSet = "http://hl7.org/fhir/ValueSet";
/**
 * lastOccurrence
 *
 * AllergyIntolerance.lastOccurrence: Represents the date and/or time of the last known occurrence of a reaction event.
 *
 * http://hl7.org/fhir/lastOccurrence
 */
export declare const lastOccurrence = "http://hl7.org/fhir/lastOccurrence";
/**
 * disulfideLinkage
 *
 * SubstanceProtein.disulfideLinkage: The disulphide bond between two cysteine residues either on the same subunit or on two different subunits shall be described. The position of the disulfide bonds in the SubstanceProtein shall be listed in increasing order of subunit number and position within subunit followed by the abbreviation of the amino acids involved. The disulfide linkage positions shall actually contain the amino acid Cysteine at the respective positions.
 *
 * http://hl7.org/fhir/disulfideLinkage
 */
export declare const disulfideLinkage = "http://hl7.org/fhir/disulfideLinkage";
/**
 * participatingOrganization
 *
 * OrganizationAffiliation.participatingOrganization: The Participating Organization provides/performs the role(s) defined by the code to the Primary Organization (e.g. providing services or is a member of).
 *
 * http://hl7.org/fhir/participatingOrganization
 */
export declare const participatingOrganization = "http://hl7.org/fhir/participatingOrganization";
/**
 * ResearchSubject
 *
 * A ResearchSubject is a participant or object which is the recipient of investigative activities in a research study.
 *
 * http://hl7.org/fhir/ResearchSubject
 */
export declare const ResearchSubject = "http://hl7.org/fhir/ResearchSubject";
/**
 * heartbeatPeriod
 *
 * Subscription.heartbeatPeriod: If present, a 'heartbeat' notification (keep-alive) is sent via this channel with an interval period equal to this elements integer value in seconds.  If not present, a heartbeat notification is not sent.
 *
 * http://hl7.org/fhir/heartbeatPeriod
 */
export declare const heartbeatPeriod = "http://hl7.org/fhir/heartbeatPeriod";
/**
 * OrganizationAffiliation
 *
 * Defines an affiliation/assotiation/relationship between 2 distinct organizations, that is not a part-of relationship/sub-division relationship.
 *
 * http://hl7.org/fhir/OrganizationAffiliation
 */
export declare const OrganizationAffiliation = "http://hl7.org/fhir/OrganizationAffiliation";
/**
 * _binding
 *
 * (Modified) OperationDefinition.parameter.part.binding
 *
 * http://hl7.org/fhir/_binding
 */
export declare const _binding = "http://hl7.org/fhir/_binding";
/**
 * SubstanceNucleicAcidSubunitLinkageComponent
 *
 * SubstanceNucleicAcidSubunitComponent.SubstanceNucleicAcidSubunitLinkageComponent: The linkages between sugar residues will also be captured.
 *
 * http://hl7.org/fhir/SubstanceNucleicAcidSubunitLinkageComponent
 */
export declare const SubstanceNucleicAcidSubunitLinkageComponent = "http://hl7.org/fhir/SubstanceNucleicAcidSubunitLinkageComponent";
/**
 * ImplementationGuideDefinitionPageComponent
 *
 * ImplementationGuideDefinitionComponent.ImplementationGuideDefinitionPageComponent: A page / section in the implementation guide. The root page is the implementation guide home page.
 *
 * http://hl7.org/fhir/ImplementationGuideDefinitionPageComponent
 */
export declare const ImplementationGuideDefinitionPageComponent = "http://hl7.org/fhir/ImplementationGuideDefinitionPageComponent";
/**
 * FamilyMemberHistoryProcedureComponent
 *
 * FamilyMemberHistoryProcedureComponent: The significant Procedures (or procedure) that the family member had. This is a repeating section to allow a system to represent more than one procedure per resource, though there is nothing stopping multiple resources - one per procedure.
 *
 * http://hl7.org/fhir/FamilyMemberHistoryProcedureComponent
 */
export declare const FamilyMemberHistoryProcedureComponent = "http://hl7.org/fhir/FamilyMemberHistoryProcedureComponent";
/**
 * subscriptionTopic
 *
 * TriggerDefinition.subscriptionTopic: A reference to a SubscriptionTopic resource that defines the event. If this element is provided, no other information about the trigger definition may be supplied.
 *
 * http://hl7.org/fhir/subscriptionTopic
 */
export declare const subscriptionTopic = "http://hl7.org/fhir/subscriptionTopic";
/**
 * _resource
 *
 * (Modified) RelatedArtifact.resource
 *
 * http://hl7.org/fhir/_resource
 */
export declare const _resource = "http://hl7.org/fhir/_resource";
/**
 * correspondingContact
 *
 * Citation.citedArtifact.contributorship.entry.correspondingContact: Whether the contributor is the corresponding contributor for the role.
 *
 * http://hl7.org/fhir/correspondingContact
 */
export declare const correspondingContact = "http://hl7.org/fhir/correspondingContact";
/**
 * graph
 *
 * MessageDefinition.graph: Graph is Canonical reference to a GraphDefinition. If a URL is provided, it is the canonical reference to a GraphDefinition that it controls what additional resources are to be added to the Bundle when building the message. The GraphDefinition can also specify profiles that apply to the various resources.
 *
 * http://hl7.org/fhir/graph
 */
export declare const graph = "http://hl7.org/fhir/graph";
/**
 * _QuestionnaireResponse
 *
 * (Modified) QuestionnaireResponse
 *
 * http://hl7.org/fhir/_QuestionnaireResponse
 */
export declare const _QuestionnaireResponse = "http://hl7.org/fhir/_QuestionnaireResponse";
/**
 * RequestOrchestrationActionComponentAction
 *
 * Sub actions.
 *
 * http://hl7.org/fhir/RequestOrchestrationActionComponentAction
 */
export declare const RequestOrchestrationActionComponentAction = "http://hl7.org/fhir/RequestOrchestrationActionComponentAction";
/**
 * issues
 *
 * Bundle.issues: Captures issues and warnings that relate to the construction of the Bundle and the content within it.
 *
 * http://hl7.org/fhir/issues
 */
export declare const issues = "http://hl7.org/fhir/issues";
/**
 * instances
 *
 * EvidenceVariable.characteristic.instances
 *
 * http://hl7.org/fhir/instances
 */
export declare const instances = "http://hl7.org/fhir/instances";
/**
 * _isDefining
 *
 * (Modified) SubstancePolymer.monomerSet.startingMaterial.isDefining
 *
 * http://hl7.org/fhir/_isDefining
 */
export declare const _isDefining = "http://hl7.org/fhir/_isDefining";
/**
 * primaryPurposeType
 *
 * ResearchStudy.primaryPurposeType: The type of study based upon the intent of the study activities. A classification of the intent of the study.
 *
 * http://hl7.org/fhir/primaryPurposeType
 */
export declare const primaryPurposeType = "http://hl7.org/fhir/primaryPurposeType";
/**
 * _specimenRequirement
 *
 * (Modified) ActivityDefinition.specimenRequirement
 *
 * http://hl7.org/fhir/_specimenRequirement
 */
export declare const _specimenRequirement = "http://hl7.org/fhir/_specimenRequirement";
/**
 * _sourceDocument
 *
 * (Modified) SubstanceDefinition.structure.sourceDocument
 *
 * http://hl7.org/fhir/_sourceDocument
 */
export declare const _sourceDocument = "http://hl7.org/fhir/_sourceDocument";
/**
 * SubstanceReferenceInformation
 *
 * Todo.
 *
 * http://hl7.org/fhir/SubstanceReferenceInformation
 */
export declare const SubstanceReferenceInformation = "http://hl7.org/fhir/SubstanceReferenceInformation";
/**
 * _multipleBirth
 *
 * (Modified) Patient.multipleBirth
 *
 * http://hl7.org/fhir/_multipleBirth
 */
export declare const _multipleBirth = "http://hl7.org/fhir/_multipleBirth";
/**
 * _InsurancePlan
 *
 * (Modified) InsurancePlan
 *
 * http://hl7.org/fhir/_InsurancePlan
 */
export declare const _InsurancePlan = "http://hl7.org/fhir/_InsurancePlan";
/**
 * repeatUnit
 *
 * SubstancePolymer.repeat.repeatUnit: An SRU - Structural Repeat Unit.
 *
 * http://hl7.org/fhir/repeatUnit
 */
export declare const repeatUnit = "http://hl7.org/fhir/repeatUnit";
/**
 * StructureDefinition
 *
 * A definition of a FHIR structure. This resource is used to describe the underlying resources, data types defined in FHIR, and also for describing extensions and constraints on resources and data types.
 *
 * http://hl7.org/fhir/StructureDefinition
 */
export declare const StructureDefinition = "http://hl7.org/fhir/StructureDefinition";
/**
 * _node
 *
 * (Modified) GraphDefinition.node
 *
 * http://hl7.org/fhir/_node
 */
export declare const _node = "http://hl7.org/fhir/_node";
/**
 * TestPlanTestCaseAssertionComponent
 *
 * TestPlanTestCaseComponent.TestPlanTestCaseAssertionComponent: The test assertions - the expectations of test results from the execution of the test case.
 *
 * http://hl7.org/fhir/TestPlanTestCaseAssertionComponent
 */
export declare const TestPlanTestCaseAssertionComponent = "http://hl7.org/fhir/TestPlanTestCaseAssertionComponent";
/**
 * relatedData
 *
 * PlanDefinition.action.input.relatedData: Points to an existing input or output element that provides data to this input.
 *
 * http://hl7.org/fhir/relatedData
 */
export declare const relatedData = "http://hl7.org/fhir/relatedData";
/**
 * _content
 *
 * (Modified) CommunicationRequest.payload.content
 *
 * http://hl7.org/fhir/_content
 */
export declare const _content = "http://hl7.org/fhir/_content";
/**
 * _associationType
 *
 * (Modified) InventoryItem.association.associationType
 *
 * http://hl7.org/fhir/_associationType
 */
export declare const _associationType = "http://hl7.org/fhir/_associationType";
/**
 * _regulatoryBasis
 *
 * (Modified) Consent.regulatoryBasis
 *
 * http://hl7.org/fhir/_regulatoryBasis
 */
export declare const _regulatoryBasis = "http://hl7.org/fhir/_regulatoryBasis";
/**
 * attachment
 *
 * SubstancePolymer.repeat.repeatUnit.structuralRepresentation.attachment: An attached file with the structural representation.
 *
 * http://hl7.org/fhir/attachment
 */
export declare const attachment = "http://hl7.org/fhir/attachment";
/**
 * ActionSubject
 *
 * Contract.Term.Action.ActionSubject: Entity of the action.
 *
 * http://hl7.org/fhir/ActionSubject
 */
export declare const ActionSubject = "http://hl7.org/fhir/ActionSubject";
/**
 * _packagedMedicinalProduct
 *
 * (Modified) MedicinalProductDefinition.packagedMedicinalProduct
 *
 * http://hl7.org/fhir/_packagedMedicinalProduct
 */
export declare const _packagedMedicinalProduct = "http://hl7.org/fhir/_packagedMedicinalProduct";
/**
 * _packagedProduct
 *
 * (Modified) MedicationKnowledge.packaging.packagedProduct
 *
 * http://hl7.org/fhir/_packagedProduct
 */
export declare const _packagedProduct = "http://hl7.org/fhir/_packagedProduct";
/**
 * _onset
 *
 * (Modified) FamilyMemberHistory.condition.onset
 *
 * http://hl7.org/fhir/_onset
 */
export declare const _onset = "http://hl7.org/fhir/_onset";
/**
 * _basedOn
 *
 * (Modified) DeviceUsage.basedOn
 *
 * http://hl7.org/fhir/_basedOn
 */
export declare const _basedOn = "http://hl7.org/fhir/_basedOn";
/**
 * CitationCitedArtifactRelatesToComponent
 *
 * CitationCitedArtifactComponent.CitationCitedArtifactRelatesToComponent: The artifact related to the cited artifact.
 *
 * http://hl7.org/fhir/CitationCitedArtifactRelatesToComponent
 */
export declare const CitationCitedArtifactRelatesToComponent = "http://hl7.org/fhir/CitationCitedArtifactRelatesToComponent";
/**
 * _backCurve
 *
 * (Modified) VisionPrescription.lensSpecification.backCurve
 *
 * http://hl7.org/fhir/_backCurve
 */
export declare const _backCurve = "http://hl7.org/fhir/_backCurve";
/**
 * AuditEventOutcomeComponent
 *
 * AuditEventOutcomeComponent: Indicates whether the event succeeded or failed. A free text descripiton can be given in outcome.text.
 *
 * http://hl7.org/fhir/AuditEventOutcomeComponent
 */
export declare const AuditEventOutcomeComponent = "http://hl7.org/fhir/AuditEventOutcomeComponent";
/**
 * payee
 *
 * PaymentNotice.payee: The party who will receive or has received payment that is the subject of this notification.
 *
 * http://hl7.org/fhir/payee
 */
export declare const payee = "http://hl7.org/fhir/payee";
/**
 * _reporter
 *
 * (Modified) PaymentNotice.reporter
 *
 * http://hl7.org/fhir/_reporter
 */
export declare const _reporter = "http://hl7.org/fhir/_reporter";
/**
 * SubstanceDefinitionStructureComponentMolecularWeight
 *
 * The molecular weight or weight range (for proteins, polymers or nucleic acids).
 *
 * http://hl7.org/fhir/SubstanceDefinitionStructureComponentMolecularWeight
 */
export declare const SubstanceDefinitionStructureComponentMolecularWeight = "http://hl7.org/fhir/SubstanceDefinitionStructureComponentMolecularWeight";
/**
 * biologicalSourceEvent
 *
 * BiologicallyDerivedProduct.biologicalSourceEvent: An identifier that supports traceability to the event during which material in this product from one or more biological entities was obtained or pooled.
 *
 * http://hl7.org/fhir/biologicalSourceEvent
 */
export declare const biologicalSourceEvent = "http://hl7.org/fhir/biologicalSourceEvent";
/**
 * RequestOrchestrationActionComponent
 *
 * RequestOrchestrationActionComponent: The actions, if any, produced by the evaluation of the artifact.
 *
 * http://hl7.org/fhir/RequestOrchestrationActionComponent
 */
export declare const RequestOrchestrationActionComponent = "http://hl7.org/fhir/RequestOrchestrationActionComponent";
/**
 * period
 *
 * RelatedPerson.period: The period of time during which this relationship is or was active. If there are no dates defined, then the interval is unknown.
 *
 * http://hl7.org/fhir/period
 */
export declare const period = "http://hl7.org/fhir/period";
/**
 * SearchParameterComponentComponent
 *
 * SearchParameterComponentComponent: Used to define the parts of a composite search parameter.
 *
 * http://hl7.org/fhir/SearchParameterComponentComponent
 */
export declare const SearchParameterComponentComponent = "http://hl7.org/fhir/SearchParameterComponentComponent";
/**
 * protocolPerformed
 *
 * GenomicStudy.analysis.protocolPerformed: The protocol that was performed for the analysis event.
 *
 * http://hl7.org/fhir/protocolPerformed
 */
export declare const protocolPerformed = "http://hl7.org/fhir/protocolPerformed";
/**
 * ResearchStudyLabelComponent
 *
 * ResearchStudyLabelComponent: Additional names for the study.
 *
 * http://hl7.org/fhir/ResearchStudyLabelComponent
 */
export declare const ResearchStudyLabelComponent = "http://hl7.org/fhir/ResearchStudyLabelComponent";
/**
 * _careTeamSequence
 *
 * (Modified) ExplanationOfBenefit.item.careTeamSequence
 *
 * http://hl7.org/fhir/_careTeamSequence
 */
export declare const _careTeamSequence = "http://hl7.org/fhir/_careTeamSequence";
/**
 * instantiates
 *
 * Observation.instantiates
 *
 * http://hl7.org/fhir/instantiates
 */
export declare const instantiates = "http://hl7.org/fhir/instantiates";
/**
 * _patientCharacteristic
 *
 * (Modified) MedicationKnowledge.indicationGuideline.dosingGuideline.patientCharacteristic
 *
 * http://hl7.org/fhir/_patientCharacteristic
 */
export declare const _patientCharacteristic = "http://hl7.org/fhir/_patientCharacteristic";
/**
 * _allowedType
 *
 * (Modified) OperationDefinition.parameter.part.allowedType
 *
 * http://hl7.org/fhir/_allowedType
 */
export declare const _allowedType = "http://hl7.org/fhir/_allowedType";
/**
 * Element
 *
 * Base definition for all elements in a resource.
 *
 * http://hl7.org/fhir/Element
 */
export declare const Element = "http://hl7.org/fhir/Element";
/**
 * DeviceMetric
 *
 * Describes a measurement, calculation or setting capability of a device.  The DeviceMetric resource is derived from the ISO/IEEE 11073-10201 Domain Information Model standard, but is more widely applicable.
 *
 * http://hl7.org/fhir/DeviceMetric
 */
export declare const DeviceMetric = "http://hl7.org/fhir/DeviceMetric";
/**
 * _maxTreatmentPeriod
 *
 * (Modified) AdministrableProductDefinition.routeOfAdministration.maxTreatmentPeriod
 *
 * http://hl7.org/fhir/_maxTreatmentPeriod
 */
export declare const _maxTreatmentPeriod = "http://hl7.org/fhir/_maxTreatmentPeriod";
/**
 * _InventoryItem
 *
 * (Modified) InventoryItem
 *
 * http://hl7.org/fhir/_InventoryItem
 */
export declare const _InventoryItem = "http://hl7.org/fhir/_InventoryItem";
/**
 * AppointmentRecurrenceTemplateComponent
 *
 * AppointmentRecurrenceTemplateComponent: The details of the recurrence pattern or template that is used to generate recurring appointments.
 *
 * http://hl7.org/fhir/AppointmentRecurrenceTemplateComponent
 */
export declare const AppointmentRecurrenceTemplateComponent = "http://hl7.org/fhir/AppointmentRecurrenceTemplateComponent";
/**
 * targetDisease
 *
 * ImmunizationRecommendation.recommendation.targetDisease: The targeted disease for the recommendation.
 *
 * http://hl7.org/fhir/targetDisease
 */
export declare const targetDisease = "http://hl7.org/fhir/targetDisease";
/**
 * PlanDefinitionActionComponentAction
 *
 * Sub actions that are contained within the action. The behavior of this action determines the functionality of the sub-actions. For example, a selection behavior of at-most-one indicates that of the sub-actions, at most one may be chosen as part of realizing the action definition.
 *
 * http://hl7.org/fhir/PlanDefinitionActionComponentAction
 */
export declare const PlanDefinitionActionComponentAction = "http://hl7.org/fhir/PlanDefinitionActionComponentAction";
/**
 * file
 *
 * SubstanceDefinition.characterization.file: The data produced by the analytical instrument or a pictorial representation of that data. Examples: a JCAMP, JDX, or ADX file, or a chromatogram or spectrum analysis.
 *
 * http://hl7.org/fhir/file
 */
export declare const file = "http://hl7.org/fhir/file";
/**
 * const
 *
 * StructureMap.const: Definition of a constant value used in the map rules.
 * Note that `const` is a reserved Javascript keyword, and is therefore suffixed by `__workaround`.
 * For a list of reserved keywords, see https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Lexical_grammar#Keywords.
 *
 * http://hl7.org/fhir/const
 */
export declare const const__workaround = "http://hl7.org/fhir/const";
/**
 * citedMedium
 *
 * Citation.citedArtifact.publicationForm.citedMedium: Describes the form of the medium cited. Common codes are "Internet" or "Print". The CitedMedium value set has 6 codes. The codes internet, print, and offline-digital-storage are the common codes for a typical publication form, though internet and print are more common for study citations. Three additional codes (each appending one of the primary codes with "-without-issue" are used for situations when a study is published both within an issue (of a periodical release as commonly done for journals) AND is published separately from the issue (as commonly done with early online publication), to represent specific identification of the publication form not associated with the issue.
 *
 * http://hl7.org/fhir/citedMedium
 */
export declare const citedMedium = "http://hl7.org/fhir/citedMedium";
/**
 * _frames
 *
 * (Modified) Attachment.frames
 *
 * http://hl7.org/fhir/_frames
 */
export declare const _frames = "http://hl7.org/fhir/_frames";
/**
 * multipleOr
 *
 * SearchParameter.multipleOr: Whether multiple values are allowed for each time the parameter exists. Values are separated by commas, and the parameter matches if any of the values match.
 *
 * http://hl7.org/fhir/multipleOr
 */
export declare const multipleOr = "http://hl7.org/fhir/multipleOr";
/**
 * inputParameters
 *
 * MeasureReport.inputParameters: A reference to a Parameters resource (typically represented using a contained resource) that represents any input parameters that were provided to the operation that generated the report.
 *
 * http://hl7.org/fhir/inputParameters
 */
export declare const inputParameters = "http://hl7.org/fhir/inputParameters";
/**
 * causality
 *
 * AdverseEvent.suspectEntity.causality: Information on the possible cause of the event.
 *
 * http://hl7.org/fhir/causality
 */
export declare const causality = "http://hl7.org/fhir/causality";
/**
 * SupplyDelivery
 *
 * Record of delivery of what is supplied.
 *
 * http://hl7.org/fhir/SupplyDelivery
 */
export declare const SupplyDelivery = "http://hl7.org/fhir/SupplyDelivery";
/**
 * minimumId
 *
 * TestScript.test.action.assert.minimumId: The ID of a fixture. Asserts that the response contains at a minimum the fixture specified by minimumId.
 *
 * http://hl7.org/fhir/minimumId
 */
export declare const minimumId = "http://hl7.org/fhir/minimumId";
/**
 * _processNote
 *
 * (Modified) PaymentReconciliation.processNote
 *
 * http://hl7.org/fhir/_processNote
 */
export declare const _processNote = "http://hl7.org/fhir/_processNote";
/**
 * Money
 *
 * An amount of economic utility in some recognized currency.
 *
 * http://hl7.org/fhir/Money
 */
export declare const Money = "http://hl7.org/fhir/Money";
/**
 * _BackboneType
 *
 * http://hl7.org/fhir/_BackboneType
 */
export declare const _BackboneType = "http://hl7.org/fhir/_BackboneType";
/**
 * _Endpoint
 *
 * (Modified) Endpoint
 *
 * http://hl7.org/fhir/_Endpoint
 */
export declare const _Endpoint = "http://hl7.org/fhir/_Endpoint";
/**
 * udiDeviceIdentifier
 *
 * DeviceDefinition.packaging.packaging.udiDeviceIdentifier: Unique Device Identifier (UDI) Barcode string on the packaging.
 *
 * http://hl7.org/fhir/udiDeviceIdentifier
 */
export declare const udiDeviceIdentifier = "http://hl7.org/fhir/udiDeviceIdentifier";
/**
 * EnteralFormulaSchedule
 *
 * NutritionOrderEnteralFormulaComponent.NutritionOrderEnteralFormulaAdministrationComponent.EnteralFormulaSchedule: Schedule information for an enteral formula.
 *
 * http://hl7.org/fhir/EnteralFormulaSchedule
 */
export declare const EnteralFormulaSchedule = "http://hl7.org/fhir/EnteralFormulaSchedule";
/**
 * diseaseStatus
 *
 * ClinicalUseDefinition.indication.diseaseStatus: The status of the disease or symptom for the indication, for example "chronic" or "metastatic".
 *
 * http://hl7.org/fhir/diseaseStatus
 */
export declare const diseaseStatus = "http://hl7.org/fhir/diseaseStatus";
/**
 * _expectedSupplyDuration
 *
 * (Modified) MedicationRequest.dispenseRequest.expectedSupplyDuration
 *
 * http://hl7.org/fhir/_expectedSupplyDuration
 */
export declare const _expectedSupplyDuration = "http://hl7.org/fhir/_expectedSupplyDuration";
/**
 * ifModifiedSince
 *
 * Bundle.entry.request.ifModifiedSince: Only perform the operation if the last updated date matches. See the API documentation for ["Conditional Read"](http.html#cread).
 *
 * http://hl7.org/fhir/ifModifiedSince
 */
export declare const ifModifiedSince = "http://hl7.org/fhir/ifModifiedSince";
/**
 * formCode
 *
 * PaymentReconciliation.formCode: A code for the form to be used for printing the content.
 *
 * http://hl7.org/fhir/formCode
 */
export declare const formCode = "http://hl7.org/fhir/formCode";
/**
 * _connectionType
 *
 * (Modified) Endpoint.connectionType
 *
 * http://hl7.org/fhir/_connectionType
 */
export declare const _connectionType = "http://hl7.org/fhir/_connectionType";
/**
 * ImplementationGuideDefinitionResourceComponent
 *
 * ImplementationGuideDefinitionComponent.ImplementationGuideDefinitionResourceComponent: A resource that is part of the implementation guide. Conformance resources (value set, structure definition, capability statements etc.) are obvious candidates for inclusion, but any kind of resource can be included as an example resource.
 *
 * http://hl7.org/fhir/ImplementationGuideDefinitionResourceComponent
 */
export declare const ImplementationGuideDefinitionResourceComponent = "http://hl7.org/fhir/ImplementationGuideDefinitionResourceComponent";
/**
 * _fundsReserveRequested
 *
 * (Modified) ExplanationOfBenefit.fundsReserveRequested
 *
 * http://hl7.org/fhir/_fundsReserveRequested
 */
export declare const _fundsReserveRequested = "http://hl7.org/fhir/_fundsReserveRequested";
/**
 * dateFilter
 *
 * DataRequirement.dateFilter: Date filters specify additional constraints on the data in terms of the applicable date range for specific elements. Each date filter specifies an additional constraint on the data, i.e. date filters are AND'ed, not OR'ed.
 *
 * http://hl7.org/fhir/dateFilter
 */
export declare const dateFilter = "http://hl7.org/fhir/dateFilter";
/**
 * matchStatus
 *
 * BiologicallyDerivedProductDispense.matchStatus: Indicates the type of matching associated with the dispense.
 *
 * http://hl7.org/fhir/matchStatus
 */
export declare const matchStatus = "http://hl7.org/fhir/matchStatus";
/**
 * usePeriod
 *
 * Contract.term.group.asset.usePeriod: Time period of asset use.
 *
 * http://hl7.org/fhir/usePeriod
 */
export declare const usePeriod = "http://hl7.org/fhir/usePeriod";
/**
 * _participant
 *
 * (Modified) PlanDefinition.action.participant
 *
 * http://hl7.org/fhir/_participant
 */
export declare const _participant = "http://hl7.org/fhir/_participant";
/**
 * MessageDestination
 *
 * MessageHeader.MessageDestination: The destination application which the message is intended for.
 *
 * http://hl7.org/fhir/MessageDestination
 */
export declare const MessageDestination = "http://hl7.org/fhir/MessageDestination";
/**
 * _additionalInfo
 *
 * (Modified) VirtualServiceDetail.additionalInfo
 *
 * http://hl7.org/fhir/_additionalInfo
 */
export declare const _additionalInfo = "http://hl7.org/fhir/_additionalInfo";
/**
 * _numberOfEvents
 *
 * (Modified) Evidence.statistic.numberOfEvents
 *
 * http://hl7.org/fhir/_numberOfEvents
 */
export declare const _numberOfEvents = "http://hl7.org/fhir/_numberOfEvents";
/**
 * _includedStructure
 *
 * (Modified) BodyStructure.includedStructure
 *
 * http://hl7.org/fhir/_includedStructure
 */
export declare const _includedStructure = "http://hl7.org/fhir/_includedStructure";
/**
 * _imageRegion2D
 *
 * (Modified) ImagingSelection.instance.imageRegion2D
 *
 * http://hl7.org/fhir/_imageRegion2D
 */
export declare const _imageRegion2D = "http://hl7.org/fhir/_imageRegion2D";
/**
 * _tax
 *
 * (Modified) ExplanationOfBenefit.item.detail.subDetail.tax
 *
 * http://hl7.org/fhir/_tax
 */
export declare const _tax = "http://hl7.org/fhir/_tax";
/**
 * _appointment
 *
 * (Modified) Encounter.appointment
 *
 * http://hl7.org/fhir/_appointment
 */
export declare const _appointment = "http://hl7.org/fhir/_appointment";
/**
 * treatmentIntent
 *
 * MedicationKnowledge.indicationGuideline.dosingGuideline.treatmentIntent: The overall intention of the treatment, for example, prophylactic, supporative, curative, etc.
 *
 * http://hl7.org/fhir/treatmentIntent
 */
export declare const treatmentIntent = "http://hl7.org/fhir/treatmentIntent";
/**
 * SubstanceDefinitionCodeComponent
 *
 * SubstanceDefinitionCodeComponent: Codes associated with the substance.
 *
 * http://hl7.org/fhir/SubstanceDefinitionCodeComponent
 */
export declare const SubstanceDefinitionCodeComponent = "http://hl7.org/fhir/SubstanceDefinitionCodeComponent";
/**
 * _study
 *
 * (Modified) ResearchSubject.study
 *
 * http://hl7.org/fhir/_study
 */
export declare const _study = "http://hl7.org/fhir/_study";
/**
 * _ratioType
 *
 * (Modified) SubstancePolymer.monomerSet.ratioType
 *
 * http://hl7.org/fhir/_ratioType
 */
export declare const _ratioType = "http://hl7.org/fhir/_ratioType";
/**
 * policyHolder
 *
 * Coverage.policyHolder: The party who 'owns' the insurance policy.
 *
 * http://hl7.org/fhir/policyHolder
 */
export declare const policyHolder = "http://hl7.org/fhir/policyHolder";
/**
 * region
 *
 * ResearchStudy.region: A country, state or other area where the study is taking place rather than its precise geographic location or address.
 *
 * http://hl7.org/fhir/region
 */
export declare const region = "http://hl7.org/fhir/region";
/**
 * operationType
 *
 * InventoryReport.operationType: What type of operation is being performed - addition or subtraction.
 *
 * http://hl7.org/fhir/operationType
 */
export declare const operationType = "http://hl7.org/fhir/operationType";
/**
 * _actuality
 *
 * (Modified) AdverseEvent.actuality
 *
 * http://hl7.org/fhir/_actuality
 */
export declare const _actuality = "http://hl7.org/fhir/_actuality";
/**
 * _definitionUri
 *
 * (Modified) ChargeItem.definitionUri
 *
 * http://hl7.org/fhir/_definitionUri
 */
export declare const _definitionUri = "http://hl7.org/fhir/_definitionUri";
/**
 * organismId
 *
 * SubstanceSourceMaterial.organismId: The unique identifier associated with the source material parent organism shall be specified.
 *
 * http://hl7.org/fhir/organismId
 */
export declare const organismId = "http://hl7.org/fhir/organismId";
/**
 * ManufacturedItemDefinitionComponentComponentComponentProperty
 *
 * General characteristics of this component.
 *
 * http://hl7.org/fhir/ManufacturedItemDefinitionComponentComponentComponentProperty
 */
export declare const ManufacturedItemDefinitionComponentComponentComponentProperty = "http://hl7.org/fhir/ManufacturedItemDefinitionComponentComponentComponentProperty";
/**
 * _consumedItem
 *
 * (Modified) NutritionIntake.consumedItem
 *
 * http://hl7.org/fhir/_consumedItem
 */
export declare const _consumedItem = "http://hl7.org/fhir/_consumedItem";
/**
 * thursday
 *
 * Appointment.recurrenceTemplate.weeklyTemplate.thursday: Indicates that recurring appointments should occur on Thursdays.
 *
 * http://hl7.org/fhir/thursday
 */
export declare const thursday = "http://hl7.org/fhir/thursday";
/**
 * _rules
 *
 * (Modified) ElementDefinition.slicing.rules
 *
 * http://hl7.org/fhir/_rules
 */
export declare const _rules = "http://hl7.org/fhir/_rules";
/**
 * dependent
 *
 * StructureMap.group.rule.dependent: Which other rules to apply in the context of this rule.
 *
 * http://hl7.org/fhir/dependent
 */
export declare const dependent = "http://hl7.org/fhir/dependent";
/**
 * deliverFrom
 *
 * SupplyRequest.deliverFrom: Where the supply is expected to come from.
 *
 * http://hl7.org/fhir/deliverFrom
 */
export declare const deliverFrom = "http://hl7.org/fhir/deliverFrom";
/**
 * ImmunizationProtocolAppliedComponent
 *
 * ImmunizationProtocolAppliedComponent: The protocol (set of recommendations) being followed by the provider who administered the dose.
 *
 * http://hl7.org/fhir/ImmunizationProtocolAppliedComponent
 */
export declare const ImmunizationProtocolAppliedComponent = "http://hl7.org/fhir/ImmunizationProtocolAppliedComponent";
/**
 * actualGroup
 *
 * ResearchStudy.recruitment.actualGroup: Group of participants who were enrolled in study.
 *
 * http://hl7.org/fhir/actualGroup
 */
export declare const actualGroup = "http://hl7.org/fhir/actualGroup";
/**
 * Age
 *
 * A duration of time during which an organism (or a process) has existed.
 *
 * http://hl7.org/fhir/Age
 */
export declare const Age = "http://hl7.org/fhir/Age";
/**
 * subsumption
 *
 * TerminologyCapabilities.codeSystem.subsumption: True if subsumption is supported for this version of the code system.
 *
 * http://hl7.org/fhir/subsumption
 */
export declare const subsumption = "http://hl7.org/fhir/subsumption";
/**
 * ElementDefinitionConstraintComponent
 *
 * ElementDefinitionConstraintComponent: Formal constraints such as co-occurrence and other constraints that can be computationally evaluated within the context of the instance.
 *
 * http://hl7.org/fhir/ElementDefinitionConstraintComponent
 */
export declare const ElementDefinitionConstraintComponent = "http://hl7.org/fhir/ElementDefinitionConstraintComponent";
/**
 * subjectResults
 *
 * MeasureReport.group.stratifier.stratum.population.subjectResults: This element refers to a List of individual level MeasureReport resources, one for each subject in this population in this stratum.
 *
 * http://hl7.org/fhir/subjectResults
 */
export declare const subjectResults = "http://hl7.org/fhir/subjectResults";
/**
 * OperationDefinitionOverloadComponent
 *
 * OperationDefinitionOverloadComponent: Defines an appropriate combination of parameters to use when invoking this operation, to help code generators when generating overloaded parameter sets for this operation.
 *
 * http://hl7.org/fhir/OperationDefinitionOverloadComponent
 */
export declare const OperationDefinitionOverloadComponent = "http://hl7.org/fhir/OperationDefinitionOverloadComponent";
/**
 * recurrenceTemplate
 *
 * Appointment.recurrenceTemplate: The details of the recurrence pattern or template that is used to generate recurring appointments.
 *
 * http://hl7.org/fhir/recurrenceTemplate
 */
export declare const recurrenceTemplate = "http://hl7.org/fhir/recurrenceTemplate";
/**
 * doseForm
 *
 * MedicationKnowledge.definitional.doseForm: Describes the form of the item.  Powder; tablets; capsule.
 *
 * http://hl7.org/fhir/doseForm
 */
export declare const doseForm = "http://hl7.org/fhir/doseForm";
/**
 * adherence
 *
 * MedicationStatement.adherence: Indicates whether the medication is or is not being consumed or administered.
 *
 * http://hl7.org/fhir/adherence
 */
export declare const adherence = "http://hl7.org/fhir/adherence";
/**
 * ServiceRequest
 *
 * A record of a request for service such as diagnostic investigations, treatments, or operations to be performed.
 *
 * http://hl7.org/fhir/ServiceRequest
 */
export declare const ServiceRequest = "http://hl7.org/fhir/ServiceRequest";
/**
 * deviceIdentifier
 *
 * Device.udiCarrier.deviceIdentifier: The device identifier (DI) is a mandatory, fixed portion of a UDI that identifies the labeler and the specific version or model of a device.
 *
 * http://hl7.org/fhir/deviceIdentifier
 */
export declare const deviceIdentifier = "http://hl7.org/fhir/deviceIdentifier";
/**
 * _reasonLinkId
 *
 * (Modified) Contract.term.group.action.reasonLinkId
 *
 * http://hl7.org/fhir/_reasonLinkId
 */
export declare const _reasonLinkId = "http://hl7.org/fhir/_reasonLinkId";
/**
 * versionId
 *
 * Meta.versionId: The version specific identifier, as it appears in the version portion of the URL. This value changes when the resource is created, updated, or deleted.
 *
 * http://hl7.org/fhir/versionId
 */
export declare const versionId = "http://hl7.org/fhir/versionId";
/**
 * componentPart
 *
 * PackagedProductDefinition.packaging.packaging.componentPart: Is this a part of the packaging (e.g. a cap or bottle stopper), rather than the packaging itself (e.g. a bottle or vial). The latter type are designed be a container, but the former are not.
 *
 * http://hl7.org/fhir/componentPart
 */
export declare const componentPart = "http://hl7.org/fhir/componentPart";
/**
 * _value
 *
 * (Modified) ResearchStudy.label.value
 *
 * http://hl7.org/fhir/_value
 */
export declare const _value = "http://hl7.org/fhir/_value";
/**
 * TestReportParticipantComponent
 *
 * TestReportParticipantComponent: A participant in the test execution, either the execution engine, a client, or a server.
 *
 * http://hl7.org/fhir/TestReportParticipantComponent
 */
export declare const TestReportParticipantComponent = "http://hl7.org/fhir/TestReportParticipantComponent";
/**
 * morphology
 *
 * BodyStructure.morphology: The kind of structure being represented by the body structure at `BodyStructure.location`.  This can define both normal and abnormal morphologies.
 *
 * http://hl7.org/fhir/morphology
 */
export declare const morphology = "http://hl7.org/fhir/morphology";
/**
 * date
 *
 * ResearchStudy.date: The date (and optionally time) when the ResearchStudy Resource was last significantly changed. The date must change when the business version changes and it must change if the status code changes. In addition, it should change when the substantive content of the ResearchStudy Resource changes.
 *
 * http://hl7.org/fhir/date
 */
export declare const date = "http://hl7.org/fhir/date";
/**
 * _isModifier
 *
 * (Modified) ElementDefinition.isModifier
 *
 * http://hl7.org/fhir/_isModifier
 */
export declare const _isModifier = "http://hl7.org/fhir/_isModifier";
/**
 * _allDay
 *
 * (Modified) Availability.availableTime.allDay
 *
 * http://hl7.org/fhir/_allDay
 */
export declare const _allDay = "http://hl7.org/fhir/_allDay";
/**
 * contentReference
 *
 * ElementDefinition.contentReference: Identifies an element defined elsewhere in the definition whose content rules should be applied to the current element. ContentReferences bring across all the rules that are in the ElementDefinition for the element, including definitions, cardinality constraints, bindings, invariants etc.
 *
 * http://hl7.org/fhir/contentReference
 */
export declare const contentReference = "http://hl7.org/fhir/contentReference";
/**
 * _sunday
 *
 * (Modified) Appointment.recurrenceTemplate.weeklyTemplate.sunday
 *
 * http://hl7.org/fhir/_sunday
 */
export declare const _sunday = "http://hl7.org/fhir/_sunday";
/**
 * DeviceUsageAdherenceComponent
 *
 * DeviceUsageAdherenceComponent: This indicates how or if the device is being used.
 *
 * http://hl7.org/fhir/DeviceUsageAdherenceComponent
 */
export declare const DeviceUsageAdherenceComponent = "http://hl7.org/fhir/DeviceUsageAdherenceComponent";
/**
 * maxSingleDose
 *
 * AdministrableProductDefinition.routeOfAdministration.maxSingleDose: The maximum single dose that can be administered, specified using a numerical value and its unit of measurement.
 *
 * http://hl7.org/fhir/maxSingleDose
 */
export declare const maxSingleDose = "http://hl7.org/fhir/maxSingleDose";
/**
 * referenceRange
 *
 * Observation.component.referenceRange: Guidance on how to interpret the value by comparison to a normal or recommended range.
 *
 * http://hl7.org/fhir/referenceRange
 */
export declare const referenceRange = "http://hl7.org/fhir/referenceRange";
/**
 * _pages
 *
 * (Modified) Attachment.pages
 *
 * http://hl7.org/fhir/_pages
 */
export declare const _pages = "http://hl7.org/fhir/_pages";
/**
 * DeviceDefinitionGuidelineComponent
 *
 * DeviceDefinitionGuidelineComponent: Information aimed at providing directions for the usage of this model of device.
 *
 * http://hl7.org/fhir/DeviceDefinitionGuidelineComponent
 */
export declare const DeviceDefinitionGuidelineComponent = "http://hl7.org/fhir/DeviceDefinitionGuidelineComponent";
/**
 * _temperatureRange
 *
 * (Modified) SpecimenDefinition.typeTested.handling.temperatureRange
 *
 * http://hl7.org/fhir/_temperatureRange
 */
export declare const _temperatureRange = "http://hl7.org/fhir/_temperatureRange";
/**
 * _sequenceType
 *
 * (Modified) SubstanceProtein.sequenceType
 *
 * http://hl7.org/fhir/_sequenceType
 */
export declare const _sequenceType = "http://hl7.org/fhir/_sequenceType";
/**
 * _partNumber
 *
 * (Modified) DeviceDefinition.partNumber
 *
 * http://hl7.org/fhir/_partNumber
 */
export declare const _partNumber = "http://hl7.org/fhir/_partNumber";
/**
 * _term
 *
 * (Modified) Measure.term
 *
 * http://hl7.org/fhir/_term
 */
export declare const _term = "http://hl7.org/fhir/_term";
/**
 * StructureDefinitionDifferentialComponent
 *
 * StructureDefinitionDifferentialComponent: A differential view is expressed relative to the base StructureDefinition - a statement of differences that it applies.
 *
 * http://hl7.org/fhir/StructureDefinitionDifferentialComponent
 */
export declare const StructureDefinitionDifferentialComponent = "http://hl7.org/fhir/StructureDefinitionDifferentialComponent";
/**
 * _udi
 *
 * (Modified) Claim.item.udi
 *
 * http://hl7.org/fhir/_udi
 */
export declare const _udi = "http://hl7.org/fhir/_udi";
/**
 * _telecom
 *
 * (Modified) Patient.telecom
 *
 * http://hl7.org/fhir/_telecom
 */
export declare const _telecom = "http://hl7.org/fhir/_telecom";
/**
 * CitationCitedArtifactPublicationFormPublishedInComponent
 *
 * CitationCitedArtifactComponent.CitationCitedArtifactPublicationFormComponent.CitationCitedArtifactPublicationFormPublishedInComponent: The collection the cited article or artifact is published in.
 *
 * http://hl7.org/fhir/CitationCitedArtifactPublicationFormPublishedInComponent
 */
export declare const CitationCitedArtifactPublicationFormPublishedInComponent = "http://hl7.org/fhir/CitationCitedArtifactPublicationFormPublishedInComponent";
/**
 * _wasSubstituted
 *
 * (Modified) MedicationDispense.substitution.wasSubstituted
 *
 * http://hl7.org/fhir/_wasSubstituted
 */
export declare const _wasSubstituted = "http://hl7.org/fhir/_wasSubstituted";
/**
 * initial
 *
 * Questionnaire.item.item.initial: One or more values that should be pre-populated in the answer when initially rendering the questionnaire for user input.
 *
 * http://hl7.org/fhir/initial
 */
export declare const initial = "http://hl7.org/fhir/initial";
/**
 * doNotPerform
 *
 * Contract.term.action.doNotPerform: True if the term prohibits the  action.
 *
 * http://hl7.org/fhir/doNotPerform
 */
export declare const doNotPerform = "http://hl7.org/fhir/doNotPerform";
/**
 * diameter
 *
 * VisionPrescription.lensSpecification.diameter: Contact lens diameter measured in millimetres.
 *
 * http://hl7.org/fhir/diameter
 */
export declare const diameter = "http://hl7.org/fhir/diameter";
/**
 * _property
 *
 * (Modified) ValueSet.compose.include.filter.property
 *
 * http://hl7.org/fhir/_property
 */
export declare const _property = "http://hl7.org/fhir/_property";
/**
 * MessageHeaderResponseComponent
 *
 * MessageHeaderResponseComponent: Information about the message that this message is a response to.  Only present if this message is a response.
 *
 * http://hl7.org/fhir/MessageHeaderResponseComponent
 */
export declare const MessageHeaderResponseComponent = "http://hl7.org/fhir/MessageHeaderResponseComponent";
/**
 * Linkage
 *
 * Identifies two or more records (resource instances) that refer to the same real-world "occurrence".
 *
 * http://hl7.org/fhir/Linkage
 */
export declare const Linkage = "http://hl7.org/fhir/Linkage";
/**
 * permittedUnit
 *
 * ObservationDefinition.component.permittedUnit: Units allowed for the valueQuantity element in the instance observations conforming to this ObservationDefinition.
 *
 * http://hl7.org/fhir/permittedUnit
 */
export declare const permittedUnit = "http://hl7.org/fhir/permittedUnit";
/**
 * _sex
 *
 * (Modified) FamilyMemberHistory.sex
 *
 * http://hl7.org/fhir/_sex
 */
export declare const _sex = "http://hl7.org/fhir/_sex";
/**
 * genomeBuild
 *
 * GenomicStudy.analysis.genomeBuild: The reference genome build that is used in this analysis.
 *
 * http://hl7.org/fhir/genomeBuild
 */
export declare const genomeBuild = "http://hl7.org/fhir/genomeBuild";
/**
 * changePattern
 *
 * ClinicalImpression.changePattern: Change in the status/pattern of a subject's condition since previously assessed, such as worsening, improving, or no change.  It is a subjective assessment of the direction of the change.
 *
 * http://hl7.org/fhir/changePattern
 */
export declare const changePattern = "http://hl7.org/fhir/changePattern";
/**
 * MedicationRequestSubstitutionComponent
 *
 * MedicationRequestSubstitutionComponent: Indicates whether or not substitution can or should be part of the dispense. In some cases, substitution must happen, in other cases substitution must not happen. This block explains the prescriber's intent. If nothing is specified substitution may be done.
 *
 * http://hl7.org/fhir/MedicationRequestSubstitutionComponent
 */
export declare const MedicationRequestSubstitutionComponent = "http://hl7.org/fhir/MedicationRequestSubstitutionComponent";
/**
 * _authority
 *
 * (Modified) SubstanceDefinition.name.official.authority
 *
 * http://hl7.org/fhir/_authority
 */
export declare const _authority = "http://hl7.org/fhir/_authority";
/**
 * onBehalfOf
 *
 * Provenance.entity.agent.onBehalfOf: The agent that delegated authority to perform the activity performed by the agent.who element.
 *
 * http://hl7.org/fhir/onBehalfOf
 */
export declare const onBehalfOf = "http://hl7.org/fhir/onBehalfOf";
/**
 * _rateAggregation
 *
 * (Modified) Measure.group.rateAggregation
 *
 * http://hl7.org/fhir/_rateAggregation
 */
export declare const _rateAggregation = "http://hl7.org/fhir/_rateAggregation";
/**
 * managingOrganization
 *
 * Patient.managingOrganization: Organization that is the custodian of the patient record.
 *
 * http://hl7.org/fhir/managingOrganization
 */
export declare const managingOrganization = "http://hl7.org/fhir/managingOrganization";
/**
 * handling
 *
 * SpecimenDefinition.typeTested.handling: Set of instructions for preservation/transport of the specimen at a defined temperature interval, prior the testing process.
 *
 * http://hl7.org/fhir/handling
 */
export declare const handling = "http://hl7.org/fhir/handling";
/**
 * notConsumedReason
 *
 * NutritionIntake.consumedItem.notConsumedReason: Document the reason the food or fluid was not consumed, such as refused, held, etc.
 *
 * http://hl7.org/fhir/notConsumedReason
 */
export declare const notConsumedReason = "http://hl7.org/fhir/notConsumedReason";
/**
 * axis
 *
 * VisionPrescription.lensSpecification.axis: Adjustment for astigmatism measured in integer degrees.
 *
 * http://hl7.org/fhir/axis
 */
export declare const axis = "http://hl7.org/fhir/axis";
/**
 * _udiCarrier
 *
 * (Modified) Device.udiCarrier
 *
 * http://hl7.org/fhir/_udiCarrier
 */
export declare const _udiCarrier = "http://hl7.org/fhir/_udiCarrier";
/**
 * paymentBy
 *
 * Coverage.paymentBy: Link to the paying party and optionally what specifically they will be responsible to pay.
 *
 * http://hl7.org/fhir/paymentBy
 */
export declare const paymentBy = "http://hl7.org/fhir/paymentBy";
/**
 * _insurancePlan
 *
 * (Modified) Coverage.insurancePlan
 *
 * http://hl7.org/fhir/_insurancePlan
 */
export declare const _insurancePlan = "http://hl7.org/fhir/_insurancePlan";
/**
 * subDetailSequence
 *
 * ExplanationOfBenefit.addItem.subDetailSequence: The sequence number of the sub-details woithin the details within the claim item which this line is intended to replace.
 *
 * http://hl7.org/fhir/subDetailSequence
 */
export declare const subDetailSequence = "http://hl7.org/fhir/subDetailSequence";
/**
 * DataRequirementValueFilterComponent
 *
 * DataRequirementValueFilterComponent: Value filters specify additional constraints on the data for elements other than code-valued or date-valued. Each value filter specifies an additional constraint on the data (i.e. valueFilters are AND'ed, not OR'ed).
 *
 * http://hl7.org/fhir/DataRequirementValueFilterComponent
 */
export declare const DataRequirementValueFilterComponent = "http://hl7.org/fhir/DataRequirementValueFilterComponent";
/**
 * problem
 *
 * ClinicalImpression.problem: A list of the relevant problems/conditions for a patient.
 *
 * http://hl7.org/fhir/problem
 */
export declare const problem = "http://hl7.org/fhir/problem";
/**
 * initialFill
 *
 * MedicationRequest.dispenseRequest.initialFill: Indicates the quantity or duration for the first dispense of the medication.
 *
 * http://hl7.org/fhir/initialFill
 */
export declare const initialFill = "http://hl7.org/fhir/initialFill";
/**
 * _ManufacturedItemDefinition
 *
 * (Modified) ManufacturedItemDefinition
 *
 * http://hl7.org/fhir/_ManufacturedItemDefinition
 */
export declare const _ManufacturedItemDefinition = "http://hl7.org/fhir/_ManufacturedItemDefinition";
/**
 * _improvementNotation
 *
 * (Modified) MeasureReport.improvementNotation
 *
 * http://hl7.org/fhir/_improvementNotation
 */
export declare const _improvementNotation = "http://hl7.org/fhir/_improvementNotation";
/**
 * ClinicalUseDefinitionIndicationComponentOtherTherapy
 *
 * Information about the use of the medicinal product in relation to other therapies described as part of the indication.
 *
 * http://hl7.org/fhir/ClinicalUseDefinitionIndicationComponentOtherTherapy
 */
export declare const ClinicalUseDefinitionIndicationComponentOtherTherapy = "http://hl7.org/fhir/ClinicalUseDefinitionIndicationComponentOtherTherapy";
/**
 * fraction
 *
 * SubstanceSourceMaterial.fractionDescription.fraction: This element is capturing information about the fraction of a plant part, or human plasma for fractionation.
 *
 * http://hl7.org/fhir/fraction
 */
export declare const fraction = "http://hl7.org/fhir/fraction";
/**
 * _lastOccurrence
 *
 * (Modified) AllergyIntolerance.lastOccurrence
 *
 * http://hl7.org/fhir/_lastOccurrence
 */
export declare const _lastOccurrence = "http://hl7.org/fhir/_lastOccurrence";
/**
 * _assessment
 *
 * (Modified) Condition.stage.assessment
 *
 * http://hl7.org/fhir/_assessment
 */
export declare const _assessment = "http://hl7.org/fhir/_assessment";
/**
 * Patient
 *
 * Demographics and other administrative information about an individual or animal receiving care or other health-related services.
 *
 * http://hl7.org/fhir/Patient
 */
export declare const Patient = "http://hl7.org/fhir/Patient";
/**
 * _identified
 *
 * (Modified) DetectedIssue.identified
 *
 * http://hl7.org/fhir/_identified
 */
export declare const _identified = "http://hl7.org/fhir/_identified";
/**
 * ExplanationOfBenefitAdjudication
 *
 * The adjudication results which are presented at the header level rather than at the line-item or add-item levels.
 *
 * http://hl7.org/fhir/ExplanationOfBenefitAdjudication
 */
export declare const ExplanationOfBenefitAdjudication = "http://hl7.org/fhir/ExplanationOfBenefitAdjudication";
/**
 * _Subscription
 *
 * (Modified) Subscription
 *
 * http://hl7.org/fhir/_Subscription
 */
export declare const _Subscription = "http://hl7.org/fhir/_Subscription";
/**
 * tag
 *
 * Meta.tag: Tags applied to this resource. Tags are intended to be used to identify and relate resources to process and workflow, and applications are not required to consider the tags when interpreting the meaning of a resource.
 *
 * http://hl7.org/fhir/tag
 */
export declare const tag = "http://hl7.org/fhir/tag";
/**
 * _performed
 *
 * (Modified) FamilyMemberHistory.procedure.performed
 *
 * http://hl7.org/fhir/_performed
 */
export declare const _performed = "http://hl7.org/fhir/_performed";
/**
 * _formOf
 *
 * (Modified) AdministrableProductDefinition.formOf
 *
 * http://hl7.org/fhir/_formOf
 */
export declare const _formOf = "http://hl7.org/fhir/_formOf";
/**
 * DeviceDefinitionPackagingComponentPackagingPackaging
 *
 * Allows packages within packages.
 *
 * http://hl7.org/fhir/DeviceDefinitionPackagingComponentPackagingPackaging
 */
export declare const DeviceDefinitionPackagingComponentPackagingPackaging = "http://hl7.org/fhir/DeviceDefinitionPackagingComponentPackagingPackaging";
/**
 * _subrogation
 *
 * (Modified) Coverage.subrogation
 *
 * http://hl7.org/fhir/_subrogation
 */
export declare const _subrogation = "http://hl7.org/fhir/_subrogation";
/**
 * _deceased
 *
 * (Modified) Practitioner.deceased
 *
 * http://hl7.org/fhir/_deceased
 */
export declare const _deceased = "http://hl7.org/fhir/_deceased";
/**
 * relatedAccount
 *
 * Account.relatedAccount: Other associated accounts related to this account.
 *
 * http://hl7.org/fhir/relatedAccount
 */
export declare const relatedAccount = "http://hl7.org/fhir/relatedAccount";
/**
 * Transport
 *
 * Record of transport.
 *
 * http://hl7.org/fhir/Transport
 */
export declare const Transport = "http://hl7.org/fhir/Transport";
/**
 * Measure
 *
 * The Measure resource provides the definition of a quality measure.
 *
 * http://hl7.org/fhir/Measure
 */
export declare const Measure = "http://hl7.org/fhir/Measure";
/**
 * RiskAssessment
 *
 * An assessment of the likely outcome(s) for a patient or other subject as well as the likelihood of each outcome.
 *
 * http://hl7.org/fhir/RiskAssessment
 */
export declare const RiskAssessment = "http://hl7.org/fhir/RiskAssessment";
/**
 * _teardown
 *
 * (Modified) TestScript.teardown
 *
 * http://hl7.org/fhir/_teardown
 */
export declare const _teardown = "http://hl7.org/fhir/_teardown";
/**
 * degreeOfPolymerisation
 *
 * SubstancePolymer.repeat.repeatUnit.degreeOfPolymerisation: Applies to homopolymer and block co-polymers where the degree of polymerisation within a block can be described.
 *
 * http://hl7.org/fhir/degreeOfPolymerisation
 */
export declare const degreeOfPolymerisation = "http://hl7.org/fhir/degreeOfPolymerisation";
/**
 * _CoverageEligibilityRequest
 *
 * (Modified) CoverageEligibilityRequest
 *
 * http://hl7.org/fhir/_CoverageEligibilityRequest
 */
export declare const _CoverageEligibilityRequest = "http://hl7.org/fhir/_CoverageEligibilityRequest";
/**
 * _Medication
 *
 * (Modified) Medication
 *
 * http://hl7.org/fhir/_Medication
 */
export declare const _Medication = "http://hl7.org/fhir/_Medication";
/**
 * manufacturedDoseForm
 *
 * ManufacturedItemDefinition.manufacturedDoseForm: Dose form as manufactured and before any transformation into the pharmaceutical product.
 *
 * http://hl7.org/fhir/manufacturedDoseForm
 */
export declare const manufacturedDoseForm = "http://hl7.org/fhir/manufacturedDoseForm";
/**
 * sliceName
 *
 * GraphDefinition.link.sliceName: Which slice (if profiled).
 *
 * http://hl7.org/fhir/sliceName
 */
export declare const sliceName = "http://hl7.org/fhir/sliceName";
/**
 * dateAsserted
 *
 * MedicationStatement.dateAsserted: The date when the Medication Statement was asserted by the information source.
 *
 * http://hl7.org/fhir/dateAsserted
 */
export declare const dateAsserted = "http://hl7.org/fhir/dateAsserted";
/**
 * ContractParty
 *
 * Contract.TermTerm.ContractOffer.ContractParty: Offer Recipient.
 *
 * http://hl7.org/fhir/ContractParty
 */
export declare const ContractParty = "http://hl7.org/fhir/ContractParty";
/**
 * validationStatus
 *
 * VerificationResult.primarySource.validationStatus: Status of the validation of the target against the primary source (successful; failed; unknown).
 *
 * http://hl7.org/fhir/validationStatus
 */
export declare const validationStatus = "http://hl7.org/fhir/validationStatus";
/**
 * TestScriptMetadataComponent
 *
 * TestScriptMetadataComponent: The required capability must exist and are assumed to function correctly on the FHIR server being tested.
 *
 * http://hl7.org/fhir/TestScriptMetadataComponent
 */
export declare const TestScriptMetadataComponent = "http://hl7.org/fhir/TestScriptMetadataComponent";
/**
 * _headerField
 *
 * (Modified) TestScript.test.action.assert.headerField
 *
 * http://hl7.org/fhir/_headerField
 */
export declare const _headerField = "http://hl7.org/fhir/_headerField";
/**
 * geographicalLocation
 *
 * SubstanceSourceMaterial.geographicalLocation: The place/region where the plant is harvested or the places/regions where the animal source material has its habitat.
 *
 * http://hl7.org/fhir/geographicalLocation
 */
export declare const geographicalLocation = "http://hl7.org/fhir/geographicalLocation";
/**
 * versionNeeded
 *
 * CodeSystem.versionNeeded: This flag is used to signify that the code system does not commit to concept permanence across versions. If true, a version must be specified when referencing this code system.
 *
 * http://hl7.org/fhir/versionNeeded
 */
export declare const versionNeeded = "http://hl7.org/fhir/versionNeeded";
/**
 * ConceptDefinition
 *
 * CodeSystem.ConceptDefinition: Concepts that are in the code system. The concept definitions are inherently hierarchical, but the definitions must be consulted to determine what the meanings of the hierarchical relationships are.
 *
 * http://hl7.org/fhir/ConceptDefinition
 */
export declare const ConceptDefinition = "http://hl7.org/fhir/ConceptDefinition";
/**
 * _sigFormat
 *
 * (Modified) Signature.sigFormat
 *
 * http://hl7.org/fhir/_sigFormat
 */
export declare const _sigFormat = "http://hl7.org/fhir/_sigFormat";
/**
 * publishedIn
 *
 * Citation.citedArtifact.publicationForm.publishedIn: The collection the cited article or artifact is published in.
 *
 * http://hl7.org/fhir/publishedIn
 */
export declare const publishedIn = "http://hl7.org/fhir/publishedIn";
/**
 * sphere
 *
 * VisionPrescription.lensSpecification.sphere: Lens power measured in dioptres (0.25 units).
 *
 * http://hl7.org/fhir/sphere
 */
export declare const sphere = "http://hl7.org/fhir/sphere";
/**
 * _SubstanceDefinition
 *
 * (Modified) SubstanceDefinition
 *
 * http://hl7.org/fhir/_SubstanceDefinition
 */
export declare const _SubstanceDefinition = "http://hl7.org/fhir/_SubstanceDefinition";
/**
 * SubstanceDefinitionNameOfficialComponent
 *
 * SubstanceDefinitionNameComponentName.SubstanceDefinitionNameOfficialComponent: Details of the official nature of this name.
 *
 * http://hl7.org/fhir/SubstanceDefinitionNameOfficialComponent
 */
export declare const SubstanceDefinitionNameOfficialComponent = "http://hl7.org/fhir/SubstanceDefinitionNameOfficialComponent";
/**
 * _listRuleId
 *
 * (Modified) StructureMap.group.rule.rule.target.listRuleId
 *
 * http://hl7.org/fhir/_listRuleId
 */
export declare const _listRuleId = "http://hl7.org/fhir/_listRuleId";
/**
 * started
 *
 * ImagingStudy.series.started: The date and time the series was started.
 *
 * http://hl7.org/fhir/started
 */
export declare const started = "http://hl7.org/fhir/started";
/**
 * EvidenceVariable
 *
 * The EvidenceVariable resource describes an element that knowledge (Evidence) is about.
 *
 * http://hl7.org/fhir/EvidenceVariable
 */
export declare const EvidenceVariable = "http://hl7.org/fhir/EvidenceVariable";
/**
 * ResearchStudyOutcomeMeasureComponent
 *
 * ResearchStudyOutcomeMeasureComponent: An "outcome measure", "endpoint", "effect measure" or "measure of effect" is a specific measurement or observation used to quantify the effect of experimental variables on the participants in a study, or for observational studies, to describe patterns of diseases or traits or associations with exposures, risk factors or treatment.
 *
 * http://hl7.org/fhir/ResearchStudyOutcomeMeasureComponent
 */
export declare const ResearchStudyOutcomeMeasureComponent = "http://hl7.org/fhir/ResearchStudyOutcomeMeasureComponent";
/**
 * allowedResponse
 *
 * MessageDefinition.allowedResponse: Indicates what types of messages may be sent as an application-level response to this message.
 *
 * http://hl7.org/fhir/allowedResponse
 */
export declare const allowedResponse = "http://hl7.org/fhir/allowedResponse";
/**
 * _ElementDefinition
 *
 * (Modified) ElementDefinition
 *
 * http://hl7.org/fhir/_ElementDefinition
 */
export declare const _ElementDefinition = "http://hl7.org/fhir/_ElementDefinition";
/**
 * CitationCitedArtifactContributorshipComponent
 *
 * CitationCitedArtifactComponent.CitationCitedArtifactContributorshipComponent: This element is used to list authors and other contributors, their contact information, specific contributions, and summary statements.
 *
 * http://hl7.org/fhir/CitationCitedArtifactContributorshipComponent
 */
export declare const CitationCitedArtifactContributorshipComponent = "http://hl7.org/fhir/CitationCitedArtifactContributorshipComponent";
/**
 * _contentType
 *
 * (Modified) TestScript.test.action.assert.contentType
 *
 * http://hl7.org/fhir/_contentType
 */
export declare const _contentType = "http://hl7.org/fhir/_contentType";
/**
 * _DeviceUsage
 *
 * (Modified) DeviceUsage
 *
 * http://hl7.org/fhir/_DeviceUsage
 */
export declare const _DeviceUsage = "http://hl7.org/fhir/_DeviceUsage";
/**
 * DeviceDefinitionUdiDeviceIdentifierComponent
 *
 * DeviceDefinitionUdiDeviceIdentifierComponent: Unique device identifier (UDI) assigned to device label or package.  Note that the Device may include multiple udiCarriers as it either may include just the udiCarrier for the jurisdiction it is sold, or for multiple jurisdictions it could have been sold.
 *
 * http://hl7.org/fhir/DeviceDefinitionUdiDeviceIdentifierComponent
 */
export declare const DeviceDefinitionUdiDeviceIdentifierComponent = "http://hl7.org/fhir/DeviceDefinitionUdiDeviceIdentifierComponent";
/**
 * document
 *
 * CapabilityStatement.document: A document definition.
 *
 * http://hl7.org/fhir/document
 */
export declare const document = "http://hl7.org/fhir/document";
/**
 * event
 *
 * Composition.event: The clinical service, such as a colonoscopy or an appendectomy, being documented.
 *
 * http://hl7.org/fhir/event
 */
export declare const event = "http://hl7.org/fhir/event";
/**
 * Guarantor
 *
 * Account.Guarantor: The parties responsible for balancing the account if other payment options fall short.
 *
 * http://hl7.org/fhir/Guarantor
 */
export declare const Guarantor = "http://hl7.org/fhir/Guarantor";
/**
 * molecularWeight
 *
 * SubstanceDefinition.structure.molecularWeight: The molecular weight or weight range (for proteins, polymers or nucleic acids).
 *
 * http://hl7.org/fhir/molecularWeight
 */
export declare const molecularWeight = "http://hl7.org/fhir/molecularWeight";
/**
 * substitution
 *
 * MedicationRequest.substitution: Indicates whether or not substitution can or should be part of the dispense. In some cases, substitution must happen, in other cases substitution must not happen. This block explains the prescriber's intent. If nothing is specified substitution may be done.
 *
 * http://hl7.org/fhir/substitution
 */
export declare const substitution = "http://hl7.org/fhir/substitution";
/**
 * NutritionOrderSupplementComponent
 *
 * NutritionOrderSupplementComponent: Oral nutritional products given in order to add further nutritional value to the patient's diet.
 *
 * http://hl7.org/fhir/NutritionOrderSupplementComponent
 */
export declare const NutritionOrderSupplementComponent = "http://hl7.org/fhir/NutritionOrderSupplementComponent";
/**
 * _relativeRisk
 *
 * (Modified) RiskAssessment.prediction.relativeRisk
 *
 * http://hl7.org/fhir/_relativeRisk
 */
export declare const _relativeRisk = "http://hl7.org/fhir/_relativeRisk";
/**
 * _volume
 *
 * (Modified) Citation.citedArtifact.publicationForm.volume
 *
 * http://hl7.org/fhir/_volume
 */
export declare const _volume = "http://hl7.org/fhir/_volume";
/**
 * _manager
 *
 * (Modified) Consent.manager
 *
 * http://hl7.org/fhir/_manager
 */
export declare const _manager = "http://hl7.org/fhir/_manager";
/**
 * _presentation
 *
 * (Modified) Ingredient.substance.strength.presentation
 *
 * http://hl7.org/fhir/_presentation
 */
export declare const _presentation = "http://hl7.org/fhir/_presentation";
/**
 * _linkage
 *
 * (Modified) SubstanceNucleicAcid.subunit.linkage
 *
 * http://hl7.org/fhir/_linkage
 */
export declare const _linkage = "http://hl7.org/fhir/_linkage";
/**
 * isDefault
 *
 * TerminologyCapabilities.codeSystem.version.isDefault: If this is the default version for this code system.
 *
 * http://hl7.org/fhir/isDefault
 */
export declare const isDefault = "http://hl7.org/fhir/isDefault";
/**
 * BodyStructure
 *
 * Record details about an anatomical structure.  This resource may be used when a coded concept does not provide the necessary detail needed for the use case.
 *
 * http://hl7.org/fhir/BodyStructure
 */
export declare const BodyStructure = "http://hl7.org/fhir/BodyStructure";
/**
 * _relationship
 *
 * (Modified) Contract.term.group.asset.relationship
 *
 * http://hl7.org/fhir/_relationship
 */
export declare const _relationship = "http://hl7.org/fhir/_relationship";
/**
 * _maxDispense
 *
 * (Modified) MedicationKnowledge.regulatory.maxDispense
 *
 * http://hl7.org/fhir/_maxDispense
 */
export declare const _maxDispense = "http://hl7.org/fhir/_maxDispense";
/**
 * ChargeItemDefinition
 *
 * The ChargeItemDefinition resource provides the properties that apply to the (billing) codes necessary to calculate costs and prices. The properties may differ largely depending on type and realm, therefore this resource gives only a rough structure and requires profiling for each type of billing code system.
 *
 * http://hl7.org/fhir/ChargeItemDefinition
 */
export declare const ChargeItemDefinition = "http://hl7.org/fhir/ChargeItemDefinition";
/**
 * _SupplyDelivery
 *
 * (Modified) SupplyDelivery
 *
 * http://hl7.org/fhir/_SupplyDelivery
 */
export declare const _SupplyDelivery = "http://hl7.org/fhir/_SupplyDelivery";
/**
 * _specialArrangement
 *
 * (Modified) Encounter.specialArrangement
 *
 * http://hl7.org/fhir/_specialArrangement
 */
export declare const _specialArrangement = "http://hl7.org/fhir/_specialArrangement";
/**
 * DosageDoseAndRateComponent
 *
 * DosageDoseAndRateComponent: Depending on the resource,this is the amount of medication administered, to  be administered or typical amount to be administered.
 *
 * http://hl7.org/fhir/DosageDoseAndRateComponent
 */
export declare const DosageDoseAndRateComponent = "http://hl7.org/fhir/DosageDoseAndRateComponent";
/**
 * _guideline
 *
 * (Modified) DeviceDefinition.guideline
 *
 * http://hl7.org/fhir/_guideline
 */
export declare const _guideline = "http://hl7.org/fhir/_guideline";
/**
 * _grantee
 *
 * (Modified) Consent.grantee
 *
 * http://hl7.org/fhir/_grantee
 */
export declare const _grantee = "http://hl7.org/fhir/_grantee";
/**
 * serviced
 *
 * ExplanationOfBenefit.addItem.serviced
 *
 * http://hl7.org/fhir/serviced
 */
export declare const serviced = "http://hl7.org/fhir/serviced";
/**
 * _active
 *
 * (Modified) Patient.active
 *
 * http://hl7.org/fhir/_active
 */
export declare const _active = "http://hl7.org/fhir/_active";
/**
 * _preference
 *
 * (Modified) SpecimenDefinition.typeTested.preference
 *
 * http://hl7.org/fhir/_preference
 */
export declare const _preference = "http://hl7.org/fhir/_preference";
/**
 * useContext
 *
 * ExampleScenario.useContext: The content was developed with a focus and intent of supporting the contexts that are listed. These contexts may be general categories (gender, age, ...) or may be references to specific programs (insurance plans, studies, ...) and may be used to assist with indexing and searching for appropriate example scenario instances.
 *
 * http://hl7.org/fhir/useContext
 */
export declare const useContext = "http://hl7.org/fhir/useContext";
/**
 * _container
 *
 * (Modified) SpecimenDefinition.typeTested.container
 *
 * http://hl7.org/fhir/_container
 */
export declare const _container = "http://hl7.org/fhir/_container";
/**
 * justification
 *
 * Permission.justification: The asserted justification for using the data.
 *
 * http://hl7.org/fhir/justification
 */
export declare const justification = "http://hl7.org/fhir/justification";
/**
 * oralDiet
 *
 * NutritionOrder.oralDiet: Diet given orally in contrast to enteral (tube) feeding.
 *
 * http://hl7.org/fhir/oralDiet
 */
export declare const oralDiet = "http://hl7.org/fhir/oralDiet";
/**
 * _testingDestination
 *
 * (Modified) SpecimenDefinition.typeTested.testingDestination
 *
 * http://hl7.org/fhir/_testingDestination
 */
export declare const _testingDestination = "http://hl7.org/fhir/_testingDestination";
/**
 * lastRevisionDate
 *
 * Citation.citedArtifact.publicationForm.lastRevisionDate: The date the article was last revised or updated in the database.
 *
 * http://hl7.org/fhir/lastRevisionDate
 */
export declare const lastRevisionDate = "http://hl7.org/fhir/lastRevisionDate";
/**
 * NutritionIntakeIngredientLabelComponent
 *
 * NutritionIntakeIngredientLabelComponent: Total nutrient amounts for the whole meal, product, serving, etc.
 *
 * http://hl7.org/fhir/NutritionIntakeIngredientLabelComponent
 */
export declare const NutritionIntakeIngredientLabelComponent = "http://hl7.org/fhir/NutritionIntakeIngredientLabelComponent";
/**
 * QuestionnaireResponseItemComponentItem
 *
 * Sub-questions, sub-groups or display items nested beneath a group.
 *
 * http://hl7.org/fhir/QuestionnaireResponseItemComponentItem
 */
export declare const QuestionnaireResponseItemComponentItem = "http://hl7.org/fhir/QuestionnaireResponseItemComponentItem";
/**
 * PermissionJustificationComponent
 *
 * PermissionJustificationComponent: The asserted justification for using the data.
 *
 * http://hl7.org/fhir/PermissionJustificationComponent
 */
export declare const PermissionJustificationComponent = "http://hl7.org/fhir/PermissionJustificationComponent";
/**
 * recorder
 *
 * Procedure.recorder: Individual who recorded the record and takes responsibility for its content.
 *
 * http://hl7.org/fhir/recorder
 */
export declare const recorder = "http://hl7.org/fhir/recorder";
/**
 * ImmunizationRecommendationRecommendationDateCriterionComponent
 *
 * ImmunizationRecommendationRecommendationComponent.ImmunizationRecommendationRecommendationDateCriterionComponent: Vaccine date recommendations.  For example, earliest date to administer, latest date to administer, etc.
 *
 * http://hl7.org/fhir/ImmunizationRecommendationRecommendationDateCriterionComponent
 */
export declare const ImmunizationRecommendationRecommendationDateCriterionComponent = "http://hl7.org/fhir/ImmunizationRecommendationRecommendationDateCriterionComponent";
/**
 * _focus
 *
 * (Modified) ServiceRequest.focus
 *
 * http://hl7.org/fhir/_focus
 */
export declare const _focus = "http://hl7.org/fhir/_focus";
/**
 * countingDateTime
 *
 * InventoryReport.inventoryListing.countingDateTime: The date and time when the items were counted.
 *
 * http://hl7.org/fhir/countingDateTime
 */
export declare const countingDateTime = "http://hl7.org/fhir/countingDateTime";
/**
 * MedicationKnowledge
 *
 * Information about a medication that is used to support knowledge.
 *
 * http://hl7.org/fhir/MedicationKnowledge
 */
export declare const MedicationKnowledge = "http://hl7.org/fhir/MedicationKnowledge";
/**
 * ConditionDefinition
 *
 * A definition of a condition and information relevant to managing it.
 *
 * http://hl7.org/fhir/ConditionDefinition
 */
export declare const ConditionDefinition = "http://hl7.org/fhir/ConditionDefinition";
/**
 * noMap
 *
 * ConceptMap.group.element.noMap: If noMap = true this indicates that no mapping to a target concept exists for this source concept.
 *
 * http://hl7.org/fhir/noMap
 */
export declare const noMap = "http://hl7.org/fhir/noMap";
/**
 * _userSelected
 *
 * (Modified) Coding.userSelected
 *
 * http://hl7.org/fhir/_userSelected
 */
export declare const _userSelected = "http://hl7.org/fhir/_userSelected";
/**
 * appointmentRequired
 *
 * HealthcareService.appointmentRequired: Indicates whether or not a prospective consumer will require an appointment for a particular service at a site to be provided by the Organization. Indicates if an appointment is required for access to this service.
 *
 * http://hl7.org/fhir/appointmentRequired
 */
export declare const appointmentRequired = "http://hl7.org/fhir/appointmentRequired";
/**
 * _numberOfStudies
 *
 * (Modified) Evidence.statistic.sampleSize.numberOfStudies
 *
 * http://hl7.org/fhir/_numberOfStudies
 */
export declare const _numberOfStudies = "http://hl7.org/fhir/_numberOfStudies";
/**
 * capabilities
 *
 * TestScript.metadata.capability.capabilities: Minimum capabilities required of server for test script to execute successfully.   If server does not meet at a minimum the referenced capability statement, then all tests in this script are skipped.
 *
 * http://hl7.org/fhir/capabilities
 */
export declare const capabilities = "http://hl7.org/fhir/capabilities";
/**
 * Benefit
 *
 * CoverageEligibilityResponse.Insurance.Items.Benefit: Benefits used to date.
 *
 * http://hl7.org/fhir/Benefit
 */
export declare const Benefit = "http://hl7.org/fhir/Benefit";
/**
 * _uri
 *
 * (Modified) ImplementationGuide.dependsOn.uri
 *
 * http://hl7.org/fhir/_uri
 */
export declare const _uri = "http://hl7.org/fhir/_uri";
/**
 * _max
 *
 * (Modified) StructureMap.group.rule.rule.source.max
 *
 * http://hl7.org/fhir/_max
 */
export declare const _max = "http://hl7.org/fhir/_max";
/**
 * inactive
 *
 * ValueSet.expansion.contains.contains.inactive: If the concept is inactive in the code system that defines it. Inactive codes are those that are no longer to be used, but are maintained by the code system for understanding legacy data. It might not be known or specified whether a concept is inactive (and it may depend on the context of use).
 *
 * http://hl7.org/fhir/inactive
 */
export declare const inactive = "http://hl7.org/fhir/inactive";
/**
 * other
 *
 * Patient.link.other: Link to a Patient or RelatedPerson resource that concerns the same actual individual.
 *
 * http://hl7.org/fhir/other
 */
export declare const other = "http://hl7.org/fhir/other";
/**
 * dependsOn
 *
 * ImplementationGuide.dependsOn: Another implementation guide that this implementation depends on. Typically, an implementation guide uses value sets, profiles etc.defined in other implementation guides.
 *
 * http://hl7.org/fhir/dependsOn
 */
export declare const dependsOn = "http://hl7.org/fhir/dependsOn";
/**
 * citedArtifact
 *
 * Citation.citedArtifact: The article or artifact being described.
 *
 * http://hl7.org/fhir/citedArtifact
 */
export declare const citedArtifact = "http://hl7.org/fhir/citedArtifact";
/**
 * fixture
 *
 * TestScript.fixture: Fixture in the test script - by reference (uri). All fixtures are required for the test script to execute.
 *
 * http://hl7.org/fhir/fixture
 */
export declare const fixture = "http://hl7.org/fhir/fixture";
/**
 * _insurer
 *
 * (Modified) ExplanationOfBenefit.insurer
 *
 * http://hl7.org/fhir/_insurer
 */
export declare const _insurer = "http://hl7.org/fhir/_insurer";
/**
 * _endParam
 *
 * (Modified) CompartmentDefinition.resource.endParam
 *
 * http://hl7.org/fhir/_endParam
 */
export declare const _endParam = "http://hl7.org/fhir/_endParam";
/**
 * continuous
 *
 * Goal.continuous: After meeting the goal, ongoing activity is needed to sustain the goal objective.
 *
 * http://hl7.org/fhir/continuous
 */
export declare const continuous = "http://hl7.org/fhir/continuous";
/**
 * SubstancePolymerRepeatRepeatUnitStructuralRepresentationComponent
 *
 * SubstancePolymerRepeatComponent.SubstancePolymerRepeatRepeatUnitComponent.SubstancePolymerRepeatRepeatUnitStructuralRepresentationComponent: A graphical structure for this SRU.
 *
 * http://hl7.org/fhir/SubstancePolymerRepeatRepeatUnitStructuralRepresentationComponent
 */
export declare const SubstancePolymerRepeatRepeatUnitStructuralRepresentationComponent = "http://hl7.org/fhir/SubstancePolymerRepeatRepeatUnitStructuralRepresentationComponent";
/**
 * _responsibleOrganization
 *
 * (Modified) InventoryItem.responsibleOrganization
 *
 * http://hl7.org/fhir/_responsibleOrganization
 */
export declare const _responsibleOrganization = "http://hl7.org/fhir/_responsibleOrganization";
/**
 * url
 *
 * ChargeItemDefinition.url: An absolute URI that is used to identify this charge item definition when it is referenced in a specification, model, design or an instance; also called its canonical identifier. This SHOULD be globally unique and SHOULD be a literal address at which an authoritative instance of this charge item definition is (or will be) published. This URL can be the target of a canonical reference. It SHALL remain the same when the charge item definition is stored on different servers.
 *
 * http://hl7.org/fhir/url
 */
export declare const url = "http://hl7.org/fhir/url";
/**
 * compareToSourceExpression
 *
 * TestScript.test.action.assert.compareToSourceExpression: The FHIRPath expression for a specific value to evaluate against the source fixture. When compareToSourceId is defined, either compareToSourceExpression or compareToSourcePath must be defined, but not both.
 *
 * http://hl7.org/fhir/compareToSourceExpression
 */
export declare const compareToSourceExpression = "http://hl7.org/fhir/compareToSourceExpression";
/**
 * nutrient
 *
 * NutritionProduct.nutrient: The product's nutritional information expressed by the nutrients.
 *
 * http://hl7.org/fhir/nutrient
 */
export declare const nutrient = "http://hl7.org/fhir/nutrient";
/**
 * _subjectResults
 *
 * (Modified) MeasureReport.group.stratifier.stratum.population.subjectResults
 *
 * http://hl7.org/fhir/_subjectResults
 */
export declare const _subjectResults = "http://hl7.org/fhir/_subjectResults";
/**
 * DocumentReferenceRelatesToComponent
 *
 * DocumentReferenceRelatesToComponent: Relationships that this document has with other document references that already exist.
 *
 * http://hl7.org/fhir/DocumentReferenceRelatesToComponent
 */
export declare const DocumentReferenceRelatesToComponent = "http://hl7.org/fhir/DocumentReferenceRelatesToComponent";
/**
 * ImagingStudy
 *
 * Representation of the content produced in a DICOM imaging study. A study comprises a set of series, each of which includes a set of Service-Object Pair Instances (SOP Instances - images or other data) acquired or produced in a common context.  A series is of only one modality (e.g. X-ray, CT, MR, ultrasound), but a study may have multiple series of different modalities.
 *
 * http://hl7.org/fhir/ImagingStudy
 */
export declare const ImagingStudy = "http://hl7.org/fhir/ImagingStudy";
/**
 * AppointmentRecurrenceTemplateYearlyTemplateComponent
 *
 * AppointmentRecurrenceTemplateComponent.AppointmentRecurrenceTemplateYearlyTemplateComponent: Information about yearly recurring appointments.
 *
 * http://hl7.org/fhir/AppointmentRecurrenceTemplateYearlyTemplateComponent
 */
export declare const AppointmentRecurrenceTemplateYearlyTemplateComponent = "http://hl7.org/fhir/AppointmentRecurrenceTemplateYearlyTemplateComponent";
/**
 * SpecimenFeatureComponent
 *
 * SpecimenFeatureComponent: A physical feature or landmark on a specimen, highlighted for context by the collector of the specimen (e.g. surgeon), that identifies the type of feature as well as its meaning (e.g. the red ink indicating the resection margin of the right lobe of the excised prostate tissue or wire loop at radiologically suspected tumor location).
 *
 * http://hl7.org/fhir/SpecimenFeatureComponent
 */
export declare const SpecimenFeatureComponent = "http://hl7.org/fhir/SpecimenFeatureComponent";
/**
 * _ServiceRequest
 *
 * (Modified) ServiceRequest
 *
 * http://hl7.org/fhir/_ServiceRequest
 */
export declare const _ServiceRequest = "http://hl7.org/fhir/_ServiceRequest";
/**
 * tester
 *
 * TestReport.tester: Name of the tester producing this report (Organization or individual).
 *
 * http://hl7.org/fhir/tester
 */
export declare const tester = "http://hl7.org/fhir/tester";
/**
 * seriousness
 *
 * AdverseEvent.seriousness: Assessment whether this event, or averted event, was of clinical importance.
 *
 * http://hl7.org/fhir/seriousness
 */
export declare const seriousness = "http://hl7.org/fhir/seriousness";
/**
 * isDefining
 *
 * SubstancePolymer.monomerSet.startingMaterial.isDefining: Used to specify whether the attribute described is a defining element for the unique identification of the polymer.
 *
 * http://hl7.org/fhir/isDefining
 */
export declare const isDefining = "http://hl7.org/fhir/isDefining";
/**
 * contributingFactor
 *
 * AdverseEvent.contributingFactor: The contributing factors suspected to have increased the probability or severity of the adverse event.
 *
 * http://hl7.org/fhir/contributingFactor
 */
export declare const contributingFactor = "http://hl7.org/fhir/contributingFactor";
/**
 * CapabilityStatement
 *
 * A Capability Statement documents a set of capabilities (behaviors) of a FHIR Server or Client for a particular version of FHIR that may be used as a statement of actual server functionality or a statement of required or desired server implementation.
 *
 * http://hl7.org/fhir/CapabilityStatement
 */
export declare const CapabilityStatement = "http://hl7.org/fhir/CapabilityStatement";
/**
 * _ImagingSelection
 *
 * (Modified) ImagingSelection
 *
 * http://hl7.org/fhir/_ImagingSelection
 */
export declare const _ImagingSelection = "http://hl7.org/fhir/_ImagingSelection";
/**
 * _unmapped
 *
 * (Modified) ConceptMap.group.unmapped
 *
 * http://hl7.org/fhir/_unmapped
 */
export declare const _unmapped = "http://hl7.org/fhir/_unmapped";
/**
 * compositional
 *
 * TerminologyCapabilities.codeSystem.version.compositional: If the compositional grammar defined by the code system is supported.
 *
 * http://hl7.org/fhir/compositional
 */
export declare const compositional = "http://hl7.org/fhir/compositional";
/**
 * fundsReserveRequested
 *
 * ExplanationOfBenefit.fundsReserveRequested: A code to indicate whether and for whom funds are to be reserved for future claims.
 *
 * http://hl7.org/fhir/fundsReserveRequested
 */
export declare const fundsReserveRequested = "http://hl7.org/fhir/fundsReserveRequested";
/**
 * Total
 *
 * ExplanationOfBenefit.Total: Categorized monetary totals for the adjudication.
 *
 * http://hl7.org/fhir/Total
 */
export declare const Total = "http://hl7.org/fhir/Total";
/**
 * _citeAs
 *
 * (Modified) EvidenceReport.citeAs
 *
 * http://hl7.org/fhir/_citeAs
 */
export declare const _citeAs = "http://hl7.org/fhir/_citeAs";
/**
 * _protein
 *
 * (Modified) SubstanceDefinition.protein
 *
 * http://hl7.org/fhir/_protein
 */
export declare const _protein = "http://hl7.org/fhir/_protein";
/**
 * _referenceRange
 *
 * (Modified) Observation.component.referenceRange
 *
 * http://hl7.org/fhir/_referenceRange
 */
export declare const _referenceRange = "http://hl7.org/fhir/_referenceRange";
/**
 * complication
 *
 * Procedure.complication: Any complications that occurred during the procedure, or in the immediate post-performance period. These are generally tracked separately from the notes, which will typically describe the procedure itself rather than any 'post procedure' issues.
 *
 * http://hl7.org/fhir/complication
 */
export declare const complication = "http://hl7.org/fhir/complication";
/**
 * SubscriptionTopicResourceTriggerComponent
 *
 * SubscriptionTopicResourceTriggerComponent: A definition of a resource-based event that triggers a notification based on the SubscriptionTopic. The criteria may be just a human readable description and/or a full FHIR search string or FHIRPath expression. Multiple triggers are considered OR joined (e.g., a resource update matching ANY of the definitions will trigger a notification).
 *
 * http://hl7.org/fhir/SubscriptionTopicResourceTriggerComponent
 */
export declare const SubscriptionTopicResourceTriggerComponent = "http://hl7.org/fhir/SubscriptionTopicResourceTriggerComponent";
/**
 * estimate
 *
 * Account.balance.estimate: The amount is only an estimated value - this is likely common for `current` term balances, but not with known terms (that were generated by a backend process).
 *
 * http://hl7.org/fhir/estimate
 */
export declare const estimate = "http://hl7.org/fhir/estimate";
/**
 * _material
 *
 * (Modified) SpecimenDefinition.typeTested.container.material
 *
 * http://hl7.org/fhir/_material
 */
export declare const _material = "http://hl7.org/fhir/_material";
/**
 * Item
 *
 * ClaimResponse.Item: A claim line. Either a simple (a product or service) or a 'group' of details which can also be a simple items or groups of sub-details.
 *
 * http://hl7.org/fhir/Item
 */
export declare const Item = "http://hl7.org/fhir/Item";
/**
 * encodeRequestUrl
 *
 * TestScript.teardown.action.operation.encodeRequestUrl: Whether or not to implicitly send the request url in encoded format. The default is true to match the standard RESTful client behavior. Set to false when communicating with a server that does not support encoded url paths.
 *
 * http://hl7.org/fhir/encodeRequestUrl
 */
export declare const encodeRequestUrl = "http://hl7.org/fhir/encodeRequestUrl";
/**
 * _currentLocation
 *
 * (Modified) Transport.currentLocation
 *
 * http://hl7.org/fhir/_currentLocation
 */
export declare const _currentLocation = "http://hl7.org/fhir/_currentLocation";
/**
 * style
 *
 * Citation.citedArtifact.contributorship.summary.style: The format for the display string, such as author last name with first letter capitalized followed by forename initials.
 *
 * http://hl7.org/fhir/style
 */
export declare const style = "http://hl7.org/fhir/style";
/**
 * method
 *
 * TestScript.test.action.operation.method: The HTTP method the test engine MUST use for this operation regardless of any other operation details.
 *
 * http://hl7.org/fhir/method
 */
export declare const method = "http://hl7.org/fhir/method";
/**
 * _MarketingStatus
 *
 * (Modified) MarketingStatus
 *
 * http://hl7.org/fhir/_MarketingStatus
 */
export declare const _MarketingStatus = "http://hl7.org/fhir/_MarketingStatus";
/**
 * group
 *
 * StructureMap.group: Organizes the mapping into managable chunks for human review/ease of maintenance.
 *
 * http://hl7.org/fhir/group
 */
export declare const group = "http://hl7.org/fhir/group";
/**
 * achievementStatus
 *
 * Goal.achievementStatus: Describes the progression, or lack thereof, towards the goal against the target.
 *
 * http://hl7.org/fhir/achievementStatus
 */
export declare const achievementStatus = "http://hl7.org/fhir/achievementStatus";
/**
 * evaluatedResource
 *
 * MeasureReport.evaluatedResource: Evaluated resources are used to capture what data was involved in the calculation of a measure. This usage is only allowed for individual reports to ensure that the size of the MeasureReport resource is bounded.
 *
 * http://hl7.org/fhir/evaluatedResource
 */
export declare const evaluatedResource = "http://hl7.org/fhir/evaluatedResource";
/**
 * _udiDeviceIdentifier
 *
 * (Modified) DeviceDefinition.packaging.packaging.udiDeviceIdentifier
 *
 * http://hl7.org/fhir/_udiDeviceIdentifier
 */
export declare const _udiDeviceIdentifier = "http://hl7.org/fhir/_udiDeviceIdentifier";
/**
 * _RelatedPerson
 *
 * (Modified) RelatedPerson
 *
 * http://hl7.org/fhir/_RelatedPerson
 */
export declare const _RelatedPerson = "http://hl7.org/fhir/_RelatedPerson";
/**
 * dateTime
 *
 * A date, date-time or partial date (e.g. just year or year + month).  If hours and minutes are specified, a UTC offset SHALL be populated. The format is a union of the schema types gYear, gYearMonth, date and dateTime. Seconds must be provided due to schema type constraints but may be zero-filled and may be ignored.                 Dates SHALL be valid dates.
 *
 * http://hl7.org/fhir/dateTime
 */
export declare const dateTime = "http://hl7.org/fhir/dateTime";
/**
 * _intervalUnit
 *
 * (Modified) SampledData.intervalUnit
 *
 * http://hl7.org/fhir/_intervalUnit
 */
export declare const _intervalUnit = "http://hl7.org/fhir/_intervalUnit";
/**
 * text
 *
 * Annotation.text: The text of the annotation in markdown format.
 *
 * http://hl7.org/fhir/text
 */
export declare const text = "http://hl7.org/fhir/text";
/**
 * _contact
 *
 * (Modified) DeviceDefinition.contact
 *
 * http://hl7.org/fhir/_contact
 */
export declare const _contact = "http://hl7.org/fhir/_contact";
/**
 * searchInclude
 *
 * CapabilityStatement.rest.resource.searchInclude: A list of _include values supported by the server.
 *
 * http://hl7.org/fhir/searchInclude
 */
export declare const searchInclude = "http://hl7.org/fhir/searchInclude";
/**
 * _fivePrime
 *
 * (Modified) SubstanceNucleicAcid.subunit.fivePrime
 *
 * http://hl7.org/fhir/_fivePrime
 */
export declare const _fivePrime = "http://hl7.org/fhir/_fivePrime";
/**
 * timeOfDay
 *
 * Timing.repeat.timeOfDay: Specified time of day for action to take place.
 *
 * http://hl7.org/fhir/timeOfDay
 */
export declare const timeOfDay = "http://hl7.org/fhir/timeOfDay";
/**
 * originRelationshipType
 *
 * BiologicallyDerivedProductDispense.originRelationshipType: Indicates the relationship between the donor of the biologically derived product and the intended recipient.
 *
 * http://hl7.org/fhir/originRelationshipType
 */
export declare const originRelationshipType = "http://hl7.org/fhir/originRelationshipType";
/**
 * CitationClassificationComponent
 *
 * CitationClassificationComponent: The assignment to an organizing scheme.
 *
 * http://hl7.org/fhir/CitationClassificationComponent
 */
export declare const CitationClassificationComponent = "http://hl7.org/fhir/CitationClassificationComponent";
/**
 * _plannedStartDate
 *
 * (Modified) EncounterHistory.plannedStartDate
 *
 * http://hl7.org/fhir/_plannedStartDate
 */
export declare const _plannedStartDate = "http://hl7.org/fhir/_plannedStartDate";
/**
 * documentType
 *
 * Consent.provision.provision.documentType: The documentType(s) covered by this provision. The type can be a CDA document, or some other type that indicates what sort of information the consent relates to.
 *
 * http://hl7.org/fhir/documentType
 */
export declare const documentType = "http://hl7.org/fhir/documentType";
/**
 * CoverageEligibilityRequestEventComponent
 *
 * CoverageEligibilityRequestEventComponent: Information code for an event with a corresponding date or period.
 *
 * http://hl7.org/fhir/CoverageEligibilityRequestEventComponent
 */
export declare const CoverageEligibilityRequestEventComponent = "http://hl7.org/fhir/CoverageEligibilityRequestEventComponent";
/**
 * _milestone
 *
 * (Modified) ResearchSubject.progress.milestone
 *
 * http://hl7.org/fhir/_milestone
 */
export declare const _milestone = "http://hl7.org/fhir/_milestone";
/**
 * page
 *
 * ImplementationGuide.definition.page.page: Nested Pages/Sections under this page.
 *
 * http://hl7.org/fhir/page
 */
export declare const page = "http://hl7.org/fhir/page";
/**
 * params
 *
 * TestScript.setup.action.operation.params: Path plus parameters after [type].  Used to set parts of the request URL explicitly.
 *
 * http://hl7.org/fhir/params
 */
export declare const params = "http://hl7.org/fhir/params";
/**
 * regionsCalled
 *
 * GenomicStudy.analysis.regionsCalled: Genomic regions actually called in the analysis event (BED file).
 *
 * http://hl7.org/fhir/regionsCalled
 */
export declare const regionsCalled = "http://hl7.org/fhir/regionsCalled";
/**
 * conditionalCreate
 *
 * CapabilityStatement.rest.resource.conditionalCreate: A flag that indicates that the server supports conditional create.
 *
 * http://hl7.org/fhir/conditionalCreate
 */
export declare const conditionalCreate = "http://hl7.org/fhir/conditionalCreate";
/**
 * lensSpecification
 *
 * VisionPrescription.lensSpecification: Contain the details of  the individual lens specifications and serves as the authorization for the fullfillment by certified professionals.
 *
 * http://hl7.org/fhir/lensSpecification
 */
export declare const lensSpecification = "http://hl7.org/fhir/lensSpecification";
/**
 * _grantor
 *
 * (Modified) Consent.grantor
 *
 * http://hl7.org/fhir/_grantor
 */
export declare const _grantor = "http://hl7.org/fhir/_grantor";
/**
 * coverage
 *
 * Account.coverage.coverage: The party(s) that contribute to payment (or part of) of the charges applied to this account (including self-pay).
 *
 * A coverage may only be responsible for specific types of charges, and the sequence of the coverages in the account could be important when processing billing.
 *
 * http://hl7.org/fhir/coverage
 */
export declare const coverage = "http://hl7.org/fhir/coverage";
/**
 * authorizationSupporting
 *
 * CoverageEligibilityResponse.insurance.item.authorizationSupporting: Codes or comments regarding information or actions associated with the preauthorization.
 *
 * http://hl7.org/fhir/authorizationSupporting
 */
export declare const authorizationSupporting = "http://hl7.org/fhir/authorizationSupporting";
/**
 * ElementDefinitionBindingAdditionalComponent
 *
 * ElementDefinitionBindingComponent.ElementDefinitionBindingAdditionalComponent: Additional bindings that help applications implementing this element. Additional bindings do not replace the main binding but provide more information and/or context.
 *
 * http://hl7.org/fhir/ElementDefinitionBindingAdditionalComponent
 */
export declare const ElementDefinitionBindingAdditionalComponent = "http://hl7.org/fhir/ElementDefinitionBindingAdditionalComponent";
/**
 * _benefit
 *
 * (Modified) InsurancePlan.plan.specificCost.benefit
 *
 * http://hl7.org/fhir/_benefit
 */
export declare const _benefit = "http://hl7.org/fhir/_benefit";
/**
 * _testData
 *
 * (Modified) TestPlan.testCase.testData
 *
 * http://hl7.org/fhir/_testData
 */
export declare const _testData = "http://hl7.org/fhir/_testData";
/**
 * _OrganizationAffiliation
 *
 * (Modified) OrganizationAffiliation
 *
 * http://hl7.org/fhir/_OrganizationAffiliation
 */
export declare const _OrganizationAffiliation = "http://hl7.org/fhir/_OrganizationAffiliation";
/**
 * excludedStructure
 *
 * BodyStructure.excludedStructure: The anatomical location(s) or region(s) not occupied or represented by the specimen, lesion, or body structure.
 *
 * http://hl7.org/fhir/excludedStructure
 */
export declare const excludedStructure = "http://hl7.org/fhir/excludedStructure";
/**
 * _searchRevInclude
 *
 * (Modified) CapabilityStatement.rest.resource.searchRevInclude
 *
 * http://hl7.org/fhir/_searchRevInclude
 */
export declare const _searchRevInclude = "http://hl7.org/fhir/_searchRevInclude";
/**
 * serviceProvisionCode
 *
 * HealthcareService.serviceProvisionCode: The code(s) that detail the conditions under which the healthcare service is available/offered.
 *
 * http://hl7.org/fhir/serviceProvisionCode
 */
export declare const serviceProvisionCode = "http://hl7.org/fhir/serviceProvisionCode";
/**
 * typeMode
 *
 * StructureMap.group.typeMode: If this is the default rule set to apply for the source type or this combination of types.
 *
 * http://hl7.org/fhir/typeMode
 */
export declare const typeMode = "http://hl7.org/fhir/typeMode";
/**
 * ValueSetScopeComponent
 *
 * ValueSetScopeComponent: Description of the semantic space the Value Set Expansion is intended to cover and should further clarify the text in ValueSet.description.
 *
 * http://hl7.org/fhir/ValueSetScopeComponent
 */
export declare const ValueSetScopeComponent = "http://hl7.org/fhir/ValueSetScopeComponent";
/**
 * SupplyRequestParameterComponent
 *
 * SupplyRequestParameterComponent: Specific parameters for the ordered item.  For example, the size of the indicated item.
 *
 * http://hl7.org/fhir/SupplyRequestParameterComponent
 */
export declare const SupplyRequestParameterComponent = "http://hl7.org/fhir/SupplyRequestParameterComponent";
/**
 * attributeEstimate
 *
 * Evidence.statistic.modelCharacteristic.attributeEstimate: An attribute of the statistic used as a model characteristic.
 *
 * http://hl7.org/fhir/attributeEstimate
 */
export declare const attributeEstimate = "http://hl7.org/fhir/attributeEstimate";
/**
 * immutable
 *
 * ValueSet.immutable: If this is set to 'true', then no new versions of the content logical definition can be created.  Note: Other metadata might still change.
 *
 * http://hl7.org/fhir/immutable
 */
export declare const immutable = "http://hl7.org/fhir/immutable";
/**
 * _relatedAccount
 *
 * (Modified) Account.relatedAccount
 *
 * http://hl7.org/fhir/_relatedAccount
 */
export declare const _relatedAccount = "http://hl7.org/fhir/_relatedAccount";
/**
 * _RiskAssessment
 *
 * (Modified) RiskAssessment
 *
 * http://hl7.org/fhir/_RiskAssessment
 */
export declare const _RiskAssessment = "http://hl7.org/fhir/_RiskAssessment";
/**
 * BiologicallyDerivedProductPropertyComponent
 *
 * BiologicallyDerivedProductPropertyComponent: A property that is specific to this BiologicallyDerviedProduct instance.
 *
 * http://hl7.org/fhir/BiologicallyDerivedProductPropertyComponent
 */
export declare const BiologicallyDerivedProductPropertyComponent = "http://hl7.org/fhir/BiologicallyDerivedProductPropertyComponent";
/**
 * _totalVolume
 *
 * (Modified) Medication.totalVolume
 *
 * http://hl7.org/fhir/_totalVolume
 */
export declare const _totalVolume = "http://hl7.org/fhir/_totalVolume";
/**
 * _adjudication
 *
 * (Modified) ExplanationOfBenefit.adjudication
 *
 * http://hl7.org/fhir/_adjudication
 */
export declare const _adjudication = "http://hl7.org/fhir/_adjudication";
/**
 * history
 *
 * Transport.history: The transport event prior to this one.
 *
 * http://hl7.org/fhir/history
 */
export declare const history = "http://hl7.org/fhir/history";
/**
 * _isSubpotent
 *
 * (Modified) Immunization.isSubpotent
 *
 * http://hl7.org/fhir/_isSubpotent
 */
export declare const _isSubpotent = "http://hl7.org/fhir/_isSubpotent";
/**
 * _longitude
 *
 * (Modified) Location.position.longitude
 *
 * http://hl7.org/fhir/_longitude
 */
export declare const _longitude = "http://hl7.org/fhir/_longitude";
/**
 * _sliceIsConstraining
 *
 * (Modified) ElementDefinition.sliceIsConstraining
 *
 * http://hl7.org/fhir/_sliceIsConstraining
 */
export declare const _sliceIsConstraining = "http://hl7.org/fhir/_sliceIsConstraining";
/**
 * collected
 *
 * Specimen.collection.collected
 *
 * http://hl7.org/fhir/collected
 */
export declare const collected = "http://hl7.org/fhir/collected";
/**
 * medicineClassification
 *
 * MedicationKnowledge.medicineClassification: Categorization of the medication within a formulary or classification system.
 *
 * http://hl7.org/fhir/medicineClassification
 */
export declare const medicineClassification = "http://hl7.org/fhir/medicineClassification";
/**
 * Signature
 *
 * A signature along with supporting context. The signature may be a digital signature that is cryptographic in nature, or some other signature acceptable to the domain. This other signature may be as simple as a graphical image representing a hand-written signature, or a signature ceremony Different signature approaches have different utilities.
 *
 * http://hl7.org/fhir/Signature
 */
export declare const Signature = "http://hl7.org/fhir/Signature";
/**
 * ConceptReference
 *
 * ValueSetComposeComponent.ConceptSet.ConceptReference: Specifies a concept to be included or excluded.
 *
 * http://hl7.org/fhir/ConceptReference
 */
export declare const ConceptReference = "http://hl7.org/fhir/ConceptReference";
/**
 * TransportRestrictionComponent
 *
 * TransportRestrictionComponent: If the Transport.focus is a request resource and the transport is seeking fulfillment (i.e. is asking for the request to be actioned), this element identifies any limitations on what parts of the referenced request should be actioned.
 *
 * http://hl7.org/fhir/TransportRestrictionComponent
 */
export declare const TransportRestrictionComponent = "http://hl7.org/fhir/TransportRestrictionComponent";
/**
 * _rank
 *
 * (Modified) ContactPoint.rank
 *
 * http://hl7.org/fhir/_rank
 */
export declare const _rank = "http://hl7.org/fhir/_rank";
/**
 * _inResponseTo
 *
 * (Modified) Communication.inResponseTo
 *
 * http://hl7.org/fhir/_inResponseTo
 */
export declare const _inResponseTo = "http://hl7.org/fhir/_inResponseTo";
/**
 * CitationCitedArtifactAbstractComponent
 *
 * CitationCitedArtifactComponent.CitationCitedArtifactAbstractComponent: The abstract may be used to convey article-contained abstracts, externally-created abstracts, or other descriptive summaries.
 *
 * http://hl7.org/fhir/CitationCitedArtifactAbstractComponent
 */
export declare const CitationCitedArtifactAbstractComponent = "http://hl7.org/fhir/CitationCitedArtifactAbstractComponent";
/**
 * _error
 *
 * (Modified) SubscriptionStatus.error
 *
 * http://hl7.org/fhir/_error
 */
export declare const _error = "http://hl7.org/fhir/_error";
/**
 * origin
 *
 * TestScript.test.action.operation.origin: The server where the request message originates from.  Must be one of the server numbers listed in TestScript.origin section.
 *
 * http://hl7.org/fhir/origin
 */
export declare const origin = "http://hl7.org/fhir/origin";
/**
 * treeRoot
 *
 * http://hl7.org/fhir/treeRoot
 */
export declare const treeRoot = "http://hl7.org/fhir/treeRoot";
/**
 * _sourceMaterialType
 *
 * (Modified) SubstanceSourceMaterial.sourceMaterialType
 *
 * http://hl7.org/fhir/_sourceMaterialType
 */
export declare const _sourceMaterialType = "http://hl7.org/fhir/_sourceMaterialType";
/**
 * bodyStructure
 *
 * ServiceRequest.bodyStructure: Anatomic location where the procedure should be performed. This is the target site.
 *
 * http://hl7.org/fhir/bodyStructure
 */
export declare const bodyStructure = "http://hl7.org/fhir/bodyStructure";
/**
 * _releaseDate
 *
 * (Modified) CapabilityStatement.software.releaseDate
 *
 * http://hl7.org/fhir/_releaseDate
 */
export declare const _releaseDate = "http://hl7.org/fhir/_releaseDate";
/**
 * normalValue
 *
 * Observation.component.referenceRange.normalValue: The value of the normal value of the reference range.
 *
 * http://hl7.org/fhir/normalValue
 */
export declare const normalValue = "http://hl7.org/fhir/normalValue";
/**
 * PractitionerCommunicationComponent
 *
 * PractitionerCommunicationComponent: A language which may be used to communicate with the practitioner, often for correspondence/administrative purposes.

The `PractitionerRole.communication` property should be used for publishing the languages that a practitioner is able to communicate with patients (on a per Organization/Role basis).
 *
 * http://hl7.org/fhir/PractitionerCommunicationComponent
 */
export declare const PractitionerCommunicationComponent = "http://hl7.org/fhir/PractitionerCommunicationComponent";
/**
 * targetProfile
 *
 * OperationDefinition.parameter.part.targetProfile: Used when the type is "Reference" or "canonical", and identifies a profile structure or implementation Guide that applies to the target of the reference this parameter refers to. If any profiles are specified, then the content must conform to at least one of them. The URL can be a local reference - to a contained StructureDefinition, or a reference to another StructureDefinition or Implementation Guide by a canonical URL. When an implementation guide is specified, the target resource SHALL conform to at least one profile defined in the implementation guide.
 *
 * http://hl7.org/fhir/targetProfile
 */
export declare const targetProfile = "http://hl7.org/fhir/targetProfile";
/**
 * bounds
 *
 * Timing.repeat.bounds
 *
 * http://hl7.org/fhir/bounds
 */
export declare const bounds = "http://hl7.org/fhir/bounds";
/**
 * _op
 *
 * (Modified) ValueSet.compose.exclude.filter.op
 *
 * http://hl7.org/fhir/_op
 */
export declare const _op = "http://hl7.org/fhir/_op";
/**
 * OperationDefinitionParameterComponentParameterParameter
 *
 * The parts of a nested Parameter.
 *
 * http://hl7.org/fhir/OperationDefinitionParameterComponentParameterParameter
 */
export declare const OperationDefinitionParameterComponentParameterParameter = "http://hl7.org/fhir/OperationDefinitionParameterComponentParameterParameter";
/**
 * plannedActivityReference
 *
 * CarePlan.activity.plannedActivityReference: The details of the proposed activity represented in a specific resource.
 *
 * http://hl7.org/fhir/plannedActivityReference
 */
export declare const plannedActivityReference = "http://hl7.org/fhir/plannedActivityReference";
/**
 * _preAuthRef
 *
 * (Modified) ExplanationOfBenefit.addItem.detail.subDetail.reviewOutcome.preAuthRef
 *
 * http://hl7.org/fhir/_preAuthRef
 */
export declare const _preAuthRef = "http://hl7.org/fhir/_preAuthRef";
/**
 * _imageRegion3D
 *
 * (Modified) ImagingSelection.instance.imageRegion3D
 *
 * http://hl7.org/fhir/_imageRegion3D
 */
export declare const _imageRegion3D = "http://hl7.org/fhir/_imageRegion3D";
/**
 * _object
 *
 * (Modified) TestPlan.testCase.assertion.object
 *
 * http://hl7.org/fhir/_object
 */
export declare const _object = "http://hl7.org/fhir/_object";
/**
 * DocumentReferenceAttesterComponent
 *
 * DocumentReferenceAttesterComponent: A participant who has authenticated the accuracy of the document.
 *
 * http://hl7.org/fhir/DocumentReferenceAttesterComponent
 */
export declare const DocumentReferenceAttesterComponent = "http://hl7.org/fhir/DocumentReferenceAttesterComponent";
/**
 * _recall
 *
 * (Modified) DeviceDefinition.correctiveAction.recall
 *
 * http://hl7.org/fhir/_recall
 */
export declare const _recall = "http://hl7.org/fhir/_recall";
/**
 * fastingStatus
 *
 * Specimen.collection.fastingStatus
 *
 * http://hl7.org/fhir/fastingStatus
 */
export declare const fastingStatus = "http://hl7.org/fhir/fastingStatus";
/**
 * seriesUid
 *
 * ImagingSelection.seriesUid: The Series Instance UID for the DICOM Series from which the images were selected.
 *
 * http://hl7.org/fhir/seriesUid
 */
export declare const seriesUid = "http://hl7.org/fhir/seriesUid";
/**
 * SubstanceSourceMaterialPartDescriptionComponent
 *
 * SubstanceSourceMaterialPartDescriptionComponent: To do.
 *
 * http://hl7.org/fhir/SubstanceSourceMaterialPartDescriptionComponent
 */
export declare const SubstanceSourceMaterialPartDescriptionComponent = "http://hl7.org/fhir/SubstanceSourceMaterialPartDescriptionComponent";
/**
 * _geneElement
 *
 * (Modified) SubstanceReferenceInformation.geneElement
 *
 * http://hl7.org/fhir/_geneElement
 */
export declare const _geneElement = "http://hl7.org/fhir/_geneElement";
/**
 * publicationDateText
 *
 * Citation.citedArtifact.publicationForm.publicationDateText: Text representation of the date on which the issue of the cited artifact was published.
 *
 * http://hl7.org/fhir/publicationDateText
 */
export declare const publicationDateText = "http://hl7.org/fhir/publicationDateText";
/**
 * EpisodeOfCareStatusHistoryComponent
 *
 * EpisodeOfCareStatusHistoryComponent: The history of statuses that the EpisodeOfCare has been through (without requiring processing the history of the resource).
 *
 * http://hl7.org/fhir/EpisodeOfCareStatusHistoryComponent
 */
export declare const EpisodeOfCareStatusHistoryComponent = "http://hl7.org/fhir/EpisodeOfCareStatusHistoryComponent";
/**
 * evaluationMessage
 *
 * GuidanceResponse.evaluationMessage: Messages resulting from the evaluation of the artifact or artifacts. As part of evaluating the request, the engine may produce informational or warning messages. These messages will be provided by this element.
 *
 * http://hl7.org/fhir/evaluationMessage
 */
export declare const evaluationMessage = "http://hl7.org/fhir/evaluationMessage";
/**
 * division
 *
 * BiologicallyDerivedProduct.division: A unique identifier for an aliquot of a product.  Used to distinguish individual aliquots of a product carrying the same biologicalSource and productCode identifiers.
 *
 * http://hl7.org/fhir/division
 */
export declare const division = "http://hl7.org/fhir/division";
/**
 * windowEnd
 *
 * MolecularSequence.relative.startingSequence.windowEnd: End position of the window on the starting sequence. This value should honor the rules of the  coordinateSystem.
 *
 * http://hl7.org/fhir/windowEnd
 */
export declare const windowEnd = "http://hl7.org/fhir/windowEnd";
/**
 * _foodType
 *
 * (Modified) NutritionOrder.oralDiet.texture.foodType
 *
 * http://hl7.org/fhir/_foodType
 */
export declare const _foodType = "http://hl7.org/fhir/_foodType";
/**
 * _repeats
 *
 * (Modified) Questionnaire.item.item.repeats
 *
 * http://hl7.org/fhir/_repeats
 */
export declare const _repeats = "http://hl7.org/fhir/_repeats";
/**
 * _Observation
 *
 * (Modified) Observation
 *
 * http://hl7.org/fhir/_Observation
 */
export declare const _Observation = "http://hl7.org/fhir/_Observation";
/**
 * validateCode
 *
 * TerminologyCapabilities.validateCode: Information about the [ValueSet/$validate-code](valueset-operation-validate-code.html) operation.
 *
 * http://hl7.org/fhir/validateCode
 */
export declare const validateCode = "http://hl7.org/fhir/validateCode";
/**
 * parameterName
 *
 * OperationDefinition.overload.parameterName: Name of parameter to include in overload.
 *
 * http://hl7.org/fhir/parameterName
 */
export declare const parameterName = "http://hl7.org/fhir/parameterName";
/**
 * source
 *
 * MedicationKnowledge.medicineClassification.source
 *
 * http://hl7.org/fhir/source
 */
export declare const source = "http://hl7.org/fhir/source";
/**
 * currentState
 *
 * Citation.citedArtifact.currentState: The status of the cited artifact.
 *
 * http://hl7.org/fhir/currentState
 */
export declare const currentState = "http://hl7.org/fhir/currentState";
/**
 * publicationStatus
 *
 * Contract.contentDefinition.publicationStatus: amended | appended | cancelled | disputed | entered-in-error | executable +.
 *
 * http://hl7.org/fhir/publicationStatus
 */
export declare const publicationStatus = "http://hl7.org/fhir/publicationStatus";
/**
 * _license
 *
 * (Modified) ImplementationGuide.license
 *
 * http://hl7.org/fhir/_license
 */
export declare const _license = "http://hl7.org/fhir/_license";
/**
 * _created
 *
 * (Modified) EnrollmentResponse.created
 *
 * http://hl7.org/fhir/_created
 */
export declare const _created = "http://hl7.org/fhir/_created";
/**
 * ClinicalUseDefinitionContraindicationOtherTherapyComponent
 *
 * ClinicalUseDefinitionContraindicationComponent.ClinicalUseDefinitionContraindicationOtherTherapyComponent: Information about the use of the medicinal product in relation to other therapies described as part of the contraindication.
 *
 * http://hl7.org/fhir/ClinicalUseDefinitionContraindicationOtherTherapyComponent
 */
export declare const ClinicalUseDefinitionContraindicationOtherTherapyComponent = "http://hl7.org/fhir/ClinicalUseDefinitionContraindicationOtherTherapyComponent";
/**
 * isModifier
 *
 * ElementDefinition.isModifier: If true, the value of this element affects the interpretation of the element or resource that contains it, and the value of the element cannot be ignored. Typically, this is used for status, negation and qualification codes. The effect of this is that the element cannot be ignored by systems: they SHALL either recognize the element and process it, and/or a pre-determination has been made that it is not relevant to their particular system. When used on the root element in an extension definition, this indicates whether or not the extension is a modifier extension.
 *
 * http://hl7.org/fhir/isModifier
 */
export declare const isModifier = "http://hl7.org/fhir/isModifier";
/**
 * _needsMap
 *
 * (Modified) TerminologyCapabilities.translation.needsMap
 *
 * http://hl7.org/fhir/_needsMap
 */
export declare const _needsMap = "http://hl7.org/fhir/_needsMap";
/**
 * performerType
 *
 * ObservationDefinition.performerType: The type of individual/organization/device that is expected to act upon instances of this definition.
 *
 * http://hl7.org/fhir/performerType
 */
export declare const performerType = "http://hl7.org/fhir/performerType";
/**
 * unitPrice
 *
 * ExplanationOfBenefit.item.detail.subDetail.unitPrice: If the item is not a group then this is the fee for the product or service, otherwise this is the total of the fees for the details of the group.
 *
 * http://hl7.org/fhir/unitPrice
 */
export declare const unitPrice = "http://hl7.org/fhir/unitPrice";
/**
 * _topic
 *
 * (Modified) Contract.term.group.topic
 *
 * http://hl7.org/fhir/_topic
 */
export declare const _topic = "http://hl7.org/fhir/_topic";
/**
 * _lastUpdated
 *
 * (Modified) Meta.lastUpdated
 *
 * http://hl7.org/fhir/_lastUpdated
 */
export declare const _lastUpdated = "http://hl7.org/fhir/_lastUpdated";
/**
 * preparedDate
 *
 * DeviceDispense.preparedDate: The time when the dispensed product was packaged and reviewed.
 *
 * http://hl7.org/fhir/preparedDate
 */
export declare const preparedDate = "http://hl7.org/fhir/preparedDate";
/**
 * accident
 *
 * ExplanationOfBenefit.accident: Details of a accident which resulted in injuries which required the products and services listed in the claim.
 *
 * http://hl7.org/fhir/accident
 */
export declare const accident = "http://hl7.org/fhir/accident";
/**
 * code
 *
 * ChargeItemDefinition.code: The defined billing details in this resource pertain to the given billing code.
 *
 * http://hl7.org/fhir/code
 */
export declare const code = "http://hl7.org/fhir/code";
/**
 * _designation
 *
 * (Modified) ValueSet.expansion.contains.contains.designation
 *
 * http://hl7.org/fhir/_designation
 */
export declare const _designation = "http://hl7.org/fhir/_designation";
/**
 * _creation
 *
 * (Modified) Invoice.creation
 *
 * http://hl7.org/fhir/_creation
 */
export declare const _creation = "http://hl7.org/fhir/_creation";
/**
 * verificationType
 *
 * Consent.verification.verificationType: Extensible list of verification type starting with verification and re-validation.
 *
 * http://hl7.org/fhir/verificationType
 */
export declare const verificationType = "http://hl7.org/fhir/verificationType";
/**
 * DeviceDefinitionPackagingComponentPackagingUdiDeviceIdentifier
 *
 * Unique Device Identifier (UDI) Barcode string on the packaging.
 *
 * http://hl7.org/fhir/DeviceDefinitionPackagingComponentPackagingUdiDeviceIdentifier
 */
export declare const DeviceDefinitionPackagingComponentPackagingUdiDeviceIdentifier = "http://hl7.org/fhir/DeviceDefinitionPackagingComponentPackagingUdiDeviceIdentifier";
/**
 * _containedInstance
 *
 * (Modified) ExampleScenario.instance.containedInstance
 *
 * http://hl7.org/fhir/_containedInstance
 */
export declare const _containedInstance = "http://hl7.org/fhir/_containedInstance";
/**
 * PackagedProductDefinitionLegalStatusOfSupplyComponent
 *
 * PackagedProductDefinitionLegalStatusOfSupplyComponent: The legal status of supply of the packaged item as classified by the regulator.
 *
 * http://hl7.org/fhir/PackagedProductDefinitionLegalStatusOfSupplyComponent
 */
export declare const PackagedProductDefinitionLegalStatusOfSupplyComponent = "http://hl7.org/fhir/PackagedProductDefinitionLegalStatusOfSupplyComponent";
/**
 * _recipient
 *
 * (Modified) Communication.recipient
 *
 * http://hl7.org/fhir/_recipient
 */
export declare const _recipient = "http://hl7.org/fhir/_recipient";
/**
 * ifMatch
 *
 * Bundle.entry.request.ifMatch: Only perform the operation if the Etag value matches. For more information, see the API section ["Managing Resource Contention"](http.html#concurrency).
 *
 * http://hl7.org/fhir/ifMatch
 */
export declare const ifMatch = "http://hl7.org/fhir/ifMatch";
/**
 * partNumber
 *
 * DeviceDefinition.partNumber: The part number or catalog number of the device.
 *
 * http://hl7.org/fhir/partNumber
 */
export declare const partNumber = "http://hl7.org/fhir/partNumber";
/**
 * _severity
 *
 * (Modified) OperationOutcome.issue.severity
 *
 * http://hl7.org/fhir/_severity
 */
export declare const _severity = "http://hl7.org/fhir/_severity";
/**
 * _filterBy
 *
 * (Modified) Subscription.filterBy
 *
 * http://hl7.org/fhir/_filterBy
 */
export declare const _filterBy = "http://hl7.org/fhir/_filterBy";
/**
 * _NutritionIntake
 *
 * (Modified) NutritionIntake
 *
 * http://hl7.org/fhir/_NutritionIntake
 */
export declare const _NutritionIntake = "http://hl7.org/fhir/_NutritionIntake";
/**
 * BundleEntrySearchComponent
 *
 * BundleEntryComponent.BundleEntrySearchComponent: Information about the search process that lead to the creation of this entry.
 *
 * http://hl7.org/fhir/BundleEntrySearchComponent
 */
export declare const BundleEntrySearchComponent = "http://hl7.org/fhir/BundleEntrySearchComponent";
/**
 * _responseCode
 *
 * (Modified) TestScript.test.action.assert.responseCode
 *
 * http://hl7.org/fhir/_responseCode
 */
export declare const _responseCode = "http://hl7.org/fhir/_responseCode";
/**
 * _eventHistory
 *
 * (Modified) MedicationRequest.eventHistory
 *
 * http://hl7.org/fhir/_eventHistory
 */
export declare const _eventHistory = "http://hl7.org/fhir/_eventHistory";
/**
 * _rejectionCriterion
 *
 * (Modified) SpecimenDefinition.typeTested.rejectionCriterion
 *
 * http://hl7.org/fhir/_rejectionCriterion
 */
export declare const _rejectionCriterion = "http://hl7.org/fhir/_rejectionCriterion";
/**
 * notPerformedReason
 *
 * MedicationDispense.notPerformedReason: Indicates the reason why a dispense was not performed.
 *
 * http://hl7.org/fhir/notPerformedReason
 */
export declare const notPerformedReason = "http://hl7.org/fhir/notPerformedReason";
/**
 * _entryType
 *
 * (Modified) Device.udiCarrier.entryType
 *
 * http://hl7.org/fhir/_entryType
 */
export declare const _entryType = "http://hl7.org/fhir/_entryType";
/**
 * EncounterHistory
 *
 * A record of significant events/milestones key data throughout the history of an Encounter
 *
 * http://hl7.org/fhir/EncounterHistory
 */
export declare const EncounterHistory = "http://hl7.org/fhir/EncounterHistory";
/**
 * _specialPrecautionsForStorage
 *
 * (Modified) ProductShelfLife.specialPrecautionsForStorage
 *
 * http://hl7.org/fhir/_specialPrecautionsForStorage
 */
export declare const _specialPrecautionsForStorage = "http://hl7.org/fhir/_specialPrecautionsForStorage";
/**
 * SearchParameter
 *
 * A search parameter that defines a named search item that can be used to search/filter on a resource.
 *
 * http://hl7.org/fhir/SearchParameter
 */
export declare const SearchParameter = "http://hl7.org/fhir/SearchParameter";
/**
 * gender
 *
 * ObservationDefinition.qualifiedValue.gender: The gender this  set of qualified values applies to.
 *
 * http://hl7.org/fhir/gender
 */
export declare const gender = "http://hl7.org/fhir/gender";
/**
 * coding
 *
 * CodeableConcept.coding: A reference to a code defined by a terminology system.
 *
 * http://hl7.org/fhir/coding
 */
export declare const coding = "http://hl7.org/fhir/coding";
/**
 * ProductShelfLife
 *
 * The shelf-life and storage information for a medicinal product item or container can be described using this class.
 *
 * http://hl7.org/fhir/ProductShelfLife
 */
export declare const ProductShelfLife = "http://hl7.org/fhir/ProductShelfLife";
/**
 * system
 *
 * ValueSet.expansion.contains.contains.system: An absolute URI which is the code system in which the code for this item in the expansion is defined.
 *
 * http://hl7.org/fhir/system
 */
export declare const system = "http://hl7.org/fhir/system";
/**
 * _tissue
 *
 * (Modified) AdministrableProductDefinition.routeOfAdministration.targetSpecies.withdrawalPeriod.tissue
 *
 * http://hl7.org/fhir/_tissue
 */
export declare const _tissue = "http://hl7.org/fhir/_tissue";
/**
 * associatedParty
 *
 * ResearchStudy.associatedParty: Sponsors, collaborators, and other parties.
 *
 * http://hl7.org/fhir/associatedParty
 */
export declare const associatedParty = "http://hl7.org/fhir/associatedParty";
/**
 * statistic
 *
 * Evidence.statistic: Values and parameters for a single statistic.
 *
 * http://hl7.org/fhir/statistic
 */
export declare const statistic = "http://hl7.org/fhir/statistic";
/**
 * DataRequirement
 *
 * Describes a required data item for evaluation in terms of the type of data, and optional code or date-based filters of the data.
 *
 * http://hl7.org/fhir/DataRequirement
 */
export declare const DataRequirement = "http://hl7.org/fhir/DataRequirement";
/**
 * MedicationKnowledgeRegulatoryMaxDispenseComponent
 *
 * MedicationKnowledgeRegulatoryComponent.MedicationKnowledgeRegulatoryMaxDispenseComponent: The maximum number of units of the medication that can be dispensed in a period.
 *
 * http://hl7.org/fhir/MedicationKnowledgeRegulatoryMaxDispenseComponent
 */
export declare const MedicationKnowledgeRegulatoryMaxDispenseComponent = "http://hl7.org/fhir/MedicationKnowledgeRegulatoryMaxDispenseComponent";
/**
 * udiCarrier
 *
 * Device.udiCarrier: Unique device identifier (UDI) assigned to device label or package.  Note that the Device may include multiple udiCarriers as it either may include just the udiCarrier for the jurisdiction it is sold, or for multiple jurisdictions it could have been sold.
 *
 * http://hl7.org/fhir/udiCarrier
 */
export declare const udiCarrier = "http://hl7.org/fhir/udiCarrier";
/**
 * Availability
 *
 * Availability data for an {item}.
 *
 * http://hl7.org/fhir/Availability
 */
export declare const Availability = "http://hl7.org/fhir/Availability";
/**
 * sender
 *
 * MessageHeader.sender: Identifies the sending system to allow the use of a trust relationship.
 *
 * http://hl7.org/fhir/sender
 */
export declare const sender = "http://hl7.org/fhir/sender";
/**
 * _strand
 *
 * (Modified) MolecularSequence.relative.startingSequence.strand
 *
 * http://hl7.org/fhir/_strand
 */
export declare const _strand = "http://hl7.org/fhir/_strand";
/**
 * IngredientSubstanceStrengthComponent
 *
 * IngredientSubstanceComponent.IngredientSubstanceStrengthComponent: The quantity of substance in the unit of presentation, or in the volume (or mass) of the single pharmaceutical product or manufactured item. The allowed repetitions do not represent different strengths, but are different representations - mathematically equivalent - of a single strength.
 *
 * http://hl7.org/fhir/IngredientSubstanceStrengthComponent
 */
export declare const IngredientSubstanceStrengthComponent = "http://hl7.org/fhir/IngredientSubstanceStrengthComponent";
/**
 * MedicationKnowledgeMonitoringProgramComponent
 *
 * MedicationKnowledgeMonitoringProgramComponent: The program under which the medication is reviewed.
 *
 * http://hl7.org/fhir/MedicationKnowledgeMonitoringProgramComponent
 */
export declare const MedicationKnowledgeMonitoringProgramComponent = "http://hl7.org/fhir/MedicationKnowledgeMonitoringProgramComponent";
/**
 * _derivation
 *
 * (Modified) StructureDefinition.derivation
 *
 * http://hl7.org/fhir/_derivation
 */
export declare const _derivation = "http://hl7.org/fhir/_derivation";
/**
 * Condition
 *
 * A clinical condition, problem, diagnosis, or other event, situation, issue, or clinical concept that has risen to a level of concern.
 *
 * http://hl7.org/fhir/Condition
 */
export declare const Condition = "http://hl7.org/fhir/Condition";
/**
 * AdministrableProductDefinitionRouteOfAdministrationTargetSpeciesWithdrawalPeriodComponent
 *
 * AdministrableProductDefinitionRouteOfAdministrationComponent.AdministrableProductDefinitionRouteOfAdministrationTargetSpeciesComponent.AdministrableProductDefinitionRouteOfAdministrationTargetSpeciesWithdrawalPeriodComponent: A species specific time during which consumption of animal product is not appropriate.
 *
 * http://hl7.org/fhir/AdministrableProductDefinitionRouteOfAdministrationTargetSpeciesWithdrawalPeriodComponent
 */
export declare const AdministrableProductDefinitionRouteOfAdministrationTargetSpeciesWithdrawalPeriodComponent = "http://hl7.org/fhir/AdministrableProductDefinitionRouteOfAdministrationTargetSpeciesWithdrawalPeriodComponent";
/**
 * diagnostics
 *
 * OperationOutcome.issue.diagnostics: Additional diagnostic information about the issue.
 *
 * http://hl7.org/fhir/diagnostics
 */
export declare const diagnostics = "http://hl7.org/fhir/diagnostics";
/**
 * assessment
 *
 * Condition.stage.assessment: Reference to a formal record of the evidence on which the staging assessment is based.
 *
 * http://hl7.org/fhir/assessment
 */
export declare const assessment = "http://hl7.org/fhir/assessment";
/**
 * _clockFacePosition
 *
 * (Modified) BodyStructure.excludedStructure.bodyLandmarkOrientation.clockFacePosition
 *
 * http://hl7.org/fhir/_clockFacePosition
 */
export declare const _clockFacePosition = "http://hl7.org/fhir/_clockFacePosition";
/**
 * attestation
 *
 * VerificationResult.attestation: Information about the entity attesting to information.
 *
 * http://hl7.org/fhir/attestation
 */
export declare const attestation = "http://hl7.org/fhir/attestation";
/**
 * identified
 *
 * DetectedIssue.identified
 *
 * http://hl7.org/fhir/identified
 */
export declare const identified = "http://hl7.org/fhir/identified";
//# sourceMappingURL=fhir.d.ts.map