type Property = string;
type Class = string;
type Datatype = string;
type OwlClass = string;
type OwlObjectProperty = string;
type OwlDatatypeProperty = string;
type HydraResource = string;
type HydraClass = string;
type HydraLink = string;
type HydraTemplatedLink = string;
type HydraVariableRepresentation = string;

/**
 * constituent
 *
 * ManufacturedItemDefinition.component.component.constituent: A reference to a constituent of the manufactured item as a whole, linked here so that its component location within the item can be indicated. This not where the item's ingredient are primarily stated (for which see Ingredient.for or ManufacturedItemDefinition.ingredient).
 *
 * http://hl7.org/fhir/constituent
 */
export const constituent = 'http://hl7.org/fhir/constituent' satisfies OwlObjectProperty;

/**
 * _careTeam
 *
 * (Modified) ExplanationOfBenefit.careTeam
 *
 * http://hl7.org/fhir/_careTeam
 */
export const _careTeam = 'http://hl7.org/fhir/_careTeam' satisfies OwlObjectProperty;

/**
 * ClinicalUseDefinitionWarningComponent
 *
 * ClinicalUseDefinitionWarningComponent: A critical piece of information about environmental, health or physical risks or hazards that serve as caution to the user. For example 'Do not operate heavy machinery', 'May cause drowsiness', or 'Get medical advice/attention if you feel unwell'.
 *
 * http://hl7.org/fhir/ClinicalUseDefinitionWarningComponent
 */
export const ClinicalUseDefinitionWarningComponent = 'http://hl7.org/fhir/ClinicalUseDefinitionWarningComponent' satisfies OwlClass;

/**
 * PlanDefinitionActionParticipantComponent
 *
 * PlanDefinitionActionComponentAction.PlanDefinitionActionParticipantComponent: Indicates who should participate in performing the action described.
 *
 * http://hl7.org/fhir/PlanDefinitionActionParticipantComponent
 */
export const PlanDefinitionActionParticipantComponent = 'http://hl7.org/fhir/PlanDefinitionActionParticipantComponent' satisfies OwlClass;

/**
 * VisionPrescriptionLensSpecificationComponent
 *
 * VisionPrescriptionLensSpecificationComponent: Contain the details of  the individual lens specifications and serves as the authorization for the fullfillment by certified professionals.
 *
 * http://hl7.org/fhir/VisionPrescriptionLensSpecificationComponent
 */
export const VisionPrescriptionLensSpecificationComponent = 'http://hl7.org/fhir/VisionPrescriptionLensSpecificationComponent' satisfies OwlClass;

/**
 * _answerOption
 *
 * (Modified) Questionnaire.item.item.answerOption
 *
 * http://hl7.org/fhir/_answerOption
 */
export const _answerOption = 'http://hl7.org/fhir/_answerOption' satisfies OwlObjectProperty;

/**
 * decimal
 *
 * A rational number with implicit precision
 *
 * http://hl7.org/fhir/decimal
 */
export const decimal = 'http://hl7.org/fhir/decimal' satisfies OwlClass;

/**
 * _applies
 *
 * (Modified) Contract.term.group.applies
 *
 * http://hl7.org/fhir/_applies
 */
export const _applies = 'http://hl7.org/fhir/_applies' satisfies OwlObjectProperty;

/**
 * serviceProvider
 *
 * Encounter.serviceProvider: The organization that is primarily responsible for this Encounter's services. This MAY be the same as the organization on the Patient record, however it could be different, such as if the actor performing the services was from an external organization (which may be billed seperately) for an external consultation.  Refer to the colonoscopy example on the Encounter examples tab.
 *
 * http://hl7.org/fhir/serviceProvider
 */
export const serviceProvider = 'http://hl7.org/fhir/serviceProvider' satisfies OwlObjectProperty;

/**
 * NutritionProductIngredientComponent
 *
 * NutritionProductIngredientComponent: Ingredients contained in this product.
 *
 * http://hl7.org/fhir/NutritionProductIngredientComponent
 */
export const NutritionProductIngredientComponent = 'http://hl7.org/fhir/NutritionProductIngredientComponent' satisfies OwlClass;

/**
 * Error
 *
 * ClaimResponse.Error: Errors encountered during the processing of the adjudication.
 * Note that `Error` is a reserved Javascript keyword, and is therefore suffixed by `__workaround`.
 * For a list of reserved keywords, see https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Lexical_grammar#Keywords.
 *
 * http://hl7.org/fhir/Error
 */
export const Error__workaround = 'http://hl7.org/fhir/Error' satisfies OwlClass;

/**
 * productStatus
 *
 * BiologicallyDerivedProduct.productStatus: Whether the product is currently available.
 *
 * http://hl7.org/fhir/productStatus
 */
export const productStatus = 'http://hl7.org/fhir/productStatus' satisfies OwlObjectProperty;

/**
 * ImagingStudySeriesPerformerComponent
 *
 * ImagingStudySeriesComponent.ImagingStudySeriesPerformerComponent: Indicates who or what performed the series and how they were involved.
 *
 * http://hl7.org/fhir/ImagingStudySeriesPerformerComponent
 */
export const ImagingStudySeriesPerformerComponent = 'http://hl7.org/fhir/ImagingStudySeriesPerformerComponent' satisfies OwlClass;

/**
 * _lowerLimit
 *
 * (Modified) SampledData.lowerLimit
 *
 * http://hl7.org/fhir/_lowerLimit
 */
export const _lowerLimit = 'http://hl7.org/fhir/_lowerLimit' satisfies OwlObjectProperty;

/**
 * Medication
 *
 * This resource is primarily used for the identification and definition of a medication, including ingredients, for the purposes of prescribing, dispensing, and administering a medication as well as for making statements about medication use.
 *
 * http://hl7.org/fhir/Medication
 */
export const Medication = 'http://hl7.org/fhir/Medication' satisfies OwlClass;

/**
 * header
 *
 * Endpoint.header: Additional headers / information to send as part of the notification.
 *
 * http://hl7.org/fhir/header
 */
export const header = 'http://hl7.org/fhir/header' satisfies OwlObjectProperty;

/**
 * StructureMapGroupRuleComponent
 *
 * StructureMapGroupComponent.StructureMapGroupRuleComponent: Transform Rule from source to target.
 *
 * http://hl7.org/fhir/StructureMapGroupRuleComponent
 */
export const StructureMapGroupRuleComponent = 'http://hl7.org/fhir/StructureMapGroupRuleComponent' satisfies OwlClass;

/**
 * _productType
 *
 * (Modified) MedicationKnowledge.productType
 *
 * http://hl7.org/fhir/_productType
 */
export const _productType = 'http://hl7.org/fhir/_productType' satisfies OwlObjectProperty;

/**
 * _relatedItem
 *
 * (Modified) InventoryItem.association.relatedItem
 *
 * http://hl7.org/fhir/_relatedItem
 */
export const _relatedItem = 'http://hl7.org/fhir/_relatedItem' satisfies OwlObjectProperty;

/**
 * author
 *
 * Basic.author: Indicates who was responsible for creating the resource instance.
 *
 * http://hl7.org/fhir/author
 */
export const author = 'http://hl7.org/fhir/author' satisfies OwlObjectProperty;

/**
 * _direction
 *
 * (Modified) TestScript.test.action.assert.direction
 *
 * http://hl7.org/fhir/_direction
 */
export const _direction = 'http://hl7.org/fhir/_direction' satisfies OwlObjectProperty;

/**
 * _frequencyOfOccurrence
 *
 * (Modified) ClinicalUseDefinition.undesirableEffect.frequencyOfOccurrence
 *
 * http://hl7.org/fhir/_frequencyOfOccurrence
 */
export const _frequencyOfOccurrence = 'http://hl7.org/fhir/_frequencyOfOccurrence' satisfies OwlObjectProperty;

/**
 * RequestOrchestration
 *
 * A set of related requests that can be used to capture intended activities that have inter-dependencies such as "give this medication after that one".
 *
 * http://hl7.org/fhir/RequestOrchestration
 */
export const RequestOrchestration = 'http://hl7.org/fhir/RequestOrchestration' satisfies OwlClass;

/**
 * Detail
 *
 * Claim.Item.Detail: A claim detail line. Either a simple (a product or service) or a 'group' of sub-details which are simple items.
 *
 * http://hl7.org/fhir/Detail
 */
export const Detail = 'http://hl7.org/fhir/Detail' satisfies OwlClass;

/**
 * numberOfRepeatsAllowed
 *
 * MedicationRequest.dispenseRequest.numberOfRepeatsAllowed: An integer indicating the number of times, in addition to the original dispense, (aka refills or repeats) that the patient can receive the prescribed medication. Usage Notes: This integer does not include the original order dispense. This means that if an order indicates dispense 30 tablets plus "3 repeats", then the order can be dispensed a total of 4 times and the patient can receive a total of 120 tablets.  A prescriber may explicitly say that zero refills are permitted after the initial dispense.
 *
 * http://hl7.org/fhir/numberOfRepeatsAllowed
 */
export const numberOfRepeatsAllowed = 'http://hl7.org/fhir/numberOfRepeatsAllowed' satisfies OwlObjectProperty;

/**
 * _communicationRequest
 *
 * (Modified) ClaimResponse.communicationRequest
 *
 * http://hl7.org/fhir/_communicationRequest
 */
export const _communicationRequest = 'http://hl7.org/fhir/_communicationRequest' satisfies OwlObjectProperty;

/**
 * DocumentReferenceContentProfileComponent
 *
 * DocumentReferenceContentComponent.DocumentReferenceContentProfileComponent: An identifier of the document constraints, encoding, structure, and template that the document conforms to beyond the base format indicated in the mimeType.
 *
 * http://hl7.org/fhir/DocumentReferenceContentProfileComponent
 */
export const DocumentReferenceContentProfileComponent = 'http://hl7.org/fhir/DocumentReferenceContentProfileComponent' satisfies OwlClass;

/**
 * _masterFile
 *
 * (Modified) MedicinalProductDefinition.masterFile
 *
 * http://hl7.org/fhir/_masterFile
 */
export const _masterFile = 'http://hl7.org/fhir/_masterFile' satisfies OwlObjectProperty;

/**
 * comment
 *
 * Schedule.comment: Comments on the availability to describe any extended information. Such as custom constraints on the slots that may be associated.
 *
 * http://hl7.org/fhir/comment
 */
export const comment = 'http://hl7.org/fhir/comment' satisfies OwlObjectProperty;

/**
 * availableTime
 *
 * Availability.availableTime: Times the {item} is available.
 *
 * http://hl7.org/fhir/availableTime
 */
export const availableTime = 'http://hl7.org/fhir/availableTime' satisfies OwlObjectProperty;

/**
 * _assert
 *
 * (Modified) TestScript.test.action.assert
 *
 * http://hl7.org/fhir/_assert
 */
export const _assert = 'http://hl7.org/fhir/_assert' satisfies OwlObjectProperty;

/**
 * listRuleId
 *
 * StructureMap.group.rule.rule.target.listRuleId: Internal rule reference for shared list items.
 *
 * http://hl7.org/fhir/listRuleId
 */
export const listRuleId = 'http://hl7.org/fhir/listRuleId' satisfies OwlObjectProperty;

/**
 * preAdmissionIdentifier
 *
 * Encounter.admission.preAdmissionIdentifier: Pre-admission identifier.
 *
 * http://hl7.org/fhir/preAdmissionIdentifier
 */
export const preAdmissionIdentifier = 'http://hl7.org/fhir/preAdmissionIdentifier' satisfies OwlObjectProperty;

/**
 * participantType
 *
 * AppointmentResponse.participantType: Role of participant in the appointment.
 *
 * http://hl7.org/fhir/participantType
 */
export const participantType = 'http://hl7.org/fhir/participantType' satisfies OwlObjectProperty;

/**
 * _related
 *
 * (Modified) ExplanationOfBenefit.related
 *
 * http://hl7.org/fhir/_related
 */
export const _related = 'http://hl7.org/fhir/_related' satisfies OwlObjectProperty;

/**
 * SupplementSchedule
 *
 * NutritionOrderSupplementComponent.SupplementSchedule: Schedule information for a supplement.
 *
 * http://hl7.org/fhir/SupplementSchedule
 */
export const SupplementSchedule = 'http://hl7.org/fhir/SupplementSchedule' satisfies OwlClass;

/**
 * reAdmission
 *
 * Encounter.admission.reAdmission: Indicates that this encounter is directly related to a prior admission, often because the conditions addressed in the prior admission were not fully addressed.
 *
 * http://hl7.org/fhir/reAdmission
 */
export const reAdmission = 'http://hl7.org/fhir/reAdmission' satisfies OwlObjectProperty;

/**
 * _requestURL
 *
 * (Modified) TestScript.test.action.assert.requestURL
 *
 * http://hl7.org/fhir/_requestURL
 */
export const _requestURL = 'http://hl7.org/fhir/_requestURL' satisfies OwlObjectProperty;

/**
 * _caseSensitive
 *
 * (Modified) CodeSystem.caseSensitive
 *
 * http://hl7.org/fhir/_caseSensitive
 */
export const _caseSensitive = 'http://hl7.org/fhir/_caseSensitive' satisfies OwlObjectProperty;

/**
 * _chargeItem
 *
 * (Modified) Invoice.lineItem.chargeItem
 *
 * http://hl7.org/fhir/_chargeItem
 */
export const _chargeItem = 'http://hl7.org/fhir/_chargeItem' satisfies OwlObjectProperty;

/**
 * _withdrawalPeriod
 *
 * (Modified) AdministrableProductDefinition.routeOfAdministration.targetSpecies.withdrawalPeriod
 *
 * http://hl7.org/fhir/_withdrawalPeriod
 */
export const _withdrawalPeriod = 'http://hl7.org/fhir/_withdrawalPeriod' satisfies OwlObjectProperty;

/**
 * CapabilityStatementImplementationComponent
 *
 * CapabilityStatementImplementationComponent: Identifies a specific implementation instance that is described by the capability statement - i.e. a particular installation, rather than the capabilities of a software program.
 *
 * http://hl7.org/fhir/CapabilityStatementImplementationComponent
 */
export const CapabilityStatementImplementationComponent = 'http://hl7.org/fhir/CapabilityStatementImplementationComponent' satisfies OwlClass;

/**
 * analysis
 *
 * GenomicStudy.analysis: The details about a specific analysis that was performed in this GenomicStudy.
 *
 * http://hl7.org/fhir/analysis
 */
export const analysis = 'http://hl7.org/fhir/analysis' satisfies OwlObjectProperty;

/**
 * monitoringProgram
 *
 * MedicationKnowledge.monitoringProgram: The program under which the medication is reviewed.
 *
 * http://hl7.org/fhir/monitoringProgram
 */
export const monitoringProgram = 'http://hl7.org/fhir/monitoringProgram' satisfies OwlObjectProperty;

/**
 * _date
 *
 * (Modified) ResearchStudy.date
 *
 * http://hl7.org/fhir/_date
 */
export const _date = 'http://hl7.org/fhir/_date' satisfies OwlObjectProperty;

/**
 * satisfiedBy
 *
 * Requirements.statement.satisfiedBy: A reference to another artifact that satisfies this requirement. This could be a Profile, extension, or an element in one of those, or a CapabilityStatement, OperationDefinition, SearchParameter, CodeSystem(/code), ValueSet, Libary etc.
 *
 * http://hl7.org/fhir/satisfiedBy
 */
export const satisfiedBy = 'http://hl7.org/fhir/satisfiedBy' satisfies OwlObjectProperty;

/**
 * artifact
 *
 * TestScript.scope.artifact: The specific conformance artifact being tested. The canonical reference can be version-specific.
 *
 * http://hl7.org/fhir/artifact
 */
export const artifact = 'http://hl7.org/fhir/artifact' satisfies OwlObjectProperty;

/**
 * timing
 *
 * RequestOrchestration.action.timing
 *
 * http://hl7.org/fhir/timing
 */
export const timing = 'http://hl7.org/fhir/timing' satisfies OwlObjectProperty;

/**
 * appliesToAll
 *
 * CoverageEligibilityRequest.supportingInfo.appliesToAll: The supporting materials are applicable for all detail items, product/servce categories and specific billing codes.
 *
 * http://hl7.org/fhir/appliesToAll
 */
export const appliesToAll = 'http://hl7.org/fhir/appliesToAll' satisfies OwlObjectProperty;

/**
 * _appointmentRequired
 *
 * (Modified) HealthcareService.appointmentRequired
 *
 * http://hl7.org/fhir/_appointmentRequired
 */
export const _appointmentRequired = 'http://hl7.org/fhir/_appointmentRequired' satisfies OwlObjectProperty;

/**
 * _canFilterBy
 *
 * (Modified) SubscriptionTopic.canFilterBy
 *
 * http://hl7.org/fhir/_canFilterBy
 */
export const _canFilterBy = 'http://hl7.org/fhir/_canFilterBy' satisfies OwlObjectProperty;

/**
 * filter
 *
 * ValueSet.compose.exclude.filter: Select concepts by specifying a matching criterion based on the properties (including relationships) defined by the system, or on filters defined by the system. If multiple filters are specified within the include, they SHALL all be true.
 *
 * http://hl7.org/fhir/filter
 */
export const filter = 'http://hl7.org/fhir/filter' satisfies OwlObjectProperty;

/**
 * _targetNumber
 *
 * (Modified) ResearchStudy.recruitment.targetNumber
 *
 * http://hl7.org/fhir/_targetNumber
 */
export const _targetNumber = 'http://hl7.org/fhir/_targetNumber' satisfies OwlObjectProperty;

/**
 * _additive
 *
 * (Modified) SpecimenDefinition.typeTested.container.additive.additive
 *
 * http://hl7.org/fhir/_additive
 */
export const _additive = 'http://hl7.org/fhir/_additive' satisfies OwlObjectProperty;

/**
 * _management
 *
 * (Modified) ClinicalUseDefinition.interaction.management
 *
 * http://hl7.org/fhir/_management
 */
export const _management = 'http://hl7.org/fhir/_management' satisfies OwlObjectProperty;

/**
 * _phylum
 *
 * (Modified) SubstanceSourceMaterial.organism.organismGeneral.phylum
 *
 * http://hl7.org/fhir/_phylum
 */
export const _phylum = 'http://hl7.org/fhir/_phylum' satisfies OwlObjectProperty;

/**
 * _distributor
 *
 * (Modified) DeviceDefinition.packaging.packaging.distributor
 *
 * http://hl7.org/fhir/_distributor
 */
export const _distributor = 'http://hl7.org/fhir/_distributor' satisfies OwlObjectProperty;

/**
 * _clinicalRecommendationStatement
 *
 * (Modified) Measure.clinicalRecommendationStatement
 *
 * http://hl7.org/fhir/_clinicalRecommendationStatement
 */
export const _clinicalRecommendationStatement = 'http://hl7.org/fhir/_clinicalRecommendationStatement' satisfies OwlObjectProperty;

/**
 * _manifest
 *
 * (Modified) ImplementationGuide.manifest
 *
 * http://hl7.org/fhir/_manifest
 */
export const _manifest = 'http://hl7.org/fhir/_manifest' satisfies OwlObjectProperty;

/**
 * cancellationDate
 *
 * Appointment.cancellationDate: The date/time describing when the appointment was cancelled.
 *
 * http://hl7.org/fhir/cancellationDate
 */
export const cancellationDate = 'http://hl7.org/fhir/cancellationDate' satisfies OwlObjectProperty;

/**
 * _doseQuantity
 *
 * (Modified) Immunization.doseQuantity
 *
 * http://hl7.org/fhir/_doseQuantity
 */
export const _doseQuantity = 'http://hl7.org/fhir/_doseQuantity' satisfies OwlObjectProperty;

/**
 * DeviceDefinitionPackagingComponentUdiDeviceIdentifier
 *
 * Unique Device Identifier (UDI) Barcode string on the packaging.
 *
 * http://hl7.org/fhir/DeviceDefinitionPackagingComponentUdiDeviceIdentifier
 */
export const DeviceDefinitionPackagingComponentUdiDeviceIdentifier = 'http://hl7.org/fhir/DeviceDefinitionPackagingComponentUdiDeviceIdentifier' satisfies OwlClass;

/**
 * VerificationResult
 *
 * Describes validation requirements, source(s), status and dates for one or more elements.
 *
 * http://hl7.org/fhir/VerificationResult
 */
export const VerificationResult = 'http://hl7.org/fhir/VerificationResult' satisfies OwlClass;

/**
 * preference
 *
 * SpecimenDefinition.typeTested.preference: The preference for this type of conditioned specimen.
 *
 * http://hl7.org/fhir/preference
 */
export const preference = 'http://hl7.org/fhir/preference' satisfies OwlObjectProperty;

/**
 * _asserter
 *
 * (Modified) Permission.asserter
 *
 * http://hl7.org/fhir/_asserter
 */
export const _asserter = 'http://hl7.org/fhir/_asserter' satisfies OwlObjectProperty;

/**
 * _regulatoryIdentifier
 *
 * (Modified) DeviceDefinition.regulatoryIdentifier
 *
 * http://hl7.org/fhir/_regulatoryIdentifier
 */
export const _regulatoryIdentifier = 'http://hl7.org/fhir/_regulatoryIdentifier' satisfies OwlObjectProperty;

/**
 * molecularFormula
 *
 * SubstanceDefinition.structure.molecularFormula: An expression which states the number and type of atoms present in a molecule of a substance.
 *
 * http://hl7.org/fhir/molecularFormula
 */
export const molecularFormula = 'http://hl7.org/fhir/molecularFormula' satisfies OwlObjectProperty;

/**
 * isActive
 *
 * Medication.ingredient.isActive: Indication of whether this ingredient affects the therapeutic action of the drug.
 *
 * http://hl7.org/fhir/isActive
 */
export const isActive = 'http://hl7.org/fhir/isActive' satisfies OwlObjectProperty;

/**
 * dispenserInstruction
 *
 * MedicationRequest.dispenseRequest.dispenserInstruction: Provides additional information to the dispenser, for example, counselling to be provided to the patient.
 *
 * http://hl7.org/fhir/dispenserInstruction
 */
export const dispenserInstruction = 'http://hl7.org/fhir/dispenserInstruction' satisfies OwlObjectProperty;

/**
 * MedicationKnowledgeRelatedMedicationKnowledgeComponent
 *
 * MedicationKnowledgeRelatedMedicationKnowledgeComponent: Associated or related medications. For example, if the medication is a branded product (e.g. Crestor), this is the Therapeutic Moeity (e.g. Rosuvastatin) or if this is a generic medication (e.g. Rosuvastatin), this would link to a branded product (e.g. Crestor.
 *
 * http://hl7.org/fhir/MedicationKnowledgeRelatedMedicationKnowledgeComponent
 */
export const MedicationKnowledgeRelatedMedicationKnowledgeComponent = 'http://hl7.org/fhir/MedicationKnowledgeRelatedMedicationKnowledgeComponent' satisfies OwlClass;

/**
 * CapabilityStatementRestSecurityComponent
 *
 * CapabilityStatementRestComponent.CapabilityStatementRestSecurityComponent: Information about security implementation from an interface perspective - what a client needs to know.
 *
 * http://hl7.org/fhir/CapabilityStatementRestSecurityComponent
 */
export const CapabilityStatementRestSecurityComponent = 'http://hl7.org/fhir/CapabilityStatementRestSecurityComponent' satisfies OwlClass;

/**
 * initialSelected
 *
 * Questionnaire.item.item.answerOption.initialSelected: Indicates whether the answer value is selected when the list of possible answers is initially shown.
 *
 * http://hl7.org/fhir/initialSelected
 */
export const initialSelected = 'http://hl7.org/fhir/initialSelected' satisfies OwlObjectProperty;

/**
 * _preventiveAction
 *
 * (Modified) AdverseEvent.preventiveAction
 *
 * http://hl7.org/fhir/_preventiveAction
 */
export const _preventiveAction = 'http://hl7.org/fhir/_preventiveAction' satisfies OwlObjectProperty;

/**
 * DeviceDefinitionConformsToComponent
 *
 * DeviceDefinitionConformsToComponent: Identifies the standards, specifications, or formal guidances for the capabilities supported by the device. The device may be certified as conformant to these specifications e.g., communication, performance, process, measurement, or specialization standards.
 *
 * http://hl7.org/fhir/DeviceDefinitionConformsToComponent
 */
export const DeviceDefinitionConformsToComponent = 'http://hl7.org/fhir/DeviceDefinitionConformsToComponent' satisfies OwlClass;

/**
 * _MedicationStatement
 *
 * (Modified) MedicationStatement
 *
 * http://hl7.org/fhir/_MedicationStatement
 */
export const _MedicationStatement = 'http://hl7.org/fhir/_MedicationStatement' satisfies OwlClass;

/**
 * _availableStartTime
 *
 * (Modified) Availability.availableTime.availableStartTime
 *
 * http://hl7.org/fhir/_availableStartTime
 */
export const _availableStartTime = 'http://hl7.org/fhir/_availableStartTime' satisfies OwlObjectProperty;

/**
 * validationType
 *
 * VerificationResult.validationType: What the target is validated against (nothing; primary source; multiple sources).
 *
 * http://hl7.org/fhir/validationType
 */
export const validationType = 'http://hl7.org/fhir/validationType' satisfies OwlObjectProperty;

/**
 * _axis
 *
 * (Modified) VisionPrescription.lensSpecification.axis
 *
 * http://hl7.org/fhir/_axis
 */
export const _axis = 'http://hl7.org/fhir/_axis' satisfies OwlObjectProperty;

/**
 * _serialNumber
 *
 * (Modified) Device.serialNumber
 *
 * http://hl7.org/fhir/_serialNumber
 */
export const _serialNumber = 'http://hl7.org/fhir/_serialNumber' satisfies OwlObjectProperty;

/**
 * Narrative
 *
 * A human-readable summary of the resource conveying the essential clinical and business information for the resource.
 *
 * http://hl7.org/fhir/Narrative
 */
export const Narrative = 'http://hl7.org/fhir/Narrative' satisfies OwlClass;

/**
 * _dependency
 *
 * (Modified) TestPlan.testCase.dependency
 *
 * http://hl7.org/fhir/_dependency
 */
export const _dependency = 'http://hl7.org/fhir/_dependency' satisfies OwlObjectProperty;

/**
 * endDate
 *
 * ResearchSubject.progress.endDate: The date when the state ended.
 *
 * http://hl7.org/fhir/endDate
 */
export const endDate = 'http://hl7.org/fhir/endDate' satisfies OwlObjectProperty;

/**
 * _prognosisReference
 *
 * (Modified) ClinicalImpression.prognosisReference
 *
 * http://hl7.org/fhir/_prognosisReference
 */
export const _prognosisReference = 'http://hl7.org/fhir/_prognosisReference' satisfies OwlObjectProperty;

/**
 * _recruitment
 *
 * (Modified) ResearchStudy.recruitment
 *
 * http://hl7.org/fhir/_recruitment
 */
export const _recruitment = 'http://hl7.org/fhir/_recruitment' satisfies OwlObjectProperty;

/**
 * searchParam
 *
 * DataRequirement.valueFilter.searchParam: A search parameter defined on the specified type of the DataRequirement, and which searches on elements of a type compatible with the type of the valueFilter.value[x] for the filter.
 *
 * http://hl7.org/fhir/searchParam
 */
export const searchParam = 'http://hl7.org/fhir/searchParam' satisfies OwlObjectProperty;

/**
 * _usageInstruction
 *
 * (Modified) DeviceDispense.usageInstruction
 *
 * http://hl7.org/fhir/_usageInstruction
 */
export const _usageInstruction = 'http://hl7.org/fhir/_usageInstruction' satisfies OwlObjectProperty;

/**
 * _generation
 *
 * (Modified) ImplementationGuide.definition.page.page.generation
 *
 * http://hl7.org/fhir/_generation
 */
export const _generation = 'http://hl7.org/fhir/_generation' satisfies OwlObjectProperty;

/**
 * artifactAssessment
 *
 * Citation.citedArtifact.classification.artifactAssessment: Complex or externally created classification.
 *
 * http://hl7.org/fhir/artifactAssessment
 */
export const artifactAssessment = 'http://hl7.org/fhir/artifactAssessment' satisfies OwlObjectProperty;

/**
 * complete
 *
 * Citation.citedArtifact.contributorship.complete: Indicates if the list includes all authors and/or contributors.
 *
 * http://hl7.org/fhir/complete
 */
export const complete = 'http://hl7.org/fhir/complete' satisfies OwlObjectProperty;

/**
 * _dependent
 *
 * (Modified) StructureMap.group.rule.dependent
 *
 * http://hl7.org/fhir/_dependent
 */
export const _dependent = 'http://hl7.org/fhir/_dependent' satisfies OwlObjectProperty;

/**
 * _due
 *
 * (Modified) PlanDefinition.goal.target.due
 *
 * http://hl7.org/fhir/_due
 */
export const _due = 'http://hl7.org/fhir/_due' satisfies OwlObjectProperty;

/**
 * _replaces
 *
 * (Modified) DeviceRequest.replaces
 *
 * http://hl7.org/fhir/_replaces
 */
export const _replaces = 'http://hl7.org/fhir/_replaces' satisfies OwlObjectProperty;

/**
 * EvidenceStatisticModelCharacteristicComponent
 *
 * EvidenceStatisticComponent.EvidenceStatisticModelCharacteristicComponent: A component of the method to generate the statistic.
 *
 * http://hl7.org/fhir/EvidenceStatisticModelCharacteristicComponent
 */
export const EvidenceStatisticModelCharacteristicComponent = 'http://hl7.org/fhir/EvidenceStatisticModelCharacteristicComponent' satisfies OwlClass;

/**
 * _friday
 *
 * (Modified) Appointment.recurrenceTemplate.weeklyTemplate.friday
 *
 * http://hl7.org/fhir/_friday
 */
export const _friday = 'http://hl7.org/fhir/_friday' satisfies OwlObjectProperty;

/**
 * orderedBy
 *
 * EvidenceReport.section.orderedBy: Specifies the order applied to the items in the section entries.
 *
 * http://hl7.org/fhir/orderedBy
 */
export const orderedBy = 'http://hl7.org/fhir/orderedBy' satisfies OwlObjectProperty;

/**
 * _modality
 *
 * (Modified) ImagingStudy.series.modality
 *
 * http://hl7.org/fhir/_modality
 */
export const _modality = 'http://hl7.org/fhir/_modality' satisfies OwlObjectProperty;

/**
 * expirationType
 *
 * Contract.expirationType: Event resulting in discontinuation or termination of this Contract instance by one or more parties to the contract.
 *
 * http://hl7.org/fhir/expirationType
 */
export const expirationType = 'http://hl7.org/fhir/expirationType' satisfies OwlObjectProperty;

/**
 * party
 *
 * Contract.signer.party: Party which is a signator to this Contract.
 *
 * http://hl7.org/fhir/party
 */
export const party = 'http://hl7.org/fhir/party' satisfies OwlObjectProperty;

/**
 * _objective
 *
 * (Modified) ResearchStudy.objective
 *
 * http://hl7.org/fhir/_objective
 */
export const _objective = 'http://hl7.org/fhir/_objective' satisfies OwlObjectProperty;

/**
 * _totalNet
 *
 * (Modified) Invoice.totalNet
 *
 * http://hl7.org/fhir/_totalNet
 */
export const _totalNet = 'http://hl7.org/fhir/_totalNet' satisfies OwlObjectProperty;

/**
 * _adherence
 *
 * (Modified) MedicationStatement.adherence
 *
 * http://hl7.org/fhir/_adherence
 */
export const _adherence = 'http://hl7.org/fhir/_adherence' satisfies OwlObjectProperty;

/**
 * _cardinalityBehavior
 *
 * (Modified) RequestOrchestration.action.action.cardinalityBehavior
 *
 * http://hl7.org/fhir/_cardinalityBehavior
 */
export const _cardinalityBehavior = 'http://hl7.org/fhir/_cardinalityBehavior' satisfies OwlObjectProperty;

/**
 * startDate
 *
 * ResearchSubject.progress.startDate: The date when the new status started.
 *
 * http://hl7.org/fhir/startDate
 */
export const startDate = 'http://hl7.org/fhir/startDate' satisfies OwlObjectProperty;

/**
 * basis
 *
 * RegulatedAuthorization.basis: The legal or regulatory framework against which this authorization is granted, or other reasons for it.
 *
 * http://hl7.org/fhir/basis
 */
export const basis = 'http://hl7.org/fhir/basis' satisfies OwlObjectProperty;

/**
 * _minutesDuration
 *
 * (Modified) Appointment.minutesDuration
 *
 * http://hl7.org/fhir/_minutesDuration
 */
export const _minutesDuration = 'http://hl7.org/fhir/_minutesDuration' satisfies OwlObjectProperty;

/**
 * instruction
 *
 * SpecimenDefinition.typeTested.handling.instruction: Additional textual instructions for the preservation or transport of the specimen. For instance, 'Protect from light exposure'.
 *
 * http://hl7.org/fhir/instruction
 */
export const instruction = 'http://hl7.org/fhir/instruction' satisfies OwlObjectProperty;

/**
 * _targetDisease
 *
 * (Modified) ImmunizationRecommendation.recommendation.targetDisease
 *
 * http://hl7.org/fhir/_targetDisease
 */
export const _targetDisease = 'http://hl7.org/fhir/_targetDisease' satisfies OwlObjectProperty;

/**
 * eventTrigger
 *
 * SubscriptionTopic.eventTrigger: Event definition which can be used to trigger the SubscriptionTopic.
 *
 * http://hl7.org/fhir/eventTrigger
 */
export const eventTrigger = 'http://hl7.org/fhir/eventTrigger' satisfies OwlObjectProperty;

/**
 * closure
 *
 * TerminologyCapabilities.closure: Whether the $closure operation is supported.
 *
 * http://hl7.org/fhir/closure
 */
export const closure = 'http://hl7.org/fhir/closure' satisfies OwlObjectProperty;

/**
 * numberOfParticipants
 *
 * Evidence.statistic.sampleSize.numberOfParticipants: A human-readable string to clarify or explain concepts about the sample size.
 *
 * http://hl7.org/fhir/numberOfParticipants
 */
export const numberOfParticipants = 'http://hl7.org/fhir/numberOfParticipants' satisfies OwlObjectProperty;

/**
 * businessArrangement
 *
 * CoverageEligibilityRequest.insurance.businessArrangement: A business agreement number established between the provider and the insurer for special business processing purposes.
 *
 * http://hl7.org/fhir/businessArrangement
 */
export const businessArrangement = 'http://hl7.org/fhir/businessArrangement' satisfies OwlObjectProperty;

/**
 * requesterLinkId
 *
 * Contract.term.group.action.requesterLinkId: Id [identifier??] of the clause or question text related to the requester of this action in the referenced form or QuestionnaireResponse.
 *
 * http://hl7.org/fhir/requesterLinkId
 */
export const requesterLinkId = 'http://hl7.org/fhir/requesterLinkId' satisfies OwlObjectProperty;

/**
 * _programEligibility
 *
 * (Modified) Immunization.programEligibility
 *
 * http://hl7.org/fhir/_programEligibility
 */
export const _programEligibility = 'http://hl7.org/fhir/_programEligibility' satisfies OwlObjectProperty;

/**
 * _average
 *
 * (Modified) SubstancePolymer.repeat.repeatUnit.degreeOfPolymerisation.average
 *
 * http://hl7.org/fhir/_average
 */
export const _average = 'http://hl7.org/fhir/_average' satisfies OwlObjectProperty;

/**
 * proxySignature
 *
 * VerificationResult.attestation.proxySignature: Signed assertion by the proxy entity indicating that they have the right to submit attested information on behalf of the attestation source.
 *
 * http://hl7.org/fhir/proxySignature
 */
export const proxySignature = 'http://hl7.org/fhir/proxySignature' satisfies OwlObjectProperty;

/**
 * _assessmentMethod
 *
 * (Modified) AdverseEvent.suspectEntity.causality.assessmentMethod
 *
 * http://hl7.org/fhir/_assessmentMethod
 */
export const _assessmentMethod = 'http://hl7.org/fhir/_assessmentMethod' satisfies OwlObjectProperty;

/**
 * _series
 *
 * (Modified) ImmunizationRecommendation.recommendation.series
 *
 * http://hl7.org/fhir/_series
 */
export const _series = 'http://hl7.org/fhir/_series' satisfies OwlObjectProperty;

/**
 * _performingOrganization
 *
 * (Modified) ChargeItem.performingOrganization
 *
 * http://hl7.org/fhir/_performingOrganization
 */
export const _performingOrganization = 'http://hl7.org/fhir/_performingOrganization' satisfies OwlObjectProperty;

/**
 * frames
 *
 * Attachment.frames: The number of frames in a photo. This is used with a multi-page fax, or an imaging acquisition context that takes multiple slices in a single image, or an animated gif. If there is more than one frame, this SHALL have a value in order to alert interface software that a multi-frame capable rendering widget is required.
 *
 * http://hl7.org/fhir/frames
 */
export const frames = 'http://hl7.org/fhir/frames' satisfies OwlObjectProperty;

/**
 * _paternalOrganismName
 *
 * (Modified) SubstanceSourceMaterial.organism.hybrid.paternalOrganismName
 *
 * http://hl7.org/fhir/_paternalOrganismName
 */
export const _paternalOrganismName = 'http://hl7.org/fhir/_paternalOrganismName' satisfies OwlObjectProperty;

/**
 * inputProfile
 *
 * OperationDefinition.inputProfile: Additional validation information for the in parameters - a single profile that covers all the parameters. The profile is a constraint on the parameters resource as a whole.
 *
 * http://hl7.org/fhir/inputProfile
 */
export const inputProfile = 'http://hl7.org/fhir/inputProfile' satisfies OwlObjectProperty;

/**
 * _guarantor
 *
 * (Modified) Account.guarantor
 *
 * http://hl7.org/fhir/_guarantor
 */
export const _guarantor = 'http://hl7.org/fhir/_guarantor' satisfies OwlObjectProperty;

/**
 * _human
 *
 * (Modified) ElementDefinition.constraint.human
 *
 * http://hl7.org/fhir/_human
 */
export const _human = 'http://hl7.org/fhir/_human' satisfies OwlObjectProperty;

/**
 * NutritionProductCharacteristicComponent
 *
 * NutritionProductCharacteristicComponent: Specifies descriptive properties of the nutrition product.
 *
 * http://hl7.org/fhir/NutritionProductCharacteristicComponent
 */
export const NutritionProductCharacteristicComponent = 'http://hl7.org/fhir/NutritionProductCharacteristicComponent' satisfies OwlClass;

/**
 * _orderDetail
 *
 * (Modified) ServiceRequest.orderDetail
 *
 * http://hl7.org/fhir/_orderDetail
 */
export const _orderDetail = 'http://hl7.org/fhir/_orderDetail' satisfies OwlObjectProperty;

/**
 * maxParticipants
 *
 * VirtualServiceDetail.maxParticipants: Maximum number of participants supported by the virtual service.
 *
 * http://hl7.org/fhir/maxParticipants
 */
export const maxParticipants = 'http://hl7.org/fhir/maxParticipants' satisfies OwlObjectProperty;

/**
 * ClinicalUseDefinitionUndesirableEffectComponent
 *
 * ClinicalUseDefinitionUndesirableEffectComponent: Describe the possible undesirable effects (negative outcomes) from the use of the medicinal product as treatment.
 *
 * http://hl7.org/fhir/ClinicalUseDefinitionUndesirableEffectComponent
 */
export const ClinicalUseDefinitionUndesirableEffectComponent = 'http://hl7.org/fhir/ClinicalUseDefinitionUndesirableEffectComponent' satisfies OwlClass;

/**
 * _observed
 *
 * (Modified) Evidence.variableDefinition.observed
 *
 * http://hl7.org/fhir/_observed
 */
export const _observed = 'http://hl7.org/fhir/_observed' satisfies OwlObjectProperty;

/**
 * validityPeriod
 *
 * RegulatedAuthorization.validityPeriod: The time period in which the regulatory approval, clearance or licencing is in effect. As an example, a Marketing Authorization includes the date of authorization and/or an expiration date.
 *
 * http://hl7.org/fhir/validityPeriod
 */
export const validityPeriod = 'http://hl7.org/fhir/validityPeriod' satisfies OwlObjectProperty;

/**
 * ComputableLanguage
 *
 * Contract.ComputableLanguage: List of Computable Policy Rule Language Representations of this Contract.
 *
 * http://hl7.org/fhir/ComputableLanguage
 */
export const ComputableLanguage = 'http://hl7.org/fhir/ComputableLanguage' satisfies OwlClass;

/**
 * surfaceOrientation
 *
 * BodyStructure.excludedStructure.bodyLandmarkOrientation.surfaceOrientation: The surface area a body location is in relation to a landmark.
 *
 * http://hl7.org/fhir/surfaceOrientation
 */
export const surfaceOrientation = 'http://hl7.org/fhir/surfaceOrientation' satisfies OwlObjectProperty;

/**
 * _Provenance
 *
 * (Modified) Provenance
 *
 * http://hl7.org/fhir/_Provenance
 */
export const _Provenance = 'http://hl7.org/fhir/_Provenance' satisfies OwlClass;

/**
 * testRun
 *
 * TestPlan.testCase.testRun: The actual test to be executed.
 *
 * http://hl7.org/fhir/testRun
 */
export const testRun = 'http://hl7.org/fhir/testRun' satisfies OwlObjectProperty;

/**
 * SubstanceProtein
 *
 * A SubstanceProtein is defined as a single unit of a linear amino acid sequence, or a combination of subunits that are either covalently linked or have a defined invariant stoichiometric relationship. This includes all synthetic, recombinant and purified SubstanceProteins of defined sequence, whether the use is therapeutic or prophylactic. This set of elements will be used to describe albumins, coagulation factors, cytokines, growth factors, peptide/SubstanceProtein hormones, enzymes, toxins, toxoids, recombinant vaccines, and immunomodulators.
 *
 * http://hl7.org/fhir/SubstanceProtein
 */
export const SubstanceProtein = 'http://hl7.org/fhir/SubstanceProtein' satisfies OwlClass;

/**
 * _focalDevice
 *
 * (Modified) Procedure.focalDevice
 *
 * http://hl7.org/fhir/_focalDevice
 */
export const _focalDevice = 'http://hl7.org/fhir/_focalDevice' satisfies OwlObjectProperty;

/**
 * _operationType
 *
 * (Modified) InventoryReport.operationType
 *
 * http://hl7.org/fhir/_operationType
 */
export const _operationType = 'http://hl7.org/fhir/_operationType' satisfies OwlObjectProperty;

/**
 * context
 *
 * Contract.term.group.asset.context: Circumstance of the asset.
 *
 * http://hl7.org/fhir/context
 */
export const context = 'http://hl7.org/fhir/context' satisfies OwlObjectProperty;

/**
 * occurrenceDateTime
 *
 * GuidanceResponse.occurrenceDateTime: Indicates when the guidance response was processed.
 *
 * http://hl7.org/fhir/occurrenceDateTime
 */
export const occurrenceDateTime = 'http://hl7.org/fhir/occurrenceDateTime' satisfies OwlObjectProperty;

/**
 * DetectedIssueEvidenceComponent
 *
 * DetectedIssueEvidenceComponent: Supporting evidence or manifestations that provide the basis for identifying the detected issue such as a GuidanceResponse or MeasureReport.
 *
 * http://hl7.org/fhir/DetectedIssueEvidenceComponent
 */
export const DetectedIssueEvidenceComponent = 'http://hl7.org/fhir/DetectedIssueEvidenceComponent' satisfies OwlClass;

/**
 * _ExplanationOfBenefit
 *
 * (Modified) ExplanationOfBenefit
 *
 * http://hl7.org/fhir/_ExplanationOfBenefit
 */
export const _ExplanationOfBenefit = 'http://hl7.org/fhir/_ExplanationOfBenefit' satisfies OwlClass;

/**
 * validated
 *
 * TestScript.metadata.capability.validated: Whether or not the test execution will validate the given capabilities of the server in order for this test script to execute.
 *
 * http://hl7.org/fhir/validated
 */
export const validated = 'http://hl7.org/fhir/validated' satisfies OwlObjectProperty;

/**
 * _subunit
 *
 * (Modified) SubstanceProtein.subunit.subunit
 *
 * http://hl7.org/fhir/_subunit
 */
export const _subunit = 'http://hl7.org/fhir/_subunit' satisfies OwlObjectProperty;

/**
 * EvidenceStatisticAttributeEstimateComponent
 *
 * EvidenceStatisticComponent.EvidenceStatisticAttributeEstimateComponent: A statistical attribute of the statistic such as a measure of heterogeneity.
 *
 * http://hl7.org/fhir/EvidenceStatisticAttributeEstimateComponent
 */
export const EvidenceStatisticAttributeEstimateComponent = 'http://hl7.org/fhir/EvidenceStatisticAttributeEstimateComponent' satisfies OwlClass;

/**
 * replacedSequence
 *
 * MolecularSequence.relative.edit.replacedSequence: Allele in the starting sequence. Nucleotide(s)/amino acids from start position of sequence to stop position of sequence on the positive (+) strand of the starting sequence. When the sequence  type is DNA, it should be the sequence on the positive (+) strand. This will lay in the range between variant.start and variant.end.
 *
 * http://hl7.org/fhir/replacedSequence
 */
export const replacedSequence = 'http://hl7.org/fhir/replacedSequence' satisfies OwlObjectProperty;

/**
 * specimen
 *
 * ObservationDefinition.specimen: The kind of specimen that this type of observation is produced on.
 *
 * http://hl7.org/fhir/specimen
 */
export const specimen = 'http://hl7.org/fhir/specimen' satisfies OwlObjectProperty;

/**
 * rater
 *
 * Evidence.certainty.subcomponent.rater: Individual or group who did the rating.
 *
 * http://hl7.org/fhir/rater
 */
export const rater = 'http://hl7.org/fhir/rater' satisfies OwlObjectProperty;

/**
 * relatedMedicationKnowledge
 *
 * MedicationKnowledge.relatedMedicationKnowledge: Associated or related medications. For example, if the medication is a branded product (e.g. Crestor), this is the Therapeutic Moeity (e.g. Rosuvastatin) or if this is a generic medication (e.g. Rosuvastatin), this would link to a branded product (e.g. Crestor.
 *
 * http://hl7.org/fhir/relatedMedicationKnowledge
 */
export const relatedMedicationKnowledge = 'http://hl7.org/fhir/relatedMedicationKnowledge' satisfies OwlObjectProperty;

/**
 * lastModified
 *
 * Transport.lastModified: The date and time of last modification to this transport.
 *
 * http://hl7.org/fhir/lastModified
 */
export const lastModified = 'http://hl7.org/fhir/lastModified' satisfies OwlObjectProperty;

/**
 * RequestOrchestrationActionParticipantComponent
 *
 * RequestOrchestrationActionComponent.RequestOrchestrationActionParticipantComponent: The participant that should perform or be responsible for this action.
 *
 * http://hl7.org/fhir/RequestOrchestrationActionParticipantComponent
 */
export const RequestOrchestrationActionParticipantComponent = 'http://hl7.org/fhir/RequestOrchestrationActionParticipantComponent' satisfies OwlClass;

/**
 * _informationType
 *
 * (Modified) ArtifactAssessment.content.component.informationType
 *
 * http://hl7.org/fhir/_informationType
 */
export const _informationType = 'http://hl7.org/fhir/_informationType' satisfies OwlObjectProperty;

/**
 * citation
 *
 * Citation.citedArtifact.relatesTo.citation: A bibliographic citation for the related artifact. This text SHOULD be formatted according to an accepted citation format.
 *
 * http://hl7.org/fhir/citation
 */
export const citation = 'http://hl7.org/fhir/citation' satisfies OwlObjectProperty;

/**
 * paymentStatus
 *
 * PaymentNotice.paymentStatus: A code indicating whether payment has been sent or cleared.
 *
 * http://hl7.org/fhir/paymentStatus
 */
export const paymentStatus = 'http://hl7.org/fhir/paymentStatus' satisfies OwlObjectProperty;

/**
 * treatment
 *
 * ClinicalUseDefinition.indication.otherTherapy.treatment: Reference to a specific medication (active substance, medicinal product or class of products, biological, food etc.) as part of an indication or contraindication.
 *
 * http://hl7.org/fhir/treatment
 */
export const treatment = 'http://hl7.org/fhir/treatment' satisfies OwlObjectProperty;

/**
 * _initial
 *
 * (Modified) Questionnaire.item.item.initial
 *
 * http://hl7.org/fhir/_initial
 */
export const _initial = 'http://hl7.org/fhir/_initial' satisfies OwlObjectProperty;

/**
 * priceComponent
 *
 * Invoice.lineItem.priceComponent: The price for a ChargeItem may be calculated as a base price with surcharges/deductions that apply in certain conditions. A ChargeItemDefinition resource that defines the prices, factors and conditions that apply to a billing code is currently under development. The priceComponent element can be used to offer transparency to the recipient of the Invoice as to how the prices have been calculated.
 *
 * http://hl7.org/fhir/priceComponent
 */
export const priceComponent = 'http://hl7.org/fhir/priceComponent' satisfies OwlObjectProperty;

/**
 * _Linkage
 *
 * (Modified) Linkage
 *
 * http://hl7.org/fhir/_Linkage
 */
export const _Linkage = 'http://hl7.org/fhir/_Linkage' satisfies OwlClass;

/**
 * _indicationGuideline
 *
 * (Modified) MedicationKnowledge.indicationGuideline
 *
 * http://hl7.org/fhir/_indicationGuideline
 */
export const _indicationGuideline = 'http://hl7.org/fhir/_indicationGuideline' satisfies OwlObjectProperty;

/**
 * SubstanceSourceMaterial
 *
 * Source material shall capture information on the taxonomic and anatomical origins as well as the fraction of a material that can result in or can be modified to form a substance. This set of data elements shall be used to define polymer substances isolated from biological matrices. Taxonomic and anatomical origins shall be described using a controlled vocabulary as required. This information is captured for naturally derived polymers ( . starch) and structurally diverse substances. For Organisms belonging to the Kingdom Plantae the Substance level defines the fresh material of a single species or infraspecies, the Herbal Drug and the Herbal preparation. For Herbal preparations, the fraction information will be captured at the Substance information level and additional information for herbal extracts will be captured at the Specified Substance Group 1 information level. See for further explanation the Substance Class: Structurally Diverse and the herbal annex.
 *
 * http://hl7.org/fhir/SubstanceSourceMaterial
 */
export const SubstanceSourceMaterial = 'http://hl7.org/fhir/SubstanceSourceMaterial' satisfies OwlClass;

/**
 * _conditionalRead
 *
 * (Modified) CapabilityStatement.rest.resource.conditionalRead
 *
 * http://hl7.org/fhir/_conditionalRead
 */
export const _conditionalRead = 'http://hl7.org/fhir/_conditionalRead' satisfies OwlObjectProperty;

/**
 * managingEntity
 *
 * Subscription.managingEntity: Entity with authorization to make subsequent revisions to the Subscription and also determines what data the subscription is authorized to disclose.
 *
 * http://hl7.org/fhir/managingEntity
 */
export const managingEntity = 'http://hl7.org/fhir/managingEntity' satisfies OwlObjectProperty;

/**
 * EvidenceVariableCharacteristicDefinitionByTypeAndValueComponent
 *
 * EvidenceVariableCharacteristicComponent.EvidenceVariableCharacteristicDefinitionByCombinationComponentCharacteristic.EvidenceVariableCharacteristicDefinitionByTypeAndValueComponent: Defines the characteristic using both a type and value[x] elements.
 *
 * http://hl7.org/fhir/EvidenceVariableCharacteristicDefinitionByTypeAndValueComponent
 */
export const EvidenceVariableCharacteristicDefinitionByTypeAndValueComponent = 'http://hl7.org/fhir/EvidenceVariableCharacteristicDefinitionByTypeAndValueComponent' satisfies OwlClass;

/**
 * operationalStatus
 *
 * Location.operationalStatus: The operational status covers operation values most relevant to beds (but can also apply to rooms/units/chairs/etc. such as an isolation unit/dialysis chair). This typically covers concepts such as contamination, housekeeping, and other activities like maintenance.
 *
 * http://hl7.org/fhir/operationalStatus
 */
export const operationalStatus = 'http://hl7.org/fhir/operationalStatus' satisfies OwlObjectProperty;

/**
 * _module
 *
 * (Modified) GuidanceResponse.module
 *
 * http://hl7.org/fhir/_module
 */
export const _module = 'http://hl7.org/fhir/_module' satisfies OwlObjectProperty;

/**
 * MedicationAdministration
 *
 * Describes the event of a patient consuming or otherwise being administered a medication.  This may be as simple as swallowing a tablet or it may be a long running infusion. Related resources tie this event to the authorizing prescription, and the specific encounter between patient and health care practitioner. This event can also be used to record waste using a status of not-done and the appropriate statusReason.
 *
 * http://hl7.org/fhir/MedicationAdministration
 */
export const MedicationAdministration = 'http://hl7.org/fhir/MedicationAdministration' satisfies OwlClass;

/**
 * UdiDeviceIdentifierMarketDistribution
 *
 * DeviceDefinitionPackagingComponentPackagingUdiDeviceIdentifier.UdiDeviceIdentifierMarketDistribution: Indicates where and when the device is available on the market.
 *
 * http://hl7.org/fhir/UdiDeviceIdentifierMarketDistribution
 */
export const UdiDeviceIdentifierMarketDistribution = 'http://hl7.org/fhir/UdiDeviceIdentifierMarketDistribution' satisfies OwlClass;

/**
 * _probability
 *
 * (Modified) RiskAssessment.prediction.probability
 *
 * http://hl7.org/fhir/_probability
 */
export const _probability = 'http://hl7.org/fhir/_probability' satisfies OwlObjectProperty;

/**
 * clinicalRecommendationStatement
 *
 * Measure.clinicalRecommendationStatement: Provides a summary of relevant clinical guidelines or other clinical recommendations supporting the measure.
 *
 * http://hl7.org/fhir/clinicalRecommendationStatement
 */
export const clinicalRecommendationStatement = 'http://hl7.org/fhir/clinicalRecommendationStatement' satisfies OwlObjectProperty;

/**
 * _image
 *
 * (Modified) ImplementationGuide.manifest.image
 *
 * http://hl7.org/fhir/_image
 */
export const _image = 'http://hl7.org/fhir/_image' satisfies OwlObjectProperty;

/**
 * SubscriptionTopicNotificationShapeComponent
 *
 * SubscriptionTopicNotificationShapeComponent: List of properties to describe the shape (e.g., resources) included in notifications from this Subscription Topic.
 *
 * http://hl7.org/fhir/SubscriptionTopicNotificationShapeComponent
 */
export const SubscriptionTopicNotificationShapeComponent = 'http://hl7.org/fhir/SubscriptionTopicNotificationShapeComponent' satisfies OwlClass;

/**
 * _componentPart
 *
 * (Modified) PackagedProductDefinition.packaging.packaging.componentPart
 *
 * http://hl7.org/fhir/_componentPart
 */
export const _componentPart = 'http://hl7.org/fhir/_componentPart' satisfies OwlObjectProperty;

/**
 * op
 *
 * ValueSet.compose.exclude.filter.op: The kind of operation to perform as a part of the filter criteria.
 *
 * http://hl7.org/fhir/op
 */
export const op = 'http://hl7.org/fhir/op' satisfies OwlObjectProperty;

/**
 * _processingFacility
 *
 * (Modified) BiologicallyDerivedProduct.processingFacility
 *
 * http://hl7.org/fhir/_processingFacility
 */
export const _processingFacility = 'http://hl7.org/fhir/_processingFacility' satisfies OwlObjectProperty;

/**
 * unit
 *
 * Quantity.unit: A human-readable form of the unit.
 *
 * http://hl7.org/fhir/unit
 */
export const unit = 'http://hl7.org/fhir/unit' satisfies OwlObjectProperty;

/**
 * _problem
 *
 * (Modified) ClinicalImpression.problem
 *
 * http://hl7.org/fhir/_problem
 */
export const _problem = 'http://hl7.org/fhir/_problem' satisfies OwlObjectProperty;

/**
 * SubstanceDefinitionPropertyComponent
 *
 * SubstanceDefinitionPropertyComponent: General specifications for this substance.
 *
 * http://hl7.org/fhir/SubstanceDefinitionPropertyComponent
 */
export const SubstanceDefinitionPropertyComponent = 'http://hl7.org/fhir/SubstanceDefinitionPropertyComponent' satisfies OwlClass;

/**
 * _fluidConsistencyType
 *
 * (Modified) NutritionOrder.oralDiet.fluidConsistencyType
 *
 * http://hl7.org/fhir/_fluidConsistencyType
 */
export const _fluidConsistencyType = 'http://hl7.org/fhir/_fluidConsistencyType' satisfies OwlObjectProperty;

/**
 * _SubstancePolymer
 *
 * (Modified) SubstancePolymer
 *
 * http://hl7.org/fhir/_SubstancePolymer
 */
export const _SubstancePolymer = 'http://hl7.org/fhir/_SubstancePolymer' satisfies OwlClass;

/**
 * ValueSetComposeIncludeConceptDesignationComponent
 *
 * ValueSetComposeComponent.ConceptSet.ConceptReference.ValueSetComposeIncludeConceptDesignationComponent: Additional representations for this concept when used in this value set - other languages, aliases, specialized purposes, used for particular purposes, etc.
 *
 * http://hl7.org/fhir/ValueSetComposeIncludeConceptDesignationComponent
 */
export const ValueSetComposeIncludeConceptDesignationComponent = 'http://hl7.org/fhir/ValueSetComposeIncludeConceptDesignationComponent' satisfies OwlClass;

/**
 * versionReference
 *
 * ExampleScenario.process.step.alternative.step.process.step.operation.request.versionReference: A reference to the key of a specific version of an instance in this instance.
 *
 * http://hl7.org/fhir/versionReference
 */
export const versionReference = 'http://hl7.org/fhir/versionReference' satisfies OwlObjectProperty;

/**
 * _maxSingleDose
 *
 * (Modified) AdministrableProductDefinition.routeOfAdministration.maxSingleDose
 *
 * http://hl7.org/fhir/_maxSingleDose
 */
export const _maxSingleDose = 'http://hl7.org/fhir/_maxSingleDose' satisfies OwlObjectProperty;

/**
 * meaning
 *
 * Permission.rule.data.resource.meaning: How the resource reference is interpreted when testing consent restrictions.
 *
 * http://hl7.org/fhir/meaning
 */
export const meaning = 'http://hl7.org/fhir/meaning' satisfies OwlObjectProperty;

/**
 * measurementPoint
 *
 * Ingredient.substance.strength.referenceStrength.measurementPoint: For when strength is measured at a particular point or distance.
 *
 * http://hl7.org/fhir/measurementPoint
 */
export const measurementPoint = 'http://hl7.org/fhir/measurementPoint' satisfies OwlObjectProperty;

/**
 * diagnosisRelatedGroup
 *
 * ExplanationOfBenefit.diagnosisRelatedGroup: A package billing code or bundle code used to group products and services to a particular health condition (such as heart attack) which is based on a predetermined grouping code system.
 *
 * http://hl7.org/fhir/diagnosisRelatedGroup
 */
export const diagnosisRelatedGroup = 'http://hl7.org/fhir/diagnosisRelatedGroup' satisfies OwlObjectProperty;

/**
 * _relative
 *
 * (Modified) MolecularSequence.relative
 *
 * http://hl7.org/fhir/_relative
 */
export const _relative = 'http://hl7.org/fhir/_relative' satisfies OwlObjectProperty;

/**
 * _publicationForm
 *
 * (Modified) Citation.citedArtifact.publicationForm
 *
 * http://hl7.org/fhir/_publicationForm
 */
export const _publicationForm = 'http://hl7.org/fhir/_publicationForm' satisfies OwlObjectProperty;

/**
 * _Patient
 *
 * (Modified) Patient
 *
 * http://hl7.org/fhir/_Patient
 */
export const _Patient = 'http://hl7.org/fhir/_Patient' satisfies OwlClass;

/**
 * GuidanceResponse
 *
 * A guidance response is the formal response to a guidance request, including any output parameters returned by the evaluation, as well as the description of any proposed actions to be taken.
 *
 * http://hl7.org/fhir/GuidanceResponse
 */
export const GuidanceResponse = 'http://hl7.org/fhir/GuidanceResponse' satisfies OwlClass;

/**
 * entity
 *
 * Contract.term.asset.valuedItem.entity
 *
 * http://hl7.org/fhir/entity
 */
export const entity = 'http://hl7.org/fhir/entity' satisfies OwlObjectProperty;

/**
 * sourceReference
 *
 * Consent.sourceReference: A reference to a consent that links back to such a source, a reference to a document repository (e.g. XDS) that stores the original consent document.
 *
 * http://hl7.org/fhir/sourceReference
 */
export const sourceReference = 'http://hl7.org/fhir/sourceReference' satisfies OwlObjectProperty;

/**
 * valueFilter
 *
 * DataRequirement.valueFilter: Value filters specify additional constraints on the data for elements other than code-valued or date-valued. Each value filter specifies an additional constraint on the data (i.e. valueFilters are AND'ed, not OR'ed).
 *
 * http://hl7.org/fhir/valueFilter
 */
export const valueFilter = 'http://hl7.org/fhir/valueFilter' satisfies OwlObjectProperty;

/**
 * _useBy
 *
 * (Modified) NutritionProduct.instance.useBy
 *
 * http://hl7.org/fhir/_useBy
 */
export const _useBy = 'http://hl7.org/fhir/_useBy' satisfies OwlObjectProperty;

/**
 * bodyLandmarkOrientation
 *
 * BodyStructure.excludedStructure.bodyLandmarkOrientation: Body locations in relation to a specific body landmark (tatoo, scar, other body structure).
 *
 * http://hl7.org/fhir/bodyLandmarkOrientation
 */
export const bodyLandmarkOrientation = 'http://hl7.org/fhir/bodyLandmarkOrientation' satisfies OwlObjectProperty;

/**
 * SubstanceDefinitionNameComponentName
 *
 * A synonym of this particular name, by which the substance is also known.
 *
 * http://hl7.org/fhir/SubstanceDefinitionNameComponentName
 */
export const SubstanceDefinitionNameComponentName = 'http://hl7.org/fhir/SubstanceDefinitionNameComponentName' satisfies OwlClass;

/**
 * _policyText
 *
 * (Modified) Consent.policyText
 *
 * http://hl7.org/fhir/_policyText
 */
export const _policyText = 'http://hl7.org/fhir/_policyText' satisfies OwlObjectProperty;

/**
 * _changePattern
 *
 * (Modified) ClinicalImpression.changePattern
 *
 * http://hl7.org/fhir/_changePattern
 */
export const _changePattern = 'http://hl7.org/fhir/_changePattern' satisfies OwlObjectProperty;

/**
 * subDetail
 *
 * ExplanationOfBenefit.item.detail.subDetail: Third-tier of goods and services.
 *
 * http://hl7.org/fhir/subDetail
 */
export const subDetail = 'http://hl7.org/fhir/subDetail' satisfies OwlObjectProperty;

/**
 * allDay
 *
 * Availability.availableTime.allDay: Always available? i.e. 24 hour service.
 *
 * http://hl7.org/fhir/allDay
 */
export const allDay = 'http://hl7.org/fhir/allDay' satisfies OwlObjectProperty;

/**
 * _modification
 *
 * (Modified) SubstancePolymer.modification
 *
 * http://hl7.org/fhir/_modification
 */
export const _modification = 'http://hl7.org/fhir/_modification' satisfies OwlObjectProperty;

/**
 * _nodeId
 *
 * (Modified) GraphDefinition.node.nodeId
 *
 * http://hl7.org/fhir/_nodeId
 */
export const _nodeId = 'http://hl7.org/fhir/_nodeId' satisfies OwlObjectProperty;

/**
 * AdverseEventContributingFactorComponent
 *
 * AdverseEventContributingFactorComponent: The contributing factors suspected to have increased the probability or severity of the adverse event.
 *
 * http://hl7.org/fhir/AdverseEventContributingFactorComponent
 */
export const AdverseEventContributingFactorComponent = 'http://hl7.org/fhir/AdverseEventContributingFactorComponent' satisfies OwlClass;

/**
 * TestPlanTestCaseComponent
 *
 * TestPlanTestCaseComponent: The individual test cases that are part of this plan, when they they are made explicit.
 *
 * http://hl7.org/fhir/TestPlanTestCaseComponent
 */
export const TestPlanTestCaseComponent = 'http://hl7.org/fhir/TestPlanTestCaseComponent' satisfies OwlClass;

/**
 * sunday
 *
 * Appointment.recurrenceTemplate.weeklyTemplate.sunday: Indicates that recurring appointments should occur on Sundays.
 *
 * http://hl7.org/fhir/sunday
 */
export const sunday = 'http://hl7.org/fhir/sunday' satisfies OwlObjectProperty;

/**
 * cancellationReason
 *
 * Appointment.cancellationReason: The coded reason for the appointment being cancelled. This is often used in reporting/billing/futher processing to determine if further actions are required, or specific fees apply.
 *
 * http://hl7.org/fhir/cancellationReason
 */
export const cancellationReason = 'http://hl7.org/fhir/cancellationReason' satisfies OwlObjectProperty;

/**
 * _title
 *
 * (Modified) ExampleScenario.process.step.process.step.alternative.step.operation.title
 *
 * http://hl7.org/fhir/_title
 */
export const _title = 'http://hl7.org/fhir/_title' satisfies OwlObjectProperty;

/**
 * _sourceId
 *
 * (Modified) OperationDefinition.parameter.referencedFrom.sourceId
 *
 * http://hl7.org/fhir/_sourceId
 */
export const _sourceId = 'http://hl7.org/fhir/_sourceId' satisfies OwlObjectProperty;

/**
 * _entityRelatedness
 *
 * (Modified) AdverseEvent.suspectEntity.causality.entityRelatedness
 *
 * http://hl7.org/fhir/_entityRelatedness
 */
export const _entityRelatedness = 'http://hl7.org/fhir/_entityRelatedness' satisfies OwlObjectProperty;

/**
 * line
 *
 * Address.line: This component contains the house number, apartment number, street name, street direction,  P.O. Box number, delivery hints, and similar address information.
 *
 * http://hl7.org/fhir/line
 */
export const line = 'http://hl7.org/fhir/line' satisfies OwlObjectProperty;

/**
 * _effectivePeriod
 *
 * (Modified) PlanDefinition.effectivePeriod
 *
 * http://hl7.org/fhir/_effectivePeriod
 */
export const _effectivePeriod = 'http://hl7.org/fhir/_effectivePeriod' satisfies OwlObjectProperty;

/**
 * preAuthRef
 *
 * ClaimResponse.preAuthRef: Reference from the Insurer which is used in later communications which refers to this adjudication.
 *
 * http://hl7.org/fhir/preAuthRef
 */
export const preAuthRef = 'http://hl7.org/fhir/preAuthRef' satisfies OwlObjectProperty;

/**
 * requestId
 *
 * TestScript.teardown.action.operation.requestId: The fixture id (maybe new) to map to the request.
 *
 * http://hl7.org/fhir/requestId
 */
export const requestId = 'http://hl7.org/fhir/requestId' satisfies OwlObjectProperty;

/**
 * _autodelete
 *
 * (Modified) TestScript.fixture.autodelete
 *
 * http://hl7.org/fhir/_autodelete
 */
export const _autodelete = 'http://hl7.org/fhir/_autodelete' satisfies OwlObjectProperty;

/**
 * _fundsReserve
 *
 * (Modified) ExplanationOfBenefit.fundsReserve
 *
 * http://hl7.org/fhir/_fundsReserve
 */
export const _fundsReserve = 'http://hl7.org/fhir/_fundsReserve' satisfies OwlObjectProperty;

/**
 * BundleEntryComponentLink
 *
 * A series of links that provide context to this entry.
 *
 * http://hl7.org/fhir/BundleEntryComponentLink
 */
export const BundleEntryComponentLink = 'http://hl7.org/fhir/BundleEntryComponentLink' satisfies OwlClass;

/**
 * DocumentReferenceContentComponent
 *
 * DocumentReferenceContentComponent: The document and format referenced.  If there are multiple content element repetitions, these must all represent the same document in different format, or attachment metadata.
 *
 * http://hl7.org/fhir/DocumentReferenceContentComponent
 */
export const DocumentReferenceContentComponent = 'http://hl7.org/fhir/DocumentReferenceContentComponent' satisfies OwlClass;

/**
 * _holder
 *
 * (Modified) RegulatedAuthorization.holder
 *
 * http://hl7.org/fhir/_holder
 */
export const _holder = 'http://hl7.org/fhir/_holder' satisfies OwlObjectProperty;

/**
 * _qualifiers
 *
 * (Modified) InsurancePlan.plan.specificCost.benefit.cost.qualifiers
 *
 * http://hl7.org/fhir/_qualifiers
 */
export const _qualifiers = 'http://hl7.org/fhir/_qualifiers' satisfies OwlObjectProperty;

/**
 * _Specimen
 *
 * (Modified) Specimen
 *
 * http://hl7.org/fhir/_Specimen
 */
export const _Specimen = 'http://hl7.org/fhir/_Specimen' satisfies OwlClass;

/**
 * CodeSystemFilterComponent
 *
 * CodeSystemFilterComponent: A filter that can be used in a value set compose statement when selecting concepts using a filter.
 *
 * http://hl7.org/fhir/CodeSystemFilterComponent
 */
export const CodeSystemFilterComponent = 'http://hl7.org/fhir/CodeSystemFilterComponent' satisfies OwlClass;

/**
 * _replacementSequence
 *
 * (Modified) MolecularSequence.relative.edit.replacementSequence
 *
 * http://hl7.org/fhir/_replacementSequence
 */
export const _replacementSequence = 'http://hl7.org/fhir/_replacementSequence' satisfies OwlObjectProperty;

/**
 * serviceCategory
 *
 * Slot.serviceCategory: A broad categorization of the service that is to be performed during this appointment.
 *
 * http://hl7.org/fhir/serviceCategory
 */
export const serviceCategory = 'http://hl7.org/fhir/serviceCategory' satisfies OwlObjectProperty;

/**
 * _next
 *
 * (Modified) ValueSet.expansion.next
 *
 * http://hl7.org/fhir/_next
 */
export const _next = 'http://hl7.org/fhir/_next' satisfies OwlObjectProperty;

/**
 * paymentTerms
 *
 * Invoice.paymentTerms: Payment details such as banking details, period of payment, deductibles, methods of payment.
 *
 * http://hl7.org/fhir/paymentTerms
 */
export const paymentTerms = 'http://hl7.org/fhir/paymentTerms' satisfies OwlObjectProperty;

/**
 * _started
 *
 * (Modified) ImagingStudy.series.started
 *
 * http://hl7.org/fhir/_started
 */
export const _started = 'http://hl7.org/fhir/_started' satisfies OwlObjectProperty;

/**
 * offer
 *
 * Contract.term.group.offer: The matter of concern in the context of this provision of the agrement.
 *
 * http://hl7.org/fhir/offer
 */
export const offer = 'http://hl7.org/fhir/offer' satisfies OwlObjectProperty;

/**
 * coordinateSystem
 *
 * MolecularSequence.relative.coordinateSystem: These are different ways of identifying nucleotides or amino acids within a sequence. Different databases and file types may use different systems. For detail definitions, see https://loinc.org/92822-6/ for more detail.
 *
 * http://hl7.org/fhir/coordinateSystem
 */
export const coordinateSystem = 'http://hl7.org/fhir/coordinateSystem' satisfies OwlObjectProperty;

/**
 * DeviceDefinition
 *
 * This is a specialized resource that defines the characteristics and capabilities of a device.
 *
 * http://hl7.org/fhir/DeviceDefinition
 */
export const DeviceDefinition = 'http://hl7.org/fhir/DeviceDefinition' satisfies OwlClass;

/**
 * _intent
 *
 * (Modified) RequestOrchestration.intent
 *
 * http://hl7.org/fhir/_intent
 */
export const _intent = 'http://hl7.org/fhir/_intent' satisfies OwlObjectProperty;

/**
 * _text
 *
 * (Modified) QuestionnaireResponse.item.item.text
 *
 * http://hl7.org/fhir/_text
 */
export const _text = 'http://hl7.org/fhir/_text' satisfies OwlObjectProperty;

/**
 * _level
 *
 * (Modified) Evidence.statistic.modelCharacteristic.attributeEstimate.level
 *
 * http://hl7.org/fhir/_level
 */
export const _level = 'http://hl7.org/fhir/_level' satisfies OwlObjectProperty;

/**
 * facility
 *
 * CoverageEligibilityRequest.item.facility: Facility where the services will be provided.
 *
 * http://hl7.org/fhir/facility
 */
export const facility = 'http://hl7.org/fhir/facility' satisfies OwlObjectProperty;

/**
 * qualifiedValue
 *
 * ObservationDefinition.component.qualifiedValue: A set of qualified values associated with a context and a set of conditions -  provides a range for quantitative and ordinal observations and a collection of value sets for qualitative observations.
 *
 * http://hl7.org/fhir/qualifiedValue
 */
export const qualifiedValue = 'http://hl7.org/fhir/qualifiedValue' satisfies OwlObjectProperty;

/**
 * ManifestResource
 *
 * ImplementationGuideManifestComponent.ManifestResource: A resource that is part of the implementation guide. Conformance resources (value set, structure definition, capability statements etc.) are obvious candidates for inclusion, but any kind of resource can be included as an example resource.
 *
 * http://hl7.org/fhir/ManifestResource
 */
export const ManifestResource = 'http://hl7.org/fhir/ManifestResource' satisfies OwlClass;

/**
 * prism
 *
 * VisionPrescription.lensSpecification.prism: Allows for adjustment on two axis.
 *
 * http://hl7.org/fhir/prism
 */
export const prism = 'http://hl7.org/fhir/prism' satisfies OwlObjectProperty;

/**
 * MedicationBatchComponent
 *
 * MedicationBatchComponent: Information that only applies to packages (not products).
 *
 * http://hl7.org/fhir/MedicationBatchComponent
 */
export const MedicationBatchComponent = 'http://hl7.org/fhir/MedicationBatchComponent' satisfies OwlClass;

/**
 * resultForDelete
 *
 * SubscriptionTopic.resourceTrigger.queryCriteria.resultForDelete: For 'delete' interactions, should the 'current' query criteria count as an automatic pass or an automatic fail. If not present, the testing behavior during `delete` interactions is unspecified (server discretion).
 *
 * http://hl7.org/fhir/resultForDelete
 */
export const resultForDelete = 'http://hl7.org/fhir/resultForDelete' satisfies OwlObjectProperty;

/**
 * _accept
 *
 * (Modified) TestScript.teardown.action.operation.accept
 *
 * http://hl7.org/fhir/_accept
 */
export const _accept = 'http://hl7.org/fhir/_accept' satisfies OwlObjectProperty;

/**
 * overbooked
 *
 * Slot.overbooked: This slot has already been overbooked, appointments are unlikely to be accepted for this time.
 *
 * http://hl7.org/fhir/overbooked
 */
export const overbooked = 'http://hl7.org/fhir/overbooked' satisfies OwlObjectProperty;

/**
 * _plan
 *
 * (Modified) InsurancePlan.plan
 *
 * http://hl7.org/fhir/_plan
 */
export const _plan = 'http://hl7.org/fhir/_plan' satisfies OwlObjectProperty;

/**
 * ReviewOutcome
 *
 * ClaimResponse.Item.ReviewOutcome: The high-level results of the adjudication if adjudication has been performed.
 *
 * http://hl7.org/fhir/ReviewOutcome
 */
export const ReviewOutcome = 'http://hl7.org/fhir/ReviewOutcome' satisfies OwlClass;

/**
 * CitationCitedArtifactContributorshipEntryComponent
 *
 * CitationCitedArtifactComponent.CitationCitedArtifactContributorshipComponent.CitationCitedArtifactContributorshipEntryComponent: An individual entity named as a contributor, for example in the author list or contributor list.
 *
 * http://hl7.org/fhir/CitationCitedArtifactContributorshipEntryComponent
 */
export const CitationCitedArtifactContributorshipEntryComponent = 'http://hl7.org/fhir/CitationCitedArtifactContributorshipEntryComponent' satisfies OwlClass;

/**
 * discriminator
 *
 * ElementDefinition.slicing.discriminator: Designates which child elements are used to discriminate between the slices when processing an instance. If one or more discriminators are provided, the value of the child elements in the instance data SHALL completely distinguish which slice the element in the resource matches based on the allowed values for those elements in each of the slices.
 *
 * http://hl7.org/fhir/discriminator
 */
export const discriminator = 'http://hl7.org/fhir/discriminator' satisfies OwlObjectProperty;

/**
 * ordered
 *
 * ElementDefinition.slicing.ordered: If the matching elements have to occur in the same order as defined in the profile.
 *
 * http://hl7.org/fhir/ordered
 */
export const ordered = 'http://hl7.org/fhir/ordered' satisfies OwlObjectProperty;

/**
 * LegalLanguage
 *
 * Contract.LegalLanguage: List of Legal expressions or representations of this Contract.
 *
 * http://hl7.org/fhir/LegalLanguage
 */
export const LegalLanguage = 'http://hl7.org/fhir/LegalLanguage' satisfies OwlClass;

/**
 * frequencyOfOccurrence
 *
 * ClinicalUseDefinition.undesirableEffect.frequencyOfOccurrence: How often the effect is seen.
 *
 * http://hl7.org/fhir/frequencyOfOccurrence
 */
export const frequencyOfOccurrence = 'http://hl7.org/fhir/frequencyOfOccurrence' satisfies OwlObjectProperty;

/**
 * _validationType
 *
 * (Modified) VerificationResult.validationType
 *
 * http://hl7.org/fhir/_validationType
 */
export const _validationType = 'http://hl7.org/fhir/_validationType' satisfies OwlObjectProperty;

/**
 * PermissionRuleDataComponent
 *
 * Permission.Rule.PermissionRuleDataComponent: A description or definition of which activities are allowed to be done on the data.
 *
 * http://hl7.org/fhir/PermissionRuleDataComponent
 */
export const PermissionRuleDataComponent = 'http://hl7.org/fhir/PermissionRuleDataComponent' satisfies OwlClass;

/**
 * _versionNeeded
 *
 * (Modified) CodeSystem.versionNeeded
 *
 * http://hl7.org/fhir/_versionNeeded
 */
export const _versionNeeded = 'http://hl7.org/fhir/_versionNeeded' satisfies OwlObjectProperty;

/**
 * PackagedProductDefinitionPackagingContainedItemComponent
 *
 * PackagedProductDefinitionPackagingComponent.PackagedProductDefinitionPackagingContainedItemComponent: The item(s) within the packaging.
 *
 * http://hl7.org/fhir/PackagedProductDefinitionPackagingContainedItemComponent
 */
export const PackagedProductDefinitionPackagingContainedItemComponent = 'http://hl7.org/fhir/PackagedProductDefinitionPackagingContainedItemComponent' satisfies OwlClass;

/**
 * predecessor
 *
 * TestPlan.testCase.dependency.predecessor: Link to predecessor test plans.
 *
 * http://hl7.org/fhir/predecessor
 */
export const predecessor = 'http://hl7.org/fhir/predecessor' satisfies OwlObjectProperty;

/**
 * ArtifactAssessment
 *
 * This Resource provides one or more comments, classifiers or ratings about a Resource and supports attribution and rights management metadata for the added content.
 *
 * http://hl7.org/fhir/ArtifactAssessment
 */
export const ArtifactAssessment = 'http://hl7.org/fhir/ArtifactAssessment' satisfies OwlClass;

/**
 * _dependsOn
 *
 * (Modified) ImplementationGuide.dependsOn
 *
 * http://hl7.org/fhir/_dependsOn
 */
export const _dependsOn = 'http://hl7.org/fhir/_dependsOn' satisfies OwlObjectProperty;

/**
 * evidence
 *
 * Condition.evidence: Supporting evidence / manifestations that are the basis of the Condition's verification status, such as evidence that confirmed or refuted the condition.
 *
 * http://hl7.org/fhir/evidence
 */
export const evidence = 'http://hl7.org/fhir/evidence' satisfies OwlObjectProperty;

/**
 * MeasureGroupPopulationComponent
 *
 * MeasureGroupComponent.MeasureGroupPopulationComponent: A population criteria for the measure.
 *
 * http://hl7.org/fhir/MeasureGroupPopulationComponent
 */
export const MeasureGroupPopulationComponent = 'http://hl7.org/fhir/MeasureGroupPopulationComponent' satisfies OwlClass;

/**
 * opticalActivity
 *
 * SubstanceDefinition.structure.opticalActivity: Optical activity type.
 *
 * http://hl7.org/fhir/opticalActivity
 */
export const opticalActivity = 'http://hl7.org/fhir/opticalActivity' satisfies OwlObjectProperty;

/**
 * nutritionProduct
 *
 * NutritionIntake.consumedItem.nutritionProduct: Identifies the food or fluid product that was consumed. This is potentially a link to a resource representing the details of the food product (TBD) or a simple attribute carrying a code that identifies the food from a known list of foods.
 *
 * http://hl7.org/fhir/nutritionProduct
 */
export const nutritionProduct = 'http://hl7.org/fhir/nutritionProduct' satisfies OwlObjectProperty;

/**
 * specialMeasures
 *
 * MedicinalProductDefinition.specialMeasures: Whether the Medicinal Product is subject to special measures for regulatory reasons, such as a requirement to conduct post-authorization studies.
 *
 * http://hl7.org/fhir/specialMeasures
 */
export const specialMeasures = 'http://hl7.org/fhir/specialMeasures' satisfies OwlObjectProperty;

/**
 * packageId
 *
 * ImplementationGuide.dependsOn.packageId: The NPM package name for the Implementation Guide that this IG depends on.
 *
 * http://hl7.org/fhir/packageId
 */
export const packageId = 'http://hl7.org/fhir/packageId' satisfies OwlObjectProperty;

/**
 * TerminologyCapabilitiesCodeSystemVersionFilterComponent
 *
 * TerminologyCapabilitiesCodeSystemComponent.TerminologyCapabilitiesCodeSystemVersionComponent.TerminologyCapabilitiesCodeSystemVersionFilterComponent: Filter Properties supported.
 *
 * http://hl7.org/fhir/TerminologyCapabilitiesCodeSystemVersionFilterComponent
 */
export const TerminologyCapabilitiesCodeSystemVersionFilterComponent = 'http://hl7.org/fhir/TerminologyCapabilitiesCodeSystemVersionFilterComponent' satisfies OwlClass;

/**
 * SubDetail
 *
 * ExplanationOfBenefit.Item.Detail.SubDetail: Third-tier of goods and services.
 *
 * http://hl7.org/fhir/SubDetail
 */
export const SubDetail = 'http://hl7.org/fhir/SubDetail' satisfies OwlClass;

/**
 * _received
 *
 * (Modified) Communication.received
 *
 * http://hl7.org/fhir/_received
 */
export const _received = 'http://hl7.org/fhir/_received' satisfies OwlObjectProperty;

/**
 * CapabilityStatementDocumentComponent
 *
 * CapabilityStatementDocumentComponent: A document definition.
 *
 * http://hl7.org/fhir/CapabilityStatementDocumentComponent
 */
export const CapabilityStatementDocumentComponent = 'http://hl7.org/fhir/CapabilityStatementDocumentComponent' satisfies OwlClass;

/**
 * observationResultRequirement
 *
 * ActivityDefinition.observationResultRequirement: Defines the observations that are expected to be produced by the action.
 *
 * http://hl7.org/fhir/observationResultRequirement
 */
export const observationResultRequirement = 'http://hl7.org/fhir/observationResultRequirement' satisfies OwlObjectProperty;

/**
 * FriendlyLanguage
 *
 * Contract.FriendlyLanguage: The "patient friendly language" versionof the Contract in whole or in parts. "Patient friendly language" means the representation of the Contract and Contract Provisions in a manner that is readily accessible and understandable by a layperson in accordance with best practices for communication styles that ensure that those agreeing to or signing the Contract understand the roles, actions, obligations, responsibilities, and implication of the agreement.
 *
 * http://hl7.org/fhir/FriendlyLanguage
 */
export const FriendlyLanguage = 'http://hl7.org/fhir/FriendlyLanguage' satisfies OwlClass;

/**
 * _observedGroup
 *
 * (Modified) ResearchStudy.comparisonGroup.observedGroup
 *
 * http://hl7.org/fhir/_observedGroup
 */
export const _observedGroup = 'http://hl7.org/fhir/_observedGroup' satisfies OwlObjectProperty;

/**
 * cancelledReason
 *
 * Invoice.cancelledReason: In case of Invoice cancellation a reason must be given (entered in error, superseded by corrected invoice etc.).
 *
 * http://hl7.org/fhir/cancelledReason
 */
export const cancelledReason = 'http://hl7.org/fhir/cancelledReason' satisfies OwlObjectProperty;

/**
 * _expirationType
 *
 * (Modified) Contract.expirationType
 *
 * http://hl7.org/fhir/_expirationType
 */
export const _expirationType = 'http://hl7.org/fhir/_expirationType' satisfies OwlObjectProperty;

/**
 * _actualNumber
 *
 * (Modified) ResearchStudy.recruitment.actualNumber
 *
 * http://hl7.org/fhir/_actualNumber
 */
export const _actualNumber = 'http://hl7.org/fhir/_actualNumber' satisfies OwlObjectProperty;

/**
 * derivation
 *
 * StructureDefinition.derivation: How the type relates to the baseDefinition.
 *
 * http://hl7.org/fhir/derivation
 */
export const derivation = 'http://hl7.org/fhir/derivation' satisfies OwlObjectProperty;

/**
 * AdverseEventSuspectEntityComponent
 *
 * AdverseEventSuspectEntityComponent: Describes the entity that is suspected to have caused the adverse event.
 *
 * http://hl7.org/fhir/AdverseEventSuspectEntityComponent
 */
export const AdverseEventSuspectEntityComponent = 'http://hl7.org/fhir/AdverseEventSuspectEntityComponent' satisfies OwlClass;

/**
 * ImmunizationRecommendation
 *
 * A patient's point-in-time set of recommendations (i.e. forecasting) according to a published schedule with optional supporting justification.
 *
 * http://hl7.org/fhir/ImmunizationRecommendation
 */
export const ImmunizationRecommendation = 'http://hl7.org/fhir/ImmunizationRecommendation' satisfies OwlClass;

/**
 * _BiologicallyDerivedProductDispense
 *
 * (Modified) BiologicallyDerivedProductDispense
 *
 * http://hl7.org/fhir/_BiologicallyDerivedProductDispense
 */
export const _BiologicallyDerivedProductDispense = 'http://hl7.org/fhir/_BiologicallyDerivedProductDispense' satisfies OwlClass;

/**
 * _definitionId
 *
 * (Modified) EvidenceVariable.characteristic.definitionByCombination.characteristic.definitionId
 *
 * http://hl7.org/fhir/_definitionId
 */
export const _definitionId = 'http://hl7.org/fhir/_definitionId' satisfies OwlObjectProperty;

/**
 * _authoredOn
 *
 * (Modified) ServiceRequest.authoredOn
 *
 * http://hl7.org/fhir/_authoredOn
 */
export const _authoredOn = 'http://hl7.org/fhir/_authoredOn' satisfies OwlObjectProperty;

/**
 * keyword
 *
 * StructureDefinition.keyword: (DEPRECATED) A set of key words or terms from external terminologies that may be used to assist with indexing and searching of templates nby describing the use of this structure definition, or the content it describes.
 *
 * http://hl7.org/fhir/keyword
 */
export const keyword = 'http://hl7.org/fhir/keyword' satisfies OwlObjectProperty;

/**
 * characteristic
 *
 * PackagedProductDefinition.characteristic: Allows the key features to be recorded, such as "hospital pack", "nurse prescribable", "calendar pack".
 *
 * http://hl7.org/fhir/characteristic
 */
export const characteristic = 'http://hl7.org/fhir/characteristic' satisfies OwlObjectProperty;

/**
 * _note
 *
 * (Modified) List.note
 *
 * http://hl7.org/fhir/_note
 */
export const _note = 'http://hl7.org/fhir/_note' satisfies OwlObjectProperty;

/**
 * ImagingStudySeriesInstanceComponent
 *
 * ImagingStudySeriesComponent.ImagingStudySeriesInstanceComponent: A single SOP instance within the series, e.g. an image, or presentation state.
 *
 * http://hl7.org/fhir/ImagingStudySeriesInstanceComponent
 */
export const ImagingStudySeriesInstanceComponent = 'http://hl7.org/fhir/ImagingStudySeriesInstanceComponent' satisfies OwlClass;

/**
 * _signature
 *
 * (Modified) Provenance.signature
 *
 * http://hl7.org/fhir/_signature
 */
export const _signature = 'http://hl7.org/fhir/_signature' satisfies OwlObjectProperty;

/**
 * slicing
 *
 * ElementDefinition.slicing: Indicates that the element is sliced into a set of alternative definitions (i.e. in a structure definition, there are multiple different constraints on a single element in the base resource). Slicing can be used in any resource that has cardinality ..* on the base resource, or any resource with a choice of types. The set of slices is any elements that come after this in the element sequence that have the same path, until a shorter path occurs (the shorter path terminates the set).
 *
 * http://hl7.org/fhir/slicing
 */
export const slicing = 'http://hl7.org/fhir/slicing' satisfies OwlObjectProperty;

/**
 * _population
 *
 * (Modified) MeasureReport.group.stratifier.stratum.population
 *
 * http://hl7.org/fhir/_population
 */
export const _population = 'http://hl7.org/fhir/_population' satisfies OwlObjectProperty;

/**
 * cap
 *
 * SpecimenDefinition.typeTested.container.cap: Color of container cap.
 *
 * http://hl7.org/fhir/cap
 */
export const cap = 'http://hl7.org/fhir/cap' satisfies OwlObjectProperty;

/**
 * given
 *
 * HumanName.given: Given name.
 *
 * http://hl7.org/fhir/given
 */
export const given = 'http://hl7.org/fhir/given' satisfies OwlObjectProperty;

/**
 * account
 *
 * Account.relatedAccount.account: Reference to an associated Account.
 *
 * http://hl7.org/fhir/account
 */
export const account = 'http://hl7.org/fhir/account' satisfies OwlObjectProperty;

/**
 * _organism
 *
 * (Modified) SubstanceSourceMaterial.organism
 *
 * http://hl7.org/fhir/_organism
 */
export const _organism = 'http://hl7.org/fhir/_organism' satisfies OwlObjectProperty;

/**
 * _need
 *
 * (Modified) VerificationResult.need
 *
 * http://hl7.org/fhir/_need
 */
export const _need = 'http://hl7.org/fhir/_need' satisfies OwlObjectProperty;

/**
 * environmentalSetting
 *
 * MedicationKnowledge.storageGuideline.environmentalSetting: Describes a setting/value on the environment for the adequate storage of the medication and other substances.  Environment settings may involve temperature, humidity, or exposure to light.
 *
 * http://hl7.org/fhir/environmentalSetting
 */
export const environmentalSetting = 'http://hl7.org/fhir/environmentalSetting' satisfies OwlObjectProperty;

/**
 * volume
 *
 * Citation.citedArtifact.publicationForm.volume: Volume number of journal or other collection in which the article is published.
 *
 * http://hl7.org/fhir/volume
 */
export const volume = 'http://hl7.org/fhir/volume' satisfies OwlObjectProperty;

/**
 * weeklyTemplate
 *
 * Appointment.recurrenceTemplate.weeklyTemplate: Information about weekly recurring appointments.
 *
 * http://hl7.org/fhir/weeklyTemplate
 */
export const weeklyTemplate = 'http://hl7.org/fhir/weeklyTemplate' satisfies OwlObjectProperty;

/**
 * lowerLimit
 *
 * SampledData.lowerLimit: The lower limit of detection of the measured points. This is needed if any of the data points have the value "L" (lower than detection limit).
 *
 * http://hl7.org/fhir/lowerLimit
 */
export const lowerLimit = 'http://hl7.org/fhir/lowerLimit' satisfies OwlObjectProperty;

/**
 * _justification
 *
 * (Modified) Permission.justification
 *
 * http://hl7.org/fhir/_justification
 */
export const _justification = 'http://hl7.org/fhir/_justification' satisfies OwlObjectProperty;

/**
 * _fixture
 *
 * (Modified) TestScript.fixture
 *
 * http://hl7.org/fhir/_fixture
 */
export const _fixture = 'http://hl7.org/fhir/_fixture' satisfies OwlObjectProperty;

/**
 * unitPriceComponent
 *
 * ChargeItem.unitPriceComponent: The unit price of the chargable item.
 *
 * http://hl7.org/fhir/unitPriceComponent
 */
export const unitPriceComponent = 'http://hl7.org/fhir/unitPriceComponent' satisfies OwlObjectProperty;

/**
 * availabilityStatus
 *
 * Device.availabilityStatus: The availability of the device.
 *
 * http://hl7.org/fhir/availabilityStatus
 */
export const availabilityStatus = 'http://hl7.org/fhir/availabilityStatus' satisfies OwlObjectProperty;

/**
 * _proxySignature
 *
 * (Modified) VerificationResult.attestation.proxySignature
 *
 * http://hl7.org/fhir/_proxySignature
 */
export const _proxySignature = 'http://hl7.org/fhir/_proxySignature' satisfies OwlObjectProperty;

/**
 * statusChanged
 *
 * MedicationRequest.statusChanged: The date (and perhaps time) when the status was changed.
 *
 * http://hl7.org/fhir/statusChanged
 */
export const statusChanged = 'http://hl7.org/fhir/statusChanged' satisfies OwlObjectProperty;

/**
 * _about
 *
 * (Modified) CommunicationRequest.about
 *
 * http://hl7.org/fhir/_about
 */
export const _about = 'http://hl7.org/fhir/_about' satisfies OwlObjectProperty;

/**
 * occurence
 *
 * MedicationAdministration.occurence
 *
 * http://hl7.org/fhir/occurence
 */
export const occurence = 'http://hl7.org/fhir/occurence' satisfies OwlObjectProperty;

/**
 * actualPeriod
 *
 * EncounterHistory.actualPeriod: The start and end time associated with this set of values associated with the encounter, may be different to the planned times for various reasons.
 *
 * http://hl7.org/fhir/actualPeriod
 */
export const actualPeriod = 'http://hl7.org/fhir/actualPeriod' satisfies OwlObjectProperty;

/**
 * _originalPrescription
 *
 * (Modified) ExplanationOfBenefit.originalPrescription
 *
 * http://hl7.org/fhir/_originalPrescription
 */
export const _originalPrescription = 'http://hl7.org/fhir/_originalPrescription' satisfies OwlObjectProperty;

/**
 * _dosage
 *
 * (Modified) MedicationStatement.dosage
 *
 * http://hl7.org/fhir/_dosage
 */
export const _dosage = 'http://hl7.org/fhir/_dosage' satisfies OwlObjectProperty;

/**
 * returnedAmount
 *
 * PaymentReconciliation.returnedAmount: The amount returned by the receiver which is excess to the amount payable, often referred to as 'change'.
 *
 * http://hl7.org/fhir/returnedAmount
 */
export const returnedAmount = 'http://hl7.org/fhir/returnedAmount' satisfies OwlObjectProperty;

/**
 * _cTerminalModification
 *
 * (Modified) SubstanceProtein.subunit.cTerminalModification
 *
 * http://hl7.org/fhir/_cTerminalModification
 */
export const _cTerminalModification = 'http://hl7.org/fhir/_cTerminalModification' satisfies OwlObjectProperty;

/**
 * name
 *
 * ObservationDefinition.name: A natural language name identifying the ObservationDefinition. This name should be usable as an identifier for the module by machine processing applications such as code generation.
 *
 * http://hl7.org/fhir/name
 */
export const name = 'http://hl7.org/fhir/name' satisfies OwlObjectProperty;

/**
 * masterFile
 *
 * MedicinalProductDefinition.masterFile: A master file for the medicinal product (e.g. Pharmacovigilance System Master File). Drug master files (DMFs) are documents submitted to regulatory agencies to provide confidential detailed information about facilities, processes or articles used in the manufacturing, processing, packaging and storing of drug products.
 *
 * http://hl7.org/fhir/masterFile
 */
export const masterFile = 'http://hl7.org/fhir/masterFile' satisfies OwlObjectProperty;

/**
 * baseFormulaType
 *
 * NutritionOrder.enteralFormula.baseFormulaType: The type of enteral or infant formula such as an adult standard formula with fiber or a soy-based infant formula.
 *
 * http://hl7.org/fhir/baseFormulaType
 */
export const baseFormulaType = 'http://hl7.org/fhir/baseFormulaType' satisfies OwlObjectProperty;

/**
 * threshold
 *
 * EvidenceVariable.characteristic.definitionByCombination.characteristic.definitionByCombination.threshold: Provides the value of "n" when "at-least" or "at-most" codes are used.
 *
 * http://hl7.org/fhir/threshold
 */
export const threshold = 'http://hl7.org/fhir/threshold' satisfies OwlObjectProperty;

/**
 * active
 *
 * Organization.active: Whether the organization's record is still in active use.
 *
 * http://hl7.org/fhir/active
 */
export const active = 'http://hl7.org/fhir/active' satisfies OwlObjectProperty;

/**
 * IngredientSubstanceComponent
 *
 * IngredientSubstanceComponent: The substance that comprises this ingredient.
 *
 * http://hl7.org/fhir/IngredientSubstanceComponent
 */
export const IngredientSubstanceComponent = 'http://hl7.org/fhir/IngredientSubstanceComponent' satisfies OwlClass;

/**
 * size
 *
 * Attachment.size: The number of bytes of data that make up this attachment (before base64 encoding, if that is done).
 *
 * http://hl7.org/fhir/size
 */
export const size = 'http://hl7.org/fhir/size' satisfies OwlObjectProperty;

/**
 * _validityPeriod
 *
 * (Modified) RegulatedAuthorization.validityPeriod
 *
 * http://hl7.org/fhir/_validityPeriod
 */
export const _validityPeriod = 'http://hl7.org/fhir/_validityPeriod' satisfies OwlObjectProperty;

/**
 * who
 *
 * Provenance.entity.agent.who: Indicates who or what performed in the event.
 *
 * http://hl7.org/fhir/who
 */
export const who = 'http://hl7.org/fhir/who' satisfies OwlObjectProperty;

/**
 * ExampleScenarioProcessStepAlternativeComponent
 *
 * ExampleScenarioProcessComponent.ExampleScenarioProcessStepComponent.ExampleScenarioProcessStepAlternativeComponentStepProcess.ExampleScenarioProcessStepComponent.ExampleScenarioProcessStepAlternativeComponent: Indicates an alternative step that can be taken instead of the sub-process, scenario or operation.  E.g. to represent non-happy-path/exceptional/atypical circumstances.
 *
 * http://hl7.org/fhir/ExampleScenarioProcessStepAlternativeComponent
 */
export const ExampleScenarioProcessStepAlternativeComponent = 'http://hl7.org/fhir/ExampleScenarioProcessStepAlternativeComponent' satisfies OwlClass;

/**
 * InsurancePlanPlanSpecificCostComponent
 *
 * InsurancePlanPlanComponent.InsurancePlanPlanSpecificCostComponent: Costs associated with the coverage provided by the product.
 *
 * http://hl7.org/fhir/InsurancePlanPlanSpecificCostComponent
 */
export const InsurancePlanPlanSpecificCostComponent = 'http://hl7.org/fhir/InsurancePlanPlanSpecificCostComponent' satisfies OwlClass;

/**
 * interaction
 *
 * CapabilityStatement.rest.interaction: A specification of restful operations supported by the system.
 *
 * http://hl7.org/fhir/interaction
 */
export const interaction = 'http://hl7.org/fhir/interaction' satisfies OwlObjectProperty;

/**
 * _beneficiary
 *
 * (Modified) Coverage.beneficiary
 *
 * http://hl7.org/fhir/_beneficiary
 */
export const _beneficiary = 'http://hl7.org/fhir/_beneficiary' satisfies OwlObjectProperty;

/**
 * requestURL
 *
 * TestScript.test.action.assert.requestURL: The value to use in a comparison against the request URL path string.
 *
 * http://hl7.org/fhir/requestURL
 */
export const requestURL = 'http://hl7.org/fhir/requestURL' satisfies OwlObjectProperty;

/**
 * transform
 *
 * StructureMap.group.rule.rule.target.transform: How the data is copied / created.
 *
 * http://hl7.org/fhir/transform
 */
export const transform = 'http://hl7.org/fhir/transform' satisfies OwlObjectProperty;

/**
 * sugar
 *
 * SubstanceNucleicAcid.subunit.sugar: 5.3.6.8.1 Sugar ID (Mandatory).
 *
 * http://hl7.org/fhir/sugar
 */
export const sugar = 'http://hl7.org/fhir/sugar' satisfies OwlObjectProperty;

/**
 * _subscriptionTopic
 *
 * (Modified) TriggerDefinition.subscriptionTopic
 *
 * http://hl7.org/fhir/_subscriptionTopic
 */
export const _subscriptionTopic = 'http://hl7.org/fhir/_subscriptionTopic' satisfies OwlObjectProperty;

/**
 * _usageStatus
 *
 * (Modified) DeviceUsage.usageStatus
 *
 * http://hl7.org/fhir/_usageStatus
 */
export const _usageStatus = 'http://hl7.org/fhir/_usageStatus' satisfies OwlObjectProperty;

/**
 * _recurring
 *
 * (Modified) AppointmentResponse.recurring
 *
 * http://hl7.org/fhir/_recurring
 */
export const _recurring = 'http://hl7.org/fhir/_recurring' satisfies OwlObjectProperty;

/**
 * chargeItem
 *
 * Invoice.lineItem.chargeItem
 *
 * http://hl7.org/fhir/chargeItem
 */
export const chargeItem = 'http://hl7.org/fhir/chargeItem' satisfies OwlObjectProperty;

/**
 * DiagnosticReportMediaComponent
 *
 * DiagnosticReportMediaComponent: A list of key images or data associated with this report. The images or data are generally created during the diagnostic process, and may be directly of the patient, or of treated specimens (i.e. slides of interest).
 *
 * http://hl7.org/fhir/DiagnosticReportMediaComponent
 */
export const DiagnosticReportMediaComponent = 'http://hl7.org/fhir/DiagnosticReportMediaComponent' satisfies OwlClass;

/**
 * validationProcess
 *
 * VerificationResult.validationProcess: The primary process by which the target is validated (edit check; value set; primary source; multiple sources; standalone; in context).
 *
 * http://hl7.org/fhir/validationProcess
 */
export const validationProcess = 'http://hl7.org/fhir/validationProcess' satisfies OwlObjectProperty;

/**
 * _DiagnosticReport
 *
 * (Modified) DiagnosticReport
 *
 * http://hl7.org/fhir/_DiagnosticReport
 */
export const _DiagnosticReport = 'http://hl7.org/fhir/_DiagnosticReport' satisfies OwlClass;

/**
 * moiety
 *
 * SubstanceDefinition.moiety: Moiety, for structural modifications.
 *
 * http://hl7.org/fhir/moiety
 */
export const moiety = 'http://hl7.org/fhir/moiety' satisfies OwlObjectProperty;

/**
 * _marketingStatus
 *
 * (Modified) PackagedProductDefinition.marketingStatus
 *
 * http://hl7.org/fhir/_marketingStatus
 */
export const _marketingStatus = 'http://hl7.org/fhir/_marketingStatus' satisfies OwlObjectProperty;

/**
 * _citedArtifact
 *
 * (Modified) Citation.citedArtifact
 *
 * http://hl7.org/fhir/_citedArtifact
 */
export const _citedArtifact = 'http://hl7.org/fhir/_citedArtifact' satisfies OwlObjectProperty;

/**
 * CitationCitedArtifactPartComponent
 *
 * CitationCitedArtifactComponent.CitationCitedArtifactPartComponent: The component of the article or artifact.
 *
 * http://hl7.org/fhir/CitationCitedArtifactPartComponent
 */
export const CitationCitedArtifactPartComponent = 'http://hl7.org/fhir/CitationCitedArtifactPartComponent' satisfies OwlClass;

/**
 * TerminologyCapabilitiesImplementationComponent
 *
 * TerminologyCapabilitiesImplementationComponent: Identifies a specific implementation instance that is described by the terminology capability statement - i.e. a particular installation, rather than the capabilities of a software program.
 *
 * http://hl7.org/fhir/TerminologyCapabilitiesImplementationComponent
 */
export const TerminologyCapabilitiesImplementationComponent = 'http://hl7.org/fhir/TerminologyCapabilitiesImplementationComponent' satisfies OwlClass;

/**
 * _immutable
 *
 * (Modified) ValueSet.immutable
 *
 * http://hl7.org/fhir/_immutable
 */
export const _immutable = 'http://hl7.org/fhir/_immutable' satisfies OwlObjectProperty;

/**
 * _requester
 *
 * (Modified) Contract.term.action.requester
 *
 * http://hl7.org/fhir/_requester
 */
export const _requester = 'http://hl7.org/fhir/_requester' satisfies OwlObjectProperty;

/**
 * regionsStudied
 *
 * GenomicStudy.analysis.regionsStudied: The genomic regions to be studied in the analysis (BED file).
 *
 * http://hl7.org/fhir/regionsStudied
 */
export const regionsStudied = 'http://hl7.org/fhir/regionsStudied' satisfies OwlObjectProperty;

/**
 * _code
 *
 * (Modified) ClinicalUseDefinition.warning.code
 *
 * http://hl7.org/fhir/_code
 */
export const _code = 'http://hl7.org/fhir/_code' satisfies OwlObjectProperty;

/**
 * sourceMaterial
 *
 * SubstanceDefinition.sourceMaterial: Material or taxonomic/anatomical source for the substance.
 *
 * http://hl7.org/fhir/sourceMaterial
 */
export const sourceMaterial = 'http://hl7.org/fhir/sourceMaterial' satisfies OwlObjectProperty;

/**
 * subrogation
 *
 * Coverage.subrogation: When 'subrogation=true' this insurance instance has been included not for adjudication but to provide insurers with the details to recover costs.
 *
 * http://hl7.org/fhir/subrogation
 */
export const subrogation = 'http://hl7.org/fhir/subrogation' satisfies OwlObjectProperty;

/**
 * _structureVersion
 *
 * (Modified) ExampleScenario.instance.structureVersion
 *
 * http://hl7.org/fhir/_structureVersion
 */
export const _structureVersion = 'http://hl7.org/fhir/_structureVersion' satisfies OwlObjectProperty;

/**
 * _priceComponent
 *
 * (Modified) Invoice.lineItem.priceComponent
 *
 * http://hl7.org/fhir/_priceComponent
 */
export const _priceComponent = 'http://hl7.org/fhir/_priceComponent' satisfies OwlObjectProperty;

/**
 * management
 *
 * ClinicalUseDefinition.interaction.management: Actions for managing the interaction.
 *
 * http://hl7.org/fhir/management
 */
export const management = 'http://hl7.org/fhir/management' satisfies OwlObjectProperty;

/**
 * _additionalInstruction
 *
 * (Modified) Dosage.additionalInstruction
 *
 * http://hl7.org/fhir/_additionalInstruction
 */
export const _additionalInstruction = 'http://hl7.org/fhir/_additionalInstruction' satisfies OwlObjectProperty;

/**
 * _managingEntity
 *
 * (Modified) Subscription.managingEntity
 *
 * http://hl7.org/fhir/_managingEntity
 */
export const _managingEntity = 'http://hl7.org/fhir/_managingEntity' satisfies OwlObjectProperty;

/**
 * patchFormat
 *
 * CapabilityStatement.patchFormat: A list of the patch formats supported by this implementation using their content types.
 *
 * http://hl7.org/fhir/patchFormat
 */
export const patchFormat = 'http://hl7.org/fhir/patchFormat' satisfies OwlObjectProperty;

/**
 * proxyIdentityCertificate
 *
 * VerificationResult.attestation.proxyIdentityCertificate: A digital identity certificate associated with the proxy entity submitting attested information on behalf of the attestation source.
 *
 * http://hl7.org/fhir/proxyIdentityCertificate
 */
export const proxyIdentityCertificate = 'http://hl7.org/fhir/proxyIdentityCertificate' satisfies OwlObjectProperty;

/**
 * DeviceVersionComponent
 *
 * DeviceVersionComponent: The actual design of the device or software version running on the device.
 *
 * http://hl7.org/fhir/DeviceVersionComponent
 */
export const DeviceVersionComponent = 'http://hl7.org/fhir/DeviceVersionComponent' satisfies OwlClass;

/**
 * TaskRestrictionComponent
 *
 * TaskRestrictionComponent: If the Task.focus is a request resource and the task is seeking fulfillment (i.e. is asking for the request to be actioned), this element identifies any limitations on what parts of the referenced request should be actioned.
 *
 * http://hl7.org/fhir/TaskRestrictionComponent
 */
export const TaskRestrictionComponent = 'http://hl7.org/fhir/TaskRestrictionComponent' satisfies OwlClass;

/**
 * _frameOfReferenceUid
 *
 * (Modified) ImagingSelection.frameOfReferenceUid
 *
 * http://hl7.org/fhir/_frameOfReferenceUid
 */
export const _frameOfReferenceUid = 'http://hl7.org/fhir/_frameOfReferenceUid' satisfies OwlObjectProperty;

/**
 * MedicinalProductDefinition
 *
 * Detailed definition of a medicinal product, typically for uses other than direct patient care (e.g. regulatory use, drug catalogs, to support prescribing, adverse events management etc.).
 *
 * http://hl7.org/fhir/MedicinalProductDefinition
 */
export const MedicinalProductDefinition = 'http://hl7.org/fhir/MedicinalProductDefinition' satisfies OwlClass;

/**
 * paternalOrganismId
 *
 * SubstanceSourceMaterial.organism.hybrid.paternalOrganismId: The identifier of the paternal species constituting the hybrid organism shall be specified based on a controlled vocabulary.
 *
 * http://hl7.org/fhir/paternalOrganismId
 */
export const paternalOrganismId = 'http://hl7.org/fhir/paternalOrganismId' satisfies OwlObjectProperty;

/**
 * averageMolecularFormula
 *
 * SubstancePolymer.repeat.averageMolecularFormula: A representation of an (average) molecular formula from a polymer.
 *
 * http://hl7.org/fhir/averageMolecularFormula
 */
export const averageMolecularFormula = 'http://hl7.org/fhir/averageMolecularFormula' satisfies OwlObjectProperty;

/**
 * EvidenceStatisticSampleSizeComponent
 *
 * EvidenceStatisticComponent.EvidenceStatisticSampleSizeComponent: Number of samples in the statistic.
 *
 * http://hl7.org/fhir/EvidenceStatisticSampleSizeComponent
 */
export const EvidenceStatisticSampleSizeComponent = 'http://hl7.org/fhir/EvidenceStatisticSampleSizeComponent' satisfies OwlClass;

/**
 * _occurred
 *
 * (Modified) Provenance.occurred
 *
 * http://hl7.org/fhir/_occurred
 */
export const _occurred = 'http://hl7.org/fhir/_occurred' satisfies OwlObjectProperty;

/**
 * definitionByCombination
 *
 * EvidenceVariable.characteristic.definitionByCombination: Defines the characteristic as a combination of two or more characteristics.
 *
 * http://hl7.org/fhir/definitionByCombination
 */
export const definitionByCombination = 'http://hl7.org/fhir/definitionByCombination' satisfies OwlObjectProperty;

/**
 * _compositional
 *
 * (Modified) TerminologyCapabilities.codeSystem.version.compositional
 *
 * http://hl7.org/fhir/_compositional
 */
export const _compositional = 'http://hl7.org/fhir/_compositional' satisfies OwlObjectProperty;

/**
 * financial
 *
 * ExplanationOfBenefit.benefitBalance.financial: Benefits Used to date.
 *
 * http://hl7.org/fhir/financial
 */
export const financial = 'http://hl7.org/fhir/financial' satisfies OwlObjectProperty;

/**
 * _bodysite
 *
 * (Modified) ChargeItem.bodysite
 *
 * http://hl7.org/fhir/_bodysite
 */
export const _bodysite = 'http://hl7.org/fhir/_bodysite' satisfies OwlObjectProperty;

/**
 * sourceScope
 *
 * ConceptMap.sourceScope
 *
 * http://hl7.org/fhir/sourceScope
 */
export const sourceScope = 'http://hl7.org/fhir/sourceScope' satisfies OwlObjectProperty;

/**
 * parameter
 *
 * ServiceRequest.orderDetail.parameter: The parameter details for the service being requested.
 *
 * http://hl7.org/fhir/parameter
 */
export const parameter = 'http://hl7.org/fhir/parameter' satisfies OwlObjectProperty;

/**
 * lineItem
 *
 * Invoice.lineItem: Each line item represents one charge for goods and services rendered. Details such.ofType(date), code and amount are found in the referenced ChargeItem resource.
 *
 * http://hl7.org/fhir/lineItem
 */
export const lineItem = 'http://hl7.org/fhir/lineItem' satisfies OwlObjectProperty;

/**
 * _businessArrangement
 *
 * (Modified) CoverageEligibilityRequest.insurance.businessArrangement
 *
 * http://hl7.org/fhir/_businessArrangement
 */
export const _businessArrangement = 'http://hl7.org/fhir/_businessArrangement' satisfies OwlObjectProperty;

/**
 * _ordinalPosition
 *
 * (Modified) MolecularSequence.relative.ordinalPosition
 *
 * http://hl7.org/fhir/_ordinalPosition
 */
export const _ordinalPosition = 'http://hl7.org/fhir/_ordinalPosition' satisfies OwlObjectProperty;

/**
 * dependency
 *
 * TestPlan.testCase.dependency: The required criteria to execute the test case - e.g. preconditions, previous tests.
 *
 * http://hl7.org/fhir/dependency
 */
export const dependency = 'http://hl7.org/fhir/dependency' satisfies OwlObjectProperty;

/**
 * DeviceUsage
 *
 * A record of a device being used by a patient where the record is the result of a report from the patient or a clinician.
 *
 * http://hl7.org/fhir/DeviceUsage
 */
export const DeviceUsage = 'http://hl7.org/fhir/DeviceUsage' satisfies OwlClass;

/**
 * sent
 *
 * Communication.sent: The time when this communication was sent.
 *
 * http://hl7.org/fhir/sent
 */
export const sent = 'http://hl7.org/fhir/sent' satisfies OwlObjectProperty;

/**
 * _associatedMedication
 *
 * (Modified) MedicationKnowledge.associatedMedication
 *
 * http://hl7.org/fhir/_associatedMedication
 */
export const _associatedMedication = 'http://hl7.org/fhir/_associatedMedication' satisfies OwlObjectProperty;

/**
 * ParametersParameterComponentParameter
 *
 * A named part of a multi-part parameter.
 *
 * http://hl7.org/fhir/ParametersParameterComponentParameter
 */
export const ParametersParameterComponentParameter = 'http://hl7.org/fhir/ParametersParameterComponentParameter' satisfies OwlClass;

/**
 * executionPeriod
 *
 * Task.executionPeriod: Identifies the time action was first taken against the task (start) and/or the time final action was taken against the task prior to marking it as completed (end).
 *
 * http://hl7.org/fhir/executionPeriod
 */
export const executionPeriod = 'http://hl7.org/fhir/executionPeriod' satisfies OwlObjectProperty;

/**
 * _custodian
 *
 * (Modified) DocumentReference.custodian
 *
 * http://hl7.org/fhir/_custodian
 */
export const _custodian = 'http://hl7.org/fhir/_custodian' satisfies OwlObjectProperty;

/**
 * specification
 *
 * DeviceDefinition.conformsTo.specification: Code that identifies the specific standard, specification, protocol, formal guidance, regulation, legislation, or certification scheme to which the device adheres.
 *
 * http://hl7.org/fhir/specification
 */
export const specification = 'http://hl7.org/fhir/specification' satisfies OwlObjectProperty;

/**
 * HumanName
 *
 * A name, normally of a human, that can be used for other living entities (e.g. animals but not organizations) that have been assigned names by a human and may need the use of name parts or the need for usage information.
 *
 * http://hl7.org/fhir/HumanName
 */
export const HumanName = 'http://hl7.org/fhir/HumanName' satisfies OwlClass;

/**
 * ObservationDefinitionComponentComponentQualifiedValue
 *
 * A set of qualified values associated with a context and a set of conditions -  provides a range for quantitative and ordinal observations and a collection of value sets for qualitative observations.
 *
 * http://hl7.org/fhir/ObservationDefinitionComponentComponentQualifiedValue
 */
export const ObservationDefinitionComponentComponentQualifiedValue = 'http://hl7.org/fhir/ObservationDefinitionComponentComponentQualifiedValue' satisfies OwlClass;

/**
 * _searchInclude
 *
 * (Modified) CapabilityStatement.rest.resource.searchInclude
 *
 * http://hl7.org/fhir/_searchInclude
 */
export const _searchInclude = 'http://hl7.org/fhir/_searchInclude' satisfies OwlObjectProperty;

/**
 * _technique
 *
 * (Modified) SubstanceDefinition.structure.technique
 *
 * http://hl7.org/fhir/_technique
 */
export const _technique = 'http://hl7.org/fhir/_technique' satisfies OwlObjectProperty;

/**
 * legalStatusOfSupply
 *
 * PackagedProductDefinition.legalStatusOfSupply: The legal status of supply of the packaged item as classified by the regulator.
 *
 * http://hl7.org/fhir/legalStatusOfSupply
 */
export const legalStatusOfSupply = 'http://hl7.org/fhir/legalStatusOfSupply' satisfies OwlObjectProperty;

/**
 * short
 *
 * ElementDefinition.short: A concise description of what this element means (e.g. for use in autogenerated summaries).
 *
 * http://hl7.org/fhir/short
 */
export const short = 'http://hl7.org/fhir/short' satisfies OwlObjectProperty;

/**
 * generation
 *
 * ImplementationGuide.definition.page.page.generation: A code that indicates how the page is generated.
 *
 * http://hl7.org/fhir/generation
 */
export const generation = 'http://hl7.org/fhir/generation' satisfies OwlObjectProperty;

/**
 * doseAndRate
 *
 * Dosage.doseAndRate: Depending on the resource,this is the amount of medication administered, to  be administered or typical amount to be administered.
 *
 * http://hl7.org/fhir/doseAndRate
 */
export const doseAndRate = 'http://hl7.org/fhir/doseAndRate' satisfies OwlObjectProperty;

/**
 * _condition
 *
 * (Modified) Account.diagnosis.condition
 *
 * http://hl7.org/fhir/_condition
 */
export const _condition = 'http://hl7.org/fhir/_condition' satisfies OwlObjectProperty;

/**
 * _followUp
 *
 * (Modified) Procedure.followUp
 *
 * http://hl7.org/fhir/_followUp
 */
export const _followUp = 'http://hl7.org/fhir/_followUp' satisfies OwlObjectProperty;

/**
 * manufacturer
 *
 * PackagedProductDefinition.manufacturer: Manufacturer of this package type. When there are multiple it means these are all possible manufacturers.
 *
 * http://hl7.org/fhir/manufacturer
 */
export const manufacturer = 'http://hl7.org/fhir/manufacturer' satisfies OwlObjectProperty;

/**
 * BiologicallyDerivedProductDispense
 *
 * A record of dispensation of a biologically derived product.
 *
 * http://hl7.org/fhir/BiologicallyDerivedProductDispense
 */
export const BiologicallyDerivedProductDispense = 'http://hl7.org/fhir/BiologicallyDerivedProductDispense' satisfies OwlClass;

/**
 * _seriesUid
 *
 * (Modified) ImagingSelection.seriesUid
 *
 * http://hl7.org/fhir/_seriesUid
 */
export const _seriesUid = 'http://hl7.org/fhir/_seriesUid' satisfies OwlObjectProperty;

/**
 * relatesTo
 *
 * Citation.citedArtifact.relatesTo: The artifact related to the cited artifact.
 *
 * http://hl7.org/fhir/relatesTo
 */
export const relatesTo = 'http://hl7.org/fhir/relatesTo' satisfies OwlObjectProperty;

/**
 * temperatureQualifier
 *
 * SpecimenDefinition.typeTested.handling.temperatureQualifier: It qualifies the interval of temperature, which characterizes an occurrence of handling. Conditions that are not related to temperature may be handled in the instruction element.
 *
 * http://hl7.org/fhir/temperatureQualifier
 */
export const temperatureQualifier = 'http://hl7.org/fhir/temperatureQualifier' satisfies OwlObjectProperty;

/**
 * _PackagedProductDefinition
 *
 * (Modified) PackagedProductDefinition
 *
 * http://hl7.org/fhir/_PackagedProductDefinition
 */
export const _PackagedProductDefinition = 'http://hl7.org/fhir/_PackagedProductDefinition' satisfies OwlClass;

/**
 * _correspondingContact
 *
 * (Modified) Citation.citedArtifact.contributorship.entry.correspondingContact
 *
 * http://hl7.org/fhir/_correspondingContact
 */
export const _correspondingContact = 'http://hl7.org/fhir/_correspondingContact' satisfies OwlObjectProperty;

/**
 * citeAs
 *
 * EvidenceReport.citeAs
 *
 * http://hl7.org/fhir/citeAs
 */
export const citeAs = 'http://hl7.org/fhir/citeAs' satisfies OwlObjectProperty;

/**
 * _DeviceAssociation
 *
 * (Modified) DeviceAssociation
 *
 * http://hl7.org/fhir/_DeviceAssociation
 */
export const _DeviceAssociation = 'http://hl7.org/fhir/_DeviceAssociation' satisfies OwlClass;

/**
 * requireBoth
 *
 * SubscriptionTopic.resourceTrigger.queryCriteria.requireBoth: If set to `true`, both the `current` and `previous` query criteria must evaluate `true` to trigger a notification for this topic.  If set to `false` or not present, a notification for this topic will be triggered if either the `current` or `previous` tests evaluate to `true`.
 *
 * http://hl7.org/fhir/requireBoth
 */
export const requireBoth = 'http://hl7.org/fhir/requireBoth' satisfies OwlObjectProperty;

/**
 * provisionData
 *
 * Consent.provision.provisionData: The resources controlled by this provision if specific resources are referenced.
 *
 * http://hl7.org/fhir/provisionData
 */
export const provisionData = 'http://hl7.org/fhir/provisionData' satisfies OwlClass;

/**
 * _characterization
 *
 * (Modified) SubstanceDefinition.characterization
 *
 * http://hl7.org/fhir/_characterization
 */
export const _characterization = 'http://hl7.org/fhir/_characterization' satisfies OwlObjectProperty;

/**
 * criticality
 *
 * AllergyIntolerance.criticality: Estimate of the potential clinical harm, or seriousness, of the reaction to the identified substance.
 *
 * http://hl7.org/fhir/criticality
 */
export const criticality = 'http://hl7.org/fhir/criticality' satisfies OwlObjectProperty;

/**
 * ConditionDefinitionPlanComponent
 *
 * ConditionDefinitionPlanComponent: Plan that is appropriate.
 *
 * http://hl7.org/fhir/ConditionDefinitionPlanComponent
 */
export const ConditionDefinitionPlanComponent = 'http://hl7.org/fhir/ConditionDefinitionPlanComponent' satisfies OwlClass;

/**
 * canPushUpdates
 *
 * VerificationResult.primarySource.canPushUpdates: Ability of the primary source to push updates/alerts (yes; no; undetermined).
 *
 * http://hl7.org/fhir/canPushUpdates
 */
export const canPushUpdates = 'http://hl7.org/fhir/canPushUpdates' satisfies OwlObjectProperty;

/**
 * _nTerminalModificationId
 *
 * (Modified) SubstanceProtein.subunit.nTerminalModificationId
 *
 * http://hl7.org/fhir/_nTerminalModificationId
 */
export const _nTerminalModificationId = 'http://hl7.org/fhir/_nTerminalModificationId' satisfies OwlObjectProperty;

/**
 * _regionsCalled
 *
 * (Modified) GenomicStudy.analysis.regionsCalled
 *
 * http://hl7.org/fhir/_regionsCalled
 */
export const _regionsCalled = 'http://hl7.org/fhir/_regionsCalled' satisfies OwlObjectProperty;

/**
 * TestPlanTestCaseTestRunComponent
 *
 * TestPlanTestCaseComponent.TestPlanTestCaseTestRunComponent: The actual test to be executed.
 *
 * http://hl7.org/fhir/TestPlanTestCaseTestRunComponent
 */
export const TestPlanTestCaseTestRunComponent = 'http://hl7.org/fhir/TestPlanTestCaseTestRunComponent' satisfies OwlClass;

/**
 * _productOrService
 *
 * (Modified) CoverageEligibilityRequest.item.productOrService
 *
 * http://hl7.org/fhir/_productOrService
 */
export const _productOrService = 'http://hl7.org/fhir/_productOrService' satisfies OwlObjectProperty;

/**
 * reviewOutcome
 *
 * ClaimResponse.addItem.reviewOutcome: The high-level results of the adjudication if adjudication has been performed.
 *
 * http://hl7.org/fhir/reviewOutcome
 */
export const reviewOutcome = 'http://hl7.org/fhir/reviewOutcome' satisfies OwlObjectProperty;

/**
 * maxDispense
 *
 * MedicationKnowledge.regulatory.maxDispense: The maximum number of units of the medication that can be dispensed in a period.
 *
 * http://hl7.org/fhir/maxDispense
 */
export const maxDispense = 'http://hl7.org/fhir/maxDispense' satisfies OwlObjectProperty;

/**
 * filterDefinition
 *
 * SubscriptionTopic.canFilterBy.filterDefinition: Either the canonical URL to a search parameter (like "http://hl7.org/fhir/SearchParameter/encounter-patient") or the officially-defined URI for a shared filter concept (like "http://example.org/concepts/shared-common-event").
 *
 * http://hl7.org/fhir/filterDefinition
 */
export const filterDefinition = 'http://hl7.org/fhir/filterDefinition' satisfies OwlObjectProperty;

/**
 * sourceAttachment
 *
 * Consent.sourceAttachment: The source on which this consent statement is based. The source might be a scanned original paper form.
 *
 * http://hl7.org/fhir/sourceAttachment
 */
export const sourceAttachment = 'http://hl7.org/fhir/sourceAttachment' satisfies OwlObjectProperty;

/**
 * provisionActor
 *
 * Consent.provision.provisionActor: Who or what is controlled by this provision. Use group to identify a set of actors by some property they share (e.g. 'admitting officers').
 *
 * http://hl7.org/fhir/provisionActor
 */
export const provisionActor = 'http://hl7.org/fhir/provisionActor' satisfies OwlClass;

/**
 * NamingSystem
 *
 * A curated namespace that issues unique symbols within that namespace for the identification of concepts, people, devices, etc.  Represents a "System" used within the Identifier and Coding data types.
 *
 * http://hl7.org/fhir/NamingSystem
 */
export const NamingSystem = 'http://hl7.org/fhir/NamingSystem' satisfies OwlClass;

/**
 * dateOfService
 *
 * Account.procedure.dateOfService: Date of the procedure when using a coded procedure. If using a reference to a procedure, then the date on the procedure should be used.
 *
 * http://hl7.org/fhir/dateOfService
 */
export const dateOfService = 'http://hl7.org/fhir/dateOfService' satisfies OwlObjectProperty;

/**
 * VisionPrescription
 *
 * An authorization for the provision of glasses and/or contact lenses to a patient.
 *
 * http://hl7.org/fhir/VisionPrescription
 */
export const VisionPrescription = 'http://hl7.org/fhir/VisionPrescription' satisfies OwlClass;

/**
 * _unitPrice
 *
 * (Modified) Claim.item.unitPrice
 *
 * http://hl7.org/fhir/_unitPrice
 */
export const _unitPrice = 'http://hl7.org/fhir/_unitPrice' satisfies OwlObjectProperty;

/**
 * resource
 *
 * SubscriptionTopic.notificationShape.resource: URL of the Resource that is the type used in this shape. This is the 'focus' resource of the topic (or one of them if there are more than one) and the root resource for this shape definition. It will be the same, a generality, or a specificity of SubscriptionTopic.resourceTrigger.resource or SubscriptionTopic.eventTrigger.resource when they are present.
 *
 * http://hl7.org/fhir/resource
 */
export const resource = 'http://hl7.org/fhir/resource' satisfies OwlObjectProperty;

/**
 * _response
 *
 * (Modified) TestScript.test.action.assert.response
 *
 * http://hl7.org/fhir/_response
 */
export const _response = 'http://hl7.org/fhir/_response' satisfies OwlObjectProperty;

/**
 * _agent
 *
 * (Modified) Provenance.entity.agent
 *
 * http://hl7.org/fhir/_agent
 */
export const _agent = 'http://hl7.org/fhir/_agent' satisfies OwlObjectProperty;

/**
 * contraindicatedVaccineCode
 *
 * ImmunizationRecommendation.recommendation.contraindicatedVaccineCode: Vaccine(s) which should not be used to fulfill the recommendation.
 *
 * http://hl7.org/fhir/contraindicatedVaccineCode
 */
export const contraindicatedVaccineCode = 'http://hl7.org/fhir/contraindicatedVaccineCode' satisfies OwlObjectProperty;

/**
 * collector
 *
 * Specimen.collection.collector: Person who collected the specimen.
 *
 * http://hl7.org/fhir/collector
 */
export const collector = 'http://hl7.org/fhir/collector' satisfies OwlObjectProperty;

/**
 * enterer
 *
 * CoverageEligibilityRequest.enterer: Person who created the request.
 *
 * http://hl7.org/fhir/enterer
 */
export const enterer = 'http://hl7.org/fhir/enterer' satisfies OwlObjectProperty;

/**
 * _supportedInteraction
 *
 * (Modified) SubscriptionTopic.resourceTrigger.supportedInteraction
 *
 * http://hl7.org/fhir/_supportedInteraction
 */
export const _supportedInteraction = 'http://hl7.org/fhir/_supportedInteraction' satisfies OwlObjectProperty;

/**
 * _differential
 *
 * (Modified) StructureDefinition.differential
 *
 * http://hl7.org/fhir/_differential
 */
export const _differential = 'http://hl7.org/fhir/_differential' satisfies OwlObjectProperty;

/**
 * _qualifiedValue
 *
 * (Modified) ObservationDefinition.component.qualifiedValue
 *
 * http://hl7.org/fhir/_qualifiedValue
 */
export const _qualifiedValue = 'http://hl7.org/fhir/_qualifiedValue' satisfies OwlObjectProperty;

/**
 * ManufacturedItemDefinitionComponentConstituentComponent
 *
 * ManufacturedItemDefinitionComponentComponent.ManufacturedItemDefinitionComponentConstituentComponent: A reference to a constituent of the manufactured item as a whole, linked here so that its component location within the item can be indicated. This not where the item's ingredient are primarily stated (for which see Ingredient.for or ManufacturedItemDefinition.ingredient).
 *
 * http://hl7.org/fhir/ManufacturedItemDefinitionComponentConstituentComponent
 */
export const ManufacturedItemDefinitionComponentConstituentComponent = 'http://hl7.org/fhir/ManufacturedItemDefinitionComponentConstituentComponent' satisfies OwlClass;

/**
 * _additionalMonitoringIndicator
 *
 * (Modified) MedicinalProductDefinition.additionalMonitoringIndicator
 *
 * http://hl7.org/fhir/_additionalMonitoringIndicator
 */
export const _additionalMonitoringIndicator = 'http://hl7.org/fhir/_additionalMonitoringIndicator' satisfies OwlObjectProperty;

/**
 * _position
 *
 * (Modified) Location.position
 *
 * http://hl7.org/fhir/_position
 */
export const _position = 'http://hl7.org/fhir/_position' satisfies OwlObjectProperty;

/**
 * limit
 *
 * Permission.rule.limit: What limits apply to the use of the data.
 *
 * http://hl7.org/fhir/limit
 */
export const limit = 'http://hl7.org/fhir/limit' satisfies OwlObjectProperty;

/**
 * _reason
 *
 * (Modified) Appointment.reason
 *
 * http://hl7.org/fhir/_reason
 */
export const _reason = 'http://hl7.org/fhir/_reason' satisfies OwlObjectProperty;

/**
 * _planningHorizon
 *
 * (Modified) Schedule.planningHorizon
 *
 * http://hl7.org/fhir/_planningHorizon
 */
export const _planningHorizon = 'http://hl7.org/fhir/_planningHorizon' satisfies OwlObjectProperty;

/**
 * _safety
 *
 * (Modified) DeviceDefinition.safety
 *
 * http://hl7.org/fhir/_safety
 */
export const _safety = 'http://hl7.org/fhir/_safety' satisfies OwlObjectProperty;

/**
 * Identifier
 *
 * An identifier - identifies some entity uniquely and unambiguously. Typically this is used for business identifiers.
 *
 * http://hl7.org/fhir/Identifier
 */
export const Identifier = 'http://hl7.org/fhir/Identifier' satisfies OwlClass;

/**
 * _mitigation
 *
 * (Modified) RiskAssessment.mitigation
 *
 * http://hl7.org/fhir/_mitigation
 */
export const _mitigation = 'http://hl7.org/fhir/_mitigation' satisfies OwlObjectProperty;

/**
 * _specialCourtesy
 *
 * (Modified) Encounter.specialCourtesy
 *
 * http://hl7.org/fhir/_specialCourtesy
 */
export const _specialCourtesy = 'http://hl7.org/fhir/_specialCourtesy' satisfies OwlObjectProperty;

/**
 * ExampleScenarioInstanceContainedInstanceComponent
 *
 * ExampleScenarioInstanceComponent.ExampleScenarioInstanceContainedInstanceComponent: References to other instances that can be found within this instance (e.g. the observations contained in a bundle).
 *
 * http://hl7.org/fhir/ExampleScenarioInstanceContainedInstanceComponent
 */
export const ExampleScenarioInstanceContainedInstanceComponent = 'http://hl7.org/fhir/ExampleScenarioInstanceContainedInstanceComponent' satisfies OwlClass;

/**
 * edit
 *
 * MolecularSequence.relative.edit: Changes in sequence from the starting sequence.
 *
 * http://hl7.org/fhir/edit
 */
export const edit = 'http://hl7.org/fhir/edit' satisfies OwlObjectProperty;

/**
 * qualitativeRisk
 *
 * RiskAssessment.prediction.qualitativeRisk: Indicates how likely the outcome is (in the specified timeframe), expressed as a qualitative value (e.g. low, medium, or high).
 *
 * http://hl7.org/fhir/qualitativeRisk
 */
export const qualitativeRisk = 'http://hl7.org/fhir/qualitativeRisk' satisfies OwlObjectProperty;

/**
 * immunizationEvent
 *
 * ImmunizationEvaluation.immunizationEvent: The vaccine administration event being evaluated.
 *
 * http://hl7.org/fhir/immunizationEvent
 */
export const immunizationEvent = 'http://hl7.org/fhir/immunizationEvent' satisfies OwlObjectProperty;

/**
 * reference
 *
 * Contract.term.offer.party.reference: Participant in the offer.
 *
 * http://hl7.org/fhir/reference
 */
export const reference = 'http://hl7.org/fhir/reference' satisfies OwlObjectProperty;

/**
 * reporter
 *
 * MeasureReport.reporter: The individual or organization that is reporting the data.
 *
 * http://hl7.org/fhir/reporter
 */
export const reporter = 'http://hl7.org/fhir/reporter' satisfies OwlObjectProperty;

/**
 * BackboneElement
 *
 * Base definition for all elements that are defined inside a resource - but not those in a data type.
 *
 * http://hl7.org/fhir/BackboneElement
 */
export const BackboneElement = 'http://hl7.org/fhir/BackboneElement' satisfies OwlClass;

/**
 * _hasMember
 *
 * (Modified) ObservationDefinition.hasMember
 *
 * http://hl7.org/fhir/_hasMember
 */
export const _hasMember = 'http://hl7.org/fhir/_hasMember' satisfies OwlObjectProperty;

/**
 * Provenance
 *
 * Provenance of a resource is a record that describes entities and processes involved in producing and delivering or otherwise influencing that resource. Provenance provides a critical foundation for assessing authenticity, enabling trust, and allowing reproducibility. Provenance assertions are a form of contextual metadata and can themselves become important records with their own provenance. Provenance statement indicates clinical significance in terms of confidence in authenticity, reliability, and trustworthiness, integrity, and stage in lifecycle (e.g. Document Completion - has the artifact been legally authenticated), all of which may impact security, privacy, and trust policies.
 *
 * http://hl7.org/fhir/Provenance
 */
export const Provenance = 'http://hl7.org/fhir/Provenance' satisfies OwlClass;

/**
 * reasonLinkId
 *
 * Contract.term.group.action.reasonLinkId: Id [identifier??] of the clause or question text related to the reason type or reference of this  action in the referenced form or QuestionnaireResponse.
 *
 * http://hl7.org/fhir/reasonLinkId
 */
export const reasonLinkId = 'http://hl7.org/fhir/reasonLinkId' satisfies OwlObjectProperty;

/**
 * owner
 *
 * DeviceDefinition.owner: An organization that is responsible for the provision and ongoing maintenance of the device.
 *
 * http://hl7.org/fhir/owner
 */
export const owner = 'http://hl7.org/fhir/owner' satisfies OwlObjectProperty;

/**
 * _assignedComparisonGroup
 *
 * (Modified) ResearchSubject.assignedComparisonGroup
 *
 * http://hl7.org/fhir/_assignedComparisonGroup
 */
export const _assignedComparisonGroup = 'http://hl7.org/fhir/_assignedComparisonGroup' satisfies OwlObjectProperty;

/**
 * _Condition
 *
 * (Modified) Condition
 *
 * http://hl7.org/fhir/_Condition
 */
export const _Condition = 'http://hl7.org/fhir/_Condition' satisfies OwlClass;

/**
 * ConsentPolicyBasisComponent
 *
 * ConsentPolicyBasisComponent: A Reference or URL used to uniquely identify the policy the organization will enforce for this Consent. This Reference or URL should be specific to the version of the policy and should be dereferencable to a computable policy of some form.
 *
 * http://hl7.org/fhir/ConsentPolicyBasisComponent
 */
export const ConsentPolicyBasisComponent = 'http://hl7.org/fhir/ConsentPolicyBasisComponent' satisfies OwlClass;

/**
 * communicationMethod
 *
 * VerificationResult.attestation.communicationMethod: The method by which attested information was submitted/retrieved (manual; API; Push).
 *
 * http://hl7.org/fhir/communicationMethod
 */
export const communicationMethod = 'http://hl7.org/fhir/communicationMethod' satisfies OwlObjectProperty;

/**
 * _param
 *
 * (Modified) CompartmentDefinition.resource.param
 *
 * http://hl7.org/fhir/_param
 */
export const _param = 'http://hl7.org/fhir/_param' satisfies OwlObjectProperty;

/**
 * _power
 *
 * (Modified) VisionPrescription.lensSpecification.power
 *
 * http://hl7.org/fhir/_power
 */
export const _power = 'http://hl7.org/fhir/_power' satisfies OwlObjectProperty;

/**
 * _issue
 *
 * (Modified) OperationOutcome.issue
 *
 * http://hl7.org/fhir/_issue
 */
export const _issue = 'http://hl7.org/fhir/_issue' satisfies OwlObjectProperty;

/**
 * concept
 *
 * CodeSystem.concept.concept.concept: Defines children of a concept to produce a hierarchy of concepts. The nature of the relationships is variable (is-a/contains/categorizes) - see hierarchyMeaning.
 *
 * http://hl7.org/fhir/concept
 */
export const concept = 'http://hl7.org/fhir/concept' satisfies OwlObjectProperty;

/**
 * decisionMode
 *
 * Contract.term.group.offer.decisionMode: How the decision about a Contract was conveyed.
 *
 * http://hl7.org/fhir/decisionMode
 */
export const decisionMode = 'http://hl7.org/fhir/decisionMode' satisfies OwlObjectProperty;

/**
 * instantiatesUri
 *
 * CarePlan.instantiatesUri: The URL pointing to an externally maintained protocol, guideline, questionnaire or other definition that is adhered to in whole or in part by this CarePlan.
 *
 * http://hl7.org/fhir/instantiatesUri
 */
export const instantiatesUri = 'http://hl7.org/fhir/instantiatesUri' satisfies OwlObjectProperty;

/**
 * _ifMatch
 *
 * (Modified) Bundle.entry.request.ifMatch
 *
 * http://hl7.org/fhir/_ifMatch
 */
export const _ifMatch = 'http://hl7.org/fhir/_ifMatch' satisfies OwlObjectProperty;

/**
 * sequenceType
 *
 * SubstanceProtein.sequenceType: The SubstanceProtein descriptive elements will only be used when a complete or partial amino acid sequence is available or derivable from a nucleic acid sequence.
 *
 * http://hl7.org/fhir/sequenceType
 */
export const sequenceType = 'http://hl7.org/fhir/sequenceType' satisfies OwlObjectProperty;

/**
 * _fastingStatus
 *
 * (Modified) Specimen.collection.fastingStatus
 *
 * http://hl7.org/fhir/_fastingStatus
 */
export const _fastingStatus = 'http://hl7.org/fhir/_fastingStatus' satisfies OwlObjectProperty;

/**
 * preferredReportName
 *
 * ObservationDefinition.preferredReportName: The preferred name to be used when reporting the results of observations conforming to this ObservationDefinition.
 *
 * http://hl7.org/fhir/preferredReportName
 */
export const preferredReportName = 'http://hl7.org/fhir/preferredReportName' satisfies OwlObjectProperty;

/**
 * _numberOfSeries
 *
 * (Modified) ImagingStudy.numberOfSeries
 *
 * http://hl7.org/fhir/_numberOfSeries
 */
export const _numberOfSeries = 'http://hl7.org/fhir/_numberOfSeries' satisfies OwlObjectProperty;

/**
 * rankingOrder
 *
 * Citation.citedArtifact.contributorship.entry.rankingOrder: Provides a numerical ranking to represent the degree of contributorship relative to other contributors, such as 1 for first author and 2 for second author.
 *
 * http://hl7.org/fhir/rankingOrder
 */
export const rankingOrder = 'http://hl7.org/fhir/rankingOrder' satisfies OwlObjectProperty;

/**
 * _currency
 *
 * (Modified) Account.currency
 *
 * http://hl7.org/fhir/_currency
 */
export const _currency = 'http://hl7.org/fhir/_currency' satisfies OwlObjectProperty;

/**
 * testTools
 *
 * TestPlan.testTools: A description of test tools to be used in the test plan.
 *
 * http://hl7.org/fhir/testTools
 */
export const testTools = 'http://hl7.org/fhir/testTools' satisfies OwlObjectProperty;

/**
 * _warning
 *
 * (Modified) DeviceDefinition.guideline.warning
 *
 * http://hl7.org/fhir/_warning
 */
export const _warning = 'http://hl7.org/fhir/_warning' satisfies OwlObjectProperty;

/**
 * CoverageEligibilityResponseEventComponent
 *
 * CoverageEligibilityResponseEventComponent: Information code for an event with a corresponding date or period.
 *
 * http://hl7.org/fhir/CoverageEligibilityResponseEventComponent
 */
export const CoverageEligibilityResponseEventComponent = 'http://hl7.org/fhir/CoverageEligibilityResponseEventComponent' satisfies OwlClass;

/**
 * _characteristic
 *
 * (Modified) Group.characteristic
 *
 * http://hl7.org/fhir/_characteristic
 */
export const _characteristic = 'http://hl7.org/fhir/_characteristic' satisfies OwlObjectProperty;

/**
 * dataRequirement
 *
 * Library.dataRequirement: Describes a set of data that must be provided in order to be able to successfully perform the computations defined by the library.
 *
 * http://hl7.org/fhir/dataRequirement
 */
export const dataRequirement = 'http://hl7.org/fhir/dataRequirement' satisfies OwlObjectProperty;

/**
 * _domain
 *
 * (Modified) SubstanceDefinition.name.translation.domain
 *
 * http://hl7.org/fhir/_domain
 */
export const _domain = 'http://hl7.org/fhir/_domain' satisfies OwlObjectProperty;

/**
 * InventoryReport
 *
 * A report of inventory or stock items.
 *
 * http://hl7.org/fhir/InventoryReport
 */
export const InventoryReport = 'http://hl7.org/fhir/InventoryReport' satisfies OwlClass;

/**
 * _parameterName
 *
 * (Modified) OperationDefinition.overload.parameterName
 *
 * http://hl7.org/fhir/_parameterName
 */
export const _parameterName = 'http://hl7.org/fhir/_parameterName' satisfies OwlObjectProperty;

/**
 * progressStatus
 *
 * ResearchStudy.progressStatus: Status of study with time for that status.
 *
 * http://hl7.org/fhir/progressStatus
 */
export const progressStatus = 'http://hl7.org/fhir/progressStatus' satisfies OwlObjectProperty;

/**
 * _narrative
 *
 * (Modified) TestPlan.testCase.testRun.narrative
 *
 * http://hl7.org/fhir/_narrative
 */
export const _narrative = 'http://hl7.org/fhir/_narrative' satisfies OwlObjectProperty;

/**
 * Endpoint
 *
 * The technical details of an endpoint that can be used for electronic services, such as for web services providing XDS.b, a REST endpoint for another FHIR server, or a s/Mime email address. This may include any security context information.
 *
 * http://hl7.org/fhir/Endpoint
 */
export const Endpoint = 'http://hl7.org/fhir/Endpoint' satisfies OwlClass;

/**
 * subjectState
 *
 * ResearchSubject.progress.subjectState: The current state of the subject.
 *
 * http://hl7.org/fhir/subjectState
 */
export const subjectState = 'http://hl7.org/fhir/subjectState' satisfies OwlObjectProperty;

/**
 * entry
 *
 * Composition.section.entry: A reference to the actual resource from which the narrative in the section is derived.
 *
 * http://hl7.org/fhir/entry
 */
export const entry = 'http://hl7.org/fhir/entry' satisfies OwlObjectProperty;

/**
 * _weeklyTemplate
 *
 * (Modified) Appointment.recurrenceTemplate.weeklyTemplate
 *
 * http://hl7.org/fhir/_weeklyTemplate
 */
export const _weeklyTemplate = 'http://hl7.org/fhir/_weeklyTemplate' satisfies OwlObjectProperty;

/**
 * what
 *
 * Provenance.entity.what: Identity of the  Entity used. May be a logical or physical uri and maybe absolute or relative.
 *
 * http://hl7.org/fhir/what
 */
export const what = 'http://hl7.org/fhir/what' satisfies OwlObjectProperty;

/**
 * whenPrepared
 *
 * MedicationDispense.whenPrepared: The time when the dispensed product was packaged and reviewed.
 *
 * http://hl7.org/fhir/whenPrepared
 */
export const whenPrepared = 'http://hl7.org/fhir/whenPrepared' satisfies OwlObjectProperty;

/**
 * Action
 *
 * Contract.TermTerm.Action: An actor taking a role in an activity for which it can be assigned some degree of responsibility for the activity taking place.
 *
 * http://hl7.org/fhir/Action
 */
export const Action = 'http://hl7.org/fhir/Action' satisfies OwlClass;

/**
 * _observationRequirement
 *
 * (Modified) ActivityDefinition.observationRequirement
 *
 * http://hl7.org/fhir/_observationRequirement
 */
export const _observationRequirement = 'http://hl7.org/fhir/_observationRequirement' satisfies OwlObjectProperty;

/**
 * focal
 *
 * ExplanationOfBenefit.insurance.focal: A flag to indicate that this Coverage is to be used for adjudication of this claim when set to true.
 *
 * http://hl7.org/fhir/focal
 */
export const focal = 'http://hl7.org/fhir/focal' satisfies OwlObjectProperty;

/**
 * verification
 *
 * Consent.verification: Whether a treatment instruction (e.g. artificial respiration: yes or no) was verified with the patient, his/her family or another authorized person.
 *
 * http://hl7.org/fhir/verification
 */
export const verification = 'http://hl7.org/fhir/verification' satisfies OwlObjectProperty;

/**
 * _availability
 *
 * (Modified) PractitionerRole.availability
 *
 * http://hl7.org/fhir/_availability
 */
export const _availability = 'http://hl7.org/fhir/_availability' satisfies OwlObjectProperty;

/**
 * resultingEffect
 *
 * AdverseEvent.resultingEffect: Information about the condition that occurred as a result of the adverse event, such as hives due to the exposure to a substance (for example, a drug or a chemical) or a broken leg as a result of the fall.
 *
 * http://hl7.org/fhir/resultingEffect
 */
export const resultingEffect = 'http://hl7.org/fhir/resultingEffect' satisfies OwlObjectProperty;

/**
 * timeout
 *
 * Subscription.timeout: If present, the maximum amount of time a server will allow before failing a notification attempt.
 *
 * http://hl7.org/fhir/timeout
 */
export const timeout = 'http://hl7.org/fhir/timeout' satisfies OwlObjectProperty;

/**
 * CapabilityStatementMessagingSupportedMessageComponent
 *
 * CapabilityStatementMessagingComponent.CapabilityStatementMessagingSupportedMessageComponent: References to message definitions for messages this system can send or receive.
 *
 * http://hl7.org/fhir/CapabilityStatementMessagingSupportedMessageComponent
 */
export const CapabilityStatementMessagingSupportedMessageComponent = 'http://hl7.org/fhir/CapabilityStatementMessagingSupportedMessageComponent' satisfies OwlClass;

/**
 * _revenue
 *
 * (Modified) ExplanationOfBenefit.item.detail.subDetail.revenue
 *
 * http://hl7.org/fhir/_revenue
 */
export const _revenue = 'http://hl7.org/fhir/_revenue' satisfies OwlObjectProperty;

/**
 * _returnedAmount
 *
 * (Modified) PaymentReconciliation.returnedAmount
 *
 * http://hl7.org/fhir/_returnedAmount
 */
export const _returnedAmount = 'http://hl7.org/fhir/_returnedAmount' satisfies OwlObjectProperty;

/**
 * MedicationKnowledgeDefinitionalIngredientComponent
 *
 * MedicationKnowledgeDefinitionalComponent.MedicationKnowledgeDefinitionalIngredientComponent: Identifies a particular constituent of interest in the product.
 *
 * http://hl7.org/fhir/MedicationKnowledgeDefinitionalIngredientComponent
 */
export const MedicationKnowledgeDefinitionalIngredientComponent = 'http://hl7.org/fhir/MedicationKnowledgeDefinitionalIngredientComponent' satisfies OwlClass;

/**
 * candidate
 *
 * EnrollmentRequest.candidate: Patient Resource.
 *
 * http://hl7.org/fhir/candidate
 */
export const candidate = 'http://hl7.org/fhir/candidate' satisfies OwlObjectProperty;

/**
 * Subscription
 *
 * The subscription resource describes a particular client's request to be notified about a SubscriptionTopic.
 *
 * http://hl7.org/fhir/Subscription
 */
export const Subscription = 'http://hl7.org/fhir/Subscription' satisfies OwlClass;

/**
 * relatedAction
 *
 * PlanDefinition.action.action.relatedAction: A relationship to another action such as "before" or "30-60 minutes after start of".
 *
 * http://hl7.org/fhir/relatedAction
 */
export const relatedAction = 'http://hl7.org/fhir/relatedAction' satisfies OwlObjectProperty;

/**
 * textPresentation
 *
 * Ingredient.substance.strength.textPresentation: A textual represention of either the whole of the presentation strength or a part of it - with the rest being in Strength.presentation as a ratio.
 *
 * http://hl7.org/fhir/textPresentation
 */
export const textPresentation = 'http://hl7.org/fhir/textPresentation' satisfies OwlObjectProperty;

/**
 * _supplements
 *
 * (Modified) CodeSystem.supplements
 *
 * http://hl7.org/fhir/_supplements
 */
export const _supplements = 'http://hl7.org/fhir/_supplements' satisfies OwlObjectProperty;

/**
 * result
 *
 * DiagnosticReport.result: [Observations](observation.html)  that are part of this diagnostic report.
 *
 * http://hl7.org/fhir/result
 */
export const result = 'http://hl7.org/fhir/result' satisfies OwlObjectProperty;

/**
 * policyText
 *
 * Consent.policyText: A Reference to the human readable policy explaining the basis for the Consent.
 *
 * http://hl7.org/fhir/policyText
 */
export const policyText = 'http://hl7.org/fhir/policyText' satisfies OwlObjectProperty;

/**
 * _regionType
 *
 * (Modified) ImagingSelection.instance.imageRegion3D.regionType
 *
 * http://hl7.org/fhir/_regionType
 */
export const _regionType = 'http://hl7.org/fhir/_regionType' satisfies OwlObjectProperty;

/**
 * StratifierGroup
 *
 * MeasureReportGroupComponent.MeasureReportGroupStratifierComponent.StratifierGroup: This element contains the results for a single stratum within the stratifier. For example, when stratifying on administrative gender, there will be four strata, one for each possible gender value.
 *
 * http://hl7.org/fhir/StratifierGroup
 */
export const StratifierGroup = 'http://hl7.org/fhir/StratifierGroup' satisfies OwlClass;

/**
 * _contract
 *
 * (Modified) Coverage.contract
 *
 * http://hl7.org/fhir/_contract
 */
export const _contract = 'http://hl7.org/fhir/_contract' satisfies OwlObjectProperty;

/**
 * _timeFromEvent
 *
 * (Modified) EvidenceVariable.characteristic.timeFromEvent
 *
 * http://hl7.org/fhir/_timeFromEvent
 */
export const _timeFromEvent = 'http://hl7.org/fhir/_timeFromEvent' satisfies OwlObjectProperty;

/**
 * notificationEvent
 *
 * SubscriptionStatus.notificationEvent: Detailed information about events relevant to this subscription notification.
 *
 * http://hl7.org/fhir/notificationEvent
 */
export const notificationEvent = 'http://hl7.org/fhir/notificationEvent' satisfies OwlObjectProperty;

/**
 * _inclusionCriteria
 *
 * (Modified) ValueSet.scope.inclusionCriteria
 *
 * http://hl7.org/fhir/_inclusionCriteria
 */
export const _inclusionCriteria = 'http://hl7.org/fhir/_inclusionCriteria' satisfies OwlObjectProperty;

/**
 * _orderMeaning
 *
 * (Modified) ElementDefinition.orderMeaning
 *
 * http://hl7.org/fhir/_orderMeaning
 */
export const _orderMeaning = 'http://hl7.org/fhir/_orderMeaning' satisfies OwlObjectProperty;

/**
 * autodelete
 *
 * TestScript.fixture.autodelete: Whether or not to implicitly delete the fixture during teardown. If true, the fixture is automatically deleted on each server being tested during teardown, therefore no delete operation is required for this fixture in the TestScript.teardown section.
 *
 * http://hl7.org/fhir/autodelete
 */
export const autodelete = 'http://hl7.org/fhir/autodelete' satisfies OwlObjectProperty;

/**
 * qualifiers
 *
 * InsurancePlan.plan.specificCost.benefit.cost.qualifiers: Additional information about the cost, such as information about funding sources (e.g. HSA, HRA, FSA, RRA).
 *
 * http://hl7.org/fhir/qualifiers
 */
export const qualifiers = 'http://hl7.org/fhir/qualifiers' satisfies OwlObjectProperty;

/**
 * _regionsStudied
 *
 * (Modified) GenomicStudy.analysis.regionsStudied
 *
 * http://hl7.org/fhir/_regionsStudied
 */
export const _regionsStudied = 'http://hl7.org/fhir/_regionsStudied' satisfies OwlObjectProperty;

/**
 * _application
 *
 * (Modified) RegulatedAuthorization.case.application
 *
 * http://hl7.org/fhir/_application
 */
export const _application = 'http://hl7.org/fhir/_application' satisfies OwlObjectProperty;

/**
 * frequency
 *
 * VerificationResult.frequency: Frequency of revalidation.
 *
 * http://hl7.org/fhir/frequency
 */
export const frequency = 'http://hl7.org/fhir/frequency' satisfies OwlObjectProperty;

/**
 * _sourceMaterial
 *
 * (Modified) SubstanceDefinition.sourceMaterial
 *
 * http://hl7.org/fhir/_sourceMaterial
 */
export const _sourceMaterial = 'http://hl7.org/fhir/_sourceMaterial' satisfies OwlObjectProperty;

/**
 * regulatoryBasis
 *
 * Consent.regulatoryBasis: A set of codes that indicate the regulatory basis (if any) that this consent supports.
 *
 * http://hl7.org/fhir/regulatoryBasis
 */
export const regulatoryBasis = 'http://hl7.org/fhir/regulatoryBasis' satisfies OwlObjectProperty;

/**
 * associationType
 *
 * InventoryItem.association.associationType: This attribute defined the type of association when establishing associations or relations between items, e.g. 'packaged within' or 'used with' or 'to be mixed with.
 *
 * http://hl7.org/fhir/associationType
 */
export const associationType = 'http://hl7.org/fhir/associationType' satisfies OwlObjectProperty;

/**
 * _software
 *
 * (Modified) TerminologyCapabilities.software
 *
 * http://hl7.org/fhir/_software
 */
export const _software = 'http://hl7.org/fhir/_software' satisfies OwlObjectProperty;

/**
 * _copolymerConnectivity
 *
 * (Modified) SubstancePolymer.copolymerConnectivity
 *
 * http://hl7.org/fhir/_copolymerConnectivity
 */
export const _copolymerConnectivity = 'http://hl7.org/fhir/_copolymerConnectivity' satisfies OwlObjectProperty;

/**
 * _approvalDate
 *
 * (Modified) NamingSystem.approvalDate
 *
 * http://hl7.org/fhir/_approvalDate
 */
export const _approvalDate = 'http://hl7.org/fhir/_approvalDate' satisfies OwlObjectProperty;

/**
 * totalVolume
 *
 * Medication.totalVolume: When the specified product code does not infer a package size, this is the specific amount of drug in the product.  For example, when specifying a product that has the same strength (For example, Insulin glargine 100 unit per mL solution for injection), this attribute provides additional clarification of the package amount (For example, 3 mL, 10mL, etc.).
 *
 * http://hl7.org/fhir/totalVolume
 */
export const totalVolume = 'http://hl7.org/fhir/totalVolume' satisfies OwlObjectProperty;

/**
 * AppointmentRecurrenceTemplateWeeklyTemplateComponent
 *
 * AppointmentRecurrenceTemplateComponent.AppointmentRecurrenceTemplateWeeklyTemplateComponent: Information about weekly recurring appointments.
 *
 * http://hl7.org/fhir/AppointmentRecurrenceTemplateWeeklyTemplateComponent
 */
export const AppointmentRecurrenceTemplateWeeklyTemplateComponent = 'http://hl7.org/fhir/AppointmentRecurrenceTemplateWeeklyTemplateComponent' satisfies OwlClass;

/**
 * _requestedPerformer
 *
 * (Modified) Task.requestedPerformer
 *
 * http://hl7.org/fhir/_requestedPerformer
 */
export const _requestedPerformer = 'http://hl7.org/fhir/_requestedPerformer' satisfies OwlObjectProperty;

/**
 * packagedProduct
 *
 * MedicationKnowledge.packaging.packagedProduct: A reference to a PackagedProductDefinition that provides the details of the product that is in the packaging and is being priced.
 *
 * http://hl7.org/fhir/packagedProduct
 */
export const packagedProduct = 'http://hl7.org/fhir/packagedProduct' satisfies OwlObjectProperty;

/**
 * tissue
 *
 * AdministrableProductDefinition.routeOfAdministration.targetSpecies.withdrawalPeriod.tissue: Coded expression for the type of tissue for which the withdrawal period applies, e.g. meat, milk.
 *
 * http://hl7.org/fhir/tissue
 */
export const tissue = 'http://hl7.org/fhir/tissue' satisfies OwlObjectProperty;

/**
 * isSubpotent
 *
 * Immunization.isSubpotent: Indication if a dose is considered to be subpotent. By default, a dose should be considered to be potent.
 *
 * http://hl7.org/fhir/isSubpotent
 */
export const isSubpotent = 'http://hl7.org/fhir/isSubpotent' satisfies OwlObjectProperty;

/**
 * _supportingInfoSequence
 *
 * (Modified) CoverageEligibilityRequest.item.supportingInfoSequence
 *
 * http://hl7.org/fhir/_supportingInfoSequence
 */
export const _supportingInfoSequence = 'http://hl7.org/fhir/_supportingInfoSequence' satisfies OwlObjectProperty;

/**
 * _rating
 *
 * (Modified) Evidence.certainty.subcomponent.rating
 *
 * http://hl7.org/fhir/_rating
 */
export const _rating = 'http://hl7.org/fhir/_rating' satisfies OwlObjectProperty;

/**
 * maternalOrganismName
 *
 * SubstanceSourceMaterial.organism.hybrid.maternalOrganismName: The name of the maternal species constituting the hybrid organism shall be specified. For plants, the parents aren’t always known, and it is unlikely that it will be known which is maternal and which is paternal.
 *
 * http://hl7.org/fhir/maternalOrganismName
 */
export const maternalOrganismName = 'http://hl7.org/fhir/maternalOrganismName' satisfies OwlObjectProperty;

/**
 * CommunicationRequest
 *
 * A request to convey information; e.g. the CDS system proposes that an alert be sent to a responsible provider, the CDS system proposes that the public health agency be notified about a reportable condition.
 *
 * http://hl7.org/fhir/CommunicationRequest
 */
export const CommunicationRequest = 'http://hl7.org/fhir/CommunicationRequest' satisfies OwlClass;

/**
 * polymer
 *
 * SubstanceDefinition.polymer: Data items specific to polymers.
 *
 * http://hl7.org/fhir/polymer
 */
export const polymer = 'http://hl7.org/fhir/polymer' satisfies OwlObjectProperty;

/**
 * initiatorActive
 *
 * ExampleScenario.process.step.process.step.alternative.step.operation.initiatorActive: If false, the initiator is deactivated right after the operation.
 *
 * http://hl7.org/fhir/initiatorActive
 */
export const initiatorActive = 'http://hl7.org/fhir/initiatorActive' satisfies OwlObjectProperty;

/**
 * _productStatus
 *
 * (Modified) BiologicallyDerivedProduct.productStatus
 *
 * http://hl7.org/fhir/_productStatus
 */
export const _productStatus = 'http://hl7.org/fhir/_productStatus' satisfies OwlObjectProperty;

/**
 * strand
 *
 * MolecularSequence.relative.startingSequence.strand: An absolute reference to a strand. The Watson strand is the strand whose 5'-end is on the short arm of the chromosome, and the Crick strand as the one whose 5'-end is on the long arm.
 *
 * http://hl7.org/fhir/strand
 */
export const strand = 'http://hl7.org/fhir/strand' satisfies OwlObjectProperty;

/**
 * _outputParameters
 *
 * (Modified) GuidanceResponse.outputParameters
 *
 * http://hl7.org/fhir/_outputParameters
 */
export const _outputParameters = 'http://hl7.org/fhir/_outputParameters' satisfies OwlObjectProperty;

/**
 * participantStatus
 *
 * AppointmentResponse.participantStatus: Participation status of the participant. When the status is declined or tentative if the start/end times are different to the appointment, then these times should be interpreted as a requested time change. When the status is accepted, the times can either be the time of the appointment (as a confirmation of the time) or can be empty.
 *
 * http://hl7.org/fhir/participantStatus
 */
export const participantStatus = 'http://hl7.org/fhir/participantStatus' satisfies OwlObjectProperty;

/**
 * label
 *
 * RelatedArtifact.label: A short label that can be used to reference the citation from elsewhere in the containing artifact, such as a footnote index.
 *
 * http://hl7.org/fhir/label
 */
export const label = 'http://hl7.org/fhir/label' satisfies OwlObjectProperty;

/**
 * manipulated
 *
 * Procedure.focalDevice.manipulated: The device that was manipulated (changed) during the procedure.
 *
 * http://hl7.org/fhir/manipulated
 */
export const manipulated = 'http://hl7.org/fhir/manipulated' satisfies OwlObjectProperty;

/**
 * _geometry
 *
 * (Modified) SubstancePolymer.geometry
 *
 * http://hl7.org/fhir/_geometry
 */
export const _geometry = 'http://hl7.org/fhir/_geometry' satisfies OwlObjectProperty;

/**
 * Coding
 *
 * A reference to a code defined by a terminology system.
 *
 * http://hl7.org/fhir/Coding
 */
export const Coding = 'http://hl7.org/fhir/Coding' satisfies OwlClass;

/**
 * requisition
 *
 * ServiceRequest.requisition: A shared identifier common to all service requests that were authorized more or less simultaneously by a single author, representing the composite or group identifier.
 *
 * http://hl7.org/fhir/requisition
 */
export const requisition = 'http://hl7.org/fhir/requisition' satisfies OwlObjectProperty;

/**
 * InventoryReportInventoryListingComponent
 *
 * InventoryReportInventoryListingComponent: An inventory listing section (grouped by any of the attributes).
 *
 * http://hl7.org/fhir/InventoryReportInventoryListingComponent
 */
export const InventoryReportInventoryListingComponent = 'http://hl7.org/fhir/InventoryReportInventoryListingComponent' satisfies OwlClass;

/**
 * _parent
 *
 * (Modified) Specimen.parent
 *
 * http://hl7.org/fhir/_parent
 */
export const _parent = 'http://hl7.org/fhir/_parent' satisfies OwlObjectProperty;

/**
 * _net
 *
 * (Modified) Claim.item.net
 *
 * http://hl7.org/fhir/_net
 */
export const _net = 'http://hl7.org/fhir/_net' satisfies OwlObjectProperty;

/**
 * presentation
 *
 * Ingredient.substance.strength.presentation
 *
 * http://hl7.org/fhir/presentation
 */
export const presentation = 'http://hl7.org/fhir/presentation' satisfies OwlObjectProperty;

/**
 * flag
 *
 * List.entry.flag: The flag allows the system constructing the list to indicate the role and significance of the item in the list.
 *
 * http://hl7.org/fhir/flag
 */
export const flag = 'http://hl7.org/fhir/flag' satisfies OwlObjectProperty;

/**
 * hoursOfOperation
 *
 * Location.hoursOfOperation: What days/times during a week is this location usually open, and any exceptions where the location is not available.
 *
 * http://hl7.org/fhir/hoursOfOperation
 */
export const hoursOfOperation = 'http://hl7.org/fhir/hoursOfOperation' satisfies OwlObjectProperty;

/**
 * encounter
 *
 * AdverseEvent.encounter: The Encounter associated with the start of the AdverseEvent.
 *
 * http://hl7.org/fhir/encounter
 */
export const encounter = 'http://hl7.org/fhir/encounter' satisfies OwlObjectProperty;

/**
 * applicability
 *
 * ChargeItemDefinition.propertyGroup.applicability: Expressions that describe applicability criteria for the priceComponent.
 *
 * http://hl7.org/fhir/applicability
 */
export const applicability = 'http://hl7.org/fhir/applicability' satisfies OwlObjectProperty;

/**
 * releaseDate
 *
 * CapabilityStatement.software.releaseDate: Date this version of the software was released.
 *
 * http://hl7.org/fhir/releaseDate
 */
export const releaseDate = 'http://hl7.org/fhir/releaseDate' satisfies OwlObjectProperty;

/**
 * _relationshipType
 *
 * (Modified) ClinicalUseDefinition.indication.otherTherapy.relationshipType
 *
 * http://hl7.org/fhir/_relationshipType
 */
export const _relationshipType = 'http://hl7.org/fhir/_relationshipType' satisfies OwlObjectProperty;

/**
 * _managingOrganization
 *
 * (Modified) Person.managingOrganization
 *
 * http://hl7.org/fhir/_managingOrganization
 */
export const _managingOrganization = 'http://hl7.org/fhir/_managingOrganization' satisfies OwlObjectProperty;

/**
 * derivedFromCanonical
 *
 * SpecimenDefinition.derivedFromCanonical: The canonical URL pointing to another FHIR-defined SpecimenDefinition that is adhered to in whole or in part by this definition.
 *
 * http://hl7.org/fhir/derivedFromCanonical
 */
export const derivedFromCanonical = 'http://hl7.org/fhir/derivedFromCanonical' satisfies OwlObjectProperty;

/**
 * _hasSeverity
 *
 * (Modified) ConditionDefinition.hasSeverity
 *
 * http://hl7.org/fhir/_hasSeverity
 */
export const _hasSeverity = 'http://hl7.org/fhir/_hasSeverity' satisfies OwlObjectProperty;

/**
 * cTerminalModification
 *
 * SubstanceProtein.subunit.cTerminalModification: The modification at the C-terminal shall be specified.
 *
 * http://hl7.org/fhir/cTerminalModification
 */
export const cTerminalModification = 'http://hl7.org/fhir/cTerminalModification' satisfies OwlObjectProperty;

/**
 * ContentDefinition
 *
 * Contract.ContentDefinition: Precusory content developed with a focus and intent of supporting the formation a Contract instance, which may be associated with and transformable into a Contract.
 *
 * http://hl7.org/fhir/ContentDefinition
 */
export const ContentDefinition = 'http://hl7.org/fhir/ContentDefinition' satisfies OwlClass;

/**
 * _bodyLandmarkOrientation
 *
 * (Modified) BodyStructure.excludedStructure.bodyLandmarkOrientation
 *
 * http://hl7.org/fhir/_bodyLandmarkOrientation
 */
export const _bodyLandmarkOrientation = 'http://hl7.org/fhir/_bodyLandmarkOrientation' satisfies OwlObjectProperty;

/**
 * relationship
 *
 * PlanDefinition.action.action.relatedAction.relationship: The relationship of the start of this action to the related action.
 *
 * http://hl7.org/fhir/relationship
 */
export const relationship = 'http://hl7.org/fhir/relationship' satisfies OwlObjectProperty;

/**
 * goal
 *
 * PlanDefinition.goal: A goal describes an expected outcome that activities within the plan are intended to achieve. For example, weight loss, restoring an activity of daily living, obtaining herd immunity via immunization, meeting a process improvement objective, meeting the acceptance criteria for a test as specified by a quality specification, etc.
 *
 * http://hl7.org/fhir/goal
 */
export const goal = 'http://hl7.org/fhir/goal' satisfies OwlObjectProperty;

/**
 * _connectivity
 *
 * (Modified) SubstanceNucleicAcid.subunit.linkage.connectivity
 *
 * http://hl7.org/fhir/_connectivity
 */
export const _connectivity = 'http://hl7.org/fhir/_connectivity' satisfies OwlObjectProperty;

/**
 * _listMode
 *
 * (Modified) StructureMap.group.rule.rule.target.listMode
 *
 * http://hl7.org/fhir/_listMode
 */
export const _listMode = 'http://hl7.org/fhir/_listMode' satisfies OwlObjectProperty;

/**
 * _availableTime
 *
 * (Modified) Availability.availableTime
 *
 * http://hl7.org/fhir/_availableTime
 */
export const _availableTime = 'http://hl7.org/fhir/_availableTime' satisfies OwlObjectProperty;

/**
 * property
 *
 * DeviceDefinition.property: Static or essentially fixed characteristics or features of this kind of device that are otherwise not captured in more specific attributes, e.g., time or timing attributes, resolution, accuracy, and physical attributes.
 *
 * http://hl7.org/fhir/property
 */
export const property = 'http://hl7.org/fhir/property' satisfies OwlObjectProperty;

/**
 * _calibration
 *
 * (Modified) DeviceMetric.calibration
 *
 * http://hl7.org/fhir/_calibration
 */
export const _calibration = 'http://hl7.org/fhir/_calibration' satisfies OwlObjectProperty;

/**
 * TerminologyCapabilitiesExpansionParameterComponent
 *
 * TerminologyCapabilitiesExpansionComponent.TerminologyCapabilitiesExpansionParameterComponent: Supported expansion parameter.
 *
 * http://hl7.org/fhir/TerminologyCapabilitiesExpansionParameterComponent
 */
export const TerminologyCapabilitiesExpansionParameterComponent = 'http://hl7.org/fhir/TerminologyCapabilitiesExpansionParameterComponent' satisfies OwlClass;

/**
 * adjustmentReason
 *
 * ExplanationOfBenefit.payment.adjustmentReason: Reason for the payment adjustment.
 *
 * http://hl7.org/fhir/adjustmentReason
 */
export const adjustmentReason = 'http://hl7.org/fhir/adjustmentReason' satisfies OwlObjectProperty;

/**
 * AdministrableProductDefinitionRouteOfAdministrationTargetSpeciesComponent
 *
 * AdministrableProductDefinitionRouteOfAdministrationComponent.AdministrableProductDefinitionRouteOfAdministrationTargetSpeciesComponent: A species for which this route applies.
 *
 * http://hl7.org/fhir/AdministrableProductDefinitionRouteOfAdministrationTargetSpeciesComponent
 */
export const AdministrableProductDefinitionRouteOfAdministrationTargetSpeciesComponent = 'http://hl7.org/fhir/AdministrableProductDefinitionRouteOfAdministrationTargetSpeciesComponent' satisfies OwlClass;

/**
 * Basic
 *
 * Basic is used for handling concepts not yet defined in FHIR, narrative-only resources that don't map to an existing resource, and custom resources not appropriate for inclusion in the FHIR specification.
 *
 * http://hl7.org/fhir/Basic
 */
export const Basic = 'http://hl7.org/fhir/Basic' satisfies OwlClass;

/**
 * _isDerived
 *
 * (Modified) SpecimenDefinition.typeTested.isDerived
 *
 * http://hl7.org/fhir/_isDerived
 */
export const _isDerived = 'http://hl7.org/fhir/_isDerived' satisfies OwlObjectProperty;

/**
 * hierarchical
 *
 * TerminologyCapabilities.expansion.hierarchical: Whether the server can return nested value sets.
 *
 * http://hl7.org/fhir/hierarchical
 */
export const hierarchical = 'http://hl7.org/fhir/hierarchical' satisfies OwlObjectProperty;

/**
 * _resultForCreate
 *
 * (Modified) SubscriptionTopic.resourceTrigger.queryCriteria.resultForCreate
 *
 * http://hl7.org/fhir/_resultForCreate
 */
export const _resultForCreate = 'http://hl7.org/fhir/_resultForCreate' satisfies OwlObjectProperty;

/**
 * _deviceName
 *
 * (Modified) DeviceDefinition.deviceName
 *
 * http://hl7.org/fhir/_deviceName
 */
export const _deviceName = 'http://hl7.org/fhir/_deviceName' satisfies OwlObjectProperty;

/**
 * _startDate
 *
 * (Modified) ResearchSubject.progress.startDate
 *
 * http://hl7.org/fhir/_startDate
 */
export const _startDate = 'http://hl7.org/fhir/_startDate' satisfies OwlObjectProperty;

/**
 * Attachment
 *
 * For referring to data content defined in other formats.
 *
 * http://hl7.org/fhir/Attachment
 */
export const Attachment = 'http://hl7.org/fhir/Attachment' satisfies OwlClass;

/**
 * _patientPreparation
 *
 * (Modified) SpecimenDefinition.patientPreparation
 *
 * http://hl7.org/fhir/_patientPreparation
 */
export const _patientPreparation = 'http://hl7.org/fhir/_patientPreparation' satisfies OwlObjectProperty;

/**
 * CitationCitedArtifactPublicationFormComponent
 *
 * CitationCitedArtifactComponent.CitationCitedArtifactPublicationFormComponent: If multiple, used to represent alternative forms of the article that are not separate citations.
 *
 * http://hl7.org/fhir/CitationCitedArtifactPublicationFormComponent
 */
export const CitationCitedArtifactPublicationFormComponent = 'http://hl7.org/fhir/CitationCitedArtifactPublicationFormComponent' satisfies OwlClass;

/**
 * windowStart
 *
 * MolecularSequence.relative.startingSequence.windowStart: Start position of the window on the starting sequence. This value should honor the rules of the coordinateSystem.
 *
 * http://hl7.org/fhir/windowStart
 */
export const windowStart = 'http://hl7.org/fhir/windowStart' satisfies OwlObjectProperty;

/**
 * _propertyGroup
 *
 * (Modified) ChargeItemDefinition.propertyGroup
 *
 * http://hl7.org/fhir/_propertyGroup
 */
export const _propertyGroup = 'http://hl7.org/fhir/_propertyGroup' satisfies OwlObjectProperty;

/**
 * languageCode
 *
 * DeviceDefinition.languageCode: Language code for the human-readable text strings produced by the device (all supported).
 *
 * http://hl7.org/fhir/languageCode
 */
export const languageCode = 'http://hl7.org/fhir/languageCode' satisfies OwlObjectProperty;

/**
 * _canPushUpdates
 *
 * (Modified) VerificationResult.primarySource.canPushUpdates
 *
 * http://hl7.org/fhir/_canPushUpdates
 */
export const _canPushUpdates = 'http://hl7.org/fhir/_canPushUpdates' satisfies OwlObjectProperty;

/**
 * groupingBehavior
 *
 * PlanDefinition.action.action.groupingBehavior: Defines the grouping behavior for the action and its children.
 *
 * http://hl7.org/fhir/groupingBehavior
 */
export const groupingBehavior = 'http://hl7.org/fhir/groupingBehavior' satisfies OwlObjectProperty;

/**
 * for
 *
 * Ingredient.for: The product which this ingredient is a constituent part of.
 * Note that `for` is a reserved Javascript keyword, and is therefore suffixed by `__workaround`.
 * For a list of reserved keywords, see https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Lexical_grammar#Keywords.
 *
 * http://hl7.org/fhir/for
 */
export const for__workaround = 'http://hl7.org/fhir/for' satisfies OwlObjectProperty;

/**
 * _studyUid
 *
 * (Modified) ImagingSelection.studyUid
 *
 * http://hl7.org/fhir/_studyUid
 */
export const _studyUid = 'http://hl7.org/fhir/_studyUid' satisfies OwlObjectProperty;

/**
 * _event
 *
 * (Modified) MessageHeader.event
 *
 * http://hl7.org/fhir/_event
 */
export const _event = 'http://hl7.org/fhir/_event' satisfies OwlObjectProperty;

/**
 * informationProvider
 *
 * CommunicationRequest.informationProvider: The entity (e.g. person, organization, clinical information system, or device) which is to be the source of the communication.
 *
 * http://hl7.org/fhir/informationProvider
 */
export const informationProvider = 'http://hl7.org/fhir/informationProvider' satisfies OwlObjectProperty;

/**
 * network
 *
 * InsurancePlan.coverage.network: Reference to the network that providing the type of coverage.
 *
 * http://hl7.org/fhir/network
 */
export const network = 'http://hl7.org/fhir/network' satisfies OwlObjectProperty;

/**
 * _manufacturedDoseForm
 *
 * (Modified) ManufacturedItemDefinition.manufacturedDoseForm
 *
 * http://hl7.org/fhir/_manufacturedDoseForm
 */
export const _manufacturedDoseForm = 'http://hl7.org/fhir/_manufacturedDoseForm' satisfies OwlObjectProperty;

/**
 * assert
 *
 * TestScript.setup.action.assert: Evaluates the results of previous operations to determine if the server under test behaves appropriately.
 *
 * http://hl7.org/fhir/assert
 */
export const assert = 'http://hl7.org/fhir/assert' satisfies OwlObjectProperty;

/**
 * _warningOnly
 *
 * (Modified) TestScript.test.action.assert.warningOnly
 *
 * http://hl7.org/fhir/_warningOnly
 */
export const _warningOnly = 'http://hl7.org/fhir/_warningOnly' satisfies OwlObjectProperty;

/**
 * isSummary
 *
 * ElementDefinition.isSummary: Whether the element should be included if a client requests a search with the parameter _summary=true.
 *
 * http://hl7.org/fhir/isSummary
 */
export const isSummary = 'http://hl7.org/fhir/isSummary' satisfies OwlObjectProperty;

/**
 * attachedDocument
 *
 * RegulatedAuthorization.attachedDocument: Additional information or supporting documentation about the authorization.
 *
 * http://hl7.org/fhir/attachedDocument
 */
export const attachedDocument = 'http://hl7.org/fhir/attachedDocument' satisfies OwlObjectProperty;

/**
 * _unit
 *
 * (Modified) SubstancePolymer.repeat.repeatUnit.unit
 *
 * http://hl7.org/fhir/_unit
 */
export const _unit = 'http://hl7.org/fhir/_unit' satisfies OwlObjectProperty;

/**
 * _endDate
 *
 * (Modified) ResearchSubject.progress.endDate
 *
 * http://hl7.org/fhir/_endDate
 */
export const _endDate = 'http://hl7.org/fhir/_endDate' satisfies OwlObjectProperty;

/**
 * authoredOn
 *
 * RequestOrchestration.authoredOn: Indicates when the request orchestration was created.
 *
 * http://hl7.org/fhir/authoredOn
 */
export const authoredOn = 'http://hl7.org/fhir/authoredOn' satisfies OwlObjectProperty;

/**
 * _geographicalLocation
 *
 * (Modified) SubstanceSourceMaterial.geographicalLocation
 *
 * http://hl7.org/fhir/_geographicalLocation
 */
export const _geographicalLocation = 'http://hl7.org/fhir/_geographicalLocation' satisfies OwlObjectProperty;

/**
 * CitationCitedArtifactClassificationComponent
 *
 * CitationCitedArtifactComponent.CitationCitedArtifactClassificationComponent: The assignment to an organizing scheme.
 *
 * http://hl7.org/fhir/CitationCitedArtifactClassificationComponent
 */
export const CitationCitedArtifactClassificationComponent = 'http://hl7.org/fhir/CitationCitedArtifactClassificationComponent' satisfies OwlClass;

/**
 * userSelected
 *
 * Coding.userSelected: Indicates that this coding was chosen by a user directly - e.g. off a pick list of available items (codes or displays).
 *
 * http://hl7.org/fhir/userSelected
 */
export const userSelected = 'http://hl7.org/fhir/userSelected' satisfies OwlObjectProperty;

/**
 * _prognosisCodeableConcept
 *
 * (Modified) ClinicalImpression.prognosisCodeableConcept
 *
 * http://hl7.org/fhir/_prognosisCodeableConcept
 */
export const _prognosisCodeableConcept = 'http://hl7.org/fhir/_prognosisCodeableConcept' satisfies OwlObjectProperty;

/**
 * dateCriterion
 *
 * ImmunizationRecommendation.recommendation.dateCriterion: Vaccine date recommendations.  For example, earliest date to administer, latest date to administer, etc.
 *
 * http://hl7.org/fhir/dateCriterion
 */
export const dateCriterion = 'http://hl7.org/fhir/dateCriterion' satisfies OwlObjectProperty;

/**
 * additionalInstruction
 *
 * Dosage.additionalInstruction: Supplemental instructions to the patient on how to take the medication  (e.g. "with meals" or"take half to one hour before food") or warnings for the patient about the medication (e.g. "may cause drowsiness" or "avoid exposure of skin to direct sunlight or sunlamps").
 *
 * http://hl7.org/fhir/additionalInstruction
 */
export const additionalInstruction = 'http://hl7.org/fhir/additionalInstruction' satisfies OwlObjectProperty;

/**
 * specialPrecautionsForStorage
 *
 * ProductShelfLife.specialPrecautionsForStorage: Special precautions for storage, if any, can be specified using an appropriate controlled vocabulary The controlled term and the controlled term identifier shall be specified.
 *
 * http://hl7.org/fhir/specialPrecautionsForStorage
 */
export const specialPrecautionsForStorage = 'http://hl7.org/fhir/specialPrecautionsForStorage' satisfies OwlObjectProperty;

/**
 * population
 *
 * ClinicalUseDefinition.population: The population group to which this applies.
 *
 * http://hl7.org/fhir/population
 */
export const population = 'http://hl7.org/fhir/population' satisfies OwlObjectProperty;

/**
 * _member
 *
 * (Modified) Group.member
 *
 * http://hl7.org/fhir/_member
 */
export const _member = 'http://hl7.org/fhir/_member' satisfies OwlObjectProperty;

/**
 * securityLabel
 *
 * AuditEvent.entity.securityLabel: Security labels for the identified entity.
 *
 * http://hl7.org/fhir/securityLabel
 */
export const securityLabel = 'http://hl7.org/fhir/securityLabel' satisfies OwlObjectProperty;

/**
 * _renderedDosageInstruction
 *
 * (Modified) MedicationStatement.renderedDosageInstruction
 *
 * http://hl7.org/fhir/_renderedDosageInstruction
 */
export const _renderedDosageInstruction = 'http://hl7.org/fhir/_renderedDosageInstruction' satisfies OwlObjectProperty;

/**
 * Notes
 *
 * PaymentReconciliation.Notes: A note that describes or explains the processing in a human readable form.
 *
 * http://hl7.org/fhir/Notes
 */
export const Notes = 'http://hl7.org/fhir/Notes' satisfies OwlClass;

/**
 * _dynamicValue
 *
 * (Modified) RequestOrchestration.action.action.dynamicValue
 *
 * http://hl7.org/fhir/_dynamicValue
 */
export const _dynamicValue = 'http://hl7.org/fhir/_dynamicValue' satisfies OwlObjectProperty;

/**
 * _confidentialityIndicator
 *
 * (Modified) MedicinalProductDefinition.operation.confidentialityIndicator
 *
 * http://hl7.org/fhir/_confidentialityIndicator
 */
export const _confidentialityIndicator = 'http://hl7.org/fhir/_confidentialityIndicator' satisfies OwlObjectProperty;

/**
 * _intendedUse
 *
 * (Modified) RegulatedAuthorization.intendedUse
 *
 * http://hl7.org/fhir/_intendedUse
 */
export const _intendedUse = 'http://hl7.org/fhir/_intendedUse' satisfies OwlObjectProperty;

/**
 * lastUpdated
 *
 * Meta.lastUpdated: When the resource last changed - e.g. when the version changed.
 *
 * http://hl7.org/fhir/lastUpdated
 */
export const lastUpdated = 'http://hl7.org/fhir/lastUpdated' satisfies OwlObjectProperty;

/**
 * deceased
 *
 * Practitioner.deceased
 *
 * http://hl7.org/fhir/deceased
 */
export const deceased = 'http://hl7.org/fhir/deceased' satisfies OwlObjectProperty;

/**
 * NutritionOrderEnteralFormulaAdditiveComponent
 *
 * NutritionOrderEnteralFormulaComponent.NutritionOrderEnteralFormulaAdditiveComponent: Indicates modular components to be provided in addition or mixed with the base formula.
 *
 * http://hl7.org/fhir/NutritionOrderEnteralFormulaAdditiveComponent
 */
export const NutritionOrderEnteralFormulaAdditiveComponent = 'http://hl7.org/fhir/NutritionOrderEnteralFormulaAdditiveComponent' satisfies OwlClass;

/**
 * designation
 *
 * ValueSet.expansion.contains.designation: Additional representations for this item - other languages, aliases, specialized purposes, used for particular purposes, etc. These are relevant when the conditions of the expansion do not fix to a single correct representation.
 *
 * http://hl7.org/fhir/designation
 */
export const designation = 'http://hl7.org/fhir/designation' satisfies OwlObjectProperty;

/**
 * reportedDateTime
 *
 * InventoryReport.reportedDateTime: When the report has been submitted.
 *
 * http://hl7.org/fhir/reportedDateTime
 */
export const reportedDateTime = 'http://hl7.org/fhir/reportedDateTime' satisfies OwlObjectProperty;

/**
 * productOrServiceEnd
 *
 * ExplanationOfBenefit.addItem.productOrServiceEnd: This contains the end of a range of product, service, drug or other billing codes for the item. This element is not used when the .productOrService is a group code. This value may only be present when a .productOfService code has been provided to convey the start of the range. Typically this value may be used only with preauthorizations and not with claims.
 *
 * http://hl7.org/fhir/productOrServiceEnd
 */
export const productOrServiceEnd = 'http://hl7.org/fhir/productOrServiceEnd' satisfies OwlObjectProperty;

/**
 * teardown
 *
 * TestScript.teardown: A series of operations required to clean up after all the tests are executed (successfully or otherwise).
 *
 * http://hl7.org/fhir/teardown
 */
export const teardown = 'http://hl7.org/fhir/teardown' satisfies OwlObjectProperty;

/**
 * securityLabelNumber
 *
 * Contract.term.action.securityLabelNumber: Security labels that protects the action.
 *
 * http://hl7.org/fhir/securityLabelNumber
 */
export const securityLabelNumber = 'http://hl7.org/fhir/securityLabelNumber' satisfies OwlObjectProperty;

/**
 * _manufactureDate
 *
 * (Modified) Device.manufactureDate
 *
 * http://hl7.org/fhir/_manufactureDate
 */
export const _manufactureDate = 'http://hl7.org/fhir/_manufactureDate' satisfies OwlObjectProperty;

/**
 * _textFilter
 *
 * (Modified) TerminologyCapabilities.expansion.textFilter
 *
 * http://hl7.org/fhir/_textFilter
 */
export const _textFilter = 'http://hl7.org/fhir/_textFilter' satisfies OwlObjectProperty;

/**
 * _route
 *
 * (Modified) MedicinalProductDefinition.route
 *
 * http://hl7.org/fhir/_route
 */
export const _route = 'http://hl7.org/fhir/_route' satisfies OwlObjectProperty;

/**
 * parentSubstanceName
 *
 * SubstanceSourceMaterial.parentSubstanceName: The parent substance of the Herbal Drug, or Herbal preparation.
 *
 * http://hl7.org/fhir/parentSubstanceName
 */
export const parentSubstanceName = 'http://hl7.org/fhir/parentSubstanceName' satisfies OwlObjectProperty;

/**
 * _docStatus
 *
 * (Modified) DocumentReference.docStatus
 *
 * http://hl7.org/fhir/_docStatus
 */
export const _docStatus = 'http://hl7.org/fhir/_docStatus' satisfies OwlObjectProperty;

/**
 * ArtifactAssessmentContentComponentContentContent
 *
 * If the informationType is container, the components of the content.
 *
 * http://hl7.org/fhir/ArtifactAssessmentContentComponentContentContent
 */
export const ArtifactAssessmentContentComponentContentContent = 'http://hl7.org/fhir/ArtifactAssessmentContentComponentContentContent' satisfies OwlClass;

/**
 * _subscriber
 *
 * (Modified) Coverage.subscriber
 *
 * http://hl7.org/fhir/_subscriber
 */
export const _subscriber = 'http://hl7.org/fhir/_subscriber' satisfies OwlObjectProperty;

/**
 * workflowStatus
 *
 * ArtifactAssessment.workflowStatus: Indicates the workflow status of the comment or change request.
 *
 * http://hl7.org/fhir/workflowStatus
 */
export const workflowStatus = 'http://hl7.org/fhir/workflowStatus' satisfies OwlObjectProperty;

/**
 * phylum
 *
 * SubstanceSourceMaterial.organism.organismGeneral.phylum: The phylum of an organism shall be specified.
 *
 * http://hl7.org/fhir/phylum
 */
export const phylum = 'http://hl7.org/fhir/phylum' satisfies OwlObjectProperty;

/**
 * _mustSupport
 *
 * (Modified) ElementDefinition.mustSupport
 *
 * http://hl7.org/fhir/_mustSupport
 */
export const _mustSupport = 'http://hl7.org/fhir/_mustSupport' satisfies OwlObjectProperty;

/**
 * forecastStatus
 *
 * ImmunizationRecommendation.recommendation.forecastStatus: Indicates the patient status with respect to the path to immunity for the target disease.
 *
 * http://hl7.org/fhir/forecastStatus
 */
export const forecastStatus = 'http://hl7.org/fhir/forecastStatus' satisfies OwlObjectProperty;

/**
 * _closure
 *
 * (Modified) TerminologyCapabilities.closure
 *
 * http://hl7.org/fhir/_closure
 */
export const _closure = 'http://hl7.org/fhir/_closure' satisfies OwlObjectProperty;

/**
 * _abstract
 *
 * (Modified) ValueSet.expansion.contains.contains.abstract
 *
 * http://hl7.org/fhir/_abstract
 */
export const _abstract = 'http://hl7.org/fhir/_abstract' satisfies OwlObjectProperty;

/**
 * relatedClinicalInformation
 *
 * MedicationStatement.relatedClinicalInformation: Link to information that is relevant to a medication statement, for example, illicit drug use, gestational age, etc.
 *
 * http://hl7.org/fhir/relatedClinicalInformation
 */
export const relatedClinicalInformation = 'http://hl7.org/fhir/relatedClinicalInformation' satisfies OwlObjectProperty;

/**
 * PersonCommunicationComponent
 *
 * PersonCommunicationComponent: A language which may be used to communicate with the person about his or her health.
 *
 * http://hl7.org/fhir/PersonCommunicationComponent
 */
export const PersonCommunicationComponent = 'http://hl7.org/fhir/PersonCommunicationComponent' satisfies OwlClass;

/**
 * _relativePath
 *
 * (Modified) ImplementationGuide.manifest.resource.relativePath
 *
 * http://hl7.org/fhir/_relativePath
 */
export const _relativePath = 'http://hl7.org/fhir/_relativePath' satisfies OwlObjectProperty;

/**
 * CitationCitedArtifactVersionComponent
 *
 * CitationCitedArtifactComponent.CitationCitedArtifactVersionComponent: The defined version of the cited artifact.
 *
 * http://hl7.org/fhir/CitationCitedArtifactVersionComponent
 */
export const CitationCitedArtifactVersionComponent = 'http://hl7.org/fhir/CitationCitedArtifactVersionComponent' satisfies OwlClass;

/**
 * _paging
 *
 * (Modified) TerminologyCapabilities.expansion.paging
 *
 * http://hl7.org/fhir/_paging
 */
export const _paging = 'http://hl7.org/fhir/_paging' satisfies OwlObjectProperty;

/**
 * _uniqueId
 *
 * (Modified) NamingSystem.uniqueId
 *
 * http://hl7.org/fhir/_uniqueId
 */
export const _uniqueId = 'http://hl7.org/fhir/_uniqueId' satisfies OwlObjectProperty;

/**
 * _readOnly
 *
 * (Modified) Questionnaire.item.item.readOnly
 *
 * http://hl7.org/fhir/_readOnly
 */
export const _readOnly = 'http://hl7.org/fhir/_readOnly' satisfies OwlObjectProperty;

/**
 * _jurisdiction
 *
 * (Modified) DeviceDefinition.packaging.packaging.udiDeviceIdentifier.jurisdiction
 *
 * http://hl7.org/fhir/_jurisdiction
 */
export const _jurisdiction = 'http://hl7.org/fhir/_jurisdiction' satisfies OwlObjectProperty;

/**
 * _treatment
 *
 * (Modified) ClinicalUseDefinition.indication.otherTherapy.treatment
 *
 * http://hl7.org/fhir/_treatment
 */
export const _treatment = 'http://hl7.org/fhir/_treatment' satisfies OwlObjectProperty;

/**
 * _responsibleParty
 *
 * (Modified) MedicationDispense.substitution.responsibleParty
 *
 * http://hl7.org/fhir/_responsibleParty
 */
export const _responsibleParty = 'http://hl7.org/fhir/_responsibleParty' satisfies OwlObjectProperty;

/**
 * RequestOrchestrationActionComponentActionAction
 *
 * Sub actions.
 *
 * http://hl7.org/fhir/RequestOrchestrationActionComponentActionAction
 */
export const RequestOrchestrationActionComponentActionAction = 'http://hl7.org/fhir/RequestOrchestrationActionComponentActionAction' satisfies OwlClass;

/**
 * _role
 *
 * (Modified) PlanDefinition.action.action.participant.role
 *
 * http://hl7.org/fhir/_role
 */
export const _role = 'http://hl7.org/fhir/_role' satisfies OwlObjectProperty;

/**
 * TestPlanDependencyComponent
 *
 * TestPlanDependencyComponent: The required criteria to execute the test plan - e.g. preconditions, previous tests...
 *
 * http://hl7.org/fhir/TestPlanDependencyComponent
 */
export const TestPlanDependencyComponent = 'http://hl7.org/fhir/TestPlanDependencyComponent' satisfies OwlClass;

/**
 * Binary
 *
 * A resource that represents the data of a single raw artifact as digital content accessible in its native format.  A Binary resource can contain any content, whether text, image, pdf, zip archive, etc.
 *
 * http://hl7.org/fhir/Binary
 */
export const Binary = 'http://hl7.org/fhir/Binary' satisfies OwlClass;

/**
 * contentDerivative
 *
 * Contract.contentDerivative: The minimal content derived from the basal information source at a specific stage in its lifecycle.
 *
 * http://hl7.org/fhir/contentDerivative
 */
export const contentDerivative = 'http://hl7.org/fhir/contentDerivative' satisfies OwlObjectProperty;

/**
 * inforce
 *
 * CoverageEligibilityResponse.insurance.inforce: Flag indicating if the coverage provided is inforce currently if no service date(s) specified or for the whole duration of the service dates.
 *
 * http://hl7.org/fhir/inforce
 */
export const inforce = 'http://hl7.org/fhir/inforce' satisfies OwlObjectProperty;

/**
 * RiskAssessmentPredictionComponent
 *
 * RiskAssessmentPredictionComponent: Describes the expected outcome for the subject.
 *
 * http://hl7.org/fhir/RiskAssessmentPredictionComponent
 */
export const RiskAssessmentPredictionComponent = 'http://hl7.org/fhir/RiskAssessmentPredictionComponent' satisfies OwlClass;

/**
 * _enteredDate
 *
 * (Modified) ChargeItem.enteredDate
 *
 * http://hl7.org/fhir/_enteredDate
 */
export const _enteredDate = 'http://hl7.org/fhir/_enteredDate' satisfies OwlObjectProperty;

/**
 * _legalStatusOfSupply
 *
 * (Modified) PackagedProductDefinition.legalStatusOfSupply
 *
 * http://hl7.org/fhir/_legalStatusOfSupply
 */
export const _legalStatusOfSupply = 'http://hl7.org/fhir/_legalStatusOfSupply' satisfies OwlObjectProperty;

/**
 * valueAlternatives
 *
 * ElementDefinition.valueAlternatives: Specifies a list of extensions that can appear in place of a primitive value.
 *
 * http://hl7.org/fhir/valueAlternatives
 */
export const valueAlternatives = 'http://hl7.org/fhir/valueAlternatives' satisfies OwlObjectProperty;

/**
 * subject
 *
 * Account.subject: Identifies the entity which incurs the expenses. While the immediate recipients of services or goods might be entities related to the subject, the expenses were ultimately incurred by the subject of the Account.
 *
 * http://hl7.org/fhir/subject
 */
export const subject = 'http://hl7.org/fhir/subject' satisfies OwlObjectProperty;

/**
 * _publicationDate
 *
 * (Modified) Contract.contentDefinition.publicationDate
 *
 * http://hl7.org/fhir/_publicationDate
 */
export const _publicationDate = 'http://hl7.org/fhir/_publicationDate' satisfies OwlObjectProperty;

/**
 * occurrenceChanged
 *
 * Appointment.occurrenceChanged: This appointment varies from the recurring pattern.
 *
 * http://hl7.org/fhir/occurrenceChanged
 */
export const occurrenceChanged = 'http://hl7.org/fhir/occurrenceChanged' satisfies OwlObjectProperty;

/**
 * _referralRequest
 *
 * (Modified) EpisodeOfCare.referralRequest
 *
 * http://hl7.org/fhir/_referralRequest
 */
export const _referralRequest = 'http://hl7.org/fhir/_referralRequest' satisfies OwlObjectProperty;

/**
 * friday
 *
 * Appointment.recurrenceTemplate.weeklyTemplate.friday: Indicates that recurring appointments should occur on Fridays.
 *
 * http://hl7.org/fhir/friday
 */
export const friday = 'http://hl7.org/fhir/friday' satisfies OwlObjectProperty;

/**
 * productType
 *
 * MedicationKnowledge.productType: Category of the medication or product (e.g. branded product, therapeutic moeity, generic product, innovator product, etc.).
 *
 * http://hl7.org/fhir/productType
 */
export const productType = 'http://hl7.org/fhir/productType' satisfies OwlObjectProperty;

/**
 * _payeeType
 *
 * (Modified) ClaimResponse.payeeType
 *
 * http://hl7.org/fhir/_payeeType
 */
export const _payeeType = 'http://hl7.org/fhir/_payeeType' satisfies OwlObjectProperty;

/**
 * _fixed
 *
 * (Modified) ElementDefinition.fixed
 *
 * http://hl7.org/fhir/_fixed
 */
export const _fixed = 'http://hl7.org/fhir/_fixed' satisfies OwlObjectProperty;

/**
 * _nTerminalModification
 *
 * (Modified) SubstanceProtein.subunit.nTerminalModification
 *
 * http://hl7.org/fhir/_nTerminalModification
 */
export const _nTerminalModification = 'http://hl7.org/fhir/_nTerminalModification' satisfies OwlObjectProperty;

/**
 * _progressStatus
 *
 * (Modified) ResearchStudy.progressStatus
 *
 * http://hl7.org/fhir/_progressStatus
 */
export const _progressStatus = 'http://hl7.org/fhir/_progressStatus' satisfies OwlObjectProperty;

/**
 * _age
 *
 * (Modified) ObservationDefinition.component.qualifiedValue.age
 *
 * http://hl7.org/fhir/_age
 */
export const _age = 'http://hl7.org/fhir/_age' satisfies OwlObjectProperty;

/**
 * _verificationDate
 *
 * (Modified) Consent.verification.verificationDate
 *
 * http://hl7.org/fhir/_verificationDate
 */
export const _verificationDate = 'http://hl7.org/fhir/_verificationDate' satisfies OwlObjectProperty;

/**
 * CompartmentDefinitionResourceComponent
 *
 * CompartmentDefinitionResourceComponent: Information about how a resource is related to the compartment.
 *
 * http://hl7.org/fhir/CompartmentDefinitionResourceComponent
 */
export const CompartmentDefinitionResourceComponent = 'http://hl7.org/fhir/CompartmentDefinitionResourceComponent' satisfies OwlClass;

/**
 * _questionnaire
 *
 * (Modified) QuestionnaireResponse.questionnaire
 *
 * http://hl7.org/fhir/_questionnaire
 */
export const _questionnaire = 'http://hl7.org/fhir/_questionnaire' satisfies OwlObjectProperty;

/**
 * TestScript
 *
 * A structured set of tests against a FHIR server or client implementation to determine compliance against the FHIR specification.
 *
 * http://hl7.org/fhir/TestScript
 */
export const TestScript = 'http://hl7.org/fhir/TestScript' satisfies OwlClass;

/**
 * billingStatus
 *
 * Account.billingStatus: The BillingStatus tracks the lifecycle of the account through the billing process. It indicates how transactions are treated when they are allocated to the account.
 *
 * http://hl7.org/fhir/billingStatus
 */
export const billingStatus = 'http://hl7.org/fhir/billingStatus' satisfies OwlObjectProperty;

/**
 * _resourceTrigger
 *
 * (Modified) SubscriptionTopic.resourceTrigger
 *
 * http://hl7.org/fhir/_resourceTrigger
 */
export const _resourceTrigger = 'http://hl7.org/fhir/_resourceTrigger' satisfies OwlObjectProperty;

/**
 * compose
 *
 * ValueSet.compose: A set of criteria that define the contents of the value set by including or excluding codes selected from the specified code system(s) that the value set draws from. This is also known as the Content Logical Definition (CLD).
 *
 * http://hl7.org/fhir/compose
 */
export const compose = 'http://hl7.org/fhir/compose' satisfies OwlObjectProperty;

/**
 * _submitter
 *
 * (Modified) PaymentReconciliation.allocation.submitter
 *
 * http://hl7.org/fhir/_submitter
 */
export const _submitter = 'http://hl7.org/fhir/_submitter' satisfies OwlObjectProperty;

/**
 * _productReference
 *
 * (Modified) InventoryItem.productReference
 *
 * http://hl7.org/fhir/_productReference
 */
export const _productReference = 'http://hl7.org/fhir/_productReference' satisfies OwlObjectProperty;

/**
 * payment
 *
 * ClaimResponse.payment: Payment details for the adjudication of the claim.
 *
 * http://hl7.org/fhir/payment
 */
export const payment = 'http://hl7.org/fhir/payment' satisfies OwlObjectProperty;

/**
 * rateAggregation
 *
 * Measure.group.rateAggregation: Describes how to combine the information calculated, based on logic in each of several populations, into one summarized result.
 *
 * http://hl7.org/fhir/rateAggregation
 */
export const rateAggregation = 'http://hl7.org/fhir/rateAggregation' satisfies OwlObjectProperty;

/**
 * OrganizationQualificationComponent
 *
 * OrganizationQualificationComponent: The official certifications, accreditations, training, designations and licenses that authorize and/or otherwise endorse the provision of care by the organization.

For example, an approval to provide a type of services issued by a certifying body (such as the US Joint Commission) to an organization.
 *
 * http://hl7.org/fhir/OrganizationQualificationComponent
 */
export const OrganizationQualificationComponent = 'http://hl7.org/fhir/OrganizationQualificationComponent' satisfies OwlClass;

/**
 * identityCertificate
 *
 * VerificationResult.validator.identityCertificate: A digital identity certificate associated with the validator.
 *
 * http://hl7.org/fhir/identityCertificate
 */
export const identityCertificate = 'http://hl7.org/fhir/identityCertificate' satisfies OwlObjectProperty;

/**
 * _subDetail
 *
 * (Modified) ExplanationOfBenefit.addItem.detail.subDetail
 *
 * http://hl7.org/fhir/_subDetail
 */
export const _subDetail = 'http://hl7.org/fhir/_subDetail' satisfies OwlObjectProperty;

/**
 * contextInvariant
 *
 * StructureDefinition.contextInvariant: A set of rules as FHIRPath Invariants about when the extension can be used (e.g. co-occurrence variants for the extension). All the rules must be true.
 *
 * http://hl7.org/fhir/contextInvariant
 */
export const contextInvariant = 'http://hl7.org/fhir/contextInvariant' satisfies OwlObjectProperty;

/**
 * _suffix
 *
 * (Modified) HumanName.suffix
 *
 * http://hl7.org/fhir/_suffix
 */
export const _suffix = 'http://hl7.org/fhir/_suffix' satisfies OwlObjectProperty;

/**
 * _recurrenceId
 *
 * (Modified) AppointmentResponse.recurrenceId
 *
 * http://hl7.org/fhir/_recurrenceId
 */
export const _recurrenceId = 'http://hl7.org/fhir/_recurrenceId' satisfies OwlObjectProperty;

/**
 * dispenseInterval
 *
 * MedicationRequest.dispenseRequest.dispenseInterval: The minimum period of time that must occur between dispenses of the medication.
 *
 * http://hl7.org/fhir/dispenseInterval
 */
export const dispenseInterval = 'http://hl7.org/fhir/dispenseInterval' satisfies OwlObjectProperty;

/**
 * _map
 *
 * (Modified) ElementDefinition.mapping.map
 *
 * http://hl7.org/fhir/_map
 */
export const _map = 'http://hl7.org/fhir/_map' satisfies OwlObjectProperty;

/**
 * _lensSpecification
 *
 * (Modified) VisionPrescription.lensSpecification
 *
 * http://hl7.org/fhir/_lensSpecification
 */
export const _lensSpecification = 'http://hl7.org/fhir/_lensSpecification' satisfies OwlObjectProperty;

/**
 * allergyIntolerance
 *
 * NutritionOrder.allergyIntolerance: A link to a record of allergies or intolerances  which should be included in the nutrition order.
 *
 * http://hl7.org/fhir/allergyIntolerance
 */
export const allergyIntolerance = 'http://hl7.org/fhir/allergyIntolerance' satisfies OwlObjectProperty;

/**
 * asset
 *
 * Contract.term.group.asset: Contract Term Asset List.
 *
 * http://hl7.org/fhir/asset
 */
export const asset = 'http://hl7.org/fhir/asset' satisfies OwlObjectProperty;

/**
 * CoverageEligibilityResponse
 *
 * This resource provides eligibility and plan details from the processing of an CoverageEligibilityRequest resource.
 *
 * http://hl7.org/fhir/CoverageEligibilityResponse
 */
export const CoverageEligibilityResponse = 'http://hl7.org/fhir/CoverageEligibilityResponse' satisfies OwlClass;

/**
 * OperationDefinitionParameterComponentParameter
 *
 * The parts of a nested Parameter.
 *
 * http://hl7.org/fhir/OperationDefinitionParameterComponentParameter
 */
export const OperationDefinitionParameterComponentParameter = 'http://hl7.org/fhir/OperationDefinitionParameterComponentParameter' satisfies OwlClass;

/**
 * packagedMedicinalProduct
 *
 * MedicinalProductDefinition.packagedMedicinalProduct: Package type for the product. See also the PackagedProductDefinition resource.
 *
 * http://hl7.org/fhir/packagedMedicinalProduct
 */
export const packagedMedicinalProduct = 'http://hl7.org/fhir/packagedMedicinalProduct' satisfies OwlObjectProperty;

/**
 * _count
 *
 * (Modified) DeviceDefinition.packaging.packaging.count
 *
 * http://hl7.org/fhir/_count
 */
export const _count = 'http://hl7.org/fhir/_count' satisfies OwlObjectProperty;

/**
 * SubstancePolymerRepeatRepeatUnitDegreeOfPolymerisationComponent
 *
 * SubstancePolymerRepeatComponent.SubstancePolymerRepeatRepeatUnitComponent.SubstancePolymerRepeatRepeatUnitDegreeOfPolymerisationComponent: Applies to homopolymer and block co-polymers where the degree of polymerisation within a block can be described.
 *
 * http://hl7.org/fhir/SubstancePolymerRepeatRepeatUnitDegreeOfPolymerisationComponent
 */
export const SubstancePolymerRepeatRepeatUnitDegreeOfPolymerisationComponent = 'http://hl7.org/fhir/SubstancePolymerRepeatRepeatUnitDegreeOfPolymerisationComponent' satisfies OwlClass;

/**
 * adjudication
 *
 * ExplanationOfBenefit.adjudication: The adjudication results which are presented at the header level rather than at the line-item or add-item levels.
 *
 * http://hl7.org/fhir/adjudication
 */
export const adjudication = 'http://hl7.org/fhir/adjudication' satisfies OwlObjectProperty;

/**
 * RequestOrchestrationActionConditionComponent
 *
 * RequestOrchestrationActionComponentAction.RequestOrchestrationActionConditionComponent: An expression that describes applicability criteria, or start/stop conditions for the action.
 *
 * http://hl7.org/fhir/RequestOrchestrationActionConditionComponent
 */
export const RequestOrchestrationActionConditionComponent = 'http://hl7.org/fhir/RequestOrchestrationActionConditionComponent' satisfies OwlClass;

/**
 * validator
 *
 * VerificationResult.validator: Information about the entity validating information.
 *
 * http://hl7.org/fhir/validator
 */
export const validator = 'http://hl7.org/fhir/validator' satisfies OwlObjectProperty;

/**
 * _gene
 *
 * (Modified) SubstanceReferenceInformation.gene.gene
 *
 * http://hl7.org/fhir/_gene
 */
export const _gene = 'http://hl7.org/fhir/_gene' satisfies OwlObjectProperty;

/**
 * _length
 *
 * (Modified) SubstanceProtein.subunit.length
 *
 * http://hl7.org/fhir/_length
 */
export const _length = 'http://hl7.org/fhir/_length' satisfies OwlObjectProperty;

/**
 * series
 *
 * ImmunizationEvaluation.series: One possible path to achieve presumed immunity against a disease - within the context of an authority.
 *
 * http://hl7.org/fhir/series
 */
export const series = 'http://hl7.org/fhir/series' satisfies OwlObjectProperty;

/**
 * maxDosePerAdministration
 *
 * Dosage.maxDosePerAdministration: Upper limit on medication per administration.
 *
 * http://hl7.org/fhir/maxDosePerAdministration
 */
export const maxDosePerAdministration = 'http://hl7.org/fhir/maxDosePerAdministration' satisfies OwlObjectProperty;

/**
 * _performerRole
 *
 * (Modified) Contract.term.group.action.performerRole
 *
 * http://hl7.org/fhir/_performerRole
 */
export const _performerRole = 'http://hl7.org/fhir/_performerRole' satisfies OwlObjectProperty;

/**
 * _balance
 *
 * (Modified) Account.balance
 *
 * http://hl7.org/fhir/_balance
 */
export const _balance = 'http://hl7.org/fhir/_balance' satisfies OwlObjectProperty;

/**
 * _correctiveAction
 *
 * (Modified) DeviceDefinition.correctiveAction
 *
 * http://hl7.org/fhir/_correctiveAction
 */
export const _correctiveAction = 'http://hl7.org/fhir/_correctiveAction' satisfies OwlObjectProperty;

/**
 * dispenser
 *
 * MedicationRequest.dispenseRequest.dispenser: Indicates the intended performing Organization that will dispense the medication as specified by the prescriber.
 *
 * http://hl7.org/fhir/dispenser
 */
export const dispenser = 'http://hl7.org/fhir/dispenser' satisfies OwlObjectProperty;

/**
 * NutritionOrderOralDietComponent
 *
 * NutritionOrderOralDietComponent: Diet given orally in contrast to enteral (tube) feeding.
 *
 * http://hl7.org/fhir/NutritionOrderOralDietComponent
 */
export const NutritionOrderOralDietComponent = 'http://hl7.org/fhir/NutritionOrderOralDietComponent' satisfies OwlClass;

/**
 * _meaning
 *
 * (Modified) Permission.rule.data.resource.meaning
 *
 * http://hl7.org/fhir/_meaning
 */
export const _meaning = 'http://hl7.org/fhir/_meaning' satisfies OwlObjectProperty;

/**
 * endParam
 *
 * CompartmentDefinition.resource.endParam: Search Parameter for mapping requests made with $everything.end (e.g. on [Patient.$everything](patient-operation-everything.html)).
 *
 * http://hl7.org/fhir/endParam
 */
export const endParam = 'http://hl7.org/fhir/endParam' satisfies OwlObjectProperty;

/**
 * _provider
 *
 * (Modified) CoverageEligibilityRequest.item.provider
 *
 * http://hl7.org/fhir/_provider
 */
export const _provider = 'http://hl7.org/fhir/_provider' satisfies OwlObjectProperty;

/**
 * inResponseTo
 *
 * Communication.inResponseTo: Prior communication that this communication is in response to.
 *
 * http://hl7.org/fhir/inResponseTo
 */
export const inResponseTo = 'http://hl7.org/fhir/inResponseTo' satisfies OwlObjectProperty;

/**
 * authorDescription
 *
 * SubstanceSourceMaterial.organism.author.authorDescription: The author of an organism species shall be specified. The author year of an organism shall also be specified when applicable; refers to the year in which the first author(s) published the infraspecific plant/animal name (of any rank).
 *
 * http://hl7.org/fhir/authorDescription
 */
export const authorDescription = 'http://hl7.org/fhir/authorDescription' satisfies OwlObjectProperty;

/**
 * _intendedExposure
 *
 * (Modified) ResearchStudy.comparisonGroup.intendedExposure
 *
 * http://hl7.org/fhir/_intendedExposure
 */
export const _intendedExposure = 'http://hl7.org/fhir/_intendedExposure' satisfies OwlObjectProperty;

/**
 * _cycle
 *
 * (Modified) Device.cycle
 *
 * http://hl7.org/fhir/_cycle
 */
export const _cycle = 'http://hl7.org/fhir/_cycle' satisfies OwlObjectProperty;

/**
 * ProvenanceEntityComponentAgent
 *
 * The entity is attributed to an agent to express the agent's responsibility for that entity, possibly along with other agents. This description can be understood as shorthand for saying that the agent was responsible for the activity which used the entity.
 *
 * http://hl7.org/fhir/ProvenanceEntityComponentAgent
 */
export const ProvenanceEntityComponentAgent = 'http://hl7.org/fhir/ProvenanceEntityComponentAgent' satisfies OwlClass;

/**
 * high
 *
 * Range.high: The high limit. The boundary is inclusive.
 *
 * http://hl7.org/fhir/high
 */
export const high = 'http://hl7.org/fhir/high' satisfies OwlObjectProperty;

/**
 * _paymentStatus
 *
 * (Modified) PaymentNotice.paymentStatus
 *
 * http://hl7.org/fhir/_paymentStatus
 */
export const _paymentStatus = 'http://hl7.org/fhir/_paymentStatus' satisfies OwlObjectProperty;

/**
 * TestScriptVariableComponent
 *
 * TestScriptVariableComponent: Variable is set based either on element value in response body or on header field value in the response headers.
 *
 * http://hl7.org/fhir/TestScriptVariableComponent
 */
export const TestScriptVariableComponent = 'http://hl7.org/fhir/TestScriptVariableComponent' satisfies OwlClass;

/**
 * _comparator
 *
 * (Modified) SubstanceDefinition.relationship.comparator
 *
 * http://hl7.org/fhir/_comparator
 */
export const _comparator = 'http://hl7.org/fhir/_comparator' satisfies OwlObjectProperty;

/**
 * _instantiatesCanonical
 *
 * (Modified) Transport.instantiatesCanonical
 *
 * http://hl7.org/fhir/_instantiatesCanonical
 */
export const _instantiatesCanonical = 'http://hl7.org/fhir/_instantiatesCanonical' satisfies OwlObjectProperty;

/**
 * class
 *
 * EncounterHistory.class: Concepts representing classification of patient encounter such as ambulatory (outpatient), inpatient, emergency, home health or others due to local variations.
 * Note that `class` is a reserved Javascript keyword, and is therefore suffixed by `__workaround`.
 * For a list of reserved keywords, see https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Lexical_grammar#Keywords.
 *
 * http://hl7.org/fhir/class
 */
export const class__workaround = 'http://hl7.org/fhir/class' satisfies OwlObjectProperty;

/**
 * _countryOfOrigin
 *
 * (Modified) SubstanceSourceMaterial.countryOfOrigin
 *
 * http://hl7.org/fhir/_countryOfOrigin
 */
export const _countryOfOrigin = 'http://hl7.org/fhir/_countryOfOrigin' satisfies OwlObjectProperty;

/**
 * structuralRepresentation
 *
 * SubstancePolymer.repeat.repeatUnit.structuralRepresentation: A graphical structure for this SRU.
 *
 * http://hl7.org/fhir/structuralRepresentation
 */
export const structuralRepresentation = 'http://hl7.org/fhir/structuralRepresentation' satisfies OwlObjectProperty;

/**
 * _communicationMethod
 *
 * (Modified) VerificationResult.attestation.communicationMethod
 *
 * http://hl7.org/fhir/_communicationMethod
 */
export const _communicationMethod = 'http://hl7.org/fhir/_communicationMethod' satisfies OwlObjectProperty;

/**
 * _size
 *
 * (Modified) Attachment.size
 *
 * http://hl7.org/fhir/_size
 */
export const _size = 'http://hl7.org/fhir/_size' satisfies OwlObjectProperty;

/**
 * _averageMolecularFormula
 *
 * (Modified) SubstancePolymer.repeat.averageMolecularFormula
 *
 * http://hl7.org/fhir/_averageMolecularFormula
 */
export const _averageMolecularFormula = 'http://hl7.org/fhir/_averageMolecularFormula' satisfies OwlObjectProperty;

/**
 * _ingredientLabel
 *
 * (Modified) NutritionIntake.ingredientLabel
 *
 * http://hl7.org/fhir/_ingredientLabel
 */
export const _ingredientLabel = 'http://hl7.org/fhir/_ingredientLabel' satisfies OwlObjectProperty;

/**
 * _landmarkDescription
 *
 * (Modified) BodyStructure.excludedStructure.bodyLandmarkOrientation.landmarkDescription
 *
 * http://hl7.org/fhir/_landmarkDescription
 */
export const _landmarkDescription = 'http://hl7.org/fhir/_landmarkDescription' satisfies OwlObjectProperty;

/**
 * _criticalCodedValueSet
 *
 * (Modified) ObservationDefinition.component.qualifiedValue.criticalCodedValueSet
 *
 * http://hl7.org/fhir/_criticalCodedValueSet
 */
export const _criticalCodedValueSet = 'http://hl7.org/fhir/_criticalCodedValueSet' satisfies OwlObjectProperty;

/**
 * unmapped
 *
 * ConceptMap.group.unmapped: What to do when there is no mapping to a target concept from the source concept and ConceptMap.group.element.noMap is not true. This provides the "default" to be applied when there is no target concept mapping specified or the expansion of ConceptMap.group.element.target.valueSet is empty.
 *
 * http://hl7.org/fhir/unmapped
 */
export const unmapped = 'http://hl7.org/fhir/unmapped' satisfies OwlObjectProperty;

/**
 * _productCategory
 *
 * (Modified) BiologicallyDerivedProduct.productCategory
 *
 * http://hl7.org/fhir/_productCategory
 */
export const _productCategory = 'http://hl7.org/fhir/_productCategory' satisfies OwlObjectProperty;

/**
 * SubstanceReferenceInformationTargetComponent
 *
 * SubstanceReferenceInformationTargetComponent: Todo.
 *
 * http://hl7.org/fhir/SubstanceReferenceInformationTargetComponent
 */
export const SubstanceReferenceInformationTargetComponent = 'http://hl7.org/fhir/SubstanceReferenceInformationTargetComponent' satisfies OwlClass;

/**
 * _preferredReportName
 *
 * (Modified) ObservationDefinition.preferredReportName
 *
 * http://hl7.org/fhir/_preferredReportName
 */
export const _preferredReportName = 'http://hl7.org/fhir/_preferredReportName' satisfies OwlObjectProperty;

/**
 * _maternalOrganismId
 *
 * (Modified) SubstanceSourceMaterial.organism.hybrid.maternalOrganismId
 *
 * http://hl7.org/fhir/_maternalOrganismId
 */
export const _maternalOrganismId = 'http://hl7.org/fhir/_maternalOrganismId' satisfies OwlObjectProperty;

/**
 * _order
 *
 * (Modified) SubstanceSourceMaterial.organism.organismGeneral.order
 *
 * http://hl7.org/fhir/_order
 */
export const _order = 'http://hl7.org/fhir/_order' satisfies OwlObjectProperty;

/**
 * qualifier
 *
 * BodyStructure.excludedStructure.qualifier: Code that represents the included structure qualifier.
 *
 * http://hl7.org/fhir/qualifier
 */
export const qualifier = 'http://hl7.org/fhir/qualifier' satisfies OwlObjectProperty;

/**
 * recruitment
 *
 * ResearchStudy.recruitment: Target or actual group of participants enrolled in study.
 *
 * http://hl7.org/fhir/recruitment
 */
export const recruitment = 'http://hl7.org/fhir/recruitment' satisfies OwlObjectProperty;

/**
 * mitigation
 *
 * RiskAssessment.mitigation: A description of the steps that might be taken to reduce the identified risk(s).
 *
 * http://hl7.org/fhir/mitigation
 */
export const mitigation = 'http://hl7.org/fhir/mitigation' satisfies OwlObjectProperty;

/**
 * Procedure
 *
 * An action that is or was performed on or for a patient, practitioner, device, organization, or location. For example, this can be a physical intervention on a patient like an operation, or less invasive like long term services, counseling, or hypnotherapy.  This can be a quality or safety inspection for a location, organization, or device.  This can be an accreditation procedure on a practitioner for licensing.
 *
 * http://hl7.org/fhir/Procedure
 */
export const Procedure = 'http://hl7.org/fhir/Procedure' satisfies OwlClass;

/**
 * material
 *
 * PackagedProductDefinition.packaging.material: Material type of the package item.
 *
 * http://hl7.org/fhir/material
 */
export const material = 'http://hl7.org/fhir/material' satisfies OwlObjectProperty;

/**
 * _packageId
 *
 * (Modified) ImplementationGuide.dependsOn.packageId
 *
 * http://hl7.org/fhir/_packageId
 */
export const _packageId = 'http://hl7.org/fhir/_packageId' satisfies OwlObjectProperty;

/**
 * address
 *
 * Practitioner.address: Address(es) of the practitioner that are not role specific (typically home address). 
Work addresses are not typically entered in this property as they are usually role dependent.
 *
 * http://hl7.org/fhir/address
 */
export const address = 'http://hl7.org/fhir/address' satisfies OwlObjectProperty;

/**
 * module
 *
 * GuidanceResponse.module
 *
 * http://hl7.org/fhir/module
 */
export const module = 'http://hl7.org/fhir/module' satisfies OwlObjectProperty;

/**
 * SubstanceNucleicAcidSubunitComponent
 *
 * SubstanceNucleicAcidSubunitComponent: Subunits are listed in order of decreasing length; sequences of the same length will be ordered by molecular weight; subunits that have identical sequences will be repeated multiple times.
 *
 * http://hl7.org/fhir/SubstanceNucleicAcidSubunitComponent
 */
export const SubstanceNucleicAcidSubunitComponent = 'http://hl7.org/fhir/SubstanceNucleicAcidSubunitComponent' satisfies OwlClass;

/**
 * _healthcareService
 *
 * (Modified) PractitionerRole.healthcareService
 *
 * http://hl7.org/fhir/_healthcareService
 */
export const _healthcareService = 'http://hl7.org/fhir/_healthcareService' satisfies OwlObjectProperty;

/**
 * check
 *
 * StructureMap.group.rule.rule.source.check: FHIRPath expression  - must be true or the mapping engine throws an error instead of completing.
 *
 * http://hl7.org/fhir/check
 */
export const check = 'http://hl7.org/fhir/check' satisfies OwlObjectProperty;

/**
 * _serviceProvisionCode
 *
 * (Modified) HealthcareService.serviceProvisionCode
 *
 * http://hl7.org/fhir/_serviceProvisionCode
 */
export const _serviceProvisionCode = 'http://hl7.org/fhir/_serviceProvisionCode' satisfies OwlObjectProperty;

/**
 * DeviceDefinitionHasPartComponent
 *
 * DeviceDefinitionHasPartComponent: A device that is part (for example a component) of the present device.
 *
 * http://hl7.org/fhir/DeviceDefinitionHasPartComponent
 */
export const DeviceDefinitionHasPartComponent = 'http://hl7.org/fhir/DeviceDefinitionHasPartComponent' satisfies OwlClass;

/**
 * hybrid
 *
 * SubstanceSourceMaterial.organism.hybrid: 4.9.13.8.1 Hybrid species maternal organism ID (Optional).
 *
 * http://hl7.org/fhir/hybrid
 */
export const hybrid = 'http://hl7.org/fhir/hybrid' satisfies OwlObjectProperty;

/**
 * DeviceDefinitionPackagingComponentPackaging
 *
 * Allows packages within packages.
 *
 * http://hl7.org/fhir/DeviceDefinitionPackagingComponentPackaging
 */
export const DeviceDefinitionPackagingComponentPackaging = 'http://hl7.org/fhir/DeviceDefinitionPackagingComponentPackaging' satisfies OwlClass;

/**
 * extends
 *
 * StructureMap.group.extends: Another group that this group adds rules to.
 * Note that `extends` is a reserved Javascript keyword, and is therefore suffixed by `__workaround`.
 * For a list of reserved keywords, see https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Lexical_grammar#Keywords.
 *
 * http://hl7.org/fhir/extends
 */
export const extends__workaround = 'http://hl7.org/fhir/extends' satisfies OwlObjectProperty;

/**
 * AdverseEventSupportingInfoComponent
 *
 * AdverseEventSupportingInfoComponent: Supporting information relevant to the event.
 *
 * http://hl7.org/fhir/AdverseEventSupportingInfoComponent
 */
export const AdverseEventSupportingInfoComponent = 'http://hl7.org/fhir/AdverseEventSupportingInfoComponent' satisfies OwlClass;

/**
 * _MedicationRequest
 *
 * (Modified) MedicationRequest
 *
 * http://hl7.org/fhir/_MedicationRequest
 */
export const _MedicationRequest = 'http://hl7.org/fhir/_MedicationRequest' satisfies OwlClass;

/**
 * startingSequence
 *
 * MolecularSequence.relative.startingSequence: A sequence that is used as a starting sequence to describe variants that are present in a sequence analyzed.
 *
 * http://hl7.org/fhir/startingSequence
 */
export const startingSequence = 'http://hl7.org/fhir/startingSequence' satisfies OwlObjectProperty;

/**
 * MedicationKnowledgeMonographComponent
 *
 * MedicationKnowledgeMonographComponent: Associated documentation about the medication.
 *
 * http://hl7.org/fhir/MedicationKnowledgeMonographComponent
 */
export const MedicationKnowledgeMonographComponent = 'http://hl7.org/fhir/MedicationKnowledgeMonographComponent' satisfies OwlClass;

/**
 * DetectedIssue
 *
 * Indicates an actual or potential clinical issue with or between one or more active or proposed clinical actions for a patient; e.g. Drug-drug interaction, Ineffective treatment frequency, Procedure-condition conflict, gaps in care, etc.
 *
 * http://hl7.org/fhir/DetectedIssue
 */
export const DetectedIssue = 'http://hl7.org/fhir/DetectedIssue' satisfies OwlClass;

/**
 * targetLocation
 *
 * VerificationResult.targetLocation: The fhirpath location(s) within the resource that was validated.
 *
 * http://hl7.org/fhir/targetLocation
 */
export const targetLocation = 'http://hl7.org/fhir/targetLocation' satisfies OwlObjectProperty;

/**
 * MedicinalProductDefinitionCrossReferenceComponent
 *
 * MedicinalProductDefinitionCrossReferenceComponent: Reference to another product, e.g. for linking authorised to investigational product, or a virtual product.
 *
 * http://hl7.org/fhir/MedicinalProductDefinitionCrossReferenceComponent
 */
export const MedicinalProductDefinitionCrossReferenceComponent = 'http://hl7.org/fhir/MedicinalProductDefinitionCrossReferenceComponent' satisfies OwlClass;

/**
 * _alternateMaterial
 *
 * (Modified) PackagedProductDefinition.packaging.packaging.alternateMaterial
 *
 * http://hl7.org/fhir/_alternateMaterial
 */
export const _alternateMaterial = 'http://hl7.org/fhir/_alternateMaterial' satisfies OwlObjectProperty;

/**
 * _ordered
 *
 * (Modified) ElementDefinition.slicing.ordered
 *
 * http://hl7.org/fhir/_ordered
 */
export const _ordered = 'http://hl7.org/fhir/_ordered' satisfies OwlObjectProperty;

/**
 * _List
 *
 * (Modified) List
 *
 * http://hl7.org/fhir/_List
 */
export const _List = 'http://hl7.org/fhir/_List' satisfies OwlClass;

/**
 * _gateway
 *
 * (Modified) Device.gateway
 *
 * http://hl7.org/fhir/_gateway
 */
export const _gateway = 'http://hl7.org/fhir/_gateway' satisfies OwlObjectProperty;

/**
 * _effect
 *
 * (Modified) ClinicalUseDefinition.interaction.effect
 *
 * http://hl7.org/fhir/_effect
 */
export const _effect = 'http://hl7.org/fhir/_effect' satisfies OwlObjectProperty;

/**
 * _coordinate
 *
 * (Modified) ImagingSelection.instance.imageRegion3D.coordinate
 *
 * http://hl7.org/fhir/_coordinate
 */
export const _coordinate = 'http://hl7.org/fhir/_coordinate' satisfies OwlObjectProperty;

/**
 * case
 *
 * RegulatedAuthorization.case: The case or regulatory procedure for granting or amending a regulated authorization. An authorization is granted in response to submissions/applications by those seeking authorization. A case is the administrative process that deals with the application(s) that relate to this and assesses them. Note: This area is subject to ongoing review and the workgroup is seeking implementer feedback on its use (see link at bottom of page).
 * Note that `case` is a reserved Javascript keyword, and is therefore suffixed by `__workaround`.
 * For a list of reserved keywords, see https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Lexical_grammar#Keywords.
 *
 * http://hl7.org/fhir/case
 */
export const case__workaround = 'http://hl7.org/fhir/case' satisfies OwlObjectProperty;

/**
 * QuestionnaireItemComponentItem
 *
 * Text, questions and other groups to be nested beneath a question or group.
 *
 * http://hl7.org/fhir/QuestionnaireItemComponentItem
 */
export const QuestionnaireItemComponentItem = 'http://hl7.org/fhir/QuestionnaireItemComponentItem' satisfies OwlClass;

/**
 * DeviceConformsToComponent
 *
 * DeviceConformsToComponent: Identifies the standards, specifications, or formal guidances for the capabilities supported by the device. The device may be certified as conformant to these specifications e.g., communication, performance, process, measurement, or specialization standards.
 *
 * http://hl7.org/fhir/DeviceConformsToComponent
 */
export const DeviceConformsToComponent = 'http://hl7.org/fhir/DeviceConformsToComponent' satisfies OwlClass;

/**
 * PatientLinkComponent
 *
 * PatientLinkComponent: Link to a Patient or RelatedPerson resource that concerns the same actual individual.
 *
 * http://hl7.org/fhir/PatientLinkComponent
 */
export const PatientLinkComponent = 'http://hl7.org/fhir/PatientLinkComponent' satisfies OwlClass;

/**
 * testData
 *
 * TestPlan.testCase.testData: The test data used in the test case.
 *
 * http://hl7.org/fhir/testData
 */
export const testData = 'http://hl7.org/fhir/testData' satisfies OwlObjectProperty;

/**
 * ProcedureFocalDeviceComponent
 *
 * ProcedureFocalDeviceComponent: A device that is implanted, removed or otherwise manipulated (calibration, battery replacement, fitting a prosthesis, attaching a wound-vac, etc.) as a focal portion of the Procedure.
 *
 * http://hl7.org/fhir/ProcedureFocalDeviceComponent
 */
export const ProcedureFocalDeviceComponent = 'http://hl7.org/fhir/ProcedureFocalDeviceComponent' satisfies OwlClass;

/**
 * _typeCanonical
 *
 * (Modified) RequestOrchestration.action.action.participant.typeCanonical
 *
 * http://hl7.org/fhir/_typeCanonical
 */
export const _typeCanonical = 'http://hl7.org/fhir/_typeCanonical' satisfies OwlObjectProperty;

/**
 * nodeId
 *
 * GraphDefinition.node.nodeId: Internal ID of node - target for link references.
 *
 * http://hl7.org/fhir/nodeId
 */
export const nodeId = 'http://hl7.org/fhir/nodeId' satisfies OwlObjectProperty;

/**
 * CapabilityStatementSoftwareComponent
 *
 * CapabilityStatementSoftwareComponent: Software that is covered by this capability statement.  It is used when the capability statement describes the capabilities of a particular software version, independent of an installation.
 *
 * http://hl7.org/fhir/CapabilityStatementSoftwareComponent
 */
export const CapabilityStatementSoftwareComponent = 'http://hl7.org/fhir/CapabilityStatementSoftwareComponent' satisfies OwlClass;

/**
 * _preparation
 *
 * (Modified) SpecimenDefinition.typeTested.container.preparation
 *
 * http://hl7.org/fhir/_preparation
 */
export const _preparation = 'http://hl7.org/fhir/_preparation' satisfies OwlObjectProperty;

/**
 * _subType
 *
 * (Modified) ExplanationOfBenefit.subType
 *
 * http://hl7.org/fhir/_subType
 */
export const _subType = 'http://hl7.org/fhir/_subType' satisfies OwlObjectProperty;

/**
 * _definitionCodeableConcept
 *
 * (Modified) EvidenceVariable.characteristic.definitionByCombination.characteristic.definitionCodeableConcept
 *
 * http://hl7.org/fhir/_definitionCodeableConcept
 */
export const _definitionCodeableConcept = 'http://hl7.org/fhir/_definitionCodeableConcept' satisfies OwlObjectProperty;

/**
 * benefitBalance
 *
 * ExplanationOfBenefit.benefitBalance: Balance by Benefit Category.
 *
 * http://hl7.org/fhir/benefitBalance
 */
export const benefitBalance = 'http://hl7.org/fhir/benefitBalance' satisfies OwlObjectProperty;

/**
 * exclusionCriteria
 *
 * ValueSet.scope.exclusionCriteria: Criteria describing which concepts or codes should be excluded and why.
 *
 * http://hl7.org/fhir/exclusionCriteria
 */
export const exclusionCriteria = 'http://hl7.org/fhir/exclusionCriteria' satisfies OwlObjectProperty;

/**
 * numberOfStudies
 *
 * Evidence.statistic.sampleSize.numberOfStudies: Number of participants in the population.
 *
 * http://hl7.org/fhir/numberOfStudies
 */
export const numberOfStudies = 'http://hl7.org/fhir/numberOfStudies' satisfies OwlObjectProperty;

/**
 * start
 *
 * MolecularSequence.relative.edit.start: Start position of the edit on the starting sequence. If the coordinate system is either 0-based or 1-based, then start position is inclusive.
 *
 * http://hl7.org/fhir/start
 */
export const start = 'http://hl7.org/fhir/start' satisfies OwlObjectProperty;

/**
 * AccountRelatedAccountComponent
 *
 * AccountRelatedAccountComponent: Other associated accounts related to this account.
 *
 * http://hl7.org/fhir/AccountRelatedAccountComponent
 */
export const AccountRelatedAccountComponent = 'http://hl7.org/fhir/AccountRelatedAccountComponent' satisfies OwlClass;

/**
 * _OperationOutcome
 *
 * (Modified) OperationOutcome
 *
 * http://hl7.org/fhir/_OperationOutcome
 */
export const _OperationOutcome = 'http://hl7.org/fhir/_OperationOutcome' satisfies OwlClass;

/**
 * orientation
 *
 * SubstancePolymer.repeat.repeatUnit.orientation: The orientation of the polymerisation, e.g. head-tail, head-head, random.
 *
 * http://hl7.org/fhir/orientation
 */
export const orientation = 'http://hl7.org/fhir/orientation' satisfies OwlObjectProperty;

/**
 * holder
 *
 * RegulatedAuthorization.holder: The organization that has been granted this authorization, by some authoritative body (the 'regulator').
 *
 * http://hl7.org/fhir/holder
 */
export const holder = 'http://hl7.org/fhir/holder' satisfies OwlObjectProperty;

/**
 * _mitigatingAction
 *
 * (Modified) AdverseEvent.mitigatingAction
 *
 * http://hl7.org/fhir/_mitigatingAction
 */
export const _mitigatingAction = 'http://hl7.org/fhir/_mitigatingAction' satisfies OwlObjectProperty;

/**
 * include
 *
 * ValueSet.compose.include: Include one or more codes from a code system or other value set(s).
 *
 * http://hl7.org/fhir/include
 */
export const include = 'http://hl7.org/fhir/include' satisfies OwlObjectProperty;

/**
 * _conditionalPatch
 *
 * (Modified) CapabilityStatement.rest.resource.conditionalPatch
 *
 * http://hl7.org/fhir/_conditionalPatch
 */
export const _conditionalPatch = 'http://hl7.org/fhir/_conditionalPatch' satisfies OwlObjectProperty;

/**
 * NamingSystemUniqueIdComponent
 *
 * NamingSystemUniqueIdComponent: Indicates how the system may be identified when referenced in electronic exchange.
 *
 * http://hl7.org/fhir/NamingSystemUniqueIdComponent
 */
export const NamingSystemUniqueIdComponent = 'http://hl7.org/fhir/NamingSystemUniqueIdComponent' satisfies OwlClass;

/**
 * _threshold
 *
 * (Modified) EvidenceVariable.characteristic.definitionByCombination.characteristic.definitionByCombination.threshold
 *
 * http://hl7.org/fhir/_threshold
 */
export const _threshold = 'http://hl7.org/fhir/_threshold' satisfies OwlObjectProperty;

/**
 * Count
 *
 * A measured amount (or an amount that can potentially be measured). Note that measured amounts include amounts that are not precisely quantified, including amounts involving arbitrary units and floating currencies.
 *
 * http://hl7.org/fhir/Count
 */
export const Count = 'http://hl7.org/fhir/Count' satisfies OwlClass;

/**
 * _instantiates
 *
 * (Modified) Observation.instantiates
 *
 * http://hl7.org/fhir/_instantiates
 */
export const _instantiates = 'http://hl7.org/fhir/_instantiates' satisfies OwlObjectProperty;

/**
 * media
 *
 * DiagnosticReport.media: A list of key images or data associated with this report. The images or data are generally created during the diagnostic process, and may be directly of the patient, or of treated specimens (i.e. slides of interest).
 *
 * http://hl7.org/fhir/media
 */
export const media = 'http://hl7.org/fhir/media' satisfies OwlObjectProperty;

/**
 * appliesTo
 *
 * Observation.component.referenceRange.appliesTo: Codes to indicate the target population this reference range applies to.  For example, a reference range may be based on the normal population or a particular sex or race.  Multiple `appliesTo`  are interpreted as an "AND" of the target populations.  For example, to represent a target population of African American females, both a code of female and a code for African American would be used.
 *
 * http://hl7.org/fhir/appliesTo
 */
export const appliesTo = 'http://hl7.org/fhir/appliesTo' satisfies OwlObjectProperty;

/**
 * _implementationGuide
 *
 * (Modified) CapabilityStatement.implementationGuide
 *
 * http://hl7.org/fhir/_implementationGuide
 */
export const _implementationGuide = 'http://hl7.org/fhir/_implementationGuide' satisfies OwlObjectProperty;

/**
 * RequestOrchestrationActionInputComponent
 *
 * RequestOrchestrationActionComponentAction.RequestOrchestrationActionInputComponent: Defines input data requirements for the action.
 *
 * http://hl7.org/fhir/RequestOrchestrationActionInputComponent
 */
export const RequestOrchestrationActionInputComponent = 'http://hl7.org/fhir/RequestOrchestrationActionInputComponent' satisfies OwlClass;

/**
 * _discriminator
 *
 * (Modified) ElementDefinition.slicing.discriminator
 *
 * http://hl7.org/fhir/_discriminator
 */
export const _discriminator = 'http://hl7.org/fhir/_discriminator' satisfies OwlObjectProperty;

/**
 * ClaimResponse
 *
 * This resource provides the adjudication details from the processing of a Claim resource.
 *
 * http://hl7.org/fhir/ClaimResponse
 */
export const ClaimResponse = 'http://hl7.org/fhir/ClaimResponse' satisfies OwlClass;

/**
 * section
 *
 * EvidenceReport.section.section.section: A nested sub-section within this section.
 *
 * http://hl7.org/fhir/section
 */
export const section = 'http://hl7.org/fhir/section' satisfies OwlObjectProperty;

/**
 * _workflowStatus
 *
 * (Modified) ArtifactAssessment.workflowStatus
 *
 * http://hl7.org/fhir/_workflowStatus
 */
export const _workflowStatus = 'http://hl7.org/fhir/_workflowStatus' satisfies OwlObjectProperty;

/**
 * _DeviceMetric
 *
 * (Modified) DeviceMetric
 *
 * http://hl7.org/fhir/_DeviceMetric
 */
export const _DeviceMetric = 'http://hl7.org/fhir/_DeviceMetric' satisfies OwlClass;

/**
 * diseaseSymptomProcedure
 *
 * ClinicalUseDefinition.indication.diseaseSymptomProcedure: The situation that is being documented as an indicaton for this item.
 *
 * http://hl7.org/fhir/diseaseSymptomProcedure
 */
export const diseaseSymptomProcedure = 'http://hl7.org/fhir/diseaseSymptomProcedure' satisfies OwlObjectProperty;

/**
 * _keyword
 *
 * (Modified) StructureDefinition.keyword
 *
 * http://hl7.org/fhir/_keyword
 */
export const _keyword = 'http://hl7.org/fhir/_keyword' satisfies OwlObjectProperty;

/**
 * _forecastStatus
 *
 * (Modified) ImmunizationRecommendation.recommendation.forecastStatus
 *
 * http://hl7.org/fhir/_forecastStatus
 */
export const _forecastStatus = 'http://hl7.org/fhir/_forecastStatus' satisfies OwlObjectProperty;

/**
 * Bundle
 *
 * A container for a collection of resources.
 *
 * http://hl7.org/fhir/Bundle
 */
export const Bundle = 'http://hl7.org/fhir/Bundle' satisfies OwlClass;

/**
 * _excluded
 *
 * (Modified) ExplanationOfBenefit.benefitBalance.excluded
 *
 * http://hl7.org/fhir/_excluded
 */
export const _excluded = 'http://hl7.org/fhir/_excluded' satisfies OwlObjectProperty;

/**
 * _transform
 *
 * (Modified) StructureMap.group.rule.rule.target.transform
 *
 * http://hl7.org/fhir/_transform
 */
export const _transform = 'http://hl7.org/fhir/_transform' satisfies OwlObjectProperty;

/**
 * intent
 *
 * CarePlan.intent: Indicates the level of authority/intentionality associated with the care plan and where the care plan fits into the workflow chain.
 *
 * http://hl7.org/fhir/intent
 */
export const intent = 'http://hl7.org/fhir/intent' satisfies OwlObjectProperty;

/**
 * _slicing
 *
 * (Modified) ElementDefinition.slicing
 *
 * http://hl7.org/fhir/_slicing
 */
export const _slicing = 'http://hl7.org/fhir/_slicing' satisfies OwlObjectProperty;

/**
 * generalPractitioner
 *
 * Patient.generalPractitioner: Patient's nominated care provider.
 *
 * http://hl7.org/fhir/generalPractitioner
 */
export const generalPractitioner = 'http://hl7.org/fhir/generalPractitioner' satisfies OwlObjectProperty;

/**
 * gestationalAge
 *
 * ObservationDefinition.component.qualifiedValue.gestationalAge: The gestational age this  set of qualified values applies to.
 *
 * http://hl7.org/fhir/gestationalAge
 */
export const gestationalAge = 'http://hl7.org/fhir/gestationalAge' satisfies OwlObjectProperty;

/**
 * _account
 *
 * (Modified) PaymentReconciliation.allocation.account
 *
 * http://hl7.org/fhir/_account
 */
export const _account = 'http://hl7.org/fhir/_account' satisfies OwlObjectProperty;

/**
 * _administeredProduct
 *
 * (Modified) Immunization.administeredProduct
 *
 * http://hl7.org/fhir/_administeredProduct
 */
export const _administeredProduct = 'http://hl7.org/fhir/_administeredProduct' satisfies OwlObjectProperty;

/**
 * answerOption
 *
 * Questionnaire.item.item.answerOption: One of the permitted answers for the question.
 *
 * http://hl7.org/fhir/answerOption
 */
export const answerOption = 'http://hl7.org/fhir/answerOption' satisfies OwlObjectProperty;

/**
 * regionType
 *
 * ImagingSelection.instance.imageRegion3D.regionType: Specifies the type of image region.
 *
 * http://hl7.org/fhir/regionType
 */
export const regionType = 'http://hl7.org/fhir/regionType' satisfies OwlObjectProperty;

/**
 * _association
 *
 * (Modified) InventoryItem.association
 *
 * http://hl7.org/fhir/_association
 */
export const _association = 'http://hl7.org/fhir/_association' satisfies OwlObjectProperty;

/**
 * _messaging
 *
 * (Modified) CapabilityStatement.messaging
 *
 * http://hl7.org/fhir/_messaging
 */
export const _messaging = 'http://hl7.org/fhir/_messaging' satisfies OwlObjectProperty;

/**
 * organismType
 *
 * SubstanceReferenceInformation.target.organismType: Todo.
 *
 * http://hl7.org/fhir/organismType
 */
export const organismType = 'http://hl7.org/fhir/organismType' satisfies OwlObjectProperty;

/**
 * accept
 *
 * TestScript.teardown.action.operation.accept: The mime-type to use for RESTful operation in the 'Accept' header.
 *
 * http://hl7.org/fhir/accept
 */
export const accept = 'http://hl7.org/fhir/accept' satisfies OwlObjectProperty;

/**
 * _methodType
 *
 * (Modified) GenomicStudy.analysis.methodType
 *
 * http://hl7.org/fhir/_methodType
 */
export const _methodType = 'http://hl7.org/fhir/_methodType' satisfies OwlObjectProperty;

/**
 * _authorizationRequired
 *
 * (Modified) CoverageEligibilityResponse.insurance.item.authorizationRequired
 *
 * http://hl7.org/fhir/_authorizationRequired
 */
export const _authorizationRequired = 'http://hl7.org/fhir/_authorizationRequired' satisfies OwlObjectProperty;

/**
 * includedStructure
 *
 * BodyStructure.includedStructure: The anatomical location(s) or region(s) of the specimen, lesion, or body structure.
 *
 * http://hl7.org/fhir/includedStructure
 */
export const includedStructure = 'http://hl7.org/fhir/includedStructure' satisfies OwlObjectProperty;

/**
 * sourceIdentityCertificate
 *
 * VerificationResult.attestation.sourceIdentityCertificate: A digital identity certificate associated with the attestation source.
 *
 * http://hl7.org/fhir/sourceIdentityCertificate
 */
export const sourceIdentityCertificate = 'http://hl7.org/fhir/sourceIdentityCertificate' satisfies OwlObjectProperty;

/**
 * foodType
 *
 * NutritionOrder.oralDiet.texture.foodType: The food type(s) (e.g. meats, all foods)  that the texture modification applies to.  This could be all foods types.
 *
 * http://hl7.org/fhir/foodType
 */
export const foodType = 'http://hl7.org/fhir/foodType' satisfies OwlObjectProperty;

/**
 * temperatureRange
 *
 * SpecimenDefinition.typeTested.handling.temperatureRange: The temperature interval for this set of handling instructions.
 *
 * http://hl7.org/fhir/temperatureRange
 */
export const temperatureRange = 'http://hl7.org/fhir/temperatureRange' satisfies OwlObjectProperty;

/**
 * ManifestPage
 *
 * ImplementationGuideManifestComponent.ManifestPage: Information about a page within the IG.
 *
 * http://hl7.org/fhir/ManifestPage
 */
export const ManifestPage = 'http://hl7.org/fhir/ManifestPage' satisfies OwlClass;

/**
 * DeviceRequest
 *
 * Represents a request a device to be provided to a specific patient. The device may be an implantable device to be subsequently implanted, or an external assistive device, such as a walker, to be delivered and subsequently be used.
 *
 * http://hl7.org/fhir/DeviceRequest
 */
export const DeviceRequest = 'http://hl7.org/fhir/DeviceRequest' satisfies OwlClass;

/**
 * _contextLinkId
 *
 * (Modified) Contract.term.group.action.contextLinkId
 *
 * http://hl7.org/fhir/_contextLinkId
 */
export const _contextLinkId = 'http://hl7.org/fhir/_contextLinkId' satisfies OwlObjectProperty;

/**
 * ExampleScenarioProcessStepOperationComponent
 *
 * ExampleScenarioProcessComponent.ExampleScenarioProcessStepComponent.ExampleScenarioProcessStepOperationComponent: The step represents a single operation invoked on receiver by sender.
 *
 * http://hl7.org/fhir/ExampleScenarioProcessStepOperationComponent
 */
export const ExampleScenarioProcessStepOperationComponent = 'http://hl7.org/fhir/ExampleScenarioProcessStepOperationComponent' satisfies OwlClass;

/**
 * SubstanceDefinitionStructureComponent
 *
 * SubstanceDefinitionStructureComponent: Structural information.
 *
 * http://hl7.org/fhir/SubstanceDefinitionStructureComponent
 */
export const SubstanceDefinitionStructureComponent = 'http://hl7.org/fhir/SubstanceDefinitionStructureComponent' satisfies OwlClass;

/**
 * calculatedAt
 *
 * Account.calculatedAt: Time the balance amount was calculated.
 *
 * http://hl7.org/fhir/calculatedAt
 */
export const calculatedAt = 'http://hl7.org/fhir/calculatedAt' satisfies OwlObjectProperty;

/**
 * MarketingStatus
 *
 * The marketing status describes the date when a medicinal product is actually put on the market or the date as of which it is no longer available.
 *
 * http://hl7.org/fhir/MarketingStatus
 */
export const MarketingStatus = 'http://hl7.org/fhir/MarketingStatus' satisfies OwlClass;

/**
 * _emptyReason
 *
 * (Modified) List.emptyReason
 *
 * http://hl7.org/fhir/_emptyReason
 */
export const _emptyReason = 'http://hl7.org/fhir/_emptyReason' satisfies OwlObjectProperty;

/**
 * _offsets
 *
 * (Modified) SampledData.offsets
 *
 * http://hl7.org/fhir/_offsets
 */
export const _offsets = 'http://hl7.org/fhir/_offsets' satisfies OwlObjectProperty;

/**
 * _financial
 *
 * (Modified) ExplanationOfBenefit.benefitBalance.financial
 *
 * http://hl7.org/fhir/_financial
 */
export const _financial = 'http://hl7.org/fhir/_financial' satisfies OwlObjectProperty;

/**
 * _exposureRoute
 *
 * (Modified) AllergyIntolerance.reaction.exposureRoute
 *
 * http://hl7.org/fhir/_exposureRoute
 */
export const _exposureRoute = 'http://hl7.org/fhir/_exposureRoute' satisfies OwlObjectProperty;

/**
 * _policyHolder
 *
 * (Modified) Coverage.policyHolder
 *
 * http://hl7.org/fhir/_policyHolder
 */
export const _policyHolder = 'http://hl7.org/fhir/_policyHolder' satisfies OwlObjectProperty;

/**
 * SupplyDeliverySuppliedItemComponent
 *
 * SupplyDeliverySuppliedItemComponent: The item that is being delivered or has been supplied.
 *
 * http://hl7.org/fhir/SupplyDeliverySuppliedItemComponent
 */
export const SupplyDeliverySuppliedItemComponent = 'http://hl7.org/fhir/SupplyDeliverySuppliedItemComponent' satisfies OwlClass;

/**
 * intendedRoute
 *
 * MedicationKnowledge.definitional.intendedRoute: The intended or approved route of administration.
 *
 * http://hl7.org/fhir/intendedRoute
 */
export const intendedRoute = 'http://hl7.org/fhir/intendedRoute' satisfies OwlObjectProperty;

/**
 * _paymentDate
 *
 * (Modified) PaymentNotice.paymentDate
 *
 * http://hl7.org/fhir/_paymentDate
 */
export const _paymentDate = 'http://hl7.org/fhir/_paymentDate' satisfies OwlObjectProperty;

/**
 * GenomicStudyAnalysisDeviceComponent
 *
 * GenomicStudyAnalysisComponent.GenomicStudyAnalysisDeviceComponent: Devices used for the analysis (e.g., instruments, software), with settings and parameters.
 *
 * http://hl7.org/fhir/GenomicStudyAnalysisDeviceComponent
 */
export const GenomicStudyAnalysisDeviceComponent = 'http://hl7.org/fhir/GenomicStudyAnalysisDeviceComponent' satisfies OwlClass;

/**
 * _informationProvider
 *
 * (Modified) CommunicationRequest.informationProvider
 *
 * http://hl7.org/fhir/_informationProvider
 */
export const _informationProvider = 'http://hl7.org/fhir/_informationProvider' satisfies OwlObjectProperty;

/**
 * _outsideFoodAllowed
 *
 * (Modified) NutritionOrder.outsideFoodAllowed
 *
 * http://hl7.org/fhir/_outsideFoodAllowed
 */
export const _outsideFoodAllowed = 'http://hl7.org/fhir/_outsideFoodAllowed' satisfies OwlObjectProperty;

/**
 * feature
 *
 * Specimen.feature: A physical feature or landmark on a specimen, highlighted for context by the collector of the specimen (e.g. surgeon), that identifies the type of feature as well as its meaning (e.g. the red ink indicating the resection margin of the right lobe of the excised prostate tissue or wire loop at radiologically suspected tumor location).
 *
 * http://hl7.org/fhir/feature
 */
export const feature = 'http://hl7.org/fhir/feature' satisfies OwlObjectProperty;

/**
 * needsMap
 *
 * TerminologyCapabilities.translation.needsMap: Whether the client must identify the map.
 *
 * http://hl7.org/fhir/needsMap
 */
export const needsMap = 'http://hl7.org/fhir/needsMap' satisfies OwlObjectProperty;

/**
 * _dataAbsentReason
 *
 * (Modified) Observation.component.dataAbsentReason
 *
 * http://hl7.org/fhir/_dataAbsentReason
 */
export const _dataAbsentReason = 'http://hl7.org/fhir/_dataAbsentReason' satisfies OwlObjectProperty;

/**
 * _definition
 *
 * (Modified) CapabilityStatement.messaging.supportedMessage.definition
 *
 * http://hl7.org/fhir/_definition
 */
export const _definition = 'http://hl7.org/fhir/_definition' satisfies OwlObjectProperty;

/**
 * creation
 *
 * Invoice.creation: Date/time(s) of when this Invoice was posted.
 *
 * http://hl7.org/fhir/creation
 */
export const creation = 'http://hl7.org/fhir/creation' satisfies OwlObjectProperty;

/**
 * _minValue
 *
 * (Modified) ElementDefinition.minValue
 *
 * http://hl7.org/fhir/_minValue
 */
export const _minValue = 'http://hl7.org/fhir/_minValue' satisfies OwlObjectProperty;

/**
 * width
 *
 * Attachment.width: Width of the image in pixels (photo/video).
 *
 * http://hl7.org/fhir/width
 */
export const width = 'http://hl7.org/fhir/width' satisfies OwlObjectProperty;

/**
 * _Permission
 *
 * (Modified) Permission
 *
 * http://hl7.org/fhir/_Permission
 */
export const _Permission = 'http://hl7.org/fhir/_Permission' satisfies OwlClass;

/**
 * AllergyIntolerance
 *
 * Risk of harmful or undesirable, physiological response which is unique to an individual and associated with exposure to a substance.
 *
 * http://hl7.org/fhir/AllergyIntolerance
 */
export const AllergyIntolerance = 'http://hl7.org/fhir/AllergyIntolerance' satisfies OwlClass;

/**
 * _Encounter
 *
 * (Modified) Encounter
 *
 * http://hl7.org/fhir/_Encounter
 */
export const _Encounter = 'http://hl7.org/fhir/_Encounter' satisfies OwlClass;

/**
 * targetNumber
 *
 * ResearchStudy.recruitment.targetNumber: Estimated total number of participants to be enrolled.
 *
 * http://hl7.org/fhir/targetNumber
 */
export const targetNumber = 'http://hl7.org/fhir/targetNumber' satisfies OwlObjectProperty;

/**
 * severity
 *
 * AllergyIntolerance.reaction.severity: Clinical assessment of the severity of the reaction event as a whole, potentially considering multiple different manifestations.
 *
 * http://hl7.org/fhir/severity
 */
export const severity = 'http://hl7.org/fhir/severity' satisfies OwlObjectProperty;

/**
 * ObservationDefinitionQualifiedValueComponent
 *
 * ObservationDefinitionQualifiedValueComponent: A set of qualified values associated with a context and a set of conditions -  provides a range for quantitative and ordinal observations and a collection of value sets for qualitative observations.
 *
 * http://hl7.org/fhir/ObservationDefinitionQualifiedValueComponent
 */
export const ObservationDefinitionQualifiedValueComponent = 'http://hl7.org/fhir/ObservationDefinitionQualifiedValueComponent' satisfies OwlClass;

/**
 * filterBy
 *
 * Subscription.filterBy: The filter properties to be applied to narrow the subscription topic stream.  When multiple filters are applied, evaluates to true if all the conditions applicable to that resource are met; otherwise it returns false (i.e., logical AND).
 *
 * http://hl7.org/fhir/filterBy
 */
export const filterBy = 'http://hl7.org/fhir/filterBy' satisfies OwlObjectProperty;

/**
 * packaging
 *
 * PackagedProductDefinition.packaging.packaging: Allows containers (and parts of containers) within containers, still as a part of a single packaged product. See also PackagedProductDefinition.packaging.containedItem.item(PackagedProductDefinition).
 *
 * http://hl7.org/fhir/packaging
 */
export const packaging = 'http://hl7.org/fhir/packaging' satisfies OwlObjectProperty;

/**
 * endorser
 *
 * Citation.endorser: Who endorsed the citation record.
 *
 * http://hl7.org/fhir/endorser
 */
export const endorser = 'http://hl7.org/fhir/endorser' satisfies OwlObjectProperty;

/**
 * _relatesTo
 *
 * (Modified) EvidenceReport.relatesTo
 *
 * http://hl7.org/fhir/_relatesTo
 */
export const _relatesTo = 'http://hl7.org/fhir/_relatesTo' satisfies OwlObjectProperty;

/**
 * _sourceSignature
 *
 * (Modified) VerificationResult.attestation.sourceSignature
 *
 * http://hl7.org/fhir/_sourceSignature
 */
export const _sourceSignature = 'http://hl7.org/fhir/_sourceSignature' satisfies OwlObjectProperty;

/**
 * abnormalCodedValueSet
 *
 * ObservationDefinition.component.qualifiedValue.abnormalCodedValueSet: The set of abnormal coded results for qualitative observations  that match the criteria of this set of qualified values.
 *
 * http://hl7.org/fhir/abnormalCodedValueSet
 */
export const abnormalCodedValueSet = 'http://hl7.org/fhir/abnormalCodedValueSet' satisfies OwlObjectProperty;

/**
 * lastOccurrenceDate
 *
 * Appointment.recurrenceTemplate.lastOccurrenceDate: Recurring appointments will not occur after this date.
 *
 * http://hl7.org/fhir/lastOccurrenceDate
 */
export const lastOccurrenceDate = 'http://hl7.org/fhir/lastOccurrenceDate' satisfies OwlObjectProperty;

/**
 * _securityLabelNumber
 *
 * (Modified) Contract.term.asset.valuedItem.securityLabelNumber
 *
 * http://hl7.org/fhir/_securityLabelNumber
 */
export const _securityLabelNumber = 'http://hl7.org/fhir/_securityLabelNumber' satisfies OwlObjectProperty;

/**
 * _queryCriteria
 *
 * (Modified) SubscriptionTopic.resourceTrigger.queryCriteria
 *
 * http://hl7.org/fhir/_queryCriteria
 */
export const _queryCriteria = 'http://hl7.org/fhir/_queryCriteria' satisfies OwlObjectProperty;

/**
 * _multipleResultsAllowed
 *
 * (Modified) ObservationDefinition.multipleResultsAllowed
 *
 * http://hl7.org/fhir/_multipleResultsAllowed
 */
export const _multipleResultsAllowed = 'http://hl7.org/fhir/_multipleResultsAllowed' satisfies OwlObjectProperty;

/**
 * _allowed
 *
 * (Modified) MedicationRequest.substitution.allowed
 *
 * http://hl7.org/fhir/_allowed
 */
export const _allowed = 'http://hl7.org/fhir/_allowed' satisfies OwlObjectProperty;

/**
 * _TestReport
 *
 * (Modified) TestReport
 *
 * http://hl7.org/fhir/_TestReport
 */
export const _TestReport = 'http://hl7.org/fhir/_TestReport' satisfies OwlClass;

/**
 * _Location
 *
 * (Modified) Location
 *
 * http://hl7.org/fhir/_Location
 */
export const _Location = 'http://hl7.org/fhir/_Location' satisfies OwlClass;

/**
 * deviceName
 *
 * DeviceDefinition.deviceName: The name or names of the device as given by the manufacturer.
 *
 * http://hl7.org/fhir/deviceName
 */
export const deviceName = 'http://hl7.org/fhir/deviceName' satisfies OwlObjectProperty;

/**
 * ImmunizationReactionComponent
 *
 * ImmunizationReactionComponent: Categorical data indicating that an adverse event is associated in time to an immunization.
 *
 * http://hl7.org/fhir/ImmunizationReactionComponent
 */
export const ImmunizationReactionComponent = 'http://hl7.org/fhir/ImmunizationReactionComponent' satisfies OwlClass;

/**
 * ConceptMap
 *
 * A statement of relationships from one set of concepts to one or more other concepts - either concepts in code systems, or data element/data element concepts, or classes in class models.
 *
 * http://hl7.org/fhir/ConceptMap
 */
export const ConceptMap = 'http://hl7.org/fhir/ConceptMap' satisfies OwlClass;

/**
 * _daysOfWeek
 *
 * (Modified) Availability.availableTime.daysOfWeek
 *
 * http://hl7.org/fhir/_daysOfWeek
 */
export const _daysOfWeek = 'http://hl7.org/fhir/_daysOfWeek' satisfies OwlObjectProperty;

/**
 * ParameterDefinition
 *
 * The parameters to the module. This collection specifies both the input and output parameters. Input parameters are provided by the caller as part of the $evaluate operation. Output parameters are included in the GuidanceResponse.
 *
 * http://hl7.org/fhir/ParameterDefinition
 */
export const ParameterDefinition = 'http://hl7.org/fhir/ParameterDefinition' satisfies OwlClass;

/**
 * _packageCode
 *
 * (Modified) Account.procedure.packageCode
 *
 * http://hl7.org/fhir/_packageCode
 */
export const _packageCode = 'http://hl7.org/fhir/_packageCode' satisfies OwlObjectProperty;

/**
 * Insurance
 *
 * ExplanationOfBenefit.Insurance: Financial instruments for reimbursement for the health care products and services specified on the claim.
 *
 * http://hl7.org/fhir/Insurance
 */
export const Insurance = 'http://hl7.org/fhir/Insurance' satisfies OwlClass;

/**
 * lastPerformed
 *
 * VerificationResult.lastPerformed: The date/time validation was last completed (including failed validations).
 *
 * http://hl7.org/fhir/lastPerformed
 */
export const lastPerformed = 'http://hl7.org/fhir/lastPerformed' satisfies OwlObjectProperty;

/**
 * IngredientManufacturerComponent
 *
 * IngredientManufacturerComponent: The organization(s) that manufacture this ingredient. Can be used to indicate:         1) Organizations we are aware of that manufacture this ingredient         2) Specific Manufacturer(s) currently being used         3) Set of organisations allowed to manufacture this ingredient for this product         Users must be clear on the application of context relevant to their use case.
 *
 * http://hl7.org/fhir/IngredientManufacturerComponent
 */
export const IngredientManufacturerComponent = 'http://hl7.org/fhir/IngredientManufacturerComponent' satisfies OwlClass;

/**
 * nthWeekOfMonth
 *
 * Appointment.recurrenceTemplate.monthlyTemplate.nthWeekOfMonth: Indicates which week within a month the appointments in the series of recurring appointments should occur on.
 *
 * http://hl7.org/fhir/nthWeekOfMonth
 */
export const nthWeekOfMonth = 'http://hl7.org/fhir/nthWeekOfMonth' satisfies OwlObjectProperty;

/**
 * targetSpecies
 *
 * AdministrableProductDefinition.routeOfAdministration.targetSpecies: A species for which this route applies.
 *
 * http://hl7.org/fhir/targetSpecies
 */
export const targetSpecies = 'http://hl7.org/fhir/targetSpecies' satisfies OwlObjectProperty;

/**
 * authorization
 *
 * AuditEvent.entity.agent.authorization: The authorization (e.g., PurposeOfUse) that was used during the event being recorded.
 *
 * http://hl7.org/fhir/authorization
 */
export const authorization = 'http://hl7.org/fhir/authorization' satisfies OwlObjectProperty;

/**
 * _RequestOrchestration
 *
 * (Modified) RequestOrchestration
 *
 * http://hl7.org/fhir/_RequestOrchestration
 */
export const _RequestOrchestration = 'http://hl7.org/fhir/_RequestOrchestration' satisfies OwlClass;

/**
 * _endpoint
 *
 * (Modified) CapabilityStatement.messaging.endpoint
 *
 * http://hl7.org/fhir/_endpoint
 */
export const _endpoint = 'http://hl7.org/fhir/_endpoint' satisfies OwlObjectProperty;

/**
 * triggeredBy
 *
 * Observation.triggeredBy: Identifies the observation(s) that triggered the performance of this observation.
 *
 * http://hl7.org/fhir/triggeredBy
 */
export const triggeredBy = 'http://hl7.org/fhir/triggeredBy' satisfies OwlObjectProperty;

/**
 * _Dosage
 *
 * (Modified) Dosage
 *
 * http://hl7.org/fhir/_Dosage
 */
export const _Dosage = 'http://hl7.org/fhir/_Dosage' satisfies OwlClass;

/**
 * _doNotPerform
 *
 * (Modified) Contract.term.group.action.doNotPerform
 *
 * http://hl7.org/fhir/_doNotPerform
 */
export const _doNotPerform = 'http://hl7.org/fhir/_doNotPerform' satisfies OwlObjectProperty;

/**
 * careTeam
 *
 * ExplanationOfBenefit.careTeam: The members of the team who provided the products and services.
 *
 * http://hl7.org/fhir/careTeam
 */
export const careTeam = 'http://hl7.org/fhir/careTeam' satisfies OwlObjectProperty;

/**
 * _meta
 *
 * (Modified) Resource.meta
 *
 * http://hl7.org/fhir/_meta
 */
export const _meta = 'http://hl7.org/fhir/_meta' satisfies OwlObjectProperty;

/**
 * TerminologyCapabilitiesCodeSystemVersionComponent
 *
 * TerminologyCapabilitiesCodeSystemComponent.TerminologyCapabilitiesCodeSystemVersionComponent: For the code system, a list of versions that are supported by the server.
 *
 * http://hl7.org/fhir/TerminologyCapabilitiesCodeSystemVersionComponent
 */
export const TerminologyCapabilitiesCodeSystemVersionComponent = 'http://hl7.org/fhir/TerminologyCapabilitiesCodeSystemVersionComponent' satisfies OwlClass;

/**
 * entryQuantity
 *
 * EvidenceReport.section.section.entryQuantity: Quantity as content.
 *
 * http://hl7.org/fhir/entryQuantity
 */
export const entryQuantity = 'http://hl7.org/fhir/entryQuantity' satisfies OwlObjectProperty;

/**
 * CapabilityStatementMessagingEndpointComponent
 *
 * CapabilityStatementMessagingComponent.CapabilityStatementMessagingEndpointComponent: An endpoint (network accessible address) to which messages and/or replies are to be sent.
 *
 * http://hl7.org/fhir/CapabilityStatementMessagingEndpointComponent
 */
export const CapabilityStatementMessagingEndpointComponent = 'http://hl7.org/fhir/CapabilityStatementMessagingEndpointComponent' satisfies OwlClass;

/**
 * nTerminalModification
 *
 * SubstanceProtein.subunit.nTerminalModification: The name of the fragment modified at the N-terminal of the SubstanceProtein shall be specified.
 *
 * http://hl7.org/fhir/nTerminalModification
 */
export const nTerminalModification = 'http://hl7.org/fhir/nTerminalModification' satisfies OwlObjectProperty;

/**
 * _asNeededFor
 *
 * (Modified) NutritionOrder.enteralFormula.administration.schedule.asNeededFor
 *
 * http://hl7.org/fhir/_asNeededFor
 */
export const _asNeededFor = 'http://hl7.org/fhir/_asNeededFor' satisfies OwlObjectProperty;

/**
 * _link
 *
 * (Modified) Bundle.link
 *
 * http://hl7.org/fhir/_link
 */
export const _link = 'http://hl7.org/fhir/_link' satisfies OwlObjectProperty;

/**
 * attribute
 *
 * ConceptMap.group.element.target.product.attribute: A reference to the additional attribute that holds a value the map depends on.
 *
 * http://hl7.org/fhir/attribute
 */
export const attribute = 'http://hl7.org/fhir/attribute' satisfies OwlObjectProperty;

/**
 * Note
 *
 * ExplanationOfBenefit.Note: A note that describes or explains adjudication results in a human readable form.
 *
 * http://hl7.org/fhir/Note
 */
export const Note = 'http://hl7.org/fhir/Note' satisfies OwlClass;

/**
 * textFilter
 *
 * TerminologyCapabilities.expansion.textFilter: Documentation about text searching works.
 *
 * http://hl7.org/fhir/textFilter
 */
export const textFilter = 'http://hl7.org/fhir/textFilter' satisfies OwlObjectProperty;

/**
 * disposition
 *
 * ExplanationOfBenefit.disposition: A human readable description of the status of the adjudication.
 *
 * http://hl7.org/fhir/disposition
 */
export const disposition = 'http://hl7.org/fhir/disposition' satisfies OwlObjectProperty;

/**
 * PackagedProductDefinition
 *
 * A medically related item or items, in a container or package.
 *
 * http://hl7.org/fhir/PackagedProductDefinition
 */
export const PackagedProductDefinition = 'http://hl7.org/fhir/PackagedProductDefinition' satisfies OwlClass;

/**
 * Accident
 *
 * ExplanationOfBenefit.Accident: Details of a accident which resulted in injuries which required the products and services listed in the claim.
 *
 * http://hl7.org/fhir/Accident
 */
export const Accident = 'http://hl7.org/fhir/Accident' satisfies OwlClass;

/**
 * _reference
 *
 * (Modified) Consent.provision.provision.data.reference
 *
 * http://hl7.org/fhir/_reference
 */
export const _reference = 'http://hl7.org/fhir/_reference' satisfies OwlObjectProperty;

/**
 * StructureMapGroupRuleTargetParameterComponent
 *
 * StructureMapGroupComponent.StructureMapGroupRuleComponentRule.StructureMapGroupRuleTargetComponent.StructureMapGroupRuleTargetParameterComponent: Parameters to the transform.
 *
 * http://hl7.org/fhir/StructureMapGroupRuleTargetParameterComponent
 */
export const StructureMapGroupRuleTargetParameterComponent = 'http://hl7.org/fhir/StructureMapGroupRuleTargetParameterComponent' satisfies OwlClass;

/**
 * subscriber
 *
 * Coverage.subscriber: The party who has signed-up for or 'owns' the contractual relationship to the policy or to whom the benefit of the policy for services rendered to them or their family is due.
 *
 * http://hl7.org/fhir/subscriber
 */
export const subscriber = 'http://hl7.org/fhir/subscriber' satisfies OwlObjectProperty;

/**
 * structureType
 *
 * ExampleScenario.instance.structureType: A code indicating the kind of data structure (FHIR resource or some other standard) this is an instance of.
 *
 * http://hl7.org/fhir/structureType
 */
export const structureType = 'http://hl7.org/fhir/structureType' satisfies OwlObjectProperty;

/**
 * _detail
 *
 * (Modified) TestReport.setup.action.operation.detail
 *
 * http://hl7.org/fhir/_detail
 */
export const _detail = 'http://hl7.org/fhir/_detail' satisfies OwlObjectProperty;

/**
 * meaningWhenMissing
 *
 * ElementDefinition.meaningWhenMissing: The Implicit meaning that is to be understood when this element is missing (e.g. 'when this element is missing, the period is ongoing').
 *
 * http://hl7.org/fhir/meaningWhenMissing
 */
export const meaningWhenMissing = 'http://hl7.org/fhir/meaningWhenMissing' satisfies OwlObjectProperty;

/**
 * modelCharacteristic
 *
 * Evidence.statistic.modelCharacteristic: A component of the method to generate the statistic.
 *
 * http://hl7.org/fhir/modelCharacteristic
 */
export const modelCharacteristic = 'http://hl7.org/fhir/modelCharacteristic' satisfies OwlObjectProperty;

/**
 * mapping
 *
 * StructureDefinition.mapping: An external specification that the content is mapped to.
 *
 * http://hl7.org/fhir/mapping
 */
export const mapping = 'http://hl7.org/fhir/mapping' satisfies OwlObjectProperty;

/**
 * _Person
 *
 * (Modified) Person
 *
 * http://hl7.org/fhir/_Person
 */
export const _Person = 'http://hl7.org/fhir/_Person' satisfies OwlClass;

/**
 * _eligibility
 *
 * (Modified) ResearchStudy.recruitment.eligibility
 *
 * http://hl7.org/fhir/_eligibility
 */
export const _eligibility = 'http://hl7.org/fhir/_eligibility' satisfies OwlObjectProperty;

/**
 * SubstanceSourceMaterialFractionDescriptionComponent
 *
 * SubstanceSourceMaterialFractionDescriptionComponent: Many complex materials are fractions of parts of plants, animals, or minerals. Fraction elements are often necessary to define both Substances and Specified Group 1 Substances. For substances derived from Plants, fraction information will be captured at the Substance information level ( . Oils, Juices and Exudates). Additional information for Extracts, such as extraction solvent composition, will be captured at the Specified Substance Group 1 information level. For plasma-derived products fraction information will be captured at the Substance and the Specified Substance Group 1 levels.
 *
 * http://hl7.org/fhir/SubstanceSourceMaterialFractionDescriptionComponent
 */
export const SubstanceSourceMaterialFractionDescriptionComponent = 'http://hl7.org/fhir/SubstanceSourceMaterialFractionDescriptionComponent' satisfies OwlClass;

/**
 * typeCollected
 *
 * SpecimenDefinition.typeCollected: The kind of material to be collected.
 *
 * http://hl7.org/fhir/typeCollected
 */
export const typeCollected = 'http://hl7.org/fhir/typeCollected' satisfies OwlObjectProperty;

/**
 * timestamp
 *
 * ValueSet.expansion.timestamp: The time at which the expansion was produced by the expanding system.
 *
 * http://hl7.org/fhir/timestamp
 */
export const timestamp = 'http://hl7.org/fhir/timestamp' satisfies OwlObjectProperty;

/**
 * _subpotentReason
 *
 * (Modified) Immunization.subpotentReason
 *
 * http://hl7.org/fhir/_subpotentReason
 */
export const _subpotentReason = 'http://hl7.org/fhir/_subpotentReason' satisfies OwlObjectProperty;

/**
 * _relatedMedicationKnowledge
 *
 * (Modified) MedicationKnowledge.relatedMedicationKnowledge
 *
 * http://hl7.org/fhir/_relatedMedicationKnowledge
 */
export const _relatedMedicationKnowledge = 'http://hl7.org/fhir/_relatedMedicationKnowledge' satisfies OwlObjectProperty;

/**
 * _inventoryStatus
 *
 * (Modified) InventoryItem.inventoryStatus
 *
 * http://hl7.org/fhir/_inventoryStatus
 */
export const _inventoryStatus = 'http://hl7.org/fhir/_inventoryStatus' satisfies OwlObjectProperty;

/**
 * synonym
 *
 * SubstanceDefinition.name.translation.synonym: A synonym of this particular name, by which the substance is also known.
 *
 * http://hl7.org/fhir/synonym
 */
export const synonym = 'http://hl7.org/fhir/synonym' satisfies OwlObjectProperty;

/**
 * _category
 *
 * (Modified) DeviceDefinition.conformsTo.category
 *
 * http://hl7.org/fhir/_category
 */
export const _category = 'http://hl7.org/fhir/_category' satisfies OwlObjectProperty;

/**
 * _regulatory
 *
 * (Modified) MedicationKnowledge.regulatory
 *
 * http://hl7.org/fhir/_regulatory
 */
export const _regulatory = 'http://hl7.org/fhir/_regulatory' satisfies OwlObjectProperty;

/**
 * birthDate
 *
 * Practitioner.birthDate: The date of birth for the practitioner.
 *
 * http://hl7.org/fhir/birthDate
 */
export const birthDate = 'http://hl7.org/fhir/birthDate' satisfies OwlObjectProperty;

/**
 * _priorPrescription
 *
 * (Modified) MedicationRequest.priorPrescription
 *
 * http://hl7.org/fhir/_priorPrescription
 */
export const _priorPrescription = 'http://hl7.org/fhir/_priorPrescription' satisfies OwlObjectProperty;

/**
 * Base
 *
 * Base definition for all types defined in FHIR type system.
 *
 * http://hl7.org/fhir/Base
 */
export const Base = 'http://hl7.org/fhir/Base' satisfies OwlClass;

/**
 * _testTools
 *
 * (Modified) TestPlan.testTools
 *
 * http://hl7.org/fhir/_testTools
 */
export const _testTools = 'http://hl7.org/fhir/_testTools' satisfies OwlObjectProperty;

/**
 * _targetLocation
 *
 * (Modified) VerificationResult.targetLocation
 *
 * http://hl7.org/fhir/_targetLocation
 */
export const _targetLocation = 'http://hl7.org/fhir/_targetLocation' satisfies OwlObjectProperty;

/**
 * substanceDefinition
 *
 * SubstanceDefinition.relationship.substanceDefinition
 *
 * http://hl7.org/fhir/substanceDefinition
 */
export const substanceDefinition = 'http://hl7.org/fhir/substanceDefinition' satisfies OwlObjectProperty;

/**
 * _medication
 *
 * (Modified) MedicationStatement.medication
 *
 * http://hl7.org/fhir/_medication
 */
export const _medication = 'http://hl7.org/fhir/_medication' satisfies OwlObjectProperty;

/**
 * _vaccineCode
 *
 * (Modified) ImmunizationRecommendation.recommendation.vaccineCode
 *
 * http://hl7.org/fhir/_vaccineCode
 */
export const _vaccineCode = 'http://hl7.org/fhir/_vaccineCode' satisfies OwlObjectProperty;

/**
 * _dateAsserted
 *
 * (Modified) MedicationStatement.dateAsserted
 *
 * http://hl7.org/fhir/_dateAsserted
 */
export const _dateAsserted = 'http://hl7.org/fhir/_dateAsserted' satisfies OwlObjectProperty;

/**
 * DeviceDefinitionMaterialComponent
 *
 * DeviceDefinitionMaterialComponent: A substance used to create the material(s) of which the device is made.
 *
 * http://hl7.org/fhir/DeviceDefinitionMaterialComponent
 */
export const DeviceDefinitionMaterialComponent = 'http://hl7.org/fhir/DeviceDefinitionMaterialComponent' satisfies OwlClass;

/**
 * _codeSearch
 *
 * (Modified) TerminologyCapabilities.codeSearch
 *
 * http://hl7.org/fhir/_codeSearch
 */
export const _codeSearch = 'http://hl7.org/fhir/_codeSearch' satisfies OwlObjectProperty;

/**
 * range
 *
 * ObservationDefinition.qualifiedValue.range: The range of values defined for continuous or ordinal observations that match the criteria of this set of qualified values.
 *
 * http://hl7.org/fhir/range
 */
export const range = 'http://hl7.org/fhir/range' satisfies OwlObjectProperty;

/**
 * NutritionOrder
 *
 * A request to supply a diet, formula feeding (enteral) or oral nutritional supplement to a patient/resident.
 *
 * http://hl7.org/fhir/NutritionOrder
 */
export const NutritionOrder = 'http://hl7.org/fhir/NutritionOrder' satisfies OwlClass;

/**
 * _dispenserInstruction
 *
 * (Modified) MedicationRequest.dispenseRequest.dispenserInstruction
 *
 * http://hl7.org/fhir/_dispenserInstruction
 */
export const _dispenserInstruction = 'http://hl7.org/fhir/_dispenserInstruction' satisfies OwlObjectProperty;

/**
 * _summary
 *
 * (Modified) Condition.stage.summary
 *
 * http://hl7.org/fhir/_summary
 */
export const _summary = 'http://hl7.org/fhir/_summary' satisfies OwlObjectProperty;

/**
 * _synthesisType
 *
 * (Modified) Evidence.synthesisType
 *
 * http://hl7.org/fhir/_synthesisType
 */
export const _synthesisType = 'http://hl7.org/fhir/_synthesisType' satisfies OwlObjectProperty;

/**
 * productName
 *
 * NutritionOrder.enteralFormula.additive.productName: The product or brand name of the type of modular component to be added to the formula.
 *
 * http://hl7.org/fhir/productName
 */
export const productName = 'http://hl7.org/fhir/productName' satisfies OwlObjectProperty;

/**
 * _reviewOutcome
 *
 * (Modified) ExplanationOfBenefit.addItem.detail.subDetail.reviewOutcome
 *
 * http://hl7.org/fhir/_reviewOutcome
 */
export const _reviewOutcome = 'http://hl7.org/fhir/_reviewOutcome' satisfies OwlObjectProperty;

/**
 * claimResponse
 *
 * ExplanationOfBenefit.claimResponse: The business identifier for the instance of the adjudication response: claim, predetermination or preauthorization response.
 *
 * http://hl7.org/fhir/claimResponse
 */
export const claimResponse = 'http://hl7.org/fhir/claimResponse' satisfies OwlObjectProperty;

/**
 * path
 *
 * RequestOrchestration.action.dynamicValue.path: The path to the element to be customized. This is the path on the resource that will hold the result of the calculation defined by the expression. The specified path SHALL be a FHIRPath resolvable on the specified target type of the ActivityDefinition, and SHALL consist only of identifiers, constant indexers, and a restricted subset of functions. The path is allowed to contain qualifiers (.) to traverse sub-elements, as well as indexers ([x]) to traverse multiple-cardinality sub-elements (see the [Simple FHIRPath Profile](fhirpath.html#simple) for full details).
 *
 * http://hl7.org/fhir/path
 */
export const path = 'http://hl7.org/fhir/path' satisfies OwlObjectProperty;

/**
 * additive
 *
 * Specimen.processing.additive: Material used in the processing step.
 *
 * http://hl7.org/fhir/additive
 */
export const additive = 'http://hl7.org/fhir/additive' satisfies OwlObjectProperty;

/**
 * ElementDefinition
 *
 * Captures constraints on each element within the resource, profile, or extension.
 *
 * http://hl7.org/fhir/ElementDefinition
 */
export const ElementDefinition = 'http://hl7.org/fhir/ElementDefinition' satisfies OwlClass;

/**
 * fundingSource
 *
 * Immunization.fundingSource: Indicates the source of the vaccine actually administered. This may be different than the patient eligibility (e.g. the patient may be eligible for a publically purchased vaccine but due to inventory issues, vaccine purchased with private funds was actually administered).
 *
 * http://hl7.org/fhir/fundingSource
 */
export const fundingSource = 'http://hl7.org/fhir/fundingSource' satisfies OwlObjectProperty;

/**
 * instantiatesCanonical
 *
 * GenomicStudy.instantiatesCanonical: The defined protocol that describes the study.
 *
 * http://hl7.org/fhir/instantiatesCanonical
 */
export const instantiatesCanonical = 'http://hl7.org/fhir/instantiatesCanonical' satisfies OwlObjectProperty;

/**
 * family
 *
 * SubstanceSourceMaterial.organism.family: The family of an organism shall be specified.
 *
 * http://hl7.org/fhir/family
 */
export const family = 'http://hl7.org/fhir/family' satisfies OwlObjectProperty;

/**
 * NutritionIntake
 *
 * A record of food or fluid that is being consumed by a patient.  A NutritionIntake may indicate that the patient may be consuming the food or fluid now or has consumed the food or fluid in the past.  The source of this information can be the patient, significant other (such as a family member or spouse), or a clinician.  A common scenario where this information is captured is during the history taking process during a patient visit or stay or through an app that tracks food or fluids consumed.   The consumption information may come from sources such as the patient's memory, from a nutrition label,  or from a clinician documenting observed intake.
 *
 * http://hl7.org/fhir/NutritionIntake
 */
export const NutritionIntake = 'http://hl7.org/fhir/NutritionIntake' satisfies OwlClass;

/**
 * EvidenceReport
 *
 * The EvidenceReport Resource is a specialized container for a collection of resources and codeable concepts, adapted to support compositions of Evidence, EvidenceVariable, and Citation resources and related concepts.
 *
 * http://hl7.org/fhir/EvidenceReport
 */
export const EvidenceReport = 'http://hl7.org/fhir/EvidenceReport' satisfies OwlClass;

/**
 * billablePeriod
 *
 * ExplanationOfBenefit.billablePeriod: The period for which charges are being submitted.
 *
 * http://hl7.org/fhir/billablePeriod
 */
export const billablePeriod = 'http://hl7.org/fhir/billablePeriod' satisfies OwlObjectProperty;

/**
 * _otherTherapy
 *
 * (Modified) ClinicalUseDefinition.indication.otherTherapy
 *
 * http://hl7.org/fhir/_otherTherapy
 */
export const _otherTherapy = 'http://hl7.org/fhir/_otherTherapy' satisfies OwlObjectProperty;

/**
 * _dateOfService
 *
 * (Modified) Account.procedure.dateOfService
 *
 * http://hl7.org/fhir/_dateOfService
 */
export const _dateOfService = 'http://hl7.org/fhir/_dateOfService' satisfies OwlObjectProperty;

/**
 * _benefitBalance
 *
 * (Modified) ExplanationOfBenefit.benefitBalance
 *
 * http://hl7.org/fhir/_benefitBalance
 */
export const _benefitBalance = 'http://hl7.org/fhir/_benefitBalance' satisfies OwlObjectProperty;

/**
 * _information
 *
 * (Modified) CoverageEligibilityRequest.supportingInfo.information
 *
 * http://hl7.org/fhir/_information
 */
export const _information = 'http://hl7.org/fhir/_information' satisfies OwlObjectProperty;

/**
 * _CareTeam
 *
 * (Modified) CareTeam
 *
 * http://hl7.org/fhir/_CareTeam
 */
export const _CareTeam = 'http://hl7.org/fhir/_CareTeam' satisfies OwlClass;

/**
 * _aggregateMethod
 *
 * (Modified) Measure.group.population.aggregateMethod
 *
 * http://hl7.org/fhir/_aggregateMethod
 */
export const _aggregateMethod = 'http://hl7.org/fhir/_aggregateMethod' satisfies OwlObjectProperty;

/**
 * generatedBy
 *
 * GenomicStudy.analysis.input.generatedBy
 *
 * http://hl7.org/fhir/generatedBy
 */
export const generatedBy = 'http://hl7.org/fhir/generatedBy' satisfies OwlObjectProperty;

/**
 * _tag
 *
 * (Modified) Meta.tag
 *
 * http://hl7.org/fhir/_tag
 */
export const _tag = 'http://hl7.org/fhir/_tag' satisfies OwlObjectProperty;

/**
 * asserter
 *
 * Permission.asserter: The person or entity that asserts the permission.
 *
 * http://hl7.org/fhir/asserter
 */
export const asserter = 'http://hl7.org/fhir/asserter' satisfies OwlObjectProperty;

/**
 * _revInclude
 *
 * (Modified) SubscriptionTopic.notificationShape.revInclude
 *
 * http://hl7.org/fhir/_revInclude
 */
export const _revInclude = 'http://hl7.org/fhir/_revInclude' satisfies OwlObjectProperty;

/**
 * onset
 *
 * FamilyMemberHistory.condition.onset
 *
 * http://hl7.org/fhir/onset
 */
export const onset = 'http://hl7.org/fhir/onset' satisfies OwlObjectProperty;

/**
 * criticalCodedValueSet
 *
 * ObservationDefinition.component.qualifiedValue.criticalCodedValueSet: The set of critical coded results for qualitative observations  that match the criteria of this set of qualified values.
 *
 * http://hl7.org/fhir/criticalCodedValueSet
 */
export const criticalCodedValueSet = 'http://hl7.org/fhir/criticalCodedValueSet' satisfies OwlObjectProperty;

/**
 * _mode
 *
 * (Modified) Device.mode
 *
 * http://hl7.org/fhir/_mode
 */
export const _mode = 'http://hl7.org/fhir/_mode' satisfies OwlObjectProperty;

/**
 * anchor
 *
 * ImplementationGuide.manifest.page.anchor: The name of an anchor available on the page.
 *
 * http://hl7.org/fhir/anchor
 */
export const anchor = 'http://hl7.org/fhir/anchor' satisfies OwlObjectProperty;

/**
 * _substitution
 *
 * (Modified) MedicationRequest.substitution
 *
 * http://hl7.org/fhir/_substitution
 */
export const _substitution = 'http://hl7.org/fhir/_substitution' satisfies OwlObjectProperty;

/**
 * _consent
 *
 * (Modified) ResearchSubject.consent
 *
 * http://hl7.org/fhir/_consent
 */
export const _consent = 'http://hl7.org/fhir/_consent' satisfies OwlObjectProperty;

/**
 * _candidate
 *
 * (Modified) EnrollmentRequest.candidate
 *
 * http://hl7.org/fhir/_candidate
 */
export const _candidate = 'http://hl7.org/fhir/_candidate' satisfies OwlObjectProperty;

/**
 * _concept
 *
 * (Modified) ValueSet.compose.exclude.concept
 *
 * http://hl7.org/fhir/_concept
 */
export const _concept = 'http://hl7.org/fhir/_concept' satisfies OwlObjectProperty;

/**
 * MeasureReportGroupStratifierStratumComponentComponent
 *
 * MeasureReportGroupComponent.MeasureReportGroupStratifierComponent.StratifierGroup.MeasureReportGroupStratifierStratumComponentComponent: A stratifier component value.
 *
 * http://hl7.org/fhir/MeasureReportGroupStratifierStratumComponentComponent
 */
export const MeasureReportGroupStratifierStratumComponentComponent = 'http://hl7.org/fhir/MeasureReportGroupStratifierStratumComponentComponent' satisfies OwlClass;

/**
 * ifNoneExist
 *
 * Bundle.entry.request.ifNoneExist: Instruct the server not to perform the create if a specified resource already exists. For further information, see the API documentation for ["Conditional Create"](http.html#ccreate). This is just the query portion of the URL - what follows the "?" (not including the "?").
 *
 * http://hl7.org/fhir/ifNoneExist
 */
export const ifNoneExist = 'http://hl7.org/fhir/ifNoneExist' satisfies OwlObjectProperty;

/**
 * GraphDefinitionNodeComponent
 *
 * GraphDefinitionNodeComponent: Potential target for the link.
 *
 * http://hl7.org/fhir/GraphDefinitionNodeComponent
 */
export const GraphDefinitionNodeComponent = 'http://hl7.org/fhir/GraphDefinitionNodeComponent' satisfies OwlClass;

/**
 * _answer
 *
 * (Modified) Contract.term.group.asset.answer
 *
 * http://hl7.org/fhir/_answer
 */
export const _answer = 'http://hl7.org/fhir/_answer' satisfies OwlObjectProperty;

/**
 * _schedule
 *
 * (Modified) Slot.schedule
 *
 * http://hl7.org/fhir/_schedule
 */
export const _schedule = 'http://hl7.org/fhir/_schedule' satisfies OwlObjectProperty;

/**
 * administrationTreatment
 *
 * MedicationKnowledge.indicationGuideline.dosingGuideline.administrationTreatment: The type of the treatment that the guideline applies to, for example, long term therapy, first line treatment, etc.
 *
 * http://hl7.org/fhir/administrationTreatment
 */
export const administrationTreatment = 'http://hl7.org/fhir/administrationTreatment' satisfies OwlObjectProperty;

/**
 * _baseFormulaProductName
 *
 * (Modified) NutritionOrder.enteralFormula.baseFormulaProductName
 *
 * http://hl7.org/fhir/_baseFormulaProductName
 */
export const _baseFormulaProductName = 'http://hl7.org/fhir/_baseFormulaProductName' satisfies OwlObjectProperty;

/**
 * PermissionRuleDataResourceComponent
 *
 * Permission.Rule.PermissionRuleDataComponent.PermissionRuleDataResourceComponent: Explicit FHIR Resource references.
 *
 * http://hl7.org/fhir/PermissionRuleDataResourceComponent
 */
export const PermissionRuleDataResourceComponent = 'http://hl7.org/fhir/PermissionRuleDataResourceComponent' satisfies OwlClass;

/**
 * _gestationalAge
 *
 * (Modified) ObservationDefinition.component.qualifiedValue.gestationalAge
 *
 * http://hl7.org/fhir/_gestationalAge
 */
export const _gestationalAge = 'http://hl7.org/fhir/_gestationalAge' satisfies OwlObjectProperty;

/**
 * carrierAIDC
 *
 * Device.udiCarrier.carrierAIDC: The full UDI carrier of the Automatic Identification and Data Capture (AIDC) technology representation of the barcode string as printed on the packaging of the device - e.g., a barcode or RFID.   Because of limitations on character sets in XML and the need to round-trip JSON data through XML, AIDC Formats *SHALL* be base64 encoded.
 *
 * http://hl7.org/fhir/carrierAIDC
 */
export const carrierAIDC = 'http://hl7.org/fhir/carrierAIDC' satisfies OwlObjectProperty;

/**
 * _capability
 *
 * (Modified) TestScript.metadata.capability
 *
 * http://hl7.org/fhir/_capability
 */
export const _capability = 'http://hl7.org/fhir/_capability' satisfies OwlObjectProperty;

/**
 * usageStatus
 *
 * DeviceUsage.usageStatus: The status of the device usage, for example always, sometimes, never. This is not the same as the status of the statement.
 *
 * http://hl7.org/fhir/usageStatus
 */
export const usageStatus = 'http://hl7.org/fhir/usageStatus' satisfies OwlObjectProperty;

/**
 * _knownAllergen
 *
 * (Modified) NutritionProduct.knownAllergen
 *
 * http://hl7.org/fhir/_knownAllergen
 */
export const _knownAllergen = 'http://hl7.org/fhir/_knownAllergen' satisfies OwlObjectProperty;

/**
 * storageTempRequirements
 *
 * BiologicallyDerivedProduct.storageTempRequirements: The temperature requirements for storage of the biologically-derived product.
 *
 * http://hl7.org/fhir/storageTempRequirements
 */
export const storageTempRequirements = 'http://hl7.org/fhir/storageTempRequirements' satisfies OwlObjectProperty;

/**
 * definitionReference
 *
 * EvidenceVariable.characteristic.definitionByCombination.characteristic.definitionReference: Defines the characteristic using a Reference.
 *
 * http://hl7.org/fhir/definitionReference
 */
export const definitionReference = 'http://hl7.org/fhir/definitionReference' satisfies OwlObjectProperty;

/**
 * experimental
 *
 * SubscriptionTopic.experimental: A flag to indicate that this TopSubscriptionTopicic is authored for testing purposes (or education/evaluation/marketing), and is not intended to be used for genuine usage.
 *
 * http://hl7.org/fhir/experimental
 */
export const experimental = 'http://hl7.org/fhir/experimental' satisfies OwlObjectProperty;

/**
 * _numberOfParticipants
 *
 * (Modified) Evidence.statistic.sampleSize.numberOfParticipants
 *
 * http://hl7.org/fhir/_numberOfParticipants
 */
export const _numberOfParticipants = 'http://hl7.org/fhir/_numberOfParticipants' satisfies OwlObjectProperty;

/**
 * _repeat
 *
 * (Modified) SubstancePolymer.repeat
 *
 * http://hl7.org/fhir/_repeat
 */
export const _repeat = 'http://hl7.org/fhir/_repeat' satisfies OwlObjectProperty;

/**
 * displayName
 *
 * Device.displayName: The name used to display by default when the device is referenced. Based on intent of use by the resource creator, this may reflect one of the names in Device.name, or may be another simple name.
 *
 * http://hl7.org/fhir/displayName
 */
export const displayName = 'http://hl7.org/fhir/displayName' satisfies OwlObjectProperty;

/**
 * replaces
 *
 * ServiceRequest.replaces: The request takes the place of the referenced completed or terminated request(s).
 *
 * http://hl7.org/fhir/replaces
 */
export const replaces = 'http://hl7.org/fhir/replaces' satisfies OwlObjectProperty;

/**
 * _distanceFromLandmark
 *
 * (Modified) BodyStructure.excludedStructure.bodyLandmarkOrientation.distanceFromLandmark
 *
 * http://hl7.org/fhir/_distanceFromLandmark
 */
export const _distanceFromLandmark = 'http://hl7.org/fhir/_distanceFromLandmark' satisfies OwlObjectProperty;

/**
 * _frequency
 *
 * (Modified) VerificationResult.frequency
 *
 * http://hl7.org/fhir/_frequency
 */
export const _frequency = 'http://hl7.org/fhir/_frequency' satisfies OwlObjectProperty;

/**
 * shortDoco
 *
 * ElementDefinition.binding.additional.shortDoco: Concise documentation - for summary tables.
 *
 * http://hl7.org/fhir/shortDoco
 */
export const shortDoco = 'http://hl7.org/fhir/shortDoco' satisfies OwlObjectProperty;

/**
 * ImagingSelection
 *
 * A selection of DICOM SOP instances and/or frames within a single Study and Series. This might include additional specifics such as an image region, an Observation UID or a Segmentation Number, allowing linkage to an Observation Resource or transferring this information along with the ImagingStudy Resource.
 *
 * http://hl7.org/fhir/ImagingSelection
 */
export const ImagingSelection = 'http://hl7.org/fhir/ImagingSelection' satisfies OwlClass;

/**
 * modality
 *
 * ImagingStudy.modality: A list of all the distinct values of series.modality. This may include both acquisition and non-acquisition modalities.
 *
 * http://hl7.org/fhir/modality
 */
export const modality = 'http://hl7.org/fhir/modality' satisfies OwlObjectProperty;

/**
 * _targetId
 *
 * (Modified) TestScript.test.action.operation.targetId
 *
 * http://hl7.org/fhir/_targetId
 */
export const _targetId = 'http://hl7.org/fhir/_targetId' satisfies OwlObjectProperty;

/**
 * _amount
 *
 * (Modified) ExplanationOfBenefit.adjudication.amount
 *
 * http://hl7.org/fhir/_amount
 */
export const _amount = 'http://hl7.org/fhir/_amount' satisfies OwlObjectProperty;

/**
 * species
 *
 * SubstanceSourceMaterial.organism.species: The species of an organism shall be specified; refers to the Latin epithet of the species of the plant/animal; it is present in names for species and infraspecies.
 *
 * http://hl7.org/fhir/species
 */
export const species = 'http://hl7.org/fhir/species' satisfies OwlObjectProperty;

/**
 * totalNet
 *
 * Invoice.totalNet: Invoice total , taxes excluded.
 *
 * http://hl7.org/fhir/totalNet
 */
export const totalNet = 'http://hl7.org/fhir/totalNet' satisfies OwlObjectProperty;

/**
 * observationRequirement
 *
 * ActivityDefinition.observationRequirement: Defines observation requirements for the action to be performed, such as body weight or surface area.
 *
 * http://hl7.org/fhir/observationRequirement
 */
export const observationRequirement = 'http://hl7.org/fhir/observationRequirement' satisfies OwlObjectProperty;

/**
 * InsurancePlanPlanGeneralCostComponent
 *
 * InsurancePlanPlanComponent.InsurancePlanPlanGeneralCostComponent: Overall costs associated with the plan.
 *
 * http://hl7.org/fhir/InsurancePlanPlanGeneralCostComponent
 */
export const InsurancePlanPlanGeneralCostComponent = 'http://hl7.org/fhir/InsurancePlanPlanGeneralCostComponent' satisfies OwlClass;

/**
 * InvoiceLineItemComponent
 *
 * InvoiceLineItemComponent: Each line item represents one charge for goods and services rendered. Details such.ofType(date), code and amount are found in the referenced ChargeItem resource.
 *
 * http://hl7.org/fhir/InvoiceLineItemComponent
 */
export const InvoiceLineItemComponent = 'http://hl7.org/fhir/InvoiceLineItemComponent' satisfies OwlClass;

/**
 * requestor
 *
 * ClaimResponse.requestor: The provider which is responsible for the claim, predetermination or preauthorization.
 *
 * http://hl7.org/fhir/requestor
 */
export const requestor = 'http://hl7.org/fhir/requestor' satisfies OwlObjectProperty;

/**
 * dietPreference
 *
 * Encounter.dietPreference: Diet preferences reported by the patient.
 *
 * http://hl7.org/fhir/dietPreference
 */
export const dietPreference = 'http://hl7.org/fhir/dietPreference' satisfies OwlObjectProperty;

/**
 * comparator
 *
 * SearchParameter.comparator: Comparators supported for the search parameter.
 *
 * http://hl7.org/fhir/comparator
 */
export const comparator = 'http://hl7.org/fhir/comparator' satisfies OwlObjectProperty;

/**
 * _combinedPharmaceuticalDoseForm
 *
 * (Modified) MedicinalProductDefinition.combinedPharmaceuticalDoseForm
 *
 * http://hl7.org/fhir/_combinedPharmaceuticalDoseForm
 */
export const _combinedPharmaceuticalDoseForm = 'http://hl7.org/fhir/_combinedPharmaceuticalDoseForm' satisfies OwlObjectProperty;

/**
 * servicePeriod
 *
 * Account.servicePeriod: The date range of services associated with this account.
 *
 * http://hl7.org/fhir/servicePeriod
 */
export const servicePeriod = 'http://hl7.org/fhir/servicePeriod' satisfies OwlObjectProperty;

/**
 * _rater
 *
 * (Modified) Evidence.certainty.subcomponent.rater
 *
 * http://hl7.org/fhir/_rater
 */
export const _rater = 'http://hl7.org/fhir/_rater' satisfies OwlObjectProperty;

/**
 * receiverActive
 *
 * ExampleScenario.process.step.process.step.alternative.step.operation.receiverActive: If false, the receiver is deactivated right after the operation.
 *
 * http://hl7.org/fhir/receiverActive
 */
export const receiverActive = 'http://hl7.org/fhir/receiverActive' satisfies OwlObjectProperty;

/**
 * modification
 *
 * SubstancePolymer.modification: Todo - this is intended to connect to a repeating full modification structure, also used by Protein and Nucleic Acid . String is just a placeholder.
 *
 * http://hl7.org/fhir/modification
 */
export const modification = 'http://hl7.org/fhir/modification' satisfies OwlObjectProperty;

/**
 * practitioner
 *
 * PractitionerRole.practitioner: Practitioner that is able to provide the defined services for the organization.
 *
 * http://hl7.org/fhir/practitioner
 */
export const practitioner = 'http://hl7.org/fhir/practitioner' satisfies OwlObjectProperty;

/**
 * _normalCodedValueSet
 *
 * (Modified) ObservationDefinition.component.qualifiedValue.normalCodedValueSet
 *
 * http://hl7.org/fhir/_normalCodedValueSet
 */
export const _normalCodedValueSet = 'http://hl7.org/fhir/_normalCodedValueSet' satisfies OwlObjectProperty;

/**
 * TestCaseDependency
 *
 * TestPlanTestCaseComponent.TestCaseDependency: The required criteria to execute the test case - e.g. preconditions, previous tests.
 *
 * http://hl7.org/fhir/TestCaseDependency
 */
export const TestCaseDependency = 'http://hl7.org/fhir/TestCaseDependency' satisfies OwlClass;

/**
 * _costToBeneficiary
 *
 * (Modified) Coverage.costToBeneficiary
 *
 * http://hl7.org/fhir/_costToBeneficiary
 */
export const _costToBeneficiary = 'http://hl7.org/fhir/_costToBeneficiary' satisfies OwlObjectProperty;

/**
 * MessageHeader
 *
 * The header for a message exchange that is either requesting or responding to an action.  The reference(s) that are the subject of the action as well as other information related to the action are typically transmitted in a bundle in which the MessageHeader resource instance is the first resource in the bundle.
 *
 * http://hl7.org/fhir/MessageHeader
 */
export const MessageHeader = 'http://hl7.org/fhir/MessageHeader' satisfies OwlClass;

/**
 * ResearchStudyRecruitmentComponent
 *
 * ResearchStudyRecruitmentComponent: Target or actual group of participants enrolled in study.
 *
 * http://hl7.org/fhir/ResearchStudyRecruitmentComponent
 */
export const ResearchStudyRecruitmentComponent = 'http://hl7.org/fhir/ResearchStudyRecruitmentComponent' satisfies OwlClass;

/**
 * _forenameInitials
 *
 * (Modified) Citation.citedArtifact.contributorship.entry.forenameInitials
 *
 * http://hl7.org/fhir/_forenameInitials
 */
export const _forenameInitials = 'http://hl7.org/fhir/_forenameInitials' satisfies OwlObjectProperty;

/**
 * plannedStartDate
 *
 * EncounterHistory.plannedStartDate: The planned start date/time (or admission date) of the encounter.
 *
 * http://hl7.org/fhir/plannedStartDate
 */
export const plannedStartDate = 'http://hl7.org/fhir/plannedStartDate' satisfies OwlObjectProperty;

/**
 * study
 *
 * ResearchSubject.study: Reference to the study the subject is participating in.
 *
 * http://hl7.org/fhir/study
 */
export const study = 'http://hl7.org/fhir/study' satisfies OwlObjectProperty;

/**
 * groupIdentifier
 *
 * NutritionOrder.groupIdentifier: A shared identifier common to all nutrition orders that were authorized more or less simultaneously by a single author, representing the composite or group identifier.
 *
 * http://hl7.org/fhir/groupIdentifier
 */
export const groupIdentifier = 'http://hl7.org/fhir/groupIdentifier' satisfies OwlObjectProperty;

/**
 * _participatingOrganization
 *
 * (Modified) OrganizationAffiliation.participatingOrganization
 *
 * http://hl7.org/fhir/_participatingOrganization
 */
export const _participatingOrganization = 'http://hl7.org/fhir/_participatingOrganization' satisfies OwlObjectProperty;

/**
 * MeasureGroupStratifierComponent
 *
 * MeasureGroupComponent.MeasureGroupStratifierComponent: The stratifier criteria for the measure report, specified as either the name of a valid CQL expression defined within a referenced library or a valid FHIR Resource Path.
 *
 * http://hl7.org/fhir/MeasureGroupStratifierComponent
 */
export const MeasureGroupStratifierComponent = 'http://hl7.org/fhir/MeasureGroupStratifierComponent' satisfies OwlClass;

/**
 * wednesday
 *
 * Appointment.recurrenceTemplate.weeklyTemplate.wednesday: Indicates that recurring appointments should occur on Wednesdays.
 *
 * http://hl7.org/fhir/wednesday
 */
export const wednesday = 'http://hl7.org/fhir/wednesday' satisfies OwlObjectProperty;

/**
 * _diameter
 *
 * (Modified) VisionPrescription.lensSpecification.diameter
 *
 * http://hl7.org/fhir/_diameter
 */
export const _diameter = 'http://hl7.org/fhir/_diameter' satisfies OwlObjectProperty;

/**
 * enteralFormula
 *
 * NutritionOrder.enteralFormula: Feeding provided through the gastrointestinal tract via a tube, catheter, or stoma that delivers nutrition distal to the oral cavity.
 *
 * http://hl7.org/fhir/enteralFormula
 */
export const enteralFormula = 'http://hl7.org/fhir/enteralFormula' satisfies OwlObjectProperty;

/**
 * _stabilityDuration
 *
 * (Modified) MedicationKnowledge.storageGuideline.stabilityDuration
 *
 * http://hl7.org/fhir/_stabilityDuration
 */
export const _stabilityDuration = 'http://hl7.org/fhir/_stabilityDuration' satisfies OwlObjectProperty;

/**
 * integer
 *
 * A whole number
 *
 * http://hl7.org/fhir/integer
 */
export const integer = 'http://hl7.org/fhir/integer' satisfies OwlClass;

/**
 * domain
 *
 * SubstanceDefinition.name.translation.domain: The use context of this name for example if there is a different name a drug active ingredient as opposed to a food colour additive.
 *
 * http://hl7.org/fhir/domain
 */
export const domain = 'http://hl7.org/fhir/domain' satisfies OwlObjectProperty;

/**
 * _periodType
 *
 * (Modified) Contract.term.group.asset.periodType
 *
 * http://hl7.org/fhir/_periodType
 */
export const _periodType = 'http://hl7.org/fhir/_periodType' satisfies OwlObjectProperty;

/**
 * _ImagingStudy
 *
 * (Modified) ImagingStudy
 *
 * http://hl7.org/fhir/_ImagingStudy
 */
export const _ImagingStudy = 'http://hl7.org/fhir/_ImagingStudy' satisfies OwlClass;

/**
 * searchRevInclude
 *
 * CapabilityStatement.rest.resource.searchRevInclude: A list of _revinclude (reverse include) values supported by the server.
 *
 * http://hl7.org/fhir/searchRevInclude
 */
export const searchRevInclude = 'http://hl7.org/fhir/searchRevInclude' satisfies OwlObjectProperty;

/**
 * _relatedAction
 *
 * (Modified) RequestOrchestration.action.action.relatedAction
 *
 * http://hl7.org/fhir/_relatedAction
 */
export const _relatedAction = 'http://hl7.org/fhir/_relatedAction' satisfies OwlObjectProperty;

/**
 * observed
 *
 * Evidence.variableDefinition.observed: Definition of the actual variable related to the statistic(s).
 *
 * http://hl7.org/fhir/observed
 */
export const observed = 'http://hl7.org/fhir/observed' satisfies OwlObjectProperty;

/**
 * born
 *
 * FamilyMemberHistory.born
 *
 * http://hl7.org/fhir/born
 */
export const born = 'http://hl7.org/fhir/born' satisfies OwlObjectProperty;

/**
 * _ImmunizationRecommendation
 *
 * (Modified) ImmunizationRecommendation
 *
 * http://hl7.org/fhir/_ImmunizationRecommendation
 */
export const _ImmunizationRecommendation = 'http://hl7.org/fhir/_ImmunizationRecommendation' satisfies OwlClass;

/**
 * service
 *
 * ChargeItem.service: Indicated the rendered service that caused this charge.
 *
 * http://hl7.org/fhir/service
 */
export const service = 'http://hl7.org/fhir/service' satisfies OwlObjectProperty;

/**
 * _requestIdentifier
 *
 * (Modified) GuidanceResponse.requestIdentifier
 *
 * http://hl7.org/fhir/_requestIdentifier
 */
export const _requestIdentifier = 'http://hl7.org/fhir/_requestIdentifier' satisfies OwlObjectProperty;

/**
 * maxDosePerLifetime
 *
 * Dosage.maxDosePerLifetime: Upper limit on medication per lifetime of the patient.
 *
 * http://hl7.org/fhir/maxDosePerLifetime
 */
export const maxDosePerLifetime = 'http://hl7.org/fhir/maxDosePerLifetime' satisfies OwlObjectProperty;

/**
 * format
 *
 * SubstancePolymer.repeat.repeatUnit.structuralRepresentation.format: The format of the representation e.g. InChI, SMILES, MOLFILE, CDX, SDF, PDB, mmCIF.
 *
 * http://hl7.org/fhir/format
 */
export const format = 'http://hl7.org/fhir/format' satisfies OwlObjectProperty;

/**
 * _isSummary
 *
 * (Modified) ElementDefinition.isSummary
 *
 * http://hl7.org/fhir/_isSummary
 */
export const _isSummary = 'http://hl7.org/fhir/_isSummary' satisfies OwlObjectProperty;

/**
 * supportingInfoSequence
 *
 * CoverageEligibilityRequest.item.supportingInfoSequence: Exceptions, special conditions and supporting information applicable for this service or product line.
 *
 * http://hl7.org/fhir/supportingInfoSequence
 */
export const supportingInfoSequence = 'http://hl7.org/fhir/supportingInfoSequence' satisfies OwlObjectProperty;

/**
 * EvidenceStatisticModelCharacteristicVariableComponent
 *
 * EvidenceStatisticComponent.EvidenceStatisticModelCharacteristicComponent.EvidenceStatisticModelCharacteristicVariableComponent: A variable adjusted for in the adjusted analysis.
 *
 * http://hl7.org/fhir/EvidenceStatisticModelCharacteristicVariableComponent
 */
export const EvidenceStatisticModelCharacteristicVariableComponent = 'http://hl7.org/fhir/EvidenceStatisticModelCharacteristicVariableComponent' satisfies OwlClass;

/**
 * ManufacturedItemDefinitionPropertyComponent
 *
 * ManufacturedItemDefinitionPropertyComponent: General characteristics of this item.
 *
 * http://hl7.org/fhir/ManufacturedItemDefinitionPropertyComponent
 */
export const ManufacturedItemDefinitionPropertyComponent = 'http://hl7.org/fhir/ManufacturedItemDefinitionPropertyComponent' satisfies OwlClass;

/**
 * _concentration
 *
 * (Modified) Ingredient.substance.strength.concentration
 *
 * http://hl7.org/fhir/_concentration
 */
export const _concentration = 'http://hl7.org/fhir/_concentration' satisfies OwlObjectProperty;

/**
 * coordinate
 *
 * ImagingSelection.instance.imageRegion3D.coordinate: The coordinates describing the image region. Encoded as an ordered set of (x,y,z) triplets (in mm and may be negative) that define a region of interest in the patient-relative Reference Coordinate System defined by ImagingSelection.frameOfReferenceUid element.
 *
 * http://hl7.org/fhir/coordinate
 */
export const coordinate = 'http://hl7.org/fhir/coordinate' satisfies OwlObjectProperty;

/**
 * AddedItemDetailSubDetail
 *
 * ExplanationOfBenefit.AddedItem.AddedItemDetail.AddedItemDetailSubDetail: The third-tier service adjudications for payor added services.
 *
 * http://hl7.org/fhir/AddedItemDetailSubDetail
 */
export const AddedItemDetailSubDetail = 'http://hl7.org/fhir/AddedItemDetailSubDetail' satisfies OwlClass;

/**
 * TerminologyCapabilitiesTranslationComponent
 *
 * TerminologyCapabilitiesTranslationComponent: Information about the [ConceptMap/$translate](conceptmap-operation-translate.html) operation.
 *
 * http://hl7.org/fhir/TerminologyCapabilitiesTranslationComponent
 */
export const TerminologyCapabilitiesTranslationComponent = 'http://hl7.org/fhir/TerminologyCapabilitiesTranslationComponent' satisfies OwlClass;

/**
 * _generalPractitioner
 *
 * (Modified) Patient.generalPractitioner
 *
 * http://hl7.org/fhir/_generalPractitioner
 */
export const _generalPractitioner = 'http://hl7.org/fhir/_generalPractitioner' satisfies OwlObjectProperty;

/**
 * _protocol
 *
 * (Modified) ResearchStudy.protocol
 *
 * http://hl7.org/fhir/_protocol
 */
export const _protocol = 'http://hl7.org/fhir/_protocol' satisfies OwlObjectProperty;

/**
 * _exception
 *
 * (Modified) Coverage.costToBeneficiary.exception
 *
 * http://hl7.org/fhir/_exception
 */
export const _exception = 'http://hl7.org/fhir/_exception' satisfies OwlObjectProperty;

/**
 * _complication
 *
 * (Modified) Procedure.complication
 *
 * http://hl7.org/fhir/_complication
 */
export const _complication = 'http://hl7.org/fhir/_complication' satisfies OwlObjectProperty;

/**
 * value
 *
 * CodeSystem.filter.value: A description of what the value for the filter should be.
 *
 * http://hl7.org/fhir/value
 */
export const value = 'http://hl7.org/fhir/value' satisfies OwlObjectProperty;

/**
 * _nthWeekOfMonth
 *
 * (Modified) Appointment.recurrenceTemplate.monthlyTemplate.nthWeekOfMonth
 *
 * http://hl7.org/fhir/_nthWeekOfMonth
 */
export const _nthWeekOfMonth = 'http://hl7.org/fhir/_nthWeekOfMonth' satisfies OwlObjectProperty;

/**
 * _url
 *
 * (Modified) ActorDefinition.url
 *
 * http://hl7.org/fhir/_url
 */
export const _url = 'http://hl7.org/fhir/_url' satisfies OwlObjectProperty;

/**
 * SubstanceSourceMaterialOrganismHybridComponent
 *
 * SubstanceSourceMaterialOrganismComponent.SubstanceSourceMaterialOrganismHybridComponent: 4.9.13.8.1 Hybrid species maternal organism ID (Optional).
 *
 * http://hl7.org/fhir/SubstanceSourceMaterialOrganismHybridComponent
 */
export const SubstanceSourceMaterialOrganismHybridComponent = 'http://hl7.org/fhir/SubstanceSourceMaterialOrganismHybridComponent' satisfies OwlClass;

/**
 * SubscriptionTopicEventTriggerComponent
 *
 * SubscriptionTopicEventTriggerComponent: Event definition which can be used to trigger the SubscriptionTopic.
 *
 * http://hl7.org/fhir/SubscriptionTopicEventTriggerComponent
 */
export const SubscriptionTopicEventTriggerComponent = 'http://hl7.org/fhir/SubscriptionTopicEventTriggerComponent' satisfies OwlClass;

/**
 * MedicinalProductDefinitionNameComponent
 *
 * MedicinalProductDefinitionNameComponent: The product's name, including full name and possibly coded parts.
 *
 * http://hl7.org/fhir/MedicinalProductDefinitionNameComponent
 */
export const MedicinalProductDefinitionNameComponent = 'http://hl7.org/fhir/MedicinalProductDefinitionNameComponent' satisfies OwlClass;

/**
 * SubstanceSourceMaterialOrganismComponent
 *
 * SubstanceSourceMaterialOrganismComponent: This subclause describes the organism which the substance is derived from. For vaccines, the parent organism shall be specified based on these subclause elements. As an example, full taxonomy will be described for the Substance Name: ., Leaf.
 *
 * http://hl7.org/fhir/SubstanceSourceMaterialOrganismComponent
 */
export const SubstanceSourceMaterialOrganismComponent = 'http://hl7.org/fhir/SubstanceSourceMaterialOrganismComponent' satisfies OwlClass;

/**
 * overrideReason
 *
 * ChargeItem.overrideReason: If the list price or the rule-based factor associated with the code is overridden, this attribute can capture a text to indicate the  reason for this action.
 *
 * http://hl7.org/fhir/overrideReason
 */
export const overrideReason = 'http://hl7.org/fhir/overrideReason' satisfies OwlObjectProperty;

/**
 * pages
 *
 * Attachment.pages: The number of pages when printed.
 *
 * http://hl7.org/fhir/pages
 */
export const pages = 'http://hl7.org/fhir/pages' satisfies OwlObjectProperty;

/**
 * _conclusion
 *
 * (Modified) DiagnosticReport.conclusion
 *
 * http://hl7.org/fhir/_conclusion
 */
export const _conclusion = 'http://hl7.org/fhir/_conclusion' satisfies OwlObjectProperty;

/**
 * _combined
 *
 * (Modified) Specimen.combined
 *
 * http://hl7.org/fhir/_combined
 */
export const _combined = 'http://hl7.org/fhir/_combined' satisfies OwlObjectProperty;

/**
 * _contains
 *
 * (Modified) ValueSet.expansion.contains.contains
 *
 * http://hl7.org/fhir/_contains
 */
export const _contains = 'http://hl7.org/fhir/_contains' satisfies OwlObjectProperty;

/**
 * _documentType
 *
 * (Modified) Consent.provision.provision.documentType
 *
 * http://hl7.org/fhir/_documentType
 */
export const _documentType = 'http://hl7.org/fhir/_documentType' satisfies OwlObjectProperty;

/**
 * MeasureGroupStratifierComponentComponent
 *
 * MeasureGroupComponent.MeasureGroupStratifierComponent.MeasureGroupStratifierComponentComponent: A component of the stratifier criteria for the measure report, specified as either the name of a valid CQL expression defined within a referenced library or a valid FHIR Resource Path.
 *
 * http://hl7.org/fhir/MeasureGroupStratifierComponentComponent
 */
export const MeasureGroupStratifierComponentComponent = 'http://hl7.org/fhir/MeasureGroupStratifierComponentComponent' satisfies OwlClass;

/**
 * _numberOfInstances
 *
 * (Modified) ImagingStudy.series.numberOfInstances
 *
 * http://hl7.org/fhir/_numberOfInstances
 */
export const _numberOfInstances = 'http://hl7.org/fhir/_numberOfInstances' satisfies OwlObjectProperty;

/**
 * PlanDefinitionActionComponent
 *
 * PlanDefinitionActionComponent: An action or group of actions to be taken as part of the plan. For example, in clinical care, an action would be to prescribe a particular indicated medication, or perform a particular test as appropriate. In pharmaceutical quality, an action would be the test that needs to be performed on a drug product as defined in the quality specification.
 *
 * http://hl7.org/fhir/PlanDefinitionActionComponent
 */
export const PlanDefinitionActionComponent = 'http://hl7.org/fhir/PlanDefinitionActionComponent' satisfies OwlClass;

/**
 * _processor
 *
 * (Modified) PaymentReconciliation.processor
 *
 * http://hl7.org/fhir/_processor
 */
export const _processor = 'http://hl7.org/fhir/_processor' satisfies OwlObjectProperty;

/**
 * actualNumber
 *
 * ResearchStudy.recruitment.actualNumber: Actual total number of participants enrolled in study.
 *
 * http://hl7.org/fhir/actualNumber
 */
export const actualNumber = 'http://hl7.org/fhir/actualNumber' satisfies OwlObjectProperty;

/**
 * _network
 *
 * (Modified) AuditEvent.agent.network
 *
 * http://hl7.org/fhir/_network
 */
export const _network = 'http://hl7.org/fhir/_network' satisfies OwlObjectProperty;

/**
 * effective
 *
 * Observation.effective
 *
 * http://hl7.org/fhir/effective
 */
export const effective = 'http://hl7.org/fhir/effective' satisfies OwlObjectProperty;

/**
 * textEquivalent
 *
 * RequestOrchestration.action.textEquivalent: A text equivalent of the action to be performed. This provides a human-interpretable description of the action when the definition is consumed by a system that might not be capable of interpreting it dynamically.
 *
 * http://hl7.org/fhir/textEquivalent
 */
export const textEquivalent = 'http://hl7.org/fhir/textEquivalent' satisfies OwlObjectProperty;

/**
 * preferred
 *
 * RelatedPerson.communication.preferred: Indicates whether or not the related person prefers this language (over other languages he or she masters up a certain level).
 *
 * http://hl7.org/fhir/preferred
 */
export const preferred = 'http://hl7.org/fhir/preferred' satisfies OwlObjectProperty;

/**
 * ImplementationGuide
 *
 * A set of rules of how a particular interoperability or standards problem is solved - typically through the use of FHIR resources. This resource is used to gather all the parts of an implementation guide into a logical whole and to publish a computable definition of all the parts.
 *
 * http://hl7.org/fhir/ImplementationGuide
 */
export const ImplementationGuide = 'http://hl7.org/fhir/ImplementationGuide' satisfies OwlClass;

/**
 * EvidenceReportRelatesToTargetComponent
 *
 * EvidenceReportRelatesToComponent.EvidenceReportRelatesToTargetComponent: The target composition/document of this relationship.
 *
 * http://hl7.org/fhir/EvidenceReportRelatesToTargetComponent
 */
export const EvidenceReportRelatesToTargetComponent = 'http://hl7.org/fhir/EvidenceReportRelatesToTargetComponent' satisfies OwlClass;

/**
 * _applicability
 *
 * (Modified) InsurancePlan.plan.specificCost.benefit.cost.applicability
 *
 * http://hl7.org/fhir/_applicability
 */
export const _applicability = 'http://hl7.org/fhir/_applicability' satisfies OwlObjectProperty;

/**
 * min
 *
 * GraphDefinition.link.min: Minimum occurrences for this link.
 *
 * http://hl7.org/fhir/min
 */
export const min = 'http://hl7.org/fhir/min' satisfies OwlObjectProperty;

/**
 * DeviceNameComponent
 *
 * DeviceNameComponent: This represents the manufacturer's name of the device as provided by the device, from a UDI label, or by a person describing the Device.  This typically would be used when a person provides the name(s) or when the device represents one of the names available from DeviceDefinition.
 *
 * http://hl7.org/fhir/DeviceNameComponent
 */
export const DeviceNameComponent = 'http://hl7.org/fhir/DeviceNameComponent' satisfies OwlClass;

/**
 * Payment
 *
 * ClaimResponse.Payment: Payment details for the adjudication of the claim.
 *
 * http://hl7.org/fhir/Payment
 */
export const Payment = 'http://hl7.org/fhir/Payment' satisfies OwlClass;

/**
 * organismName
 *
 * SubstanceSourceMaterial.organismName: The organism accepted Scientific name shall be provided based on the organism taxonomy.
 *
 * http://hl7.org/fhir/organismName
 */
export const organismName = 'http://hl7.org/fhir/organismName' satisfies OwlObjectProperty;

/**
 * relative
 *
 * MolecularSequence.relative: A sequence defined relative to another sequence.
 *
 * http://hl7.org/fhir/relative
 */
export const relative = 'http://hl7.org/fhir/relative' satisfies OwlObjectProperty;

/**
 * Ratio
 *
 * A relationship of two Quantity values - expressed as a numerator and a denominator.
 *
 * http://hl7.org/fhir/Ratio
 */
export const Ratio = 'http://hl7.org/fhir/Ratio' satisfies OwlClass;

/**
 * item
 *
 * ExplanationOfBenefit.item: A claim line. Either a simple (a product or service) or a 'group' of details which can also be a simple items or groups of sub-details.
 *
 * http://hl7.org/fhir/item
 */
export const item = 'http://hl7.org/fhir/item' satisfies OwlObjectProperty;

/**
 * rating
 *
 * Evidence.certainty.subcomponent.rating: Assessment or judgement of the aspect.
 *
 * http://hl7.org/fhir/rating
 */
export const rating = 'http://hl7.org/fhir/rating' satisfies OwlObjectProperty;

/**
 * _numerator
 *
 * (Modified) Ratio.numerator
 *
 * http://hl7.org/fhir/_numerator
 */
export const _numerator = 'http://hl7.org/fhir/_numerator' satisfies OwlObjectProperty;

/**
 * TestScriptScopeComponent
 *
 * TestScriptScopeComponent: The scope indicates a conformance artifact that is tested by the test(s) within this test case and the expectation of the test outcome(s) as well as the intended test phase inclusion.
 *
 * http://hl7.org/fhir/TestScriptScopeComponent
 */
export const TestScriptScopeComponent = 'http://hl7.org/fhir/TestScriptScopeComponent' satisfies OwlClass;

/**
 * _aggregation
 *
 * (Modified) ElementDefinition.type.aggregation
 *
 * http://hl7.org/fhir/_aggregation
 */
export const _aggregation = 'http://hl7.org/fhir/_aggregation' satisfies OwlObjectProperty;

/**
 * minutesDuration
 *
 * Appointment.minutesDuration: Number of minutes that the appointment is to take. This can be less than the duration between the start and end times.  For example, where the actual time of appointment is only an estimate or if a 30 minute appointment is being requested, but any time would work.  Also, if there is, for example, a planned 15 minute break in the middle of a long appointment, the duration may be 15 minutes less than the difference between the start and end.
 *
 * http://hl7.org/fhir/minutesDuration
 */
export const minutesDuration = 'http://hl7.org/fhir/minutesDuration' satisfies OwlObjectProperty;

/**
 * AuditEventEntityComponent
 *
 * AuditEventEntityComponent: Specific instances of data or objects that have been accessed.
 *
 * http://hl7.org/fhir/AuditEventEntityComponent
 */
export const AuditEventEntityComponent = 'http://hl7.org/fhir/AuditEventEntityComponent' satisfies OwlClass;

/**
 * rate
 *
 * NutritionOrder.enteralFormula.administration.rate
 *
 * http://hl7.org/fhir/rate
 */
export const rate = 'http://hl7.org/fhir/rate' satisfies OwlObjectProperty;

/**
 * CompartmentDefinition
 *
 * A compartment definition that defines how resources are accessed on a server.
 *
 * http://hl7.org/fhir/CompartmentDefinition
 */
export const CompartmentDefinition = 'http://hl7.org/fhir/CompartmentDefinition' satisfies OwlClass;

/**
 * renderedDosageInstruction
 *
 * MedicationStatement.renderedDosageInstruction: The full representation of the dose of the medication included in all dosage instructions.  To be used when multiple dosage instructions are included to represent complex dosing such as increasing or tapering doses.
 *
 * http://hl7.org/fhir/renderedDosageInstruction
 */
export const renderedDosageInstruction = 'http://hl7.org/fhir/renderedDosageInstruction' satisfies OwlObjectProperty;

/**
 * methodType
 *
 * GenomicStudy.analysis.methodType: Type of the methods used in the analysis, e.g., Fluorescence in situ hybridization (FISH), Karyotyping, or Microsatellite instability testing (MSI).
 *
 * http://hl7.org/fhir/methodType
 */
export const methodType = 'http://hl7.org/fhir/methodType' satisfies OwlObjectProperty;

/**
 * parent
 *
 * MessageDefinition.parent: Identifies a protocol or workflow that this MessageDefinition represents a step in.
 *
 * http://hl7.org/fhir/parent
 */
export const parent = 'http://hl7.org/fhir/parent' satisfies OwlObjectProperty;

/**
 * sourceId
 *
 * OperationDefinition.parameter.referencedFrom.sourceId: The id of the element in the referencing resource that is expected to resolve to this resource.
 *
 * http://hl7.org/fhir/sourceId
 */
export const sourceId = 'http://hl7.org/fhir/sourceId' satisfies OwlObjectProperty;

/**
 * _requestedPeriod
 *
 * (Modified) Task.requestedPeriod
 *
 * http://hl7.org/fhir/_requestedPeriod
 */
export const _requestedPeriod = 'http://hl7.org/fhir/_requestedPeriod' satisfies OwlObjectProperty;

/**
 * _chromosome
 *
 * (Modified) MolecularSequence.relative.startingSequence.chromosome
 *
 * http://hl7.org/fhir/_chromosome
 */
export const _chromosome = 'http://hl7.org/fhir/_chromosome' satisfies OwlObjectProperty;

/**
 * isSubPotent
 *
 * MedicationAdministration.isSubPotent: An indication that the full dose was not administered.
 *
 * http://hl7.org/fhir/isSubPotent
 */
export const isSubPotent = 'http://hl7.org/fhir/isSubPotent' satisfies OwlObjectProperty;

/**
 * presentedForm
 *
 * DiagnosticReport.presentedForm: Rich text representation of the entire result as issued by the diagnostic service. Multiple formats are allowed but they SHALL be semantically equivalent.
 *
 * http://hl7.org/fhir/presentedForm
 */
export const presentedForm = 'http://hl7.org/fhir/presentedForm' satisfies OwlObjectProperty;

/**
 * repetitions
 *
 * Transport.restriction.repetitions: Indicates the number of times the requested action should occur.
 *
 * http://hl7.org/fhir/repetitions
 */
export const repetitions = 'http://hl7.org/fhir/repetitions' satisfies OwlObjectProperty;

/**
 * aggregate
 *
 * Account.balance.aggregate: Who is expected to pay this part of the balance.
 *
 * http://hl7.org/fhir/aggregate
 */
export const aggregate = 'http://hl7.org/fhir/aggregate' satisfies OwlObjectProperty;

/**
 * EvidenceStatisticComponent
 *
 * EvidenceStatisticComponent: Values and parameters for a single statistic.
 *
 * http://hl7.org/fhir/EvidenceStatisticComponent
 */
export const EvidenceStatisticComponent = 'http://hl7.org/fhir/EvidenceStatisticComponent' satisfies OwlClass;

/**
 * ImplementationGuideDefinitionParameterComponent
 *
 * ImplementationGuideDefinitionComponent.ImplementationGuideDefinitionParameterComponent: A set of parameters that defines how the implementation guide is built. The parameters are defined by the relevant tools that build the implementation guides.
 *
 * http://hl7.org/fhir/ImplementationGuideDefinitionParameterComponent
 */
export const ImplementationGuideDefinitionParameterComponent = 'http://hl7.org/fhir/ImplementationGuideDefinitionParameterComponent' satisfies OwlClass;

/**
 * CompositionEventComponent
 *
 * CompositionEventComponent: The clinical service, such as a colonoscopy or an appendectomy, being documented.
 *
 * http://hl7.org/fhir/CompositionEventComponent
 */
export const CompositionEventComponent = 'http://hl7.org/fhir/CompositionEventComponent' satisfies OwlClass;

/**
 * _NutritionOrder
 *
 * (Modified) NutritionOrder
 *
 * http://hl7.org/fhir/_NutritionOrder
 */
export const _NutritionOrder = 'http://hl7.org/fhir/_NutritionOrder' satisfies OwlClass;

/**
 * TaskInputComponent
 *
 * TaskInputComponent: Additional information that may be needed in the execution of the task.
 *
 * http://hl7.org/fhir/TaskInputComponent
 */
export const TaskInputComponent = 'http://hl7.org/fhir/TaskInputComponent' satisfies OwlClass;

/**
 * rule
 *
 * StructureMap.group.rule.rule: Rules contained in this rule.
 *
 * http://hl7.org/fhir/rule
 */
export const rule = 'http://hl7.org/fhir/rule' satisfies OwlObjectProperty;

/**
 * Specimen
 *
 * A sample to be used for analysis.
 *
 * http://hl7.org/fhir/Specimen
 */
export const Specimen = 'http://hl7.org/fhir/Specimen' satisfies OwlClass;

/**
 * _MedicinalProductDefinition
 *
 * (Modified) MedicinalProductDefinition
 *
 * http://hl7.org/fhir/_MedicinalProductDefinition
 */
export const _MedicinalProductDefinition = 'http://hl7.org/fhir/_MedicinalProductDefinition' satisfies OwlClass;

/**
 * OperationDefinition
 *
 * A formal computable definition of an operation (on the RESTful interface) or a named query (using the search interaction).
 *
 * http://hl7.org/fhir/OperationDefinition
 */
export const OperationDefinition = 'http://hl7.org/fhir/OperationDefinition' satisfies OwlClass;

/**
 * process
 *
 * ExampleScenario.process: A group of operations that represents a significant step within a scenario.
 *
 * http://hl7.org/fhir/process
 */
export const process = 'http://hl7.org/fhir/process' satisfies OwlObjectProperty;

/**
 * CitationCitedArtifactContributorshipEntryContributionInstanceComponent
 *
 * CitationCitedArtifactComponent.CitationCitedArtifactContributorshipComponent.CitationCitedArtifactContributorshipEntryComponent.CitationCitedArtifactContributorshipEntryContributionInstanceComponent: Contributions with accounting for time or number.
 *
 * http://hl7.org/fhir/CitationCitedArtifactContributorshipEntryContributionInstanceComponent
 */
export const CitationCitedArtifactContributorshipEntryContributionInstanceComponent = 'http://hl7.org/fhir/CitationCitedArtifactContributorshipEntryContributionInstanceComponent' satisfies OwlClass;

/**
 * EncounterAdmissionComponent
 *
 * EncounterAdmissionComponent: Details about the stay during which a healthcare service is provided.

This does not describe the event of admitting the patient, but rather any information that is relevant from the time of admittance until the time of discharge.
 *
 * http://hl7.org/fhir/EncounterAdmissionComponent
 */
export const EncounterAdmissionComponent = 'http://hl7.org/fhir/EncounterAdmissionComponent' satisfies OwlClass;

/**
 * _MedicationDispense
 *
 * (Modified) MedicationDispense
 *
 * http://hl7.org/fhir/_MedicationDispense
 */
export const _MedicationDispense = 'http://hl7.org/fhir/_MedicationDispense' satisfies OwlClass;

/**
 * translation
 *
 * SubstanceDefinition.name.synonym.translation: A translation for this name into another human language.
 *
 * http://hl7.org/fhir/translation
 */
export const translation = 'http://hl7.org/fhir/translation' satisfies OwlObjectProperty;

/**
 * ObservationTriggeredByComponent
 *
 * ObservationTriggeredByComponent: Identifies the observation(s) that triggered the performance of this observation.
 *
 * http://hl7.org/fhir/ObservationTriggeredByComponent
 */
export const ObservationTriggeredByComponent = 'http://hl7.org/fhir/ObservationTriggeredByComponent' satisfies OwlClass;

/**
 * _etag
 *
 * (Modified) Bundle.entry.response.etag
 *
 * http://hl7.org/fhir/_etag
 */
export const _etag = 'http://hl7.org/fhir/_etag' satisfies OwlObjectProperty;

/**
 * _dateCriterion
 *
 * (Modified) ImmunizationRecommendation.recommendation.dateCriterion
 *
 * http://hl7.org/fhir/_dateCriterion
 */
export const _dateCriterion = 'http://hl7.org/fhir/_dateCriterion' satisfies OwlObjectProperty;

/**
 * _administrationInstruction
 *
 * (Modified) NutritionOrder.enteralFormula.administrationInstruction
 *
 * http://hl7.org/fhir/_administrationInstruction
 */
export const _administrationInstruction = 'http://hl7.org/fhir/_administrationInstruction' satisfies OwlObjectProperty;

/**
 * part
 *
 * OperationDefinition.parameter.part.part: The parts of a nested Parameter.
 *
 * http://hl7.org/fhir/part
 */
export const part = 'http://hl7.org/fhir/part' satisfies OwlObjectProperty;

/**
 * _billablePeriod
 *
 * (Modified) ExplanationOfBenefit.billablePeriod
 *
 * http://hl7.org/fhir/_billablePeriod
 */
export const _billablePeriod = 'http://hl7.org/fhir/_billablePeriod' satisfies OwlObjectProperty;

/**
 * requestHeader
 *
 * TestScript.teardown.action.operation.requestHeader: Header elements would be used to set HTTP headers.
 *
 * http://hl7.org/fhir/requestHeader
 */
export const requestHeader = 'http://hl7.org/fhir/requestHeader' satisfies OwlObjectProperty;

/**
 * _shortTitle
 *
 * (Modified) EvidenceVariable.shortTitle
 *
 * http://hl7.org/fhir/_shortTitle
 */
export const _shortTitle = 'http://hl7.org/fhir/_shortTitle' satisfies OwlObjectProperty;

/**
 * _securityLabel
 *
 * (Modified) DocumentReference.securityLabel
 *
 * http://hl7.org/fhir/_securityLabel
 */
export const _securityLabel = 'http://hl7.org/fhir/_securityLabel' satisfies OwlObjectProperty;

/**
 * _procedure
 *
 * (Modified) ExplanationOfBenefit.procedure.procedure
 *
 * http://hl7.org/fhir/_procedure
 */
export const _procedure = 'http://hl7.org/fhir/_procedure' satisfies OwlObjectProperty;

/**
 * periodMax
 *
 * Timing.repeat.periodMax: If present, indicates that the period is a range from [period] to [periodMax], allowing expressing concepts such as "do this once every 3-5 days.
 *
 * http://hl7.org/fhir/periodMax
 */
export const periodMax = 'http://hl7.org/fhir/periodMax' satisfies OwlObjectProperty;

/**
 * monograph
 *
 * MedicationKnowledge.monograph: Associated documentation about the medication.
 *
 * http://hl7.org/fhir/monograph
 */
export const monograph = 'http://hl7.org/fhir/monograph' satisfies OwlObjectProperty;

/**
 * _eventsSinceSubscriptionStart
 *
 * (Modified) SubscriptionStatus.eventsSinceSubscriptionStart
 *
 * http://hl7.org/fhir/_eventsSinceSubscriptionStart
 */
export const _eventsSinceSubscriptionStart = 'http://hl7.org/fhir/_eventsSinceSubscriptionStart' satisfies OwlObjectProperty;

/**
 * QuestionnaireResponseItemAnswerComponent
 *
 * QuestionnaireResponseItemComponent.QuestionnaireResponseItemAnswerComponent: The respondent's answer(s) to the question.
 *
 * http://hl7.org/fhir/QuestionnaireResponseItemAnswerComponent
 */
export const QuestionnaireResponseItemAnswerComponent = 'http://hl7.org/fhir/QuestionnaireResponseItemAnswerComponent' satisfies OwlClass;

/**
 * formatted
 *
 * MolecularSequence.formatted: Sequence that was observed as file content. Can be an actual file contents, or referenced by a URL to an external system.
 *
 * http://hl7.org/fhir/formatted
 */
export const formatted = 'http://hl7.org/fhir/formatted' satisfies OwlObjectProperty;

/**
 * restoreDate
 *
 * MarketingStatus.restoreDate: The date when the Medicinal Product is placed on the market by the Marketing Authorization Holder (or where applicable, the manufacturer/distributor) in a country and/or jurisdiction shall be provided A complete date consisting of day, month and year shall be specified using the ISO 8601 date format NOTE “Placed on the market” refers to the release of the Medicinal Product into the distribution chain.
 *
 * http://hl7.org/fhir/restoreDate
 */
export const restoreDate = 'http://hl7.org/fhir/restoreDate' satisfies OwlObjectProperty;

/**
 * _grouping
 *
 * (Modified) ImplementationGuide.definition.grouping
 *
 * http://hl7.org/fhir/_grouping
 */
export const _grouping = 'http://hl7.org/fhir/_grouping' satisfies OwlObjectProperty;

/**
 * definition
 *
 * QuestionnaireResponse.item.definition: A reference to an [ElementDefinition](elementdefinition.html) that provides the details for the item.
 *
 * http://hl7.org/fhir/definition
 */
export const definition = 'http://hl7.org/fhir/definition' satisfies OwlObjectProperty;

/**
 * BodyStructureIncludedStructureBodyLandmarkOrientationDistanceFromLandmarkComponent
 *
 * BodyStructureIncludedStructureBodyLandmarkOrientationComponent.BodyStructureIncludedStructureBodyLandmarkOrientationDistanceFromLandmarkComponent: The distance in centimeters a certain observation is made from a body landmark.
 *
 * http://hl7.org/fhir/BodyStructureIncludedStructureBodyLandmarkOrientationDistanceFromLandmarkComponent
 */
export const BodyStructureIncludedStructureBodyLandmarkOrientationDistanceFromLandmarkComponent = 'http://hl7.org/fhir/BodyStructureIncludedStructureBodyLandmarkOrientationDistanceFromLandmarkComponent' satisfies OwlClass;

/**
 * dayOfWeek
 *
 * Appointment.recurrenceTemplate.monthlyTemplate.dayOfWeek: Indicates which day of the week the recurring appointments should occur each nth week.
 *
 * http://hl7.org/fhir/dayOfWeek
 */
export const dayOfWeek = 'http://hl7.org/fhir/dayOfWeek' satisfies OwlObjectProperty;

/**
 * _variableDefinition
 *
 * (Modified) Evidence.statistic.modelCharacteristic.variable.variableDefinition
 *
 * http://hl7.org/fhir/_variableDefinition
 */
export const _variableDefinition = 'http://hl7.org/fhir/_variableDefinition' satisfies OwlObjectProperty;

/**
 * nodeRole
 *
 * http://hl7.org/fhir/nodeRole
 */
export const nodeRole = 'http://hl7.org/fhir/nodeRole' satisfies OwlObjectProperty;

/**
 * Permission
 *
 * Permission resource holds access rules for a given data and context.
 *
 * http://hl7.org/fhir/Permission
 */
export const Permission = 'http://hl7.org/fhir/Permission' satisfies OwlClass;

/**
 * dateWritten
 *
 * VisionPrescription.dateWritten: The date (and perhaps time) when the prescription was written.
 *
 * http://hl7.org/fhir/dateWritten
 */
export const dateWritten = 'http://hl7.org/fhir/dateWritten' satisfies OwlObjectProperty;

/**
 * ratioHighLimitAmount
 *
 * SubstanceDefinition.relationship.ratioHighLimitAmount: For use when the numeric has an uncertain range.
 *
 * http://hl7.org/fhir/ratioHighLimitAmount
 */
export const ratioHighLimitAmount = 'http://hl7.org/fhir/ratioHighLimitAmount' satisfies OwlObjectProperty;

/**
 * _relatedData
 *
 * (Modified) PlanDefinition.action.output.relatedData
 *
 * http://hl7.org/fhir/_relatedData
 */
export const _relatedData = 'http://hl7.org/fhir/_relatedData' satisfies OwlObjectProperty;

/**
 * _inforce
 *
 * (Modified) CoverageEligibilityResponse.insurance.inforce
 *
 * http://hl7.org/fhir/_inforce
 */
export const _inforce = 'http://hl7.org/fhir/_inforce' satisfies OwlObjectProperty;

/**
 * _reportingVendor
 *
 * (Modified) MeasureReport.reportingVendor
 *
 * http://hl7.org/fhir/_reportingVendor
 */
export const _reportingVendor = 'http://hl7.org/fhir/_reportingVendor' satisfies OwlObjectProperty;

/**
 * _sequenceRange
 *
 * (Modified) MolecularSequence.relative.sequenceRange
 *
 * http://hl7.org/fhir/_sequenceRange
 */
export const _sequenceRange = 'http://hl7.org/fhir/_sequenceRange' satisfies OwlObjectProperty;

/**
 * member
 *
 * Group.member: Identifies the resource instances that are members of the group.
 *
 * http://hl7.org/fhir/member
 */
export const member = 'http://hl7.org/fhir/member' satisfies OwlObjectProperty;

/**
 * _versionAlgorithm
 *
 * (Modified) Library.versionAlgorithm
 *
 * http://hl7.org/fhir/_versionAlgorithm
 */
export const _versionAlgorithm = 'http://hl7.org/fhir/_versionAlgorithm' satisfies OwlObjectProperty;

/**
 * _subject
 *
 * (Modified) Condition.subject
 *
 * http://hl7.org/fhir/_subject
 */
export const _subject = 'http://hl7.org/fhir/_subject' satisfies OwlObjectProperty;

/**
 * _case
 *
 * (Modified) RegulatedAuthorization.case
 *
 * http://hl7.org/fhir/_case
 */
export const _case = 'http://hl7.org/fhir/_case' satisfies OwlObjectProperty;

/**
 * _ClinicalUseDefinition
 *
 * (Modified) ClinicalUseDefinition
 *
 * http://hl7.org/fhir/_ClinicalUseDefinition
 */
export const _ClinicalUseDefinition = 'http://hl7.org/fhir/_ClinicalUseDefinition' satisfies OwlClass;

/**
 * _cylinder
 *
 * (Modified) VisionPrescription.lensSpecification.cylinder
 *
 * http://hl7.org/fhir/_cylinder
 */
export const _cylinder = 'http://hl7.org/fhir/_cylinder' satisfies OwlObjectProperty;

/**
 * _saturday
 *
 * (Modified) Appointment.recurrenceTemplate.weeklyTemplate.saturday
 *
 * http://hl7.org/fhir/_saturday
 */
export const _saturday = 'http://hl7.org/fhir/_saturday' satisfies OwlObjectProperty;

/**
 * ConceptMapGroupUnmappedComponent
 *
 * ConceptMapGroupComponent.ConceptMapGroupUnmappedComponent: What to do when there is no mapping to a target concept from the source concept and ConceptMap.group.element.noMap is not true. This provides the "default" to be applied when there is no target concept mapping specified or the expansion of ConceptMap.group.element.target.valueSet is empty.
 *
 * http://hl7.org/fhir/ConceptMapGroupUnmappedComponent
 */
export const ConceptMapGroupUnmappedComponent = 'http://hl7.org/fhir/ConceptMapGroupUnmappedComponent' satisfies OwlClass;

/**
 * Address
 *
 * An address expressed using postal conventions (as opposed to GPS or other location definition formats).  This data type may be used to convey addresses for use in delivering mail as well as for visiting locations which might not be valid for mail delivery.  There are a variety of postal address formats defined around the world.
 * The ISO21090-codedString may be used to provide a coded representation of the contents of strings in an Address.
 *
 * http://hl7.org/fhir/Address
 */
export const Address = 'http://hl7.org/fhir/Address' satisfies OwlClass;

/**
 * _validateCode
 *
 * (Modified) TerminologyCapabilities.validateCode
 *
 * http://hl7.org/fhir/_validateCode
 */
export const _validateCode = 'http://hl7.org/fhir/_validateCode' satisfies OwlObjectProperty;

/**
 * _dispenser
 *
 * (Modified) MedicationRequest.dispenseRequest.dispenser
 *
 * http://hl7.org/fhir/_dispenser
 */
export const _dispenser = 'http://hl7.org/fhir/_dispenser' satisfies OwlObjectProperty;

/**
 * _issued
 *
 * (Modified) TestReport.issued
 *
 * http://hl7.org/fhir/_issued
 */
export const _issued = 'http://hl7.org/fhir/_issued' satisfies OwlObjectProperty;

/**
 * TestReport
 *
 * A summary of information based on the results of executing a TestScript.
 *
 * http://hl7.org/fhir/TestReport
 */
export const TestReport = 'http://hl7.org/fhir/TestReport' satisfies OwlClass;

/**
 * conditionalRead
 *
 * CapabilityStatement.rest.resource.conditionalRead: A code that indicates how the server supports conditional read.
 *
 * http://hl7.org/fhir/conditionalRead
 */
export const conditionalRead = 'http://hl7.org/fhir/conditionalRead' satisfies OwlObjectProperty;

/**
 * fullUrl
 *
 * Bundle.entry.fullUrl: The Absolute URL for the resource. Except for transactions and batches, each entry in a Bundle must have a fullUrl. The fullUrl SHALL NOT disagree with the id in the resource - i.e. if the fullUrl is not a urn:uuid, the URL shall be version-independent URL consistent with the Resource.id. The fullUrl is a version independent reference to the resource. Even when not required, fullUrl MAY be set to a urn:uuid to allow referencing entries in a transaction. The fullUrl can be an arbitrary URI and is not limited to urn:uuid, urn:oid, http, and https. The fullUrl element SHALL have a value except when: 
 * * invoking a create
 * * invoking or responding to an operation where the body is not a single identified resource
 * * invoking or returning the results of a search or history operation.
 *
 * http://hl7.org/fhir/fullUrl
 */
export const fullUrl = 'http://hl7.org/fhir/fullUrl' satisfies OwlObjectProperty;

/**
 * parameterFocus
 *
 * ServiceRequest.orderDetail.parameterFocus: Indicates the context of the order details by reference.
 *
 * http://hl7.org/fhir/parameterFocus
 */
export const parameterFocus = 'http://hl7.org/fhir/parameterFocus' satisfies OwlObjectProperty;

/**
 * _currentState
 *
 * (Modified) Citation.citedArtifact.currentState
 *
 * http://hl7.org/fhir/_currentState
 */
export const _currentState = 'http://hl7.org/fhir/_currentState' satisfies OwlObjectProperty;

/**
 * ActivityDefinition
 *
 * This resource allows for the definition of some activity to be performed, independent of a particular patient, practitioner, or other performance context.
 *
 * http://hl7.org/fhir/ActivityDefinition
 */
export const ActivityDefinition = 'http://hl7.org/fhir/ActivityDefinition' satisfies OwlClass;

/**
 * daysOfWeek
 *
 * Availability.availableTime.daysOfWeek: mon | tue | wed | thu | fri | sat | sun.
 *
 * http://hl7.org/fhir/daysOfWeek
 */
export const daysOfWeek = 'http://hl7.org/fhir/daysOfWeek' satisfies OwlObjectProperty;

/**
 * containedInstance
 *
 * ExampleScenario.instance.containedInstance: References to other instances that can be found within this instance (e.g. the observations contained in a bundle).
 *
 * http://hl7.org/fhir/containedInstance
 */
export const containedInstance = 'http://hl7.org/fhir/containedInstance' satisfies OwlObjectProperty;

/**
 * StructureMapGroupRuleSourceComponent
 *
 * StructureMapGroupComponent.StructureMapGroupRuleComponentRule.StructureMapGroupRuleSourceComponent: Source inputs to the mapping.
 *
 * http://hl7.org/fhir/StructureMapGroupRuleSourceComponent
 */
export const StructureMapGroupRuleSourceComponent = 'http://hl7.org/fhir/StructureMapGroupRuleSourceComponent' satisfies OwlClass;

/**
 * application
 *
 * RegulatedAuthorization.case.application: A regulatory submission from an organization to a regulator, as part of an assessing case. Multiple applications may occur over time, with more or different information to support or modify the submission or the authorization. The applications can be considered as steps within the longer running case or procedure for this authorization process.
 *
 * http://hl7.org/fhir/application
 */
export const application = 'http://hl7.org/fhir/application' satisfies OwlObjectProperty;

/**
 * received
 *
 * Communication.received: The time when this communication arrived at the destination.
 *
 * http://hl7.org/fhir/received
 */
export const received = 'http://hl7.org/fhir/received' satisfies OwlObjectProperty;

/**
 * AuditEventEntityComponentAgent
 *
 * The entity is attributed to an agent to express the agent's responsibility for that entity in the activity. This is most used to indicate when persistence media (the entity) are used by an agent. For example when importing data from a device, the device would be described in an entity, and the user importing data from that media would be indicated as the entity.agent.
 *
 * http://hl7.org/fhir/AuditEventEntityComponentAgent
 */
export const AuditEventEntityComponentAgent = 'http://hl7.org/fhir/AuditEventEntityComponentAgent' satisfies OwlClass;

/**
 * element
 *
 * StructureDefinition.differential.element: Captures constraints on each element within the resource.
 *
 * http://hl7.org/fhir/element
 */
export const element = 'http://hl7.org/fhir/element' satisfies OwlObjectProperty;

/**
 * _compose
 *
 * (Modified) ValueSet.compose
 *
 * http://hl7.org/fhir/_compose
 */
export const _compose = 'http://hl7.org/fhir/_compose' satisfies OwlObjectProperty;

/**
 * _environmentalSetting
 *
 * (Modified) MedicationKnowledge.storageGuideline.environmentalSetting
 *
 * http://hl7.org/fhir/_environmentalSetting
 */
export const _environmentalSetting = 'http://hl7.org/fhir/_environmentalSetting' satisfies OwlObjectProperty;

/**
 * _payment
 *
 * (Modified) PaymentNotice.payment
 *
 * http://hl7.org/fhir/_payment
 */
export const _payment = 'http://hl7.org/fhir/_payment' satisfies OwlObjectProperty;

/**
 * _preparedDate
 *
 * (Modified) DeviceDispense.preparedDate
 *
 * http://hl7.org/fhir/_preparedDate
 */
export const _preparedDate = 'http://hl7.org/fhir/_preparedDate' satisfies OwlObjectProperty;

/**
 * ImagingSelectionInstanceComponent
 *
 * ImagingSelectionInstanceComponent: Each imaging selection includes one or more selected DICOM SOP instances.
 *
 * http://hl7.org/fhir/ImagingSelectionInstanceComponent
 */
export const ImagingSelectionInstanceComponent = 'http://hl7.org/fhir/ImagingSelectionInstanceComponent' satisfies OwlClass;

/**
 * _responseRequired
 *
 * (Modified) MessageDefinition.responseRequired
 *
 * http://hl7.org/fhir/_responseRequired
 */
export const _responseRequired = 'http://hl7.org/fhir/_responseRequired' satisfies OwlObjectProperty;

/**
 * _contraindication
 *
 * (Modified) DeviceDefinition.guideline.contraindication
 *
 * http://hl7.org/fhir/_contraindication
 */
export const _contraindication = 'http://hl7.org/fhir/_contraindication' satisfies OwlObjectProperty;

/**
 * _operator
 *
 * (Modified) TestScript.test.action.assert.operator
 *
 * http://hl7.org/fhir/_operator
 */
export const _operator = 'http://hl7.org/fhir/_operator' satisfies OwlObjectProperty;

/**
 * ActivityDefinitionParticipantComponent
 *
 * ActivityDefinitionParticipantComponent: Indicates who should participate in performing the action described.
 *
 * http://hl7.org/fhir/ActivityDefinitionParticipantComponent
 */
export const ActivityDefinitionParticipantComponent = 'http://hl7.org/fhir/ActivityDefinitionParticipantComponent' satisfies OwlClass;

/**
 * _contraindicatedVaccineCode
 *
 * (Modified) ImmunizationRecommendation.recommendation.contraindicatedVaccineCode
 *
 * http://hl7.org/fhir/_contraindicatedVaccineCode
 */
export const _contraindicatedVaccineCode = 'http://hl7.org/fhir/_contraindicatedVaccineCode' satisfies OwlObjectProperty;

/**
 * _membership
 *
 * (Modified) Group.membership
 *
 * http://hl7.org/fhir/_membership
 */
export const _membership = 'http://hl7.org/fhir/_membership' satisfies OwlObjectProperty;

/**
 * _recordedDate
 *
 * (Modified) Condition.recordedDate
 *
 * http://hl7.org/fhir/_recordedDate
 */
export const _recordedDate = 'http://hl7.org/fhir/_recordedDate' satisfies OwlObjectProperty;

/**
 * _provision
 *
 * (Modified) Consent.provision.provision
 *
 * http://hl7.org/fhir/_provision
 */
export const _provision = 'http://hl7.org/fhir/_provision' satisfies OwlObjectProperty;

/**
 * _dietPreference
 *
 * (Modified) Encounter.dietPreference
 *
 * http://hl7.org/fhir/_dietPreference
 */
export const _dietPreference = 'http://hl7.org/fhir/_dietPreference' satisfies OwlObjectProperty;

/**
 * _laterality
 *
 * (Modified) ImagingStudy.series.laterality
 *
 * http://hl7.org/fhir/_laterality
 */
export const _laterality = 'http://hl7.org/fhir/_laterality' satisfies OwlObjectProperty;

/**
 * _parentSubstanceId
 *
 * (Modified) SubstanceSourceMaterial.parentSubstanceId
 *
 * http://hl7.org/fhir/_parentSubstanceId
 */
export const _parentSubstanceId = 'http://hl7.org/fhir/_parentSubstanceId' satisfies OwlObjectProperty;

/**
 * _report
 *
 * (Modified) Procedure.report
 *
 * http://hl7.org/fhir/_report
 */
export const _report = 'http://hl7.org/fhir/_report' satisfies OwlObjectProperty;

/**
 * MedicationDispensePerformerComponent
 *
 * MedicationDispensePerformerComponent: Indicates who or what performed the event.
 *
 * http://hl7.org/fhir/MedicationDispensePerformerComponent
 */
export const MedicationDispensePerformerComponent = 'http://hl7.org/fhir/MedicationDispensePerformerComponent' satisfies OwlClass;

/**
 * FamilyMemberHistoryConditionComponent
 *
 * FamilyMemberHistoryConditionComponent: The significant Conditions (or condition) that the family member had. This is a repeating section to allow a system to represent more than one condition per resource, though there is nothing stopping multiple resources - one per condition.
 *
 * http://hl7.org/fhir/FamilyMemberHistoryConditionComponent
 */
export const FamilyMemberHistoryConditionComponent = 'http://hl7.org/fhir/FamilyMemberHistoryConditionComponent' satisfies OwlClass;

/**
 * _editor
 *
 * (Modified) EvidenceVariable.editor
 *
 * http://hl7.org/fhir/_editor
 */
export const _editor = 'http://hl7.org/fhir/_editor' satisfies OwlObjectProperty;

/**
 * instant
 *
 * An instant in time - known at least to the second
 *
 * http://hl7.org/fhir/instant
 */
export const instant = 'http://hl7.org/fhir/instant' satisfies OwlClass;

/**
 * paging
 *
 * TerminologyCapabilities.expansion.paging: Whether the server supports paging on expansion.
 *
 * http://hl7.org/fhir/paging
 */
export const paging = 'http://hl7.org/fhir/paging' satisfies OwlObjectProperty;

/**
 * _receiverActive
 *
 * (Modified) ExampleScenario.process.step.alternative.step.operation.receiverActive
 *
 * http://hl7.org/fhir/_receiverActive
 */
export const _receiverActive = 'http://hl7.org/fhir/_receiverActive' satisfies OwlObjectProperty;

/**
 * publicationForm
 *
 * Citation.citedArtifact.publicationForm: If multiple, used to represent alternative forms of the article that are not separate citations.
 *
 * http://hl7.org/fhir/publicationForm
 */
export const publicationForm = 'http://hl7.org/fhir/publicationForm' satisfies OwlObjectProperty;

/**
 * operation
 *
 * TestScript.teardown.action.operation: An operation would involve a REST request to a server.
 *
 * http://hl7.org/fhir/operation
 */
export const operation = 'http://hl7.org/fhir/operation' satisfies OwlObjectProperty;

/**
 * organism
 *
 * SubstanceSourceMaterial.organism: This subclause describes the organism which the substance is derived from. For vaccines, the parent organism shall be specified based on these subclause elements. As an example, full taxonomy will be described for the Substance Name: ., Leaf.
 *
 * http://hl7.org/fhir/organism
 */
export const organism = 'http://hl7.org/fhir/organism' satisfies OwlObjectProperty;

/**
 * focus
 *
 * Composition.section.focus: The actual focus of the section when it is not the subject of the composition, but instead represents something or someone associated with the subject such as (for a patient subject) a spouse, parent, fetus, or donor. If not focus is specified, the focus is assumed to be focus of the parent section, or, for a section in the Composition itself, the subject of the composition. Sections with a focus SHALL only include resources where the logical subject (patient, subject, focus, etc.) matches the section focus, or the resources have no logical subject (few resources).
 *
 * http://hl7.org/fhir/focus
 */
export const focus = 'http://hl7.org/fhir/focus' satisfies OwlObjectProperty;

/**
 * _reviewer
 *
 * (Modified) EvidenceVariable.reviewer
 *
 * http://hl7.org/fhir/_reviewer
 */
export const _reviewer = 'http://hl7.org/fhir/_reviewer' satisfies OwlObjectProperty;

/**
 * validCodedValueSet
 *
 * ObservationDefinition.component.qualifiedValue.validCodedValueSet: The set of valid coded results for qualitative observations  that match the criteria of this set of qualified values.
 *
 * http://hl7.org/fhir/validCodedValueSet
 */
export const validCodedValueSet = 'http://hl7.org/fhir/validCodedValueSet' satisfies OwlObjectProperty;

/**
 * Signatory
 *
 * Contract.Signatory: Parties with legal standing in the Contract, including the principal parties, the grantor(s) and grantee(s), which are any person or organization bound by the contract, and any ancillary parties, which facilitate the execution of the contract such as a notary or witness.
 *
 * http://hl7.org/fhir/Signatory
 */
export const Signatory = 'http://hl7.org/fhir/Signatory' satisfies OwlClass;

/**
 * clockFacePosition
 *
 * BodyStructure.excludedStructure.bodyLandmarkOrientation.clockFacePosition: An description of the direction away from a landmark something is located based on a radial clock dial.
 *
 * http://hl7.org/fhir/clockFacePosition
 */
export const clockFacePosition = 'http://hl7.org/fhir/clockFacePosition' satisfies OwlObjectProperty;

/**
 * _instanceReference
 *
 * (Modified) ExampleScenario.process.step.operation.request.instanceReference
 *
 * http://hl7.org/fhir/_instanceReference
 */
export const _instanceReference = 'http://hl7.org/fhir/_instanceReference' satisfies OwlObjectProperty;

/**
 * withdrawalPeriod
 *
 * AdministrableProductDefinition.routeOfAdministration.targetSpecies.withdrawalPeriod: A species specific time during which consumption of animal product is not appropriate.
 *
 * http://hl7.org/fhir/withdrawalPeriod
 */
export const withdrawalPeriod = 'http://hl7.org/fhir/withdrawalPeriod' satisfies OwlObjectProperty;

/**
 * conformance
 *
 * TestScript.scope.conformance: The expectation of whether the test must pass for the system to be considered conformant with the artifact: required - all tests are expected to pass, optional - all test are expected to pass but non-pass status may be allowed, strict - all tests are expected to pass and warnings are treated as a failure.
 *
 * http://hl7.org/fhir/conformance
 */
export const conformance = 'http://hl7.org/fhir/conformance' satisfies OwlObjectProperty;

/**
 * effectivePeriod
 *
 * EvidenceVariable.effectivePeriod: The period during which the resource content was or is planned to be in active use.
 *
 * http://hl7.org/fhir/effectivePeriod
 */
export const effectivePeriod = 'http://hl7.org/fhir/effectivePeriod' satisfies OwlObjectProperty;

/**
 * _matchStatus
 *
 * (Modified) BiologicallyDerivedProductDispense.matchStatus
 *
 * http://hl7.org/fhir/_matchStatus
 */
export const _matchStatus = 'http://hl7.org/fhir/_matchStatus' satisfies OwlObjectProperty;

/**
 * virtualService
 *
 * Location.virtualService: Connection details of a virtual service (e.g. shared conference call facility with dedicated number/details).
 *
 * http://hl7.org/fhir/virtualService
 */
export const virtualService = 'http://hl7.org/fhir/virtualService' satisfies OwlObjectProperty;

/**
 * Communication
 *
 * A clinical or business level record of information being transmitted or shared; e.g. an alert that was sent to a responsible provider, a public health agency communication to a provider/reporter in response to a case report for a reportable condition.
 *
 * http://hl7.org/fhir/Communication
 */
export const Communication = 'http://hl7.org/fhir/Communication' satisfies OwlClass;

/**
 * _enteralFormula
 *
 * (Modified) NutritionOrder.enteralFormula
 *
 * http://hl7.org/fhir/_enteralFormula
 */
export const _enteralFormula = 'http://hl7.org/fhir/_enteralFormula' satisfies OwlObjectProperty;

/**
 * whenHandedOver
 *
 * MedicationDispense.whenHandedOver: The time the dispensed product was provided to the patient or their representative.
 *
 * http://hl7.org/fhir/whenHandedOver
 */
export const whenHandedOver = 'http://hl7.org/fhir/whenHandedOver' satisfies OwlObjectProperty;

/**
 * EvidenceReportSubjectComponent
 *
 * EvidenceReportSubjectComponent: Specifies the subject or focus of the report. Answers "What is this report about?".
 *
 * http://hl7.org/fhir/EvidenceReportSubjectComponent
 */
export const EvidenceReportSubjectComponent = 'http://hl7.org/fhir/EvidenceReportSubjectComponent' satisfies OwlClass;

/**
 * substance
 *
 * Ingredient.substance: The substance that comprises this ingredient.
 *
 * http://hl7.org/fhir/substance
 */
export const substance = 'http://hl7.org/fhir/substance' satisfies OwlObjectProperty;

/**
 * Section
 *
 * EvidenceReport.Section: The root of the sections that make up the composition.
 *
 * http://hl7.org/fhir/Section
 */
export const Section = 'http://hl7.org/fhir/Section' satisfies OwlClass;

/**
 * _valueRange
 *
 * (Modified) Evidence.statistic.modelCharacteristic.variable.valueRange
 *
 * http://hl7.org/fhir/_valueRange
 */
export const _valueRange = 'http://hl7.org/fhir/_valueRange' satisfies OwlObjectProperty;

/**
 * regulatoryIdentifier
 *
 * DeviceDefinition.regulatoryIdentifier: Identifier associated with the regulatory documentation (certificates, technical documentation, post-market surveillance documentation and reports) of a set of device models sharing the same intended purpose, risk class and essential design and manufacturing characteristics. One example is the Basic UDI-DI in Europe.
 *
 * http://hl7.org/fhir/regulatoryIdentifier
 */
export const regulatoryIdentifier = 'http://hl7.org/fhir/regulatoryIdentifier' satisfies OwlObjectProperty;

/**
 * kind
 *
 * NamingSystem.kind: Indicates the purpose for the naming system - what kinds of things does it make unique?
 *
 * http://hl7.org/fhir/kind
 */
export const kind = 'http://hl7.org/fhir/kind' satisfies OwlObjectProperty;

/**
 * hasIngredient
 *
 * ManufacturedItemDefinition.component.component.constituent.hasIngredient: The ingredient that is the constituent of the given component.
 *
 * http://hl7.org/fhir/hasIngredient
 */
export const hasIngredient = 'http://hl7.org/fhir/hasIngredient' satisfies OwlObjectProperty;

/**
 * detailSequence
 *
 * ClaimResponse.addItem.detailSequence: The sequence number of the details within the claim item which this line is intended to replace.
 *
 * http://hl7.org/fhir/detailSequence
 */
export const detailSequence = 'http://hl7.org/fhir/detailSequence' satisfies OwlObjectProperty;

/**
 * NutritionProductNutrientComponent
 *
 * NutritionProductNutrientComponent: The product's nutritional information expressed by the nutrients.
 *
 * http://hl7.org/fhir/NutritionProductNutrientComponent
 */
export const NutritionProductNutrientComponent = 'http://hl7.org/fhir/NutritionProductNutrientComponent' satisfies OwlClass;

/**
 * _fractionDescription
 *
 * (Modified) SubstanceSourceMaterial.fractionDescription
 *
 * http://hl7.org/fhir/_fractionDescription
 */
export const _fractionDescription = 'http://hl7.org/fhir/_fractionDescription' satisfies OwlObjectProperty;

/**
 * _degreeOfPolymerisation
 *
 * (Modified) SubstancePolymer.repeat.repeatUnit.degreeOfPolymerisation
 *
 * http://hl7.org/fhir/_degreeOfPolymerisation
 */
export const _degreeOfPolymerisation = 'http://hl7.org/fhir/_degreeOfPolymerisation' satisfies OwlObjectProperty;

/**
 * _Account
 *
 * (Modified) Account
 *
 * http://hl7.org/fhir/_Account
 */
export const _Account = 'http://hl7.org/fhir/_Account' satisfies OwlClass;

/**
 * rangeCategory
 *
 * ObservationDefinition.component.qualifiedValue.rangeCategory: The category of range of values for continuous or ordinal observations that match the criteria of this set of qualified values.
 *
 * http://hl7.org/fhir/rangeCategory
 */
export const rangeCategory = 'http://hl7.org/fhir/rangeCategory' satisfies OwlObjectProperty;

/**
 * _index
 *
 * (Modified) TestScript.destination.index
 *
 * http://hl7.org/fhir/_index
 */
export const _index = 'http://hl7.org/fhir/_index' satisfies OwlObjectProperty;

/**
 * ValueSetComposeComponentInclude
 *
 * Exclude one or more codes from the value set based on code system filters and/or other value sets.
 *
 * http://hl7.org/fhir/ValueSetComposeComponentInclude
 */
export const ValueSetComposeComponentInclude = 'http://hl7.org/fhir/ValueSetComposeComponentInclude' satisfies OwlClass;

/**
 * regulatory
 *
 * MedicationKnowledge.regulatory: Regulatory information about a medication.
 *
 * http://hl7.org/fhir/regulatory
 */
export const regulatory = 'http://hl7.org/fhir/regulatory' satisfies OwlObjectProperty;

/**
 * _modifier
 *
 * (Modified) ExplanationOfBenefit.addItem.modifier
 *
 * http://hl7.org/fhir/_modifier
 */
export const _modifier = 'http://hl7.org/fhir/_modifier' satisfies OwlObjectProperty;

/**
 * _short
 *
 * (Modified) ElementDefinition.short
 *
 * http://hl7.org/fhir/_short
 */
export const _short = 'http://hl7.org/fhir/_short' satisfies OwlObjectProperty;

/**
 * medication
 *
 * MedicationRequest.medication: Identifies the medication being requested. This is a link to a resource that represents the medication which may be the details of the medication or simply an attribute carrying a code that identifies the medication from a known list of medications.
 *
 * http://hl7.org/fhir/medication
 */
export const medication = 'http://hl7.org/fhir/medication' satisfies OwlObjectProperty;

/**
 * codeSearch
 *
 * TerminologyCapabilities.codeSearch: The degree to which the server supports the code search parameter on ValueSet, if it is supported.
 *
 * http://hl7.org/fhir/codeSearch
 */
export const codeSearch = 'http://hl7.org/fhir/codeSearch' satisfies OwlObjectProperty;

/**
 * suffix
 *
 * HumanName.suffix: Part of the name that is acquired as a title due to academic, legal, employment or nobility status, etc. and that appears at the end of the name.
 *
 * http://hl7.org/fhir/suffix
 */
export const suffix = 'http://hl7.org/fhir/suffix' satisfies OwlObjectProperty;

/**
 * MedicationDispenseSubstitutionComponent
 *
 * MedicationDispenseSubstitutionComponent: Indicates whether or not substitution was made as part of the dispense.  In some cases, substitution will be expected but does not happen, in other cases substitution is not expected but does happen.  This block explains what substitution did or did not happen and why.  If nothing is specified, substitution was not done.
 *
 * http://hl7.org/fhir/MedicationDispenseSubstitutionComponent
 */
export const MedicationDispenseSubstitutionComponent = 'http://hl7.org/fhir/MedicationDispenseSubstitutionComponent' satisfies OwlClass;

/**
 * foodPreferenceModifier
 *
 * NutritionOrder.foodPreferenceModifier: This modifier is used to convey order-specific modifiers about the type of food that should be given. These can be derived from patient allergies, intolerances, or preferences such as Halal, Vegan or Kosher. This modifier applies to the entire nutrition order inclusive of the oral diet, nutritional supplements and enteral formula feedings.
 *
 * http://hl7.org/fhir/foodPreferenceModifier
 */
export const foodPreferenceModifier = 'http://hl7.org/fhir/foodPreferenceModifier' satisfies OwlObjectProperty;

/**
 * Immunization
 *
 * Describes the event of a patient being administered a vaccine or a record of an immunization as reported by a patient, a clinician or another party.
 *
 * http://hl7.org/fhir/Immunization
 */
export const Immunization = 'http://hl7.org/fhir/Immunization' satisfies OwlClass;

/**
 * AppointmentRecurrenceTemplateMonthlyTemplateComponent
 *
 * AppointmentRecurrenceTemplateComponent.AppointmentRecurrenceTemplateMonthlyTemplateComponent: Information about monthly recurring appointments.
 *
 * http://hl7.org/fhir/AppointmentRecurrenceTemplateMonthlyTemplateComponent
 */
export const AppointmentRecurrenceTemplateMonthlyTemplateComponent = 'http://hl7.org/fhir/AppointmentRecurrenceTemplateMonthlyTemplateComponent' satisfies OwlClass;

/**
 * preventiveAction
 *
 * AdverseEvent.preventiveAction: Preventive actions that contributed to avoiding the adverse event.
 *
 * http://hl7.org/fhir/preventiveAction
 */
export const preventiveAction = 'http://hl7.org/fhir/preventiveAction' satisfies OwlObjectProperty;

/**
 * _AdministrableProductDefinition
 *
 * (Modified) AdministrableProductDefinition
 *
 * http://hl7.org/fhir/_AdministrableProductDefinition
 */
export const _AdministrableProductDefinition = 'http://hl7.org/fhir/_AdministrableProductDefinition' satisfies OwlClass;

/**
 * _deliverFrom
 *
 * (Modified) SupplyRequest.deliverFrom
 *
 * http://hl7.org/fhir/_deliverFrom
 */
export const _deliverFrom = 'http://hl7.org/fhir/_deliverFrom' satisfies OwlObjectProperty;

/**
 * _address
 *
 * (Modified) RelatedPerson.address
 *
 * http://hl7.org/fhir/_address
 */
export const _address = 'http://hl7.org/fhir/_address' satisfies OwlObjectProperty;

/**
 * intendedUse
 *
 * RegulatedAuthorization.intendedUse: The intended use of the product, e.g. prevention, treatment, diagnosis.
 *
 * http://hl7.org/fhir/intendedUse
 */
export const intendedUse = 'http://hl7.org/fhir/intendedUse' satisfies OwlObjectProperty;

/**
 * ElementDefinitionSlicingDiscriminatorComponent
 *
 * ElementDefinitionSlicingComponent.ElementDefinitionSlicingDiscriminatorComponent: Designates which child elements are used to discriminate between the slices when processing an instance. If one or more discriminators are provided, the value of the child elements in the instance data SHALL completely distinguish which slice the element in the resource matches based on the allowed values for those elements in each of the slices.
 *
 * http://hl7.org/fhir/ElementDefinitionSlicingDiscriminatorComponent
 */
export const ElementDefinitionSlicingDiscriminatorComponent = 'http://hl7.org/fhir/ElementDefinitionSlicingDiscriminatorComponent' satisfies OwlClass;

/**
 * SubscriptionTopic
 *
 * Describes a stream of resource state changes identified by trigger criteria and annotated with labels useful to filter projections from this topic.
 *
 * http://hl7.org/fhir/SubscriptionTopic
 */
export const SubscriptionTopic = 'http://hl7.org/fhir/SubscriptionTopic' satisfies OwlClass;

/**
 * GenomicStudy
 *
 * A set of analyses performed to analyze and generate genomic data.
 *
 * http://hl7.org/fhir/GenomicStudy
 */
export const GenomicStudy = 'http://hl7.org/fhir/GenomicStudy' satisfies OwlClass;

/**
 * _partLocation
 *
 * (Modified) SubstanceSourceMaterial.partDescription.partLocation
 *
 * http://hl7.org/fhir/_partLocation
 */
export const _partLocation = 'http://hl7.org/fhir/_partLocation' satisfies OwlObjectProperty;

/**
 * _subsumption
 *
 * (Modified) TerminologyCapabilities.codeSystem.subsumption
 *
 * http://hl7.org/fhir/_subsumption
 */
export const _subsumption = 'http://hl7.org/fhir/_subsumption' satisfies OwlObjectProperty;

/**
 * BenefitBalance
 *
 * ExplanationOfBenefit.BenefitBalance: Balance by Benefit Category.
 *
 * http://hl7.org/fhir/BenefitBalance
 */
export const BenefitBalance = 'http://hl7.org/fhir/BenefitBalance' satisfies OwlClass;

/**
 * script
 *
 * TestPlan.testCase.testRun.script: The test cases in a structured language e.g. gherkin, Postman, or FHIR TestScript.
 *
 * http://hl7.org/fhir/script
 */
export const script = 'http://hl7.org/fhir/script' satisfies OwlObjectProperty;

/**
 * _resourceReference
 *
 * (Modified) Citation.citedArtifact.relatesTo.resourceReference
 *
 * http://hl7.org/fhir/_resourceReference
 */
export const _resourceReference = 'http://hl7.org/fhir/_resourceReference' satisfies OwlObjectProperty;

/**
 * lastReviewDate
 *
 * EventDefinition.lastReviewDate: The date on which the resource content was last reviewed. Review happens periodically after approval but does not change the original approval date.
 *
 * http://hl7.org/fhir/lastReviewDate
 */
export const lastReviewDate = 'http://hl7.org/fhir/lastReviewDate' satisfies OwlObjectProperty;

/**
 * SubstanceDefinitionNameComponentNameName
 *
 * A translation for this name into another human language.
 *
 * http://hl7.org/fhir/SubstanceDefinitionNameComponentNameName
 */
export const SubstanceDefinitionNameComponentNameName = 'http://hl7.org/fhir/SubstanceDefinitionNameComponentNameName' satisfies OwlClass;

/**
 * length
 *
 * Encounter.length: Actual quantity of time the encounter lasted. This excludes the time during leaves of absence.

When missing it is the time in between the start and end values.
 *
 * http://hl7.org/fhir/length
 */
export const length = 'http://hl7.org/fhir/length' satisfies OwlObjectProperty;

/**
 * _overrideReason
 *
 * (Modified) ChargeItem.overrideReason
 *
 * http://hl7.org/fhir/_overrideReason
 */
export const _overrideReason = 'http://hl7.org/fhir/_overrideReason' satisfies OwlObjectProperty;

/**
 * _period
 *
 * (Modified) Coverage.costToBeneficiary.exception.period
 *
 * http://hl7.org/fhir/_period
 */
export const _period = 'http://hl7.org/fhir/_period' satisfies OwlObjectProperty;

/**
 * TerminologyCapabilities
 *
 * A TerminologyCapabilities resource documents a set of capabilities (behaviors) of a FHIR Terminology Server that may be used as a statement of actual server functionality or a statement of required or desired server implementation.
 *
 * http://hl7.org/fhir/TerminologyCapabilities
 */
export const TerminologyCapabilities = 'http://hl7.org/fhir/TerminologyCapabilities' satisfies OwlClass;

/**
 * _supportingPatientInformation
 *
 * (Modified) ImmunizationRecommendation.recommendation.supportingPatientInformation
 *
 * http://hl7.org/fhir/_supportingPatientInformation
 */
export const _supportingPatientInformation = 'http://hl7.org/fhir/_supportingPatientInformation' satisfies OwlObjectProperty;

/**
 * OperationDefinitionParameterBindingComponent
 *
 * OperationDefinitionParameterComponentParameter.OperationDefinitionParameterBindingComponent: Binds to a value set if this parameter is coded (code, Coding, CodeableConcept).
 *
 * http://hl7.org/fhir/OperationDefinitionParameterBindingComponent
 */
export const OperationDefinitionParameterBindingComponent = 'http://hl7.org/fhir/OperationDefinitionParameterBindingComponent' satisfies OwlClass;

/**
 * Task
 *
 * A task to be performed.
 *
 * http://hl7.org/fhir/Task
 */
export const Task = 'http://hl7.org/fhir/Task' satisfies OwlClass;

/**
 * MeasureReportGroupPopulationComponent
 *
 * MeasureReportGroupComponent.MeasureReportGroupPopulationComponent: The populations that make up the population group, one for each type of population appropriate for the measure.
 *
 * http://hl7.org/fhir/MeasureReportGroupPopulationComponent
 */
export const MeasureReportGroupPopulationComponent = 'http://hl7.org/fhir/MeasureReportGroupPopulationComponent' satisfies OwlClass;

/**
 * revInclude
 *
 * SubscriptionTopic.notificationShape.revInclude: Search-style _revinclude directives, rooted in the resource for this shape. Servers SHOULD include resources listed here, if they exist and the user is authorized to receive them.  Clients SHOULD be prepared to receive these additional resources, but SHALL function properly without them.
 *
 * http://hl7.org/fhir/revInclude
 */
export const revInclude = 'http://hl7.org/fhir/revInclude' satisfies OwlObjectProperty;

/**
 * _appliesTo
 *
 * (Modified) ObservationDefinition.component.qualifiedValue.appliesTo
 *
 * http://hl7.org/fhir/_appliesTo
 */
export const _appliesTo = 'http://hl7.org/fhir/_appliesTo' satisfies OwlObjectProperty;

/**
 * MedicationKnowledgeDefinitionalComponent
 *
 * MedicationKnowledgeDefinitionalComponent: Along with the link to a Medicinal Product Definition resource, this information provides common definitional elements that are needed to understand the specific medication that is being described.
 *
 * http://hl7.org/fhir/MedicationKnowledgeDefinitionalComponent
 */
export const MedicationKnowledgeDefinitionalComponent = 'http://hl7.org/fhir/MedicationKnowledgeDefinitionalComponent' satisfies OwlClass;

/**
 * usageInstruction
 *
 * DeviceDispense.usageInstruction: The full representation of the instructions.
 *
 * http://hl7.org/fhir/usageInstruction
 */
export const usageInstruction = 'http://hl7.org/fhir/usageInstruction' satisfies OwlObjectProperty;

/**
 * trigger
 *
 * PlanDefinition.action.action.trigger: A description of when the action should be triggered. When multiple triggers are specified on an action, any triggering event invokes the action.
 *
 * http://hl7.org/fhir/trigger
 */
export const trigger = 'http://hl7.org/fhir/trigger' satisfies OwlObjectProperty;

/**
 * mustSupport
 *
 * ElementDefinition.mustSupport: If true, implementations that produce or consume resources SHALL provide "support" for the element in some meaningful way. Note that this is being phased out and replaced by obligations (see below).  If false, the element may be ignored and not supported. If false, whether to populate or use the data element in any way is at the discretion of the implementation.
 *
 * http://hl7.org/fhir/mustSupport
 */
export const mustSupport = 'http://hl7.org/fhir/mustSupport' satisfies OwlObjectProperty;

/**
 * TimingRepeatComponent
 *
 * TimingRepeatComponent: A set of rules that describe when the event is scheduled.
 *
 * http://hl7.org/fhir/TimingRepeatComponent
 */
export const TimingRepeatComponent = 'http://hl7.org/fhir/TimingRepeatComponent' satisfies OwlClass;

/**
 * effectiveDosePeriod
 *
 * MedicationRequest.effectiveDosePeriod: The period over which the medication is to be taken.  Where there are multiple dosageInstruction lines (for example, tapering doses), this is the earliest date and the latest end date of the dosageInstructions.
 *
 * http://hl7.org/fhir/effectiveDosePeriod
 */
export const effectiveDosePeriod = 'http://hl7.org/fhir/effectiveDosePeriod' satisfies OwlObjectProperty;

/**
 * _textEquivalent
 *
 * (Modified) RequestOrchestration.action.action.textEquivalent
 *
 * http://hl7.org/fhir/_textEquivalent
 */
export const _textEquivalent = 'http://hl7.org/fhir/_textEquivalent' satisfies OwlObjectProperty;

/**
 * bodysite
 *
 * ChargeItem.bodysite: The anatomical location where the related service has been applied.
 *
 * http://hl7.org/fhir/bodysite
 */
export const bodysite = 'http://hl7.org/fhir/bodysite' satisfies OwlObjectProperty;

/**
 * _appliesToAll
 *
 * (Modified) CoverageEligibilityRequest.supportingInfo.appliesToAll
 *
 * http://hl7.org/fhir/_appliesToAll
 */
export const _appliesToAll = 'http://hl7.org/fhir/_appliesToAll' satisfies OwlObjectProperty;

/**
 * comorbidity
 *
 * ClinicalUseDefinition.indication.comorbidity: A comorbidity (concurrent condition) or coinfection as part of the indication.
 *
 * http://hl7.org/fhir/comorbidity
 */
export const comorbidity = 'http://hl7.org/fhir/comorbidity' satisfies OwlObjectProperty;

/**
 * TestScriptFixtureComponent
 *
 * TestScriptFixtureComponent: Fixture in the test script - by reference (uri). All fixtures are required for the test script to execute.
 *
 * http://hl7.org/fhir/TestScriptFixtureComponent
 */
export const TestScriptFixtureComponent = 'http://hl7.org/fhir/TestScriptFixtureComponent' satisfies OwlClass;

/**
 * oligoNucleotideType
 *
 * SubstanceNucleicAcid.oligoNucleotideType: (TBC).
 *
 * http://hl7.org/fhir/oligoNucleotideType
 */
export const oligoNucleotideType = 'http://hl7.org/fhir/oligoNucleotideType' satisfies OwlObjectProperty;

/**
 * intendedEffect
 *
 * ClinicalUseDefinition.indication.intendedEffect: The intended effect, aim or strategy to be achieved.
 *
 * http://hl7.org/fhir/intendedEffect
 */
export const intendedEffect = 'http://hl7.org/fhir/intendedEffect' satisfies OwlObjectProperty;

/**
 * _conformsTo
 *
 * (Modified) DeviceDefinition.conformsTo
 *
 * http://hl7.org/fhir/_conformsTo
 */
export const _conformsTo = 'http://hl7.org/fhir/_conformsTo' satisfies OwlObjectProperty;

/**
 * copyright
 *
 * CapabilityStatement.copyright: A copyright statement relating to the capability statement and/or its contents. Copyright statements are generally legal restrictions on the use and publishing of the capability statement.
 *
 * http://hl7.org/fhir/copyright
 */
export const copyright = 'http://hl7.org/fhir/copyright' satisfies OwlObjectProperty;

/**
 * _insurance
 *
 * (Modified) Task.insurance
 *
 * http://hl7.org/fhir/_insurance
 */
export const _insurance = 'http://hl7.org/fhir/_insurance' satisfies OwlObjectProperty;

/**
 * _partDescription
 *
 * (Modified) SubstanceSourceMaterial.partDescription
 *
 * http://hl7.org/fhir/_partDescription
 */
export const _partDescription = 'http://hl7.org/fhir/_partDescription' satisfies OwlObjectProperty;

/**
 * _genomeBuild
 *
 * (Modified) GenomicStudy.analysis.genomeBuild
 *
 * http://hl7.org/fhir/_genomeBuild
 */
export const _genomeBuild = 'http://hl7.org/fhir/_genomeBuild' satisfies OwlObjectProperty;

/**
 * Slot
 *
 * A slot of time on a schedule that may be available for booking appointments.
 *
 * http://hl7.org/fhir/Slot
 */
export const Slot = 'http://hl7.org/fhir/Slot' satisfies OwlClass;

/**
 * _medium
 *
 * (Modified) CommunicationRequest.medium
 *
 * http://hl7.org/fhir/_medium
 */
export const _medium = 'http://hl7.org/fhir/_medium' satisfies OwlObjectProperty;

/**
 * followUp
 *
 * Procedure.followUp: If the procedure required specific follow up - e.g. removal of sutures. The follow up may be represented as a simple note or could potentially be more complex, in which case the CarePlan resource can be used.
 *
 * http://hl7.org/fhir/followUp
 */
export const followUp = 'http://hl7.org/fhir/followUp' satisfies OwlObjectProperty;

/**
 * maxDuration
 *
 * SpecimenDefinition.typeTested.handling.maxDuration: The maximum time interval of preservation of the specimen with these conditions.
 *
 * http://hl7.org/fhir/maxDuration
 */
export const maxDuration = 'http://hl7.org/fhir/maxDuration' satisfies OwlObjectProperty;

/**
 * lotNumber
 *
 * Medication.batch.lotNumber: The assigned lot number of a batch of the specified product.
 *
 * http://hl7.org/fhir/lotNumber
 */
export const lotNumber = 'http://hl7.org/fhir/lotNumber' satisfies OwlObjectProperty;

/**
 * EncounterHistoryLocationComponent
 *
 * EncounterHistoryLocationComponent: The location of the patient at this point in the encounter, the multiple cardinality permits de-normalizing the levels of the location hierarchy, such as site/ward/room/bed.
 *
 * http://hl7.org/fhir/EncounterHistoryLocationComponent
 */
export const EncounterHistoryLocationComponent = 'http://hl7.org/fhir/EncounterHistoryLocationComponent' satisfies OwlClass;

/**
 * _owner
 *
 * (Modified) Transport.owner
 *
 * http://hl7.org/fhir/_owner
 */
export const _owner = 'http://hl7.org/fhir/_owner' satisfies OwlObjectProperty;

/**
 * InventoryItem
 *
 * functional description of an inventory item used in inventory and supply-related workflows.
 *
 * http://hl7.org/fhir/InventoryItem
 */
export const InventoryItem = 'http://hl7.org/fhir/InventoryItem' satisfies OwlClass;

/**
 * content
 *
 * Library.content: The content of the library as an Attachment. The content may be a reference to a url, or may be directly embedded as a base-64 string. Either way, the contentType of the attachment determines how to interpret the content.
 *
 * http://hl7.org/fhir/content
 */
export const content = 'http://hl7.org/fhir/content' satisfies OwlObjectProperty;

/**
 * DeviceDefinitionPropertyComponent
 *
 * DeviceDefinitionPropertyComponent: Static or essentially fixed characteristics or features of this kind of device that are otherwise not captured in more specific attributes, e.g., time or timing attributes, resolution, accuracy, and physical attributes.
 *
 * http://hl7.org/fhir/DeviceDefinitionPropertyComponent
 */
export const DeviceDefinitionPropertyComponent = 'http://hl7.org/fhir/DeviceDefinitionPropertyComponent' satisfies OwlClass;

/**
 * enteredDate
 *
 * ChargeItem.enteredDate: Date the charge item was entered.
 *
 * http://hl7.org/fhir/enteredDate
 */
export const enteredDate = 'http://hl7.org/fhir/enteredDate' satisfies OwlObjectProperty;

/**
 * _district
 *
 * (Modified) Address.district
 *
 * http://hl7.org/fhir/_district
 */
export const _district = 'http://hl7.org/fhir/_district' satisfies OwlObjectProperty;

/**
 * QuestionnaireItemComponentItemItem
 *
 * Text, questions and other groups to be nested beneath a question or group.
 *
 * http://hl7.org/fhir/QuestionnaireItemComponentItemItem
 */
export const QuestionnaireItemComponentItemItem = 'http://hl7.org/fhir/QuestionnaireItemComponentItemItem' satisfies OwlClass;

/**
 * eye
 *
 * VisionPrescription.lensSpecification.eye: The eye for which the lens specification applies.
 *
 * http://hl7.org/fhir/eye
 */
export const eye = 'http://hl7.org/fhir/eye' satisfies OwlObjectProperty;

/**
 * facilityType
 *
 * DocumentReference.facilityType: The kind of facility where the patient was seen.
 *
 * http://hl7.org/fhir/facilityType
 */
export const facilityType = 'http://hl7.org/fhir/facilityType' satisfies OwlObjectProperty;

/**
 * markdown
 *
 * A string that may contain Github Flavored Markdown syntax for optional processing by a mark down presentation engine
 *
 * http://hl7.org/fhir/markdown
 */
export const markdown = 'http://hl7.org/fhir/markdown' satisfies OwlClass;

/**
 * _friendly
 *
 * (Modified) Contract.friendly
 *
 * http://hl7.org/fhir/_friendly
 */
export const _friendly = 'http://hl7.org/fhir/_friendly' satisfies OwlObjectProperty;

/**
 * ManufacturedItemDefinitionComponentComponentComponent
 *
 * A component that this component contains or is made from.
 *
 * http://hl7.org/fhir/ManufacturedItemDefinitionComponentComponentComponent
 */
export const ManufacturedItemDefinitionComponentComponentComponent = 'http://hl7.org/fhir/ManufacturedItemDefinitionComponentComponentComponent' satisfies OwlClass;

/**
 * basedOn
 *
 * NutritionOrder.basedOn: A plan or request that is fulfilled in whole or in part by this nutrition order.
 *
 * http://hl7.org/fhir/basedOn
 */
export const basedOn = 'http://hl7.org/fhir/basedOn' satisfies OwlObjectProperty;

/**
 * assessmentMethod
 *
 * AdverseEvent.suspectEntity.causality.assessmentMethod: The method of evaluating the relatedness of the suspected entity to the event.
 *
 * http://hl7.org/fhir/assessmentMethod
 */
export const assessmentMethod = 'http://hl7.org/fhir/assessmentMethod' satisfies OwlObjectProperty;

/**
 * _sourceMaterialClass
 *
 * (Modified) SubstanceSourceMaterial.sourceMaterialClass
 *
 * http://hl7.org/fhir/_sourceMaterialClass
 */
export const _sourceMaterialClass = 'http://hl7.org/fhir/_sourceMaterialClass' satisfies OwlObjectProperty;

/**
 * CarePlanActivityComponent
 *
 * CarePlanActivityComponent: Identifies an action that has occurred or is a planned action to occur as part of the plan. For example, a medication to be used, lab tests to perform, self-monitoring that has occurred, education etc.
 *
 * http://hl7.org/fhir/CarePlanActivityComponent
 */
export const CarePlanActivityComponent = 'http://hl7.org/fhir/CarePlanActivityComponent' satisfies OwlClass;

/**
 * response
 *
 * ExampleScenario.process.step.process.step.alternative.step.operation.response: A reference to the instance that is transmitted from receiver to requester as part of the operation's synchronous response (if any).
 *
 * http://hl7.org/fhir/response
 */
export const response = 'http://hl7.org/fhir/response' satisfies OwlObjectProperty;

/**
 * _singleUse
 *
 * (Modified) SpecimenDefinition.typeTested.singleUse
 *
 * http://hl7.org/fhir/_singleUse
 */
export const _singleUse = 'http://hl7.org/fhir/_singleUse' satisfies OwlObjectProperty;

/**
 * ProvenanceAgentComponent
 *
 * ProvenanceAgentComponent: An actor taking a role in an activity  for which it can be assigned some degree of responsibility for the activity taking place.
 *
 * http://hl7.org/fhir/ProvenanceAgentComponent
 */
export const ProvenanceAgentComponent = 'http://hl7.org/fhir/ProvenanceAgentComponent' satisfies OwlClass;

/**
 * _kingdom
 *
 * (Modified) SubstanceSourceMaterial.organism.organismGeneral.kingdom
 *
 * http://hl7.org/fhir/_kingdom
 */
export const _kingdom = 'http://hl7.org/fhir/_kingdom' satisfies OwlObjectProperty;

/**
 * error
 *
 * SubscriptionStatus.error: A record of errors that occurred when the server processed a notification.
 *
 * http://hl7.org/fhir/error
 */
export const error = 'http://hl7.org/fhir/error' satisfies OwlObjectProperty;

/**
 * effect
 *
 * ClinicalUseDefinition.interaction.effect: The effect of the interaction, for example "reduced gastric absorption of primary medication".
 *
 * http://hl7.org/fhir/effect
 */
export const effect = 'http://hl7.org/fhir/effect' satisfies OwlObjectProperty;

/**
 * verifiedWith
 *
 * Consent.verification.verifiedWith: Who verified the instruction (Patient, Relative or other Authorized Person).
 *
 * http://hl7.org/fhir/verifiedWith
 */
export const verifiedWith = 'http://hl7.org/fhir/verifiedWith' satisfies OwlObjectProperty;

/**
 * _packaging
 *
 * (Modified) PackagedProductDefinition.packaging.packaging
 *
 * http://hl7.org/fhir/_packaging
 */
export const _packaging = 'http://hl7.org/fhir/_packaging' satisfies OwlObjectProperty;

/**
 * position
 *
 * Location.position: The absolute geographic location of the Location, expressed using the WGS84 datum (This is the same co-ordinate system used in KML).
 *
 * http://hl7.org/fhir/position
 */
export const position = 'http://hl7.org/fhir/position' satisfies OwlObjectProperty;

/**
 * EvidenceCertaintyComponentCertainty
 *
 * A domain or subdomain of certainty.
 *
 * http://hl7.org/fhir/EvidenceCertaintyComponentCertainty
 */
export const EvidenceCertaintyComponentCertainty = 'http://hl7.org/fhir/EvidenceCertaintyComponentCertainty' satisfies OwlClass;

/**
 * low
 *
 * SubstancePolymer.repeat.repeatUnit.degreeOfPolymerisation.low: A low expected limit of the amount.
 *
 * http://hl7.org/fhir/low
 */
export const low = 'http://hl7.org/fhir/low' satisfies OwlObjectProperty;

/**
 * _Device
 *
 * (Modified) Device
 *
 * http://hl7.org/fhir/_Device
 */
export const _Device = 'http://hl7.org/fhir/_Device' satisfies OwlClass;

/**
 * AddedItemSubDetail
 *
 * ClaimResponse.AddedItem.AddedItemDetail.AddedItemSubDetail: The third-tier service adjudications for payor added services.
 *
 * http://hl7.org/fhir/AddedItemSubDetail
 */
export const AddedItemSubDetail = 'http://hl7.org/fhir/AddedItemSubDetail' satisfies OwlClass;

/**
 * _responsible
 *
 * (Modified) PaymentReconciliation.allocation.responsible
 *
 * http://hl7.org/fhir/_responsible
 */
export const _responsible = 'http://hl7.org/fhir/_responsible' satisfies OwlObjectProperty;

/**
 * excludingDate
 *
 * Appointment.recurrenceTemplate.excludingDate: Any dates, such as holidays, that should be excluded from the recurrence.
 *
 * http://hl7.org/fhir/excludingDate
 */
export const excludingDate = 'http://hl7.org/fhir/excludingDate' satisfies OwlObjectProperty;

/**
 * _verified
 *
 * (Modified) Consent.verification.verified
 *
 * http://hl7.org/fhir/_verified
 */
export const _verified = 'http://hl7.org/fhir/_verified' satisfies OwlObjectProperty;

/**
 * TestScriptMetadataCapabilityComponent
 *
 * TestScriptMetadataComponent.TestScriptMetadataCapabilityComponent: Capabilities that must exist and are assumed to function correctly on the FHIR server being tested.
 *
 * http://hl7.org/fhir/TestScriptMetadataCapabilityComponent
 */
export const TestScriptMetadataCapabilityComponent = 'http://hl7.org/fhir/TestScriptMetadataCapabilityComponent' satisfies OwlClass;

/**
 * marketingStatus
 *
 * PackagedProductDefinition.marketingStatus: Allows specifying that an item is on the market for sale, or that it is not available, and the dates and locations associated.
 *
 * http://hl7.org/fhir/marketingStatus
 */
export const marketingStatus = 'http://hl7.org/fhir/marketingStatus' satisfies OwlObjectProperty;

/**
 * _ClaimResponse
 *
 * (Modified) ClaimResponse
 *
 * http://hl7.org/fhir/_ClaimResponse
 */
export const _ClaimResponse = 'http://hl7.org/fhir/_ClaimResponse' satisfies OwlClass;

/**
 * request
 *
 * PaymentReconciliation.request: Original request resource reference.
 *
 * http://hl7.org/fhir/request
 */
export const request = 'http://hl7.org/fhir/request' satisfies OwlObjectProperty;

/**
 * MolecularSequenceRelativeEditComponent
 *
 * MolecularSequenceRelativeComponent.MolecularSequenceRelativeEditComponent: Changes in sequence from the starting sequence.
 *
 * http://hl7.org/fhir/MolecularSequenceRelativeEditComponent
 */
export const MolecularSequenceRelativeEditComponent = 'http://hl7.org/fhir/MolecularSequenceRelativeEditComponent' satisfies OwlClass;

/**
 * periodType
 *
 * Contract.term.group.asset.periodType: Type of Asset availability for use or ownership.
 *
 * http://hl7.org/fhir/periodType
 */
export const periodType = 'http://hl7.org/fhir/periodType' satisfies OwlObjectProperty;

/**
 * approvalDate
 *
 * EvidenceVariable.approvalDate: The date on which the resource content was approved by the publisher. Approval happens once when the content is officially approved for usage.
 * 
 * See guidance around (not) making local changes to elements [here](canonicalresource.html#localization).
 *
 * http://hl7.org/fhir/approvalDate
 */
export const approvalDate = 'http://hl7.org/fhir/approvalDate' satisfies OwlObjectProperty;

/**
 * _monomerSet
 *
 * (Modified) SubstancePolymer.monomerSet
 *
 * http://hl7.org/fhir/_monomerSet
 */
export const _monomerSet = 'http://hl7.org/fhir/_monomerSet' satisfies OwlObjectProperty;

/**
 * _eventTrigger
 *
 * (Modified) SubscriptionTopic.eventTrigger
 *
 * http://hl7.org/fhir/_eventTrigger
 */
export const _eventTrigger = 'http://hl7.org/fhir/_eventTrigger' satisfies OwlObjectProperty;

/**
 * _ingredient
 *
 * (Modified) Substance.ingredient
 *
 * http://hl7.org/fhir/_ingredient
 */
export const _ingredient = 'http://hl7.org/fhir/_ingredient' satisfies OwlObjectProperty;

/**
 * _biologicalSourceEvent
 *
 * (Modified) NutritionProduct.instance.biologicalSourceEvent
 *
 * http://hl7.org/fhir/_biologicalSourceEvent
 */
export const _biologicalSourceEvent = 'http://hl7.org/fhir/_biologicalSourceEvent' satisfies OwlObjectProperty;

/**
 * durationMax
 *
 * Timing.repeat.durationMax: If present, indicates that the duration is a range - so to perform the action between [duration] and [durationMax] time length.
 *
 * http://hl7.org/fhir/durationMax
 */
export const durationMax = 'http://hl7.org/fhir/durationMax' satisfies OwlObjectProperty;

/**
 * _MolecularSequence
 *
 * (Modified) MolecularSequence
 *
 * http://hl7.org/fhir/_MolecularSequence
 */
export const _MolecularSequence = 'http://hl7.org/fhir/_MolecularSequence' satisfies OwlClass;

/**
 * _permittedDataType
 *
 * (Modified) ObservationDefinition.component.permittedDataType
 *
 * http://hl7.org/fhir/_permittedDataType
 */
export const _permittedDataType = 'http://hl7.org/fhir/_permittedDataType' satisfies OwlObjectProperty;

/**
 * subtitle
 *
 * Measure.subtitle: An explanatory or alternate title for the measure giving additional information about its content.
 *
 * http://hl7.org/fhir/subtitle
 */
export const subtitle = 'http://hl7.org/fhir/subtitle' satisfies OwlObjectProperty;

/**
 * _SubscriptionStatus
 *
 * (Modified) SubscriptionStatus
 *
 * http://hl7.org/fhir/_SubscriptionStatus
 */
export const _SubscriptionStatus = 'http://hl7.org/fhir/_SubscriptionStatus' satisfies OwlClass;

/**
 * maxTreatmentPeriod
 *
 * AdministrableProductDefinition.routeOfAdministration.maxTreatmentPeriod: The maximum treatment period during which the product can be administered.
 *
 * http://hl7.org/fhir/maxTreatmentPeriod
 */
export const maxTreatmentPeriod = 'http://hl7.org/fhir/maxTreatmentPeriod' satisfies OwlObjectProperty;

/**
 * _relatedIdentifier
 *
 * (Modified) EvidenceReport.relatedIdentifier
 *
 * http://hl7.org/fhir/_relatedIdentifier
 */
export const _relatedIdentifier = 'http://hl7.org/fhir/_relatedIdentifier' satisfies OwlObjectProperty;

/**
 * _feature
 *
 * (Modified) Specimen.feature
 *
 * http://hl7.org/fhir/_feature
 */
export const _feature = 'http://hl7.org/fhir/_feature' satisfies OwlObjectProperty;

/**
 * ValueSetExpansionComponent
 *
 * ValueSetExpansionComponent: A value set can also be "expanded", where the value set is turned into a simple collection of enumerated codes. This element holds the expansion, if it has been performed.
 *
 * http://hl7.org/fhir/ValueSetExpansionComponent
 */
export const ValueSetExpansionComponent = 'http://hl7.org/fhir/ValueSetExpansionComponent' satisfies OwlClass;

/**
 * _parameterFocus
 *
 * (Modified) ServiceRequest.orderDetail.parameterFocus
 *
 * http://hl7.org/fhir/_parameterFocus
 */
export const _parameterFocus = 'http://hl7.org/fhir/_parameterFocus' satisfies OwlObjectProperty;

/**
 * _maxDosePerDay
 *
 * (Modified) AdministrableProductDefinition.routeOfAdministration.maxDosePerDay
 *
 * http://hl7.org/fhir/_maxDosePerDay
 */
export const _maxDosePerDay = 'http://hl7.org/fhir/_maxDosePerDay' satisfies OwlObjectProperty;

/**
 * CapabilityStatementMessagingComponent
 *
 * CapabilityStatementMessagingComponent: A description of the messaging capabilities of the solution.
 *
 * http://hl7.org/fhir/CapabilityStatementMessagingComponent
 */
export const CapabilityStatementMessagingComponent = 'http://hl7.org/fhir/CapabilityStatementMessagingComponent' satisfies OwlClass;

/**
 * ResearchStudyObjectiveComponent
 *
 * ResearchStudyObjectiveComponent: A goal that the study is aiming to achieve in terms of a scientific question to be answered by the analysis of data collected during the study.
 *
 * http://hl7.org/fhir/ResearchStudyObjectiveComponent
 */
export const ResearchStudyObjectiveComponent = 'http://hl7.org/fhir/ResearchStudyObjectiveComponent' satisfies OwlClass;

/**
 * MedicationIngredientComponent
 *
 * MedicationIngredientComponent: Identifies a particular constituent of interest in the product.
 *
 * http://hl7.org/fhir/MedicationIngredientComponent
 */
export const MedicationIngredientComponent = 'http://hl7.org/fhir/MedicationIngredientComponent' satisfies OwlClass;

/**
 * SourceElement
 *
 * ConceptMapGroupComponent.SourceElement: Mappings for an individual concept in the source to one or more concepts in the target.
 *
 * http://hl7.org/fhir/SourceElement
 */
export const SourceElement = 'http://hl7.org/fhir/SourceElement' satisfies OwlClass;

/**
 * _sequence
 *
 * (Modified) ExplanationOfBenefit.diagnosis.sequence
 *
 * http://hl7.org/fhir/_sequence
 */
export const _sequence = 'http://hl7.org/fhir/_sequence' satisfies OwlObjectProperty;

/**
 * _validateProfileId
 *
 * (Modified) TestScript.test.action.assert.validateProfileId
 *
 * http://hl7.org/fhir/_validateProfileId
 */
export const _validateProfileId = 'http://hl7.org/fhir/_validateProfileId' satisfies OwlObjectProperty;

/**
 * responsibility
 *
 * Coverage.paymentBy.responsibility:  Description of the financial responsibility.
 *
 * http://hl7.org/fhir/responsibility
 */
export const responsibility = 'http://hl7.org/fhir/responsibility' satisfies OwlObjectProperty;

/**
 * containedItem
 *
 * PackagedProductDefinition.packaging.packaging.containedItem: The item(s) within the packaging.
 *
 * http://hl7.org/fhir/containedItem
 */
export const containedItem = 'http://hl7.org/fhir/containedItem' satisfies OwlObjectProperty;

/**
 * completionTime
 *
 * Transport.completionTime: Identifies the completion time of the event (the occurrence).
 *
 * http://hl7.org/fhir/completionTime
 */
export const completionTime = 'http://hl7.org/fhir/completionTime' satisfies OwlObjectProperty;

/**
 * _identifier
 *
 * (Modified) Reference.identifier
 *
 * http://hl7.org/fhir/_identifier
 */
export const _identifier = 'http://hl7.org/fhir/_identifier' satisfies OwlObjectProperty;

/**
 * _scope
 *
 * (Modified) Contract.term.asset.scope
 *
 * http://hl7.org/fhir/_scope
 */
export const _scope = 'http://hl7.org/fhir/_scope' satisfies OwlObjectProperty;

/**
 * currency
 *
 * Account.currency: The default currency for the account.
 *
 * http://hl7.org/fhir/currency
 */
export const currency = 'http://hl7.org/fhir/currency' satisfies OwlObjectProperty;

/**
 * _inputProfile
 *
 * (Modified) OperationDefinition.inputProfile
 *
 * http://hl7.org/fhir/_inputProfile
 */
export const _inputProfile = 'http://hl7.org/fhir/_inputProfile' satisfies OwlObjectProperty;

/**
 * TestAction
 *
 * TestScriptTestComponent.TestAction: Action would contain either an operation or an assertion.
 *
 * http://hl7.org/fhir/TestAction
 */
export const TestAction = 'http://hl7.org/fhir/TestAction' satisfies OwlClass;

/**
 * _performer
 *
 * (Modified) Procedure.performer
 *
 * http://hl7.org/fhir/_performer
 */
export const _performer = 'http://hl7.org/fhir/_performer' satisfies OwlObjectProperty;

/**
 * QuestionnaireResponseItemComponentItemItem
 *
 * Sub-questions, sub-groups or display items nested beneath a group.
 *
 * http://hl7.org/fhir/QuestionnaireResponseItemComponentItemItem
 */
export const QuestionnaireResponseItemComponentItemItem = 'http://hl7.org/fhir/QuestionnaireResponseItemComponentItemItem' satisfies OwlClass;

/**
 * _pushTypeAvailable
 *
 * (Modified) VerificationResult.primarySource.pushTypeAvailable
 *
 * http://hl7.org/fhir/_pushTypeAvailable
 */
export const _pushTypeAvailable = 'http://hl7.org/fhir/_pushTypeAvailable' satisfies OwlObjectProperty;

/**
 * communication
 *
 * RelatedPerson.communication: A language which may be used to communicate with the related person about the patient's health.
 *
 * http://hl7.org/fhir/communication
 */
export const communication = 'http://hl7.org/fhir/communication' satisfies OwlObjectProperty;

/**
 * interpretation
 *
 * Observation.component.interpretation: A categorical assessment of an observation value.  For example, high, low, normal.
 *
 * http://hl7.org/fhir/interpretation
 */
export const interpretation = 'http://hl7.org/fhir/interpretation' satisfies OwlObjectProperty;

/**
 * _capacity
 *
 * (Modified) SpecimenDefinition.typeTested.container.capacity
 *
 * http://hl7.org/fhir/_capacity
 */
export const _capacity = 'http://hl7.org/fhir/_capacity' satisfies OwlObjectProperty;

/**
 * topic
 *
 * ConceptMap.topic: Descriptions related to the content of the ConceptMap. Topics provide a high-level categorization as well as keywords for the ConceptMap that can be useful for filtering and searching.
 *
 * http://hl7.org/fhir/topic
 */
export const topic = 'http://hl7.org/fhir/topic' satisfies OwlObjectProperty;

/**
 * _undesirableEffect
 *
 * (Modified) ClinicalUseDefinition.undesirableEffect
 *
 * http://hl7.org/fhir/_undesirableEffect
 */
export const _undesirableEffect = 'http://hl7.org/fhir/_undesirableEffect' satisfies OwlObjectProperty;

/**
 * _noteNumber
 *
 * (Modified) ExplanationOfBenefit.addItem.detail.subDetail.noteNumber
 *
 * http://hl7.org/fhir/_noteNumber
 */
export const _noteNumber = 'http://hl7.org/fhir/_noteNumber' satisfies OwlObjectProperty;

/**
 * _DeviceRequest
 *
 * (Modified) DeviceRequest
 *
 * http://hl7.org/fhir/_DeviceRequest
 */
export const _DeviceRequest = 'http://hl7.org/fhir/_DeviceRequest' satisfies OwlClass;

/**
 * courseOfTherapyType
 *
 * MedicationRequest.courseOfTherapyType: The description of the overall pattern of the administration of the medication to the patient.
 *
 * http://hl7.org/fhir/courseOfTherapyType
 */
export const courseOfTherapyType = 'http://hl7.org/fhir/courseOfTherapyType' satisfies OwlObjectProperty;

/**
 * ordinalPosition
 *
 * MolecularSequence.relative.ordinalPosition: Indicates the order in which the sequence should be considered when putting multiple 'relative' elements together.
 *
 * http://hl7.org/fhir/ordinalPosition
 */
export const ordinalPosition = 'http://hl7.org/fhir/ordinalPosition' satisfies OwlObjectProperty;

/**
 * ObservationComponentComponentReferenceRange
 *
 * Guidance on how to interpret the value by comparison to a normal or recommended range.
 *
 * http://hl7.org/fhir/ObservationComponentComponentReferenceRange
 */
export const ObservationComponentComponentReferenceRange = 'http://hl7.org/fhir/ObservationComponentComponentReferenceRange' satisfies OwlClass;

/**
 * _actorId
 *
 * (Modified) PlanDefinition.action.action.participant.actorId
 *
 * http://hl7.org/fhir/_actorId
 */
export const _actorId = 'http://hl7.org/fhir/_actorId' satisfies OwlObjectProperty;

/**
 * conclusion
 *
 * DiagnosticReport.conclusion: Concise and clinically contextualized summary conclusion (interpretation/impression) of the diagnostic report.
 *
 * http://hl7.org/fhir/conclusion
 */
export const conclusion = 'http://hl7.org/fhir/conclusion' satisfies OwlObjectProperty;

/**
 * Resource
 *
 * This is the base resource type for everything.
 *
 * http://hl7.org/fhir/Resource
 */
export const Resource = 'http://hl7.org/fhir/Resource' satisfies OwlClass;

/**
 * accountNumber
 *
 * PaymentReconciliation.accountNumber: A portion of the account number, often the last 4 digits, used for verification not charging purposes.
 *
 * http://hl7.org/fhir/accountNumber
 */
export const accountNumber = 'http://hl7.org/fhir/accountNumber' satisfies OwlObjectProperty;

/**
 * deliverTo
 *
 * SupplyRequest.deliverTo: Where the supply is destined to go.
 *
 * http://hl7.org/fhir/deliverTo
 */
export const deliverTo = 'http://hl7.org/fhir/deliverTo' satisfies OwlObjectProperty;

/**
 * multipleResultsAllowed
 *
 * ObservationDefinition.multipleResultsAllowed: Multiple results allowed for observations conforming to this ObservationDefinition.
 *
 * http://hl7.org/fhir/multipleResultsAllowed
 */
export const multipleResultsAllowed = 'http://hl7.org/fhir/multipleResultsAllowed' satisfies OwlObjectProperty;

/**
 * _asNeeded
 *
 * (Modified) NutritionOrder.supplement.schedule.asNeeded
 *
 * http://hl7.org/fhir/_asNeeded
 */
export const _asNeeded = 'http://hl7.org/fhir/_asNeeded' satisfies OwlObjectProperty;

/**
 * _onHold
 *
 * (Modified) Account.guarantor.onHold
 *
 * http://hl7.org/fhir/_onHold
 */
export const _onHold = 'http://hl7.org/fhir/_onHold' satisfies OwlObjectProperty;

/**
 * genomeAssembly
 *
 * MolecularSequence.relative.startingSequence.genomeAssembly: The genome assembly used for starting sequence, e.g. GRCh38.
 *
 * http://hl7.org/fhir/genomeAssembly
 */
export const genomeAssembly = 'http://hl7.org/fhir/genomeAssembly' satisfies OwlObjectProperty;

/**
 * _preAuthRefPeriod
 *
 * (Modified) ExplanationOfBenefit.preAuthRefPeriod
 *
 * http://hl7.org/fhir/_preAuthRefPeriod
 */
export const _preAuthRefPeriod = 'http://hl7.org/fhir/_preAuthRefPeriod' satisfies OwlObjectProperty;

/**
 * itemSequence
 *
 * ClaimResponse.item.itemSequence: A number to uniquely reference the claim item entries.
 *
 * http://hl7.org/fhir/itemSequence
 */
export const itemSequence = 'http://hl7.org/fhir/itemSequence' satisfies OwlObjectProperty;

/**
 * _relatedClinicalInformation
 *
 * (Modified) MedicationStatement.relatedClinicalInformation
 *
 * http://hl7.org/fhir/_relatedClinicalInformation
 */
export const _relatedClinicalInformation = 'http://hl7.org/fhir/_relatedClinicalInformation' satisfies OwlObjectProperty;

/**
 * ResearchStudy
 *
 * A scientific study of nature that sometimes includes processes involved in health and disease. For example, clinical trials are research studies that involve people. These studies may be related to new ways to screen, prevent, diagnose, and treat disease. They may also study certain outcomes and certain groups of people by looking at data collected in the past or future.
 *
 * http://hl7.org/fhir/ResearchStudy
 */
export const ResearchStudy = 'http://hl7.org/fhir/ResearchStudy' satisfies OwlClass;

/**
 * _action
 *
 * (Modified) PlanDefinition.action.action
 *
 * http://hl7.org/fhir/_action
 */
export const _action = 'http://hl7.org/fhir/_action' satisfies OwlObjectProperty;

/**
 * _DocumentReference
 *
 * (Modified) DocumentReference
 *
 * http://hl7.org/fhir/_DocumentReference
 */
export const _DocumentReference = 'http://hl7.org/fhir/_DocumentReference' satisfies OwlClass;

/**
 * _coverageArea
 *
 * (Modified) InsurancePlan.plan.coverageArea
 *
 * http://hl7.org/fhir/_coverageArea
 */
export const _coverageArea = 'http://hl7.org/fhir/_coverageArea' satisfies OwlObjectProperty;

/**
 * DataType
 *
 * The base class for all re-useable types defined as part of the FHIR Specification.
 *
 * http://hl7.org/fhir/DataType
 */
export const DataType = 'http://hl7.org/fhir/DataType' satisfies OwlClass;

/**
 * Duration
 *
 * A length of time.
 *
 * http://hl7.org/fhir/Duration
 */
export const Duration = 'http://hl7.org/fhir/Duration' satisfies OwlClass;

/**
 * _Consent
 *
 * (Modified) Consent
 *
 * http://hl7.org/fhir/_Consent
 */
export const _Consent = 'http://hl7.org/fhir/_Consent' satisfies OwlClass;

/**
 * _referencePolicy
 *
 * (Modified) CapabilityStatement.rest.resource.referencePolicy
 *
 * http://hl7.org/fhir/_referencePolicy
 */
export const _referencePolicy = 'http://hl7.org/fhir/_referencePolicy' satisfies OwlObjectProperty;

/**
 * _virtualService
 *
 * (Modified) Location.virtualService
 *
 * http://hl7.org/fhir/_virtualService
 */
export const _virtualService = 'http://hl7.org/fhir/_virtualService' satisfies OwlObjectProperty;

/**
 * _lastModified
 *
 * (Modified) Transport.lastModified
 *
 * http://hl7.org/fhir/_lastModified
 */
export const _lastModified = 'http://hl7.org/fhir/_lastModified' satisfies OwlObjectProperty;

/**
 * destination
 *
 * TestScript.test.action.operation.destination: The server where the request message is destined for.  Must be one of the server numbers listed in TestScript.destination section.
 *
 * http://hl7.org/fhir/destination
 */
export const destination = 'http://hl7.org/fhir/destination' satisfies OwlObjectProperty;

/**
 * _whenHandedOver
 *
 * (Modified) MedicationDispense.whenHandedOver
 *
 * http://hl7.org/fhir/_whenHandedOver
 */
export const _whenHandedOver = 'http://hl7.org/fhir/_whenHandedOver' satisfies OwlObjectProperty;

/**
 * _typeTested
 *
 * (Modified) SpecimenDefinition.typeTested
 *
 * http://hl7.org/fhir/_typeTested
 */
export const _typeTested = 'http://hl7.org/fhir/_typeTested' satisfies OwlObjectProperty;

/**
 * product
 *
 * ActivityDefinition.product
 *
 * http://hl7.org/fhir/product
 */
export const product = 'http://hl7.org/fhir/product' satisfies OwlObjectProperty;

/**
 * _referrer
 *
 * (Modified) ImagingStudy.referrer
 *
 * http://hl7.org/fhir/_referrer
 */
export const _referrer = 'http://hl7.org/fhir/_referrer' satisfies OwlObjectProperty;

/**
 * plannedEndDate
 *
 * EncounterHistory.plannedEndDate: The planned end date/time (or discharge date) of the encounter.
 *
 * http://hl7.org/fhir/plannedEndDate
 */
export const plannedEndDate = 'http://hl7.org/fhir/plannedEndDate' satisfies OwlObjectProperty;

/**
 * _birthDate
 *
 * (Modified) RelatedPerson.birthDate
 *
 * http://hl7.org/fhir/_birthDate
 */
export const _birthDate = 'http://hl7.org/fhir/_birthDate' satisfies OwlObjectProperty;

/**
 * _mustHaveValue
 *
 * (Modified) ElementDefinition.mustHaveValue
 *
 * http://hl7.org/fhir/_mustHaveValue
 */
export const _mustHaveValue = 'http://hl7.org/fhir/_mustHaveValue' satisfies OwlObjectProperty;

/**
 * ClinicalUseDefinition
 *
 * A single issue - either an indication, contraindication, interaction or an undesirable effect for a medicinal product, medication, device or procedure.
 *
 * http://hl7.org/fhir/ClinicalUseDefinition
 */
export const ClinicalUseDefinition = 'http://hl7.org/fhir/ClinicalUseDefinition' satisfies OwlClass;

/**
 * dynamicValue
 *
 * PlanDefinition.action.dynamicValue: Customizations that should be applied to the statically defined resource. For example, if the dosage of a medication must be computed based on the patient's weight, a customization would be used to specify an expression that calculated the weight, and the path on the resource that would contain the result.
 *
 * http://hl7.org/fhir/dynamicValue
 */
export const dynamicValue = 'http://hl7.org/fhir/dynamicValue' satisfies OwlObjectProperty;

/**
 * _detailSequence
 *
 * (Modified) ExplanationOfBenefit.addItem.detailSequence
 *
 * http://hl7.org/fhir/_detailSequence
 */
export const _detailSequence = 'http://hl7.org/fhir/_detailSequence' satisfies OwlObjectProperty;

/**
 * SupportingInformation
 *
 * Claim.SupportingInformation: Additional information codes regarding exceptions, special considerations, the condition, situation, prior or concurrent issues.
 *
 * http://hl7.org/fhir/SupportingInformation
 */
export const SupportingInformation = 'http://hl7.org/fhir/SupportingInformation' satisfies OwlClass;

/**
 * CitationStatusDateComponent
 *
 * CitationStatusDateComponent: The state or status of the citation record paired with an effective date or period for that state.
 *
 * http://hl7.org/fhir/CitationStatusDateComponent
 */
export const CitationStatusDateComponent = 'http://hl7.org/fhir/CitationStatusDateComponent' satisfies OwlClass;

/**
 * subscriberId
 *
 * Coverage.subscriberId: The insurer assigned ID for the Subscriber.
 *
 * http://hl7.org/fhir/subscriberId
 */
export const subscriberId = 'http://hl7.org/fhir/subscriberId' satisfies OwlObjectProperty;

/**
 * node
 *
 * GraphDefinition.node: Potential target for the link.
 *
 * http://hl7.org/fhir/node
 */
export const node = 'http://hl7.org/fhir/node' satisfies OwlObjectProperty;

/**
 * details
 *
 * OperationOutcome.issue.details: Additional details about the error. This may be a text description of the error or a system code that identifies the error.
 *
 * http://hl7.org/fhir/details
 */
export const details = 'http://hl7.org/fhir/details' satisfies OwlObjectProperty;

/**
 * GenomicStudyAnalysisInputComponent
 *
 * GenomicStudyAnalysisComponent.GenomicStudyAnalysisInputComponent: Inputs for the analysis event.
 *
 * http://hl7.org/fhir/GenomicStudyAnalysisInputComponent
 */
export const GenomicStudyAnalysisInputComponent = 'http://hl7.org/fhir/GenomicStudyAnalysisInputComponent' satisfies OwlClass;

/**
 * contract
 *
 * Coverage.contract: The policy(s) which constitute this insurance coverage.
 *
 * http://hl7.org/fhir/contract
 */
export const contract = 'http://hl7.org/fhir/contract' satisfies OwlObjectProperty;

/**
 * _paymentIssuer
 *
 * (Modified) PaymentReconciliation.paymentIssuer
 *
 * http://hl7.org/fhir/_paymentIssuer
 */
export const _paymentIssuer = 'http://hl7.org/fhir/_paymentIssuer' satisfies OwlObjectProperty;

/**
 * _clinicalTrial
 *
 * (Modified) MedicinalProductDefinition.clinicalTrial
 *
 * http://hl7.org/fhir/_clinicalTrial
 */
export const _clinicalTrial = 'http://hl7.org/fhir/_clinicalTrial' satisfies OwlObjectProperty;

/**
 * Adjudication
 *
 * ExplanationOfBenefit.Item.Adjudication: If this item is a group then the values here are a summary of the adjudication of the detail items. If this item is a simple product or service then this is the result of the adjudication of this item.
 *
 * http://hl7.org/fhir/Adjudication
 */
export const Adjudication = 'http://hl7.org/fhir/Adjudication' satisfies OwlClass;

/**
 * AdverseEventMitigatingActionComponent
 *
 * AdverseEventMitigatingActionComponent: The ameliorating action taken after the adverse event occured in order to reduce the extent of harm.
 *
 * http://hl7.org/fhir/AdverseEventMitigatingActionComponent
 */
export const AdverseEventMitigatingActionComponent = 'http://hl7.org/fhir/AdverseEventMitigatingActionComponent' satisfies OwlClass;

/**
 * ratioType
 *
 * SubstancePolymer.monomerSet.ratioType: Captures the type of ratio to the entire polymer, e.g. Monomer/Polymer ratio, SRU/Polymer Ratio.
 *
 * http://hl7.org/fhir/ratioType
 */
export const ratioType = 'http://hl7.org/fhir/ratioType' satisfies OwlObjectProperty;

/**
 * authoritative
 *
 * NamingSystem.uniqueId.authoritative: Indicates whether this identifier ie endorsed by the official owner of the associated naming system.
 *
 * http://hl7.org/fhir/authoritative
 */
export const authoritative = 'http://hl7.org/fhir/authoritative' satisfies OwlObjectProperty;

/**
 * chromosome
 *
 * MolecularSequence.relative.startingSequence.chromosome: Structural unit composed of a nucleic acid molecule which controls its own replication through the interaction of specific proteins at one or more origins of replication ([SO:0000340](http://www.sequenceontology.org/browser/current_svn/term/SO:0000340)).
 *
 * http://hl7.org/fhir/chromosome
 */
export const chromosome = 'http://hl7.org/fhir/chromosome' satisfies OwlObjectProperty;

/**
 * referralMethod
 *
 * HealthcareService.referralMethod: Ways that the service accepts referrals, if this is not provided then it is implied that no referral is required.
 *
 * http://hl7.org/fhir/referralMethod
 */
export const referralMethod = 'http://hl7.org/fhir/referralMethod' satisfies OwlObjectProperty;

/**
 * MedicationKnowledgeDefinitionalDrugCharacteristicComponent
 *
 * MedicationKnowledgeDefinitionalComponent.MedicationKnowledgeDefinitionalDrugCharacteristicComponent: Specifies descriptive properties of the medicine, such as color, shape, imprints, etc.
 *
 * http://hl7.org/fhir/MedicationKnowledgeDefinitionalDrugCharacteristicComponent
 */
export const MedicationKnowledgeDefinitionalDrugCharacteristicComponent = 'http://hl7.org/fhir/MedicationKnowledgeDefinitionalDrugCharacteristicComponent' satisfies OwlClass;

/**
 * _filterParameter
 *
 * (Modified) SubscriptionTopic.canFilterBy.filterParameter
 *
 * http://hl7.org/fhir/_filterParameter
 */
export const _filterParameter = 'http://hl7.org/fhir/_filterParameter' satisfies OwlObjectProperty;

/**
 * _costCenter
 *
 * (Modified) ChargeItem.costCenter
 *
 * http://hl7.org/fhir/_costCenter
 */
export const _costCenter = 'http://hl7.org/fhir/_costCenter' satisfies OwlObjectProperty;

/**
 * _maternalOrganismName
 *
 * (Modified) SubstanceSourceMaterial.organism.hybrid.maternalOrganismName
 *
 * http://hl7.org/fhir/_maternalOrganismName
 */
export const _maternalOrganismName = 'http://hl7.org/fhir/_maternalOrganismName' satisfies OwlObjectProperty;

/**
 * _CommunicationRequest
 *
 * (Modified) CommunicationRequest
 *
 * http://hl7.org/fhir/_CommunicationRequest
 */
export const _CommunicationRequest = 'http://hl7.org/fhir/_CommunicationRequest' satisfies OwlClass;

/**
 * _mapping
 *
 * (Modified) StructureDefinition.mapping
 *
 * http://hl7.org/fhir/_mapping
 */
export const _mapping = 'http://hl7.org/fhir/_mapping' satisfies OwlObjectProperty;

/**
 * _spatialReference
 *
 * (Modified) BodyStructure.excludedStructure.spatialReference
 *
 * http://hl7.org/fhir/_spatialReference
 */
export const _spatialReference = 'http://hl7.org/fhir/_spatialReference' satisfies OwlObjectProperty;

/**
 * _AppointmentResponse
 *
 * (Modified) AppointmentResponse
 *
 * http://hl7.org/fhir/_AppointmentResponse
 */
export const _AppointmentResponse = 'http://hl7.org/fhir/_AppointmentResponse' satisfies OwlClass;

/**
 * preparation
 *
 * SpecimenDefinition.typeTested.container.preparation: Special processing that should be applied to the container for this kind of specimen.
 *
 * http://hl7.org/fhir/preparation
 */
export const preparation = 'http://hl7.org/fhir/preparation' satisfies OwlObjectProperty;

/**
 * _outcome
 *
 * (Modified) FamilyMemberHistory.condition.outcome
 *
 * http://hl7.org/fhir/_outcome
 */
export const _outcome = 'http://hl7.org/fhir/_outcome' satisfies OwlObjectProperty;

/**
 * _policy
 *
 * (Modified) Provenance.policy
 *
 * http://hl7.org/fhir/_policy
 */
export const _policy = 'http://hl7.org/fhir/_policy' satisfies OwlObjectProperty;

/**
 * planningHorizon
 *
 * Schedule.planningHorizon: The period of time that the slots that reference this Schedule resource cover (even if none exist). These  cover the amount of time that an organization's planning horizon; the interval for which they are currently accepting appointments. This does not define a "template" for planning outside these dates.
 *
 * http://hl7.org/fhir/planningHorizon
 */
export const planningHorizon = 'http://hl7.org/fhir/planningHorizon' satisfies OwlObjectProperty;

/**
 * _targetSpecies
 *
 * (Modified) AdministrableProductDefinition.routeOfAdministration.targetSpecies
 *
 * http://hl7.org/fhir/_targetSpecies
 */
export const _targetSpecies = 'http://hl7.org/fhir/_targetSpecies' satisfies OwlObjectProperty;

/**
 * EvidenceVariableCharacteristicComponent
 *
 * EvidenceVariableCharacteristicComponent: A defining factor of the EvidenceVariable. Multiple characteristics are applied with "and" semantics.
 *
 * http://hl7.org/fhir/EvidenceVariableCharacteristicComponent
 */
export const EvidenceVariableCharacteristicComponent = 'http://hl7.org/fhir/EvidenceVariableCharacteristicComponent' satisfies OwlClass;

/**
 * _authorization
 *
 * (Modified) Provenance.authorization
 *
 * http://hl7.org/fhir/_authorization
 */
export const _authorization = 'http://hl7.org/fhir/_authorization' satisfies OwlObjectProperty;

/**
 * software
 *
 * TerminologyCapabilities.software: Software that is covered by this terminology capability statement.  It is used when the statement describes the capabilities of a particular software version, independent of an installation.
 *
 * http://hl7.org/fhir/software
 */
export const software = 'http://hl7.org/fhir/software' satisfies OwlObjectProperty;

/**
 * _lastReviewDate
 *
 * (Modified) ArtifactAssessment.lastReviewDate
 *
 * http://hl7.org/fhir/_lastReviewDate
 */
export const _lastReviewDate = 'http://hl7.org/fhir/_lastReviewDate' satisfies OwlObjectProperty;

/**
 * _derivedFromCanonical
 *
 * (Modified) SpecimenDefinition.derivedFromCanonical
 *
 * http://hl7.org/fhir/_derivedFromCanonical
 */
export const _derivedFromCanonical = 'http://hl7.org/fhir/_derivedFromCanonical' satisfies OwlObjectProperty;

/**
 * specialCourtesy
 *
 * Encounter.specialCourtesy: Special courtesies that may be provided to the patient during the encounter (VIP, board member, professional courtesy).
 *
 * http://hl7.org/fhir/specialCourtesy
 */
export const specialCourtesy = 'http://hl7.org/fhir/specialCourtesy' satisfies OwlObjectProperty;

/**
 * intraspecificType
 *
 * SubstanceSourceMaterial.organism.intraspecificType: The Intraspecific type of an organism shall be specified.
 *
 * http://hl7.org/fhir/intraspecificType
 */
export const intraspecificType = 'http://hl7.org/fhir/intraspecificType' satisfies OwlObjectProperty;

/**
 * shortTitle
 *
 * EvidenceVariable.shortTitle: The short title provides an alternate title for use in informal descriptive contexts where the full, formal title is not necessary.
 *
 * http://hl7.org/fhir/shortTitle
 */
export const shortTitle = 'http://hl7.org/fhir/shortTitle' satisfies OwlObjectProperty;

/**
 * channelType
 *
 * Subscription.channelType: The type of channel to send notifications on.
 *
 * http://hl7.org/fhir/channelType
 */
export const channelType = 'http://hl7.org/fhir/channelType' satisfies OwlObjectProperty;

/**
 * _subSite
 *
 * (Modified) ExplanationOfBenefit.addItem.bodySite.subSite
 *
 * http://hl7.org/fhir/_subSite
 */
export const _subSite = 'http://hl7.org/fhir/_subSite' satisfies OwlObjectProperty;

/**
 * use
 *
 * ValueSet.compose.include.concept.designation.use: A code that represents types of uses of designations.
 *
 * http://hl7.org/fhir/use
 */
export const use = 'http://hl7.org/fhir/use' satisfies OwlObjectProperty;

/**
 * webLocation
 *
 * Citation.citedArtifact.webLocation: Used for any URL for the article or artifact cited.
 *
 * http://hl7.org/fhir/webLocation
 */
export const webLocation = 'http://hl7.org/fhir/webLocation' satisfies OwlObjectProperty;

/**
 * PlanDefinitionGoalTargetComponent
 *
 * PlanDefinitionGoalComponent.PlanDefinitionGoalTargetComponent: Indicates what should be done and within what timeframe.
 *
 * http://hl7.org/fhir/PlanDefinitionGoalTargetComponent
 */
export const PlanDefinitionGoalTargetComponent = 'http://hl7.org/fhir/PlanDefinitionGoalTargetComponent' satisfies OwlClass;

/**
 * _entryQuantity
 *
 * (Modified) EvidenceReport.section.section.entryQuantity
 *
 * http://hl7.org/fhir/_entryQuantity
 */
export const _entryQuantity = 'http://hl7.org/fhir/_entryQuantity' satisfies OwlObjectProperty;

/**
 * _seriousness
 *
 * (Modified) AdverseEvent.seriousness
 *
 * http://hl7.org/fhir/_seriousness
 */
export const _seriousness = 'http://hl7.org/fhir/_seriousness' satisfies OwlObjectProperty;

/**
 * _born
 *
 * (Modified) FamilyMemberHistory.born
 *
 * http://hl7.org/fhir/_born
 */
export const _born = 'http://hl7.org/fhir/_born' satisfies OwlObjectProperty;

/**
 * initiator
 *
 * ExampleScenario.process.step.process.step.alternative.step.operation.initiator: The system that invokes the action/transmits the data.
 *
 * http://hl7.org/fhir/initiator
 */
export const initiator = 'http://hl7.org/fhir/initiator' satisfies OwlObjectProperty;

/**
 * geometry
 *
 * SubstancePolymer.geometry: Polymer geometry, e.g. linear, branched, cross-linked, network or dendritic.
 *
 * http://hl7.org/fhir/geometry
 */
export const geometry = 'http://hl7.org/fhir/geometry' satisfies OwlObjectProperty;

/**
 * _organismGeneral
 *
 * (Modified) SubstanceSourceMaterial.organism.organismGeneral
 *
 * http://hl7.org/fhir/_organismGeneral
 */
export const _organismGeneral = 'http://hl7.org/fhir/_organismGeneral' satisfies OwlObjectProperty;

/**
 * TestReportSetupComponent
 *
 * TestReportSetupComponent: The results of the series of required setup operations before the tests were executed.
 *
 * http://hl7.org/fhir/TestReportSetupComponent
 */
export const TestReportSetupComponent = 'http://hl7.org/fhir/TestReportSetupComponent' satisfies OwlClass;

/**
 * message
 *
 * MessageDefinition.allowedResponse.message: A reference to the message definition that must be adhered to by this supported response.
 *
 * http://hl7.org/fhir/message
 */
export const message = 'http://hl7.org/fhir/message' satisfies OwlObjectProperty;

/**
 * PlanDefinitionActionInputComponent
 *
 * PlanDefinitionActionComponentAction.PlanDefinitionActionInputComponent: Defines input data requirements for the action.
 *
 * http://hl7.org/fhir/PlanDefinitionActionInputComponent
 */
export const PlanDefinitionActionInputComponent = 'http://hl7.org/fhir/PlanDefinitionActionInputComponent' satisfies OwlClass;

/**
 * Dosage
 *
 * Indicates how the medication is/was taken or should be taken by the patient.
 *
 * http://hl7.org/fhir/Dosage
 */
export const Dosage = 'http://hl7.org/fhir/Dosage' satisfies OwlClass;

/**
 * _structureType
 *
 * (Modified) ExampleScenario.instance.structureType
 *
 * http://hl7.org/fhir/_structureType
 */
export const _structureType = 'http://hl7.org/fhir/_structureType' satisfies OwlObjectProperty;

/**
 * onAdmission
 *
 * ExplanationOfBenefit.diagnosis.onAdmission: Indication of whether the diagnosis was present on admission to a facility.
 *
 * http://hl7.org/fhir/onAdmission
 */
export const onAdmission = 'http://hl7.org/fhir/onAdmission' satisfies OwlObjectProperty;

/**
 * EncounterLocationComponent
 *
 * EncounterLocationComponent: List of locations where  the patient has been during this encounter.
 *
 * http://hl7.org/fhir/EncounterLocationComponent
 */
export const EncounterLocationComponent = 'http://hl7.org/fhir/EncounterLocationComponent' satisfies OwlClass;

/**
 * statusHistory
 *
 * EpisodeOfCare.statusHistory: The history of statuses that the EpisodeOfCare has been through (without requiring processing the history of the resource).
 *
 * http://hl7.org/fhir/statusHistory
 */
export const statusHistory = 'http://hl7.org/fhir/statusHistory' satisfies OwlObjectProperty;

/**
 * CitationCitedArtifactComponent
 *
 * CitationCitedArtifactComponent: The article or artifact being described.
 *
 * http://hl7.org/fhir/CitationCitedArtifactComponent
 */
export const CitationCitedArtifactComponent = 'http://hl7.org/fhir/CitationCitedArtifactComponent' satisfies OwlClass;

/**
 * _paymentTerms
 *
 * (Modified) Invoice.paymentTerms
 *
 * http://hl7.org/fhir/_paymentTerms
 */
export const _paymentTerms = 'http://hl7.org/fhir/_paymentTerms' satisfies OwlObjectProperty;

/**
 * _intendedEffect
 *
 * (Modified) ClinicalUseDefinition.indication.intendedEffect
 *
 * http://hl7.org/fhir/_intendedEffect
 */
export const _intendedEffect = 'http://hl7.org/fhir/_intendedEffect' satisfies OwlObjectProperty;

/**
 * SubstanceSourceMaterialOrganismAuthorComponent
 *
 * SubstanceSourceMaterialOrganismComponent.SubstanceSourceMaterialOrganismAuthorComponent: 4.9.13.6.1 Author type (Conditional).
 *
 * http://hl7.org/fhir/SubstanceSourceMaterialOrganismAuthorComponent
 */
export const SubstanceSourceMaterialOrganismAuthorComponent = 'http://hl7.org/fhir/SubstanceSourceMaterialOrganismAuthorComponent' satisfies OwlClass;

/**
 * listMode
 *
 * StructureMap.group.rule.source.listMode: How to handle the list mode for this element.
 *
 * http://hl7.org/fhir/listMode
 */
export const listMode = 'http://hl7.org/fhir/listMode' satisfies OwlObjectProperty;

/**
 * _typeCollected
 *
 * (Modified) SpecimenDefinition.typeCollected
 *
 * http://hl7.org/fhir/_typeCollected
 */
export const _typeCollected = 'http://hl7.org/fhir/_typeCollected' satisfies OwlObjectProperty;

/**
 * definitional
 *
 * MedicationKnowledge.definitional: Along with the link to a Medicinal Product Definition resource, this information provides common definitional elements that are needed to understand the specific medication that is being described.
 *
 * http://hl7.org/fhir/definitional
 */
export const definitional = 'http://hl7.org/fhir/definitional' satisfies OwlObjectProperty;

/**
 * improvementNotation
 *
 * MeasureReport.improvementNotation: Whether improvement in the measure is noted by an increase or decrease in the measure score.
 *
 * http://hl7.org/fhir/improvementNotation
 */
export const improvementNotation = 'http://hl7.org/fhir/improvementNotation' satisfies OwlObjectProperty;

/**
 * ValuedItem
 *
 * Contract.TermTerm.ContractAsset.ValuedItem: Contract Valued Item List.
 *
 * http://hl7.org/fhir/ValuedItem
 */
export const ValuedItem = 'http://hl7.org/fhir/ValuedItem' satisfies OwlClass;

/**
 * ElementDefinitionBaseComponent
 *
 * ElementDefinitionBaseComponent: Information about the base definition of the element, provided to make it unnecessary for tools to trace the deviation of the element through the derived and related profiles. When the element definition is not the original definition of an element - e.g. either in a constraint on another type, or for elements from a super type in a snap shot - then the information in provided in the element definition may be different to the base definition. On the original definition of the element, it will be same.
 *
 * http://hl7.org/fhir/ElementDefinitionBaseComponent
 */
export const ElementDefinitionBaseComponent = 'http://hl7.org/fhir/ElementDefinitionBaseComponent' satisfies OwlClass;

/**
 * Errors
 *
 * CoverageEligibilityResponse.Errors: Errors encountered during the processing of the request.
 *
 * http://hl7.org/fhir/Errors
 */
export const Errors = 'http://hl7.org/fhir/Errors' satisfies OwlClass;

/**
 * pattern
 *
 * http://hl7.org/fhir/pattern
 */
export const pattern = 'http://hl7.org/fhir/pattern' satisfies OwlObjectProperty;

/**
 * TestScriptDestinationComponent
 *
 * TestScriptDestinationComponent: An abstract server used in operations within this test script in the destination element.
 *
 * http://hl7.org/fhir/TestScriptDestinationComponent
 */
export const TestScriptDestinationComponent = 'http://hl7.org/fhir/TestScriptDestinationComponent' satisfies OwlClass;

/**
 * CoveragePaymentByComponent
 *
 * CoveragePaymentByComponent: Link to the paying party and optionally what specifically they will be responsible to pay.
 *
 * http://hl7.org/fhir/CoveragePaymentByComponent
 */
export const CoveragePaymentByComponent = 'http://hl7.org/fhir/CoveragePaymentByComponent' satisfies OwlClass;

/**
 * _AuditEvent
 *
 * (Modified) AuditEvent
 *
 * http://hl7.org/fhir/_AuditEvent
 */
export const _AuditEvent = 'http://hl7.org/fhir/_AuditEvent' satisfies OwlClass;

/**
 * requirements
 *
 * ElementDefinition.constraint.requirements: Description of why this constraint is necessary or appropriate.
 *
 * http://hl7.org/fhir/requirements
 */
export const requirements = 'http://hl7.org/fhir/requirements' satisfies OwlObjectProperty;

/**
 * authority
 *
 * SubstanceDefinition.name.synonym.official.authority: Which authority uses this official name.
 *
 * http://hl7.org/fhir/authority
 */
export const authority = 'http://hl7.org/fhir/authority' satisfies OwlObjectProperty;

/**
 * _compareToSourceId
 *
 * (Modified) TestScript.test.action.assert.compareToSourceId
 *
 * http://hl7.org/fhir/_compareToSourceId
 */
export const _compareToSourceId = 'http://hl7.org/fhir/_compareToSourceId' satisfies OwlObjectProperty;

/**
 * _Contract
 *
 * (Modified) Contract
 *
 * http://hl7.org/fhir/_Contract
 */
export const _Contract = 'http://hl7.org/fhir/_Contract' satisfies OwlClass;

/**
 * _occurrenceChanged
 *
 * (Modified) Appointment.occurrenceChanged
 *
 * http://hl7.org/fhir/_occurrenceChanged
 */
export const _occurrenceChanged = 'http://hl7.org/fhir/_occurrenceChanged' satisfies OwlObjectProperty;

/**
 * typeReference
 *
 * RequestOrchestration.action.action.participant.typeReference: The type of participant in the action.
 *
 * http://hl7.org/fhir/typeReference
 */
export const typeReference = 'http://hl7.org/fhir/typeReference' satisfies OwlObjectProperty;

/**
 * detail
 *
 * TestReport.setup.action.assert.detail: A link to further details on the result.
 *
 * http://hl7.org/fhir/detail
 */
export const detail = 'http://hl7.org/fhir/detail' satisfies OwlObjectProperty;

/**
 * _alternative
 *
 * (Modified) ExampleScenario.process.step.alternative.step.alternative
 *
 * http://hl7.org/fhir/_alternative
 */
export const _alternative = 'http://hl7.org/fhir/_alternative' satisfies OwlObjectProperty;

/**
 * ClaimResponseAdjudication
 *
 * The adjudication results which are presented at the header level rather than at the line-item or add-item levels.
 *
 * http://hl7.org/fhir/ClaimResponseAdjudication
 */
export const ClaimResponseAdjudication = 'http://hl7.org/fhir/ClaimResponseAdjudication' satisfies OwlClass;

/**
 * Person
 *
 * Demographics and administrative information about a person independent of a specific health-related context.
 *
 * http://hl7.org/fhir/Person
 */
export const Person = 'http://hl7.org/fhir/Person' satisfies OwlClass;

/**
 * readHistory
 *
 * CapabilityStatement.rest.resource.readHistory: A flag for whether the server is able to return past versions as part of the vRead operation.
 *
 * http://hl7.org/fhir/readHistory
 */
export const readHistory = 'http://hl7.org/fhir/readHistory' satisfies OwlObjectProperty;

/**
 * _subjects
 *
 * (Modified) MeasureReport.group.stratifier.stratum.population.subjects
 *
 * http://hl7.org/fhir/_subjects
 */
export const _subjects = 'http://hl7.org/fhir/_subjects' satisfies OwlObjectProperty;

/**
 * membership
 *
 * Group.membership: Basis for membership in the Group:
 * 
 * * 'definitional': The Group.characteristics specified are both necessary and sufficient to determine membership. All entities that meet the criteria are considered to be members of the group, whether referenced by the group or not. If members are present, they are individuals that happen to be known as meeting the Group.characteristics. The list cannot be presumed to be complete.
 * * 'enumerated': The Group.characteristics are necessary but not sufficient to determine membership. Membership is determined by being listed as one of the Group.member.
 *
 * http://hl7.org/fhir/membership
 */
export const membership = 'http://hl7.org/fhir/membership' satisfies OwlObjectProperty;

/**
 * studyUid
 *
 * ImagingSelection.studyUid: The Study Instance UID for the DICOM Study from which the images were selected.
 *
 * http://hl7.org/fhir/studyUid
 */
export const studyUid = 'http://hl7.org/fhir/studyUid' satisfies OwlObjectProperty;

/**
 * GraphDefinitionLinkCompartmentComponent
 *
 * GraphDefinitionLinkComponent.GraphDefinitionLinkCompartmentComponent: Compartment Consistency Rules.
 *
 * http://hl7.org/fhir/GraphDefinitionLinkCompartmentComponent
 */
export const GraphDefinitionLinkCompartmentComponent = 'http://hl7.org/fhir/GraphDefinitionLinkCompartmentComponent' satisfies OwlClass;

/**
 * _occurrence
 *
 * (Modified) SupplyRequest.occurrence
 *
 * http://hl7.org/fhir/_occurrence
 */
export const _occurrence = 'http://hl7.org/fhir/_occurrence' satisfies OwlObjectProperty;

/**
 * _dayOfMonth
 *
 * (Modified) Appointment.recurrenceTemplate.monthlyTemplate.dayOfMonth
 *
 * http://hl7.org/fhir/_dayOfMonth
 */
export const _dayOfMonth = 'http://hl7.org/fhir/_dayOfMonth' satisfies OwlObjectProperty;

/**
 * Extension
 *
 * Optional Extension Element - found in all resources.
 *
 * http://hl7.org/fhir/Extension
 */
export const Extension = 'http://hl7.org/fhir/Extension' satisfies OwlClass;

/**
 * _proxyIdentityCertificate
 *
 * (Modified) VerificationResult.attestation.proxyIdentityCertificate
 *
 * http://hl7.org/fhir/_proxyIdentityCertificate
 */
export const _proxyIdentityCertificate = 'http://hl7.org/fhir/_proxyIdentityCertificate' satisfies OwlObjectProperty;

/**
 * emptyReason
 *
 * EvidenceReport.section.section.emptyReason: If the section is empty, why the list is empty. An empty section typically has some text explaining the empty reason.
 *
 * http://hl7.org/fhir/emptyReason
 */
export const emptyReason = 'http://hl7.org/fhir/emptyReason' satisfies OwlObjectProperty;

/**
 * ConceptMapGroupComponent
 *
 * ConceptMapGroupComponent: A group of mappings that all have the same source and target system.
 *
 * http://hl7.org/fhir/ConceptMapGroupComponent
 */
export const ConceptMapGroupComponent = 'http://hl7.org/fhir/ConceptMapGroupComponent' satisfies OwlClass;

/**
 * laterality
 *
 * BodyStructure.includedStructure.laterality: Code that represents the included structure laterality.
 *
 * http://hl7.org/fhir/laterality
 */
export const laterality = 'http://hl7.org/fhir/laterality' satisfies OwlObjectProperty;

/**
 * _previous
 *
 * (Modified) SubscriptionTopic.resourceTrigger.queryCriteria.previous
 *
 * http://hl7.org/fhir/_previous
 */
export const _previous = 'http://hl7.org/fhir/_previous' satisfies OwlObjectProperty;

/**
 * _claimResponse
 *
 * (Modified) ExplanationOfBenefit.claimResponse
 *
 * http://hl7.org/fhir/_claimResponse
 */
export const _claimResponse = 'http://hl7.org/fhir/_claimResponse' satisfies OwlObjectProperty;

/**
 * dataUpdateType
 *
 * MeasureReport.dataUpdateType: Indicates whether the data submitted in a data-exchange report represents a snapshot or incremental update. A snapshot update replaces all previously submitted data for the receiver, whereas an incremental update represents only updated and/or changed data and should be applied as a differential update to the existing submitted data for the receiver.
 *
 * http://hl7.org/fhir/dataUpdateType
 */
export const dataUpdateType = 'http://hl7.org/fhir/dataUpdateType' satisfies OwlObjectProperty;

/**
 * paymentDate
 *
 * PaymentNotice.paymentDate: The date when the above payment action occurred.
 *
 * http://hl7.org/fhir/paymentDate
 */
export const paymentDate = 'http://hl7.org/fhir/paymentDate' satisfies OwlObjectProperty;

/**
 * baseFormulaProductName
 *
 * NutritionOrder.enteralFormula.baseFormulaProductName: The product or brand name of the enteral or infant formula product such as "ACME Adult Standard Formula".
 *
 * http://hl7.org/fhir/baseFormulaProductName
 */
export const baseFormulaProductName = 'http://hl7.org/fhir/baseFormulaProductName' satisfies OwlObjectProperty;

/**
 * performed
 *
 * FamilyMemberHistory.procedure.performed
 *
 * http://hl7.org/fhir/performed
 */
export const performed = 'http://hl7.org/fhir/performed' satisfies OwlObjectProperty;

/**
 * ServiceRequestOrderDetailComponent
 *
 * ServiceRequestOrderDetailComponent: Additional details and instructions about the how the services are to be delivered.   For example, and order for a urinary catheter may have an order detail for an external or indwelling catheter, or an order for a bandage may require additional instructions specifying how the bandage should be applied.
 *
 * http://hl7.org/fhir/ServiceRequestOrderDetailComponent
 */
export const ServiceRequestOrderDetailComponent = 'http://hl7.org/fhir/ServiceRequestOrderDetailComponent' satisfies OwlClass;

/**
 * _informationSequence
 *
 * (Modified) ExplanationOfBenefit.item.informationSequence
 *
 * http://hl7.org/fhir/_informationSequence
 */
export const _informationSequence = 'http://hl7.org/fhir/_informationSequence' satisfies OwlObjectProperty;

/**
 * _wednesday
 *
 * (Modified) Appointment.recurrenceTemplate.weeklyTemplate.wednesday
 *
 * http://hl7.org/fhir/_wednesday
 */
export const _wednesday = 'http://hl7.org/fhir/_wednesday' satisfies OwlObjectProperty;

/**
 * _id
 *
 * (Modified) Resource.id
 *
 * http://hl7.org/fhir/_id
 */
export const _id = 'http://hl7.org/fhir/_id' satisfies OwlObjectProperty;

/**
 * nucleicAcid
 *
 * SubstanceDefinition.nucleicAcid: Data items specific to nucleic acids.
 *
 * http://hl7.org/fhir/nucleicAcid
 */
export const nucleicAcid = 'http://hl7.org/fhir/nucleicAcid' satisfies OwlObjectProperty;

/**
 * implementation
 *
 * TerminologyCapabilities.implementation: Identifies a specific implementation instance that is described by the terminology capability statement - i.e. a particular installation, rather than the capabilities of a software program.
 *
 * http://hl7.org/fhir/implementation
 */
export const implementation = 'http://hl7.org/fhir/implementation' satisfies OwlObjectProperty;

/**
 * _species
 *
 * (Modified) SubstanceSourceMaterial.organism.species
 *
 * http://hl7.org/fhir/_species
 */
export const _species = 'http://hl7.org/fhir/_species' satisfies OwlObjectProperty;

/**
 * _goalId
 *
 * (Modified) PlanDefinition.action.action.goalId
 *
 * http://hl7.org/fhir/_goalId
 */
export const _goalId = 'http://hl7.org/fhir/_goalId' satisfies OwlObjectProperty;

/**
 * manager
 *
 * Consent.manager: The actor that manages the consent through its lifecycle.
 *
 * http://hl7.org/fhir/manager
 */
export const manager = 'http://hl7.org/fhir/manager' satisfies OwlObjectProperty;

/**
 * Meta
 *
 * The metadata about a resource. This is content in the resource that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.
 *
 * http://hl7.org/fhir/Meta
 */
export const Meta = 'http://hl7.org/fhir/Meta' satisfies OwlClass;

/**
 * interpreter
 *
 * GenomicStudy.interpreter: Healthcare professionals who interpreted the genomic study.
 *
 * http://hl7.org/fhir/interpreter
 */
export const interpreter = 'http://hl7.org/fhir/interpreter' satisfies OwlObjectProperty;

/**
 * situation
 *
 * MessageDefinition.allowedResponse.situation: Provides a description of the circumstances in which this response should be used (as opposed to one of the alternative responses).
 *
 * http://hl7.org/fhir/situation
 */
export const situation = 'http://hl7.org/fhir/situation' satisfies OwlObjectProperty;

/**
 * _recorded
 *
 * (Modified) Provenance.recorded
 *
 * http://hl7.org/fhir/_recorded
 */
export const _recorded = 'http://hl7.org/fhir/_recorded' satisfies OwlObjectProperty;

/**
 * DiagnosticReport
 *
 * The findings and interpretation of diagnostic tests performed on patients, groups of patients, products, substances, devices, and locations, and/or specimens derived from these. The report includes clinical context such as requesting provider information, and some mix of atomic results, images, textual and coded interpretations, and formatted representation of diagnostic reports. The report also includes non-clinical context such as batch analysis and stability reporting of products and substances.
 *
 * http://hl7.org/fhir/DiagnosticReport
 */
export const DiagnosticReport = 'http://hl7.org/fhir/DiagnosticReport' satisfies OwlClass;

/**
 * drugCharacteristic
 *
 * MedicationKnowledge.definitional.drugCharacteristic: Specifies descriptive properties of the medicine, such as color, shape, imprints, etc.
 *
 * http://hl7.org/fhir/drugCharacteristic
 */
export const drugCharacteristic = 'http://hl7.org/fhir/drugCharacteristic' satisfies OwlObjectProperty;

/**
 * SubstanceDefinitionStructureRepresentationComponent
 *
 * SubstanceDefinitionStructureComponent.SubstanceDefinitionStructureRepresentationComponent: A depiction of the structure of the substance.
 *
 * http://hl7.org/fhir/SubstanceDefinitionStructureRepresentationComponent
 */
export const SubstanceDefinitionStructureRepresentationComponent = 'http://hl7.org/fhir/SubstanceDefinitionStructureRepresentationComponent' satisfies OwlClass;

/**
 * RequestOrchestrationActionRelatedActionComponent
 *
 * RequestOrchestrationActionComponentAction.RequestOrchestrationActionRelatedActionComponent: A relationship to another action such as "before" or "30-60 minutes after start of".
 *
 * http://hl7.org/fhir/RequestOrchestrationActionRelatedActionComponent
 */
export const RequestOrchestrationActionRelatedActionComponent = 'http://hl7.org/fhir/RequestOrchestrationActionRelatedActionComponent' satisfies OwlClass;

/**
 * variableRole
 *
 * Evidence.variableDefinition.variableRole: population | subpopulation | exposure | referenceExposure | measuredVariable | confounder.
 *
 * http://hl7.org/fhir/variableRole
 */
export const variableRole = 'http://hl7.org/fhir/variableRole' satisfies OwlObjectProperty;

/**
 * failureAction
 *
 * VerificationResult.failureAction: The result if validation fails (fatal; warning; record only; none).
 *
 * http://hl7.org/fhir/failureAction
 */
export const failureAction = 'http://hl7.org/fhir/failureAction' satisfies OwlObjectProperty;

/**
 * suppliedItem
 *
 * SupplyDelivery.suppliedItem: The item that is being delivered or has been supplied.
 *
 * http://hl7.org/fhir/suppliedItem
 */
export const suppliedItem = 'http://hl7.org/fhir/suppliedItem' satisfies OwlObjectProperty;

/**
 * abstract
 *
 * StructureDefinition.abstract: Whether structure this definition describes is abstract or not  - that is, whether the structure is not intended to be instantiated. For Resources and Data types, abstract types will never be exchanged  between systems.
 *
 * http://hl7.org/fhir/abstract
 */
export const abstract = 'http://hl7.org/fhir/abstract' satisfies OwlObjectProperty;

/**
 * valueRange
 *
 * Evidence.statistic.modelCharacteristic.variable.valueRange: Range of values for grouping of ordinal or polychotomous variables.
 *
 * http://hl7.org/fhir/valueRange
 */
export const valueRange = 'http://hl7.org/fhir/valueRange' satisfies OwlObjectProperty;

/**
 * _query
 *
 * (Modified) AuditEvent.entity.query
 *
 * http://hl7.org/fhir/_query
 */
export const _query = 'http://hl7.org/fhir/_query' satisfies OwlObjectProperty;

/**
 * sigFormat
 *
 * Signature.sigFormat: A mime type that indicates the technical format of the signature. Important mime types are application/signature+xml for X ML DigSig, application/jose for JWS, and image/* for a graphical image of a signature, etc.
 *
 * http://hl7.org/fhir/sigFormat
 */
export const sigFormat = 'http://hl7.org/fhir/sigFormat' satisfies OwlObjectProperty;

/**
 * VirtualServiceDetail
 *
 * Virtual Service Contact Details.
 *
 * http://hl7.org/fhir/VirtualServiceDetail
 */
export const VirtualServiceDetail = 'http://hl7.org/fhir/VirtualServiceDetail' satisfies OwlClass;

/**
 * _rest
 *
 * (Modified) CapabilityStatement.rest
 *
 * http://hl7.org/fhir/_rest
 */
export const _rest = 'http://hl7.org/fhir/_rest' satisfies OwlObjectProperty;

/**
 * packageCode
 *
 * Account.procedure.packageCode: The package code can be used to group procedures that may be priced or delivered as a single product. Such as DRGs.
 *
 * http://hl7.org/fhir/packageCode
 */
export const packageCode = 'http://hl7.org/fhir/packageCode' satisfies OwlObjectProperty;

/**
 * _reaction
 *
 * (Modified) Immunization.reaction
 *
 * http://hl7.org/fhir/_reaction
 */
export const _reaction = 'http://hl7.org/fhir/_reaction' satisfies OwlObjectProperty;

/**
 * _contributor
 *
 * (Modified) Citation.citedArtifact.contributorship.entry.contributor
 *
 * http://hl7.org/fhir/_contributor
 */
export const _contributor = 'http://hl7.org/fhir/_contributor' satisfies OwlObjectProperty;

/**
 * _normalValue
 *
 * (Modified) Observation.component.referenceRange.normalValue
 *
 * http://hl7.org/fhir/_normalValue
 */
export const _normalValue = 'http://hl7.org/fhir/_normalValue' satisfies OwlObjectProperty;

/**
 * _resultsInterpreter
 *
 * (Modified) DiagnosticReport.resultsInterpreter
 *
 * http://hl7.org/fhir/_resultsInterpreter
 */
export const _resultsInterpreter = 'http://hl7.org/fhir/_resultsInterpreter' satisfies OwlObjectProperty;

/**
 * _tester
 *
 * (Modified) TestReport.tester
 *
 * http://hl7.org/fhir/_tester
 */
export const _tester = 'http://hl7.org/fhir/_tester' satisfies OwlObjectProperty;

/**
 * denominator
 *
 * RatioRange.denominator: The value of the denominator.
 *
 * http://hl7.org/fhir/denominator
 */
export const denominator = 'http://hl7.org/fhir/denominator' satisfies OwlObjectProperty;

/**
 * uniqueId
 *
 * NamingSystem.uniqueId: Indicates how the system may be identified when referenced in electronic exchange.
 *
 * http://hl7.org/fhir/uniqueId
 */
export const uniqueId = 'http://hl7.org/fhir/uniqueId' satisfies OwlObjectProperty;

/**
 * readOnly
 *
 * Questionnaire.item.item.readOnly: An indication, when true, that the value cannot be changed by a human respondent to the Questionnaire.
 *
 * http://hl7.org/fhir/readOnly
 */
export const readOnly = 'http://hl7.org/fhir/readOnly' satisfies OwlObjectProperty;

/**
 * _effectiveDosePeriod
 *
 * (Modified) MedicationRequest.effectiveDosePeriod
 *
 * http://hl7.org/fhir/_effectiveDosePeriod
 */
export const _effectiveDosePeriod = 'http://hl7.org/fhir/_effectiveDosePeriod' satisfies OwlObjectProperty;

/**
 * _patientInstruction
 *
 * (Modified) ServiceRequest.patientInstruction
 *
 * http://hl7.org/fhir/_patientInstruction
 */
export const _patientInstruction = 'http://hl7.org/fhir/_patientInstruction' satisfies OwlObjectProperty;

/**
 * focusReference
 *
 * EvidenceReport.section.section.focusReference: A definitional Resource identifying the kind of content contained within the section. This should be consistent with the section title.
 *
 * http://hl7.org/fhir/focusReference
 */
export const focusReference = 'http://hl7.org/fhir/focusReference' satisfies OwlObjectProperty;

/**
 * _sopClass
 *
 * (Modified) ImagingStudy.series.instance.sopClass
 *
 * http://hl7.org/fhir/_sopClass
 */
export const _sopClass = 'http://hl7.org/fhir/_sopClass' satisfies OwlObjectProperty;

/**
 * _brand
 *
 * (Modified) VisionPrescription.lensSpecification.brand
 *
 * http://hl7.org/fhir/_brand
 */
export const _brand = 'http://hl7.org/fhir/_brand' satisfies OwlObjectProperty;

/**
 * SubscriptionStatusNotificationEventComponent
 *
 * SubscriptionStatusNotificationEventComponent: Detailed information about events relevant to this subscription notification.
 *
 * http://hl7.org/fhir/SubscriptionStatusNotificationEventComponent
 */
export const SubscriptionStatusNotificationEventComponent = 'http://hl7.org/fhir/SubscriptionStatusNotificationEventComponent' satisfies OwlClass;

/**
 * specialArrangement
 *
 * Encounter.specialArrangement: Any special requests that have been made for this encounter, such as the provision of specific equipment or other things.
 *
 * http://hl7.org/fhir/specialArrangement
 */
export const specialArrangement = 'http://hl7.org/fhir/specialArrangement' satisfies OwlObjectProperty;

/**
 * _autocreate
 *
 * (Modified) TestScript.fixture.autocreate
 *
 * http://hl7.org/fhir/_autocreate
 */
export const _autocreate = 'http://hl7.org/fhir/_autocreate' satisfies OwlObjectProperty;

/**
 * _responsibility
 *
 * (Modified) Coverage.paymentBy.responsibility
 *
 * http://hl7.org/fhir/_responsibility
 */
export const _responsibility = 'http://hl7.org/fhir/_responsibility' satisfies OwlObjectProperty;

/**
 * any
 *
 * ElementDefinition.binding.additional.any: Whether the binding applies to all repeats, or just to any one of them. This is only relevant for elements that can repeat.
 *
 * http://hl7.org/fhir/any
 */
export const any = 'http://hl7.org/fhir/any' satisfies OwlObjectProperty;

/**
 * protocolApplied
 *
 * Immunization.protocolApplied: The protocol (set of recommendations) being followed by the provider who administered the dose.
 *
 * http://hl7.org/fhir/protocolApplied
 */
export const protocolApplied = 'http://hl7.org/fhir/protocolApplied' satisfies OwlObjectProperty;

/**
 * PaymentNotice
 *
 * This resource provides the status of the payment for goods and services rendered, and the request and response resource references.
 *
 * http://hl7.org/fhir/PaymentNotice
 */
export const PaymentNotice = 'http://hl7.org/fhir/PaymentNotice' satisfies OwlClass;

/**
 * _completionTime
 *
 * (Modified) Transport.completionTime
 *
 * http://hl7.org/fhir/_completionTime
 */
export const _completionTime = 'http://hl7.org/fhir/_completionTime' satisfies OwlObjectProperty;

/**
 * _preAdmissionIdentifier
 *
 * (Modified) Encounter.admission.preAdmissionIdentifier
 *
 * http://hl7.org/fhir/_preAdmissionIdentifier
 */
export const _preAdmissionIdentifier = 'http://hl7.org/fhir/_preAdmissionIdentifier' satisfies OwlObjectProperty;

/**
 * _interpretation
 *
 * (Modified) Observation.component.interpretation
 *
 * http://hl7.org/fhir/_interpretation
 */
export const _interpretation = 'http://hl7.org/fhir/_interpretation' satisfies OwlObjectProperty;

/**
 * testingDestination
 *
 * SpecimenDefinition.typeTested.testingDestination: Where the specimen will be tested: e.g., lab, sector, device or any combination of these.
 *
 * http://hl7.org/fhir/testingDestination
 */
export const testingDestination = 'http://hl7.org/fhir/testingDestination' satisfies OwlObjectProperty;

/**
 * ExtendedContactDetail
 *
 * Specifies contact information for a specific purpose over a period of time, might be handled/monitored by a specific named person or organization.
 *
 * http://hl7.org/fhir/ExtendedContactDetail
 */
export const ExtendedContactDetail = 'http://hl7.org/fhir/ExtendedContactDetail' satisfies OwlClass;

/**
 * administrableDoseForm
 *
 * AdministrableProductDefinition.administrableDoseForm: The dose form of the final product after necessary reconstitution or processing. Contrasts to the manufactured dose form (see ManufacturedItemDefinition). If the manufactured form was 'powder for solution for injection', the administrable dose form could be 'solution for injection' (once mixed with another item having manufactured form 'solvent for solution for injection').
 *
 * http://hl7.org/fhir/administrableDoseForm
 */
export const administrableDoseForm = 'http://hl7.org/fhir/administrableDoseForm' satisfies OwlObjectProperty;

/**
 * repeat
 *
 * SubstancePolymer.repeat: Specifies and quantifies the repeated units and their configuration.
 *
 * http://hl7.org/fhir/repeat
 */
export const repeat = 'http://hl7.org/fhir/repeat' satisfies OwlObjectProperty;

/**
 * CapabilityStatementRestResourceSearchParamComponent
 *
 * CapabilityStatementRestComponent.CapabilityStatementRestResourceComponent.CapabilityStatementRestResourceSearchParamComponent: Search parameters for implementations to support and/or make use of - either references to ones defined in the specification, or additional ones defined for/by the implementation.
 *
 * http://hl7.org/fhir/CapabilityStatementRestResourceSearchParamComponent
 */
export const CapabilityStatementRestResourceSearchParamComponent = 'http://hl7.org/fhir/CapabilityStatementRestResourceSearchParamComponent' satisfies OwlClass;

/**
 * interactant
 *
 * ClinicalUseDefinition.interaction.interactant: The specific medication, product, food, substance etc. or laboratory test that interacts.
 *
 * http://hl7.org/fhir/interactant
 */
export const interactant = 'http://hl7.org/fhir/interactant' satisfies OwlObjectProperty;

/**
 * _groupDefinition
 *
 * (Modified) Measure.group.stratifier.component.groupDefinition
 *
 * http://hl7.org/fhir/_groupDefinition
 */
export const _groupDefinition = 'http://hl7.org/fhir/_groupDefinition' satisfies OwlObjectProperty;

/**
 * _effective
 *
 * (Modified) Observation.effective
 *
 * http://hl7.org/fhir/_effective
 */
export const _effective = 'http://hl7.org/fhir/_effective' satisfies OwlObjectProperty;

/**
 * _service
 *
 * (Modified) ChargeItem.service
 *
 * http://hl7.org/fhir/_service
 */
export const _service = 'http://hl7.org/fhir/_service' satisfies OwlObjectProperty;

/**
 * admitSource
 *
 * Encounter.admission.admitSource: From where patient was admitted (physician referral, transfer).
 *
 * http://hl7.org/fhir/admitSource
 */
export const admitSource = 'http://hl7.org/fhir/admitSource' satisfies OwlObjectProperty;

/**
 * _cap
 *
 * (Modified) SpecimenDefinition.typeTested.container.cap
 *
 * http://hl7.org/fhir/_cap
 */
export const _cap = 'http://hl7.org/fhir/_cap' satisfies OwlObjectProperty;

/**
 * _structure
 *
 * (Modified) SubstanceDefinition.structure
 *
 * http://hl7.org/fhir/_structure
 */
export const _structure = 'http://hl7.org/fhir/_structure' satisfies OwlObjectProperty;

/**
 * _preferred
 *
 * (Modified) SubstanceDefinition.name.translation.preferred
 *
 * http://hl7.org/fhir/_preferred
 */
export const _preferred = 'http://hl7.org/fhir/_preferred' satisfies OwlObjectProperty;

/**
 * human
 *
 * ElementDefinition.constraint.human: Text that can be used to describe the constraint in messages identifying that the constraint has been violated.
 *
 * http://hl7.org/fhir/human
 */
export const human = 'http://hl7.org/fhir/human' satisfies OwlObjectProperty;

/**
 * _genomeAssembly
 *
 * (Modified) MolecularSequence.relative.startingSequence.genomeAssembly
 *
 * http://hl7.org/fhir/_genomeAssembly
 */
export const _genomeAssembly = 'http://hl7.org/fhir/_genomeAssembly' satisfies OwlObjectProperty;

/**
 * _dimensions
 *
 * (Modified) SampledData.dimensions
 *
 * http://hl7.org/fhir/_dimensions
 */
export const _dimensions = 'http://hl7.org/fhir/_dimensions' satisfies OwlObjectProperty;

/**
 * Reason
 *
 * Encounter.Reason: The list of medical reasons that are expected to be addressed during the episode of care.
 *
 * http://hl7.org/fhir/Reason
 */
export const Reason = 'http://hl7.org/fhir/Reason' satisfies OwlClass;

/**
 * eligibility
 *
 * ResearchStudy.recruitment.eligibility: Inclusion and exclusion criteria.
 *
 * http://hl7.org/fhir/eligibility
 */
export const eligibility = 'http://hl7.org/fhir/eligibility' satisfies OwlObjectProperty;

/**
 * resultForCreate
 *
 * SubscriptionTopic.resourceTrigger.queryCriteria.resultForCreate: For `create` interactions, should the `previous` criteria count as an automatic pass or an automatic fail. If not present, the testing behavior during `create` interactions is unspecified (server discretion).
 *
 * http://hl7.org/fhir/resultForCreate
 */
export const resultForCreate = 'http://hl7.org/fhir/resultForCreate' satisfies OwlObjectProperty;

/**
 * PersonLinkComponent
 *
 * PersonLinkComponent: Link to a resource that concerns the same actual person.
 *
 * http://hl7.org/fhir/PersonLinkComponent
 */
export const PersonLinkComponent = 'http://hl7.org/fhir/PersonLinkComponent' satisfies OwlClass;

/**
 * EvidenceCertaintyComponent
 *
 * EvidenceCertaintyComponent: Assessment of certainty, confidence in the estimates, or quality of the evidence.
 *
 * http://hl7.org/fhir/EvidenceCertaintyComponent
 */
export const EvidenceCertaintyComponent = 'http://hl7.org/fhir/EvidenceCertaintyComponent' satisfies OwlClass;

/**
 * texture
 *
 * NutritionOrder.oralDiet.texture: Class that describes any texture modifications required for the patient to safely consume various types of solid foods.
 *
 * http://hl7.org/fhir/texture
 */
export const texture = 'http://hl7.org/fhir/texture' satisfies OwlObjectProperty;

/**
 * characterization
 *
 * SubstanceDefinition.characterization: General specifications for this substance.
 *
 * http://hl7.org/fhir/characterization
 */
export const characterization = 'http://hl7.org/fhir/characterization' satisfies OwlObjectProperty;

/**
 * TerminologyCapabilitiesExpansionComponent
 *
 * TerminologyCapabilitiesExpansionComponent: Information about the [ValueSet/$expand](valueset-operation-expand.html) operation.
 *
 * http://hl7.org/fhir/TerminologyCapabilitiesExpansionComponent
 */
export const TerminologyCapabilitiesExpansionComponent = 'http://hl7.org/fhir/TerminologyCapabilitiesExpansionComponent' satisfies OwlClass;

/**
 * DataRequirementCodeFilterComponent
 *
 * DataRequirementCodeFilterComponent: Code filters specify additional constraints on the data, specifying the value set of interest for a particular element of the data. Each code filter defines an additional constraint on the data, i.e. code filters are AND'ed, not OR'ed.
 *
 * http://hl7.org/fhir/DataRequirementCodeFilterComponent
 */
export const DataRequirementCodeFilterComponent = 'http://hl7.org/fhir/DataRequirementCodeFilterComponent' satisfies OwlClass;

/**
 * _derivedFrom
 *
 * (Modified) Requirements.statement.derivedFrom
 *
 * http://hl7.org/fhir/_derivedFrom
 */
export const _derivedFrom = 'http://hl7.org/fhir/_derivedFrom' satisfies OwlObjectProperty;

/**
 * _doseAdministrationAid
 *
 * (Modified) MedicationRequest.dispenseRequest.doseAdministrationAid
 *
 * http://hl7.org/fhir/_doseAdministrationAid
 */
export const _doseAdministrationAid = 'http://hl7.org/fhir/_doseAdministrationAid' satisfies OwlObjectProperty;

/**
 * productOrService
 *
 * ExplanationOfBenefit.item.detail.subDetail.productOrService: When the value is a group code then this item collects a set of related item details, otherwise this contains the product, service, drug or other billing code for the item. This element may be the start of a range of .productOrService codes used in conjunction with .productOrServiceEnd or it may be a solo element where .productOrServiceEnd is not used.
 *
 * http://hl7.org/fhir/productOrService
 */
export const productOrService = 'http://hl7.org/fhir/productOrService' satisfies OwlObjectProperty;

/**
 * _plannedEndDate
 *
 * (Modified) EncounterHistory.plannedEndDate
 *
 * http://hl7.org/fhir/_plannedEndDate
 */
export const _plannedEndDate = 'http://hl7.org/fhir/_plannedEndDate' satisfies OwlObjectProperty;

/**
 * conformsTo
 *
 * DeviceDefinition.conformsTo: Identifies the standards, specifications, or formal guidances for the capabilities supported by the device. The device may be certified as conformant to these specifications e.g., communication, performance, process, measurement, or specialization standards.
 *
 * http://hl7.org/fhir/conformsTo
 */
export const conformsTo = 'http://hl7.org/fhir/conformsTo' satisfies OwlObjectProperty;

/**
 * _detected
 *
 * (Modified) AdverseEvent.detected
 *
 * http://hl7.org/fhir/_detected
 */
export const _detected = 'http://hl7.org/fhir/_detected' satisfies OwlObjectProperty;

/**
 * _threePrime
 *
 * (Modified) SubstanceNucleicAcid.subunit.threePrime
 *
 * http://hl7.org/fhir/_threePrime
 */
export const _threePrime = 'http://hl7.org/fhir/_threePrime' satisfies OwlObjectProperty;

/**
 * referencedFrom
 *
 * OperationDefinition.parameter.part.referencedFrom: Identifies other resource parameters within the operation invocation that are expected to resolve to this resource.
 *
 * http://hl7.org/fhir/referencedFrom
 */
export const referencedFrom = 'http://hl7.org/fhir/referencedFrom' satisfies OwlObjectProperty;

/**
 * targetFormat
 *
 * Signature.targetFormat: A mime type that indicates the technical format of the target resources signed by the signature.
 *
 * http://hl7.org/fhir/targetFormat
 */
export const targetFormat = 'http://hl7.org/fhir/targetFormat' satisfies OwlObjectProperty;

/**
 * _characteristicType
 *
 * (Modified) InventoryItem.characteristic.characteristicType
 *
 * http://hl7.org/fhir/_characteristicType
 */
export const _characteristicType = 'http://hl7.org/fhir/_characteristicType' satisfies OwlObjectProperty;

/**
 * StructureDefinitionMappingComponent
 *
 * StructureDefinitionMappingComponent: An external specification that the content is mapped to.
 *
 * http://hl7.org/fhir/StructureDefinitionMappingComponent
 */
export const StructureDefinitionMappingComponent = 'http://hl7.org/fhir/StructureDefinitionMappingComponent' satisfies OwlClass;

/**
 * _initiatorActive
 *
 * (Modified) ExampleScenario.process.step.alternative.step.operation.initiatorActive
 *
 * http://hl7.org/fhir/_initiatorActive
 */
export const _initiatorActive = 'http://hl7.org/fhir/_initiatorActive' satisfies OwlObjectProperty;

/**
 * supportedInteraction
 *
 * SubscriptionTopic.resourceTrigger.supportedInteraction: The FHIR RESTful interaction which can be used to trigger a notification for the SubscriptionTopic. Multiple values are considered OR joined (e.g., CREATE or UPDATE). If not present, all supported interactions are assumed.
 *
 * http://hl7.org/fhir/supportedInteraction
 */
export const supportedInteraction = 'http://hl7.org/fhir/supportedInteraction' satisfies OwlObjectProperty;

/**
 * vaccineCode
 *
 * ImmunizationRecommendation.recommendation.vaccineCode: Vaccine(s) or vaccine group that pertain to the recommendation.
 *
 * http://hl7.org/fhir/vaccineCode
 */
export const vaccineCode = 'http://hl7.org/fhir/vaccineCode' satisfies OwlObjectProperty;

/**
 * seriesNumber
 *
 * ImagingSelection.seriesNumber: The Series Number for the DICOM Series from which the images were selected.
 *
 * http://hl7.org/fhir/seriesNumber
 */
export const seriesNumber = 'http://hl7.org/fhir/seriesNumber' satisfies OwlObjectProperty;

/**
 * pageCount
 *
 * Citation.citedArtifact.publicationForm.pageCount: Actual or approximate number of pages or screens. Distinct from reporting the page numbers.
 *
 * http://hl7.org/fhir/pageCount
 */
export const pageCount = 'http://hl7.org/fhir/pageCount' satisfies OwlObjectProperty;

/**
 * _who
 *
 * (Modified) VerificationResult.attestation.who
 *
 * http://hl7.org/fhir/_who
 */
export const _who = 'http://hl7.org/fhir/_who' satisfies OwlObjectProperty;

/**
 * PermissionRuleActivityComponent
 *
 * Permission.Rule.PermissionRuleActivityComponent: A description or definition of which activities are allowed to be done on the data.
 *
 * http://hl7.org/fhir/PermissionRuleActivityComponent
 */
export const PermissionRuleActivityComponent = 'http://hl7.org/fhir/PermissionRuleActivityComponent' satisfies OwlClass;

/**
 * careManager
 *
 * EpisodeOfCare.careManager: The practitioner that is the care manager/care coordinator for this patient.
 *
 * http://hl7.org/fhir/careManager
 */
export const careManager = 'http://hl7.org/fhir/careManager' satisfies OwlObjectProperty;

/**
 * CodeSystem
 *
 * The CodeSystem resource is used to declare the existence of and describe a code system or code system supplement and its key properties, and optionally define a part or all of its content.
 *
 * http://hl7.org/fhir/CodeSystem
 */
export const CodeSystem = 'http://hl7.org/fhir/CodeSystem' satisfies OwlClass;

/**
 * MedicinalProductDefinitionNamePartComponent
 *
 * MedicinalProductDefinitionNameComponent.MedicinalProductDefinitionNamePartComponent: Coding words or phrases of the name.
 *
 * http://hl7.org/fhir/MedicinalProductDefinitionNamePartComponent
 */
export const MedicinalProductDefinitionNamePartComponent = 'http://hl7.org/fhir/MedicinalProductDefinitionNamePartComponent' satisfies OwlClass;

/**
 * _requestingOrganization
 *
 * (Modified) ChargeItem.requestingOrganization
 *
 * http://hl7.org/fhir/_requestingOrganization
 */
export const _requestingOrganization = 'http://hl7.org/fhir/_requestingOrganization' satisfies OwlObjectProperty;

/**
 * _referralMethod
 *
 * (Modified) HealthcareService.referralMethod
 *
 * http://hl7.org/fhir/_referralMethod
 */
export const _referralMethod = 'http://hl7.org/fhir/_referralMethod' satisfies OwlObjectProperty;

/**
 * _suspectEntity
 *
 * (Modified) AdverseEvent.suspectEntity
 *
 * http://hl7.org/fhir/_suspectEntity
 */
export const _suspectEntity = 'http://hl7.org/fhir/_suspectEntity' satisfies OwlObjectProperty;

/**
 * _exclusionCriteria
 *
 * (Modified) ValueSet.scope.exclusionCriteria
 *
 * http://hl7.org/fhir/_exclusionCriteria
 */
export const _exclusionCriteria = 'http://hl7.org/fhir/_exclusionCriteria' satisfies OwlObjectProperty;

/**
 * ObservationComponentComponent
 *
 * ObservationComponentComponent: Some observations have multiple component observations.  These component observations are expressed as separate code value pairs that share the same attributes.  Examples include systolic and diastolic component observations for blood pressure measurement and multiple component observations for genetics observations.
 *
 * http://hl7.org/fhir/ObservationComponentComponent
 */
export const ObservationComponentComponent = 'http://hl7.org/fhir/ObservationComponentComponent' satisfies OwlClass;

/**
 * _testScript
 *
 * (Modified) TestReport.testScript
 *
 * http://hl7.org/fhir/_testScript
 */
export const _testScript = 'http://hl7.org/fhir/_testScript' satisfies OwlObjectProperty;

/**
 * manufactureDate
 *
 * Device.manufactureDate: The date and time when the device was manufactured.
 *
 * http://hl7.org/fhir/manufactureDate
 */
export const manufactureDate = 'http://hl7.org/fhir/manufactureDate' satisfies OwlObjectProperty;

/**
 * _textPresentation
 *
 * (Modified) Ingredient.substance.strength.textPresentation
 *
 * http://hl7.org/fhir/_textPresentation
 */
export const _textPresentation = 'http://hl7.org/fhir/_textPresentation' satisfies OwlObjectProperty;

/**
 * TestReportSetupActionOperationComponent
 *
 * TestReportSetupComponent.SetupAction.TestReportSetupActionOperationComponent: The operation performed.
 *
 * http://hl7.org/fhir/TestReportSetupActionOperationComponent
 */
export const TestReportSetupActionOperationComponent = 'http://hl7.org/fhir/TestReportSetupActionOperationComponent' satisfies OwlClass;

/**
 * legal
 *
 * Contract.legal: List of Legal expressions or representations of this Contract.
 *
 * http://hl7.org/fhir/legal
 */
export const legal = 'http://hl7.org/fhir/legal' satisfies OwlObjectProperty;

/**
 * provider
 *
 * ExplanationOfBenefit.addItem.provider: The providers who are authorized for the services rendered to the patient.
 *
 * http://hl7.org/fhir/provider
 */
export const provider = 'http://hl7.org/fhir/provider' satisfies OwlObjectProperty;

/**
 * exitCriteria
 *
 * TestPlan.exitCriteria: The threshold or criteria for the test plan to be considered successfully executed - narrative.
 *
 * http://hl7.org/fhir/exitCriteria
 */
export const exitCriteria = 'http://hl7.org/fhir/exitCriteria' satisfies OwlObjectProperty;

/**
 * image
 *
 * ImplementationGuide.manifest.image: Indicates a relative path to an image that exists within the IG.
 *
 * http://hl7.org/fhir/image
 */
export const image = 'http://hl7.org/fhir/image' satisfies OwlObjectProperty;

/**
 * SupplyRequest
 *
 * A record of a non-patient specific request for a medication, substance, device, certain types of biologically derived product, and nutrition product used in the healthcare setting.
 *
 * http://hl7.org/fhir/SupplyRequest
 */
export const SupplyRequest = 'http://hl7.org/fhir/SupplyRequest' satisfies OwlClass;

/**
 * _periodMax
 *
 * (Modified) Timing.repeat.periodMax
 *
 * http://hl7.org/fhir/_periodMax
 */
export const _periodMax = 'http://hl7.org/fhir/_periodMax' satisfies OwlObjectProperty;

/**
 * _monograph
 *
 * (Modified) MedicationKnowledge.monograph
 *
 * http://hl7.org/fhir/_monograph
 */
export const _monograph = 'http://hl7.org/fhir/_monograph' satisfies OwlObjectProperty;

/**
 * _decision
 *
 * (Modified) ExplanationOfBenefit.item.detail.subDetail.reviewOutcome.decision
 *
 * http://hl7.org/fhir/_decision
 */
export const _decision = 'http://hl7.org/fhir/_decision' satisfies OwlObjectProperty;

/**
 * _diagnostics
 *
 * (Modified) OperationOutcome.issue.diagnostics
 *
 * http://hl7.org/fhir/_diagnostics
 */
export const _diagnostics = 'http://hl7.org/fhir/_diagnostics' satisfies OwlObjectProperty;

/**
 * _origin
 *
 * (Modified) TestScript.teardown.action.operation.origin
 *
 * http://hl7.org/fhir/_origin
 */
export const _origin = 'http://hl7.org/fhir/_origin' satisfies OwlObjectProperty;

/**
 * _durationUnit
 *
 * (Modified) Timing.repeat.durationUnit
 *
 * http://hl7.org/fhir/_durationUnit
 */
export const _durationUnit = 'http://hl7.org/fhir/_durationUnit' satisfies OwlObjectProperty;

/**
 * contact
 *
 * MessageHeader.source.contact: An e-mail, phone, website or other contact point to use to resolve issues with message communications.
 *
 * http://hl7.org/fhir/contact
 */
export const contact = 'http://hl7.org/fhir/contact' satisfies OwlObjectProperty;

/**
 * _disabledDisplay
 *
 * (Modified) Questionnaire.item.item.disabledDisplay
 *
 * http://hl7.org/fhir/_disabledDisplay
 */
export const _disabledDisplay = 'http://hl7.org/fhir/_disabledDisplay' satisfies OwlObjectProperty;

/**
 * _attestation
 *
 * (Modified) VerificationResult.attestation
 *
 * http://hl7.org/fhir/_attestation
 */
export const _attestation = 'http://hl7.org/fhir/_attestation' satisfies OwlObjectProperty;

/**
 * PackagedProductDefinitionPackagingComponentPackaging
 *
 * Allows containers (and parts of containers) within containers, still as a part of a single packaged product. See also PackagedProductDefinition.packaging.containedItem.item(PackagedProductDefinition).
 *
 * http://hl7.org/fhir/PackagedProductDefinitionPackagingComponentPackaging
 */
export const PackagedProductDefinitionPackagingComponentPackaging = 'http://hl7.org/fhir/PackagedProductDefinitionPackagingComponentPackaging' satisfies OwlClass;

/**
 * OperationOutcomeIssueComponent
 *
 * OperationOutcomeIssueComponent: An error, warning, or information message that results from a system action.
 *
 * http://hl7.org/fhir/OperationOutcomeIssueComponent
 */
export const OperationOutcomeIssueComponent = 'http://hl7.org/fhir/OperationOutcomeIssueComponent' satisfies OwlClass;

/**
 * _hash
 *
 * (Modified) Attachment.hash
 *
 * http://hl7.org/fhir/_hash
 */
export const _hash = 'http://hl7.org/fhir/_hash' satisfies OwlObjectProperty;

/**
 * _pageString
 *
 * (Modified) Citation.citedArtifact.publicationForm.pageString
 *
 * http://hl7.org/fhir/_pageString
 */
export const _pageString = 'http://hl7.org/fhir/_pageString' satisfies OwlObjectProperty;

/**
 * _constituent
 *
 * (Modified) ManufacturedItemDefinition.component.component.constituent
 *
 * http://hl7.org/fhir/_constituent
 */
export const _constituent = 'http://hl7.org/fhir/_constituent' satisfies OwlObjectProperty;

/**
 * DeviceAssociation
 *
 * A record of association of a device.
 *
 * http://hl7.org/fhir/DeviceAssociation
 */
export const DeviceAssociation = 'http://hl7.org/fhir/DeviceAssociation' satisfies OwlClass;

/**
 * _dayOfWeek
 *
 * (Modified) Appointment.recurrenceTemplate.monthlyTemplate.dayOfWeek
 *
 * http://hl7.org/fhir/_dayOfWeek
 */
export const _dayOfWeek = 'http://hl7.org/fhir/_dayOfWeek' satisfies OwlObjectProperty;

/**
 * _inventoryListing
 *
 * (Modified) InventoryReport.inventoryListing
 *
 * http://hl7.org/fhir/_inventoryListing
 */
export const _inventoryListing = 'http://hl7.org/fhir/_inventoryListing' satisfies OwlObjectProperty;

/**
 * _hierarchyMeaning
 *
 * (Modified) CodeSystem.hierarchyMeaning
 *
 * http://hl7.org/fhir/_hierarchyMeaning
 */
export const _hierarchyMeaning = 'http://hl7.org/fhir/_hierarchyMeaning' satisfies OwlObjectProperty;

/**
 * _dispenseRequest
 *
 * (Modified) MedicationRequest.dispenseRequest
 *
 * http://hl7.org/fhir/_dispenseRequest
 */
export const _dispenseRequest = 'http://hl7.org/fhir/_dispenseRequest' satisfies OwlObjectProperty;

/**
 * legallyBinding
 *
 * Contract.legallyBinding
 *
 * http://hl7.org/fhir/legallyBinding
 */
export const legallyBinding = 'http://hl7.org/fhir/legallyBinding' satisfies OwlObjectProperty;

/**
 * _manufacturer
 *
 * (Modified) SubstanceDefinition.manufacturer
 *
 * http://hl7.org/fhir/_manufacturer
 */
export const _manufacturer = 'http://hl7.org/fhir/_manufacturer' satisfies OwlObjectProperty;

/**
 * _answerConstraint
 *
 * (Modified) Questionnaire.item.item.answerConstraint
 *
 * http://hl7.org/fhir/_answerConstraint
 */
export const _answerConstraint = 'http://hl7.org/fhir/_answerConstraint' satisfies OwlObjectProperty;

/**
 * _when
 *
 * (Modified) ClaimResponse.event.when
 *
 * http://hl7.org/fhir/_when
 */
export const _when = 'http://hl7.org/fhir/_when' satisfies OwlObjectProperty;

/**
 * _form
 *
 * (Modified) SubstanceDefinition.characterization.form
 *
 * http://hl7.org/fhir/_form
 */
export const _form = 'http://hl7.org/fhir/_form' satisfies OwlObjectProperty;

/**
 * businessStatus
 *
 * Task.businessStatus: Contains business-specific nuances of the business state.
 *
 * http://hl7.org/fhir/businessStatus
 */
export const businessStatus = 'http://hl7.org/fhir/businessStatus' satisfies OwlObjectProperty;

/**
 * comparisonGroup
 *
 * ResearchStudy.comparisonGroup: Describes an expected event or sequence of events for one of the subjects of a study. E.g. for a living subject: exposure to drug A, wash-out, exposure to drug B, wash-out, follow-up. E.g. for a stability study: {store sample from lot A at 25 degrees for 1 month}, {store sample from lot A at 40 degrees for 1 month}.
 *
 * http://hl7.org/fhir/comparisonGroup
 */
export const comparisonGroup = 'http://hl7.org/fhir/comparisonGroup' satisfies OwlObjectProperty;

/**
 * _instance
 *
 * (Modified) ExampleScenario.instance
 *
 * http://hl7.org/fhir/_instance
 */
export const _instance = 'http://hl7.org/fhir/_instance' satisfies OwlObjectProperty;

/**
 * _itemStatus
 *
 * (Modified) InventoryReport.inventoryListing.itemStatus
 *
 * http://hl7.org/fhir/_itemStatus
 */
export const _itemStatus = 'http://hl7.org/fhir/_itemStatus' satisfies OwlObjectProperty;

/**
 * _conditionalDelete
 *
 * (Modified) CapabilityStatement.rest.resource.conditionalDelete
 *
 * http://hl7.org/fhir/_conditionalDelete
 */
export const _conditionalDelete = 'http://hl7.org/fhir/_conditionalDelete' satisfies OwlObjectProperty;

/**
 * _grade
 *
 * (Modified) SubstanceDefinition.grade
 *
 * http://hl7.org/fhir/_grade
 */
export const _grade = 'http://hl7.org/fhir/_grade' satisfies OwlObjectProperty;

/**
 * _process
 *
 * (Modified) ExampleScenario.process.step.alternative.step.process
 *
 * http://hl7.org/fhir/_process
 */
export const _process = 'http://hl7.org/fhir/_process' satisfies OwlObjectProperty;

/**
 * _articleDate
 *
 * (Modified) Citation.citedArtifact.publicationForm.articleDate
 *
 * http://hl7.org/fhir/_articleDate
 */
export const _articleDate = 'http://hl7.org/fhir/_articleDate' satisfies OwlObjectProperty;

/**
 * additionalMonitoringIndicator
 *
 * MedicinalProductDefinition.additionalMonitoringIndicator: Whether the Medicinal Product is subject to additional monitoring for regulatory reasons, such as heightened reporting requirements.
 *
 * http://hl7.org/fhir/additionalMonitoringIndicator
 */
export const additionalMonitoringIndicator = 'http://hl7.org/fhir/additionalMonitoringIndicator' satisfies OwlObjectProperty;

/**
 * title
 *
 * ValueSet.title: A short, descriptive, user-friendly title for the value set.
 *
 * http://hl7.org/fhir/title
 */
export const title = 'http://hl7.org/fhir/title' satisfies OwlObjectProperty;

/**
 * _courseOfTherapyType
 *
 * (Modified) MedicationRequest.courseOfTherapyType
 *
 * http://hl7.org/fhir/_courseOfTherapyType
 */
export const _courseOfTherapyType = 'http://hl7.org/fhir/_courseOfTherapyType' satisfies OwlObjectProperty;

/**
 * _identity
 *
 * (Modified) StructureDefinition.mapping.identity
 *
 * http://hl7.org/fhir/_identity
 */
export const _identity = 'http://hl7.org/fhir/_identity' satisfies OwlObjectProperty;

/**
 * CapabilityStatementRestComponent
 *
 * CapabilityStatementRestComponent: A definition of the restful capabilities of the solution, if any.
 *
 * http://hl7.org/fhir/CapabilityStatementRestComponent
 */
export const CapabilityStatementRestComponent = 'http://hl7.org/fhir/CapabilityStatementRestComponent' satisfies OwlClass;

/**
 * additionalAttribute
 *
 * ConceptMap.additionalAttribute: An additionalAttribute defines an additional data element found in the source or target data model where the data will come from or be mapped to. Some mappings are based on data in addition to the source data element, where codes in multiple fields are combined to a single field (or vice versa).
 *
 * http://hl7.org/fhir/additionalAttribute
 */
export const additionalAttribute = 'http://hl7.org/fhir/additionalAttribute' satisfies OwlObjectProperty;

/**
 * monomerSet
 *
 * SubstancePolymer.monomerSet: Todo.
 *
 * http://hl7.org/fhir/monomerSet
 */
export const monomerSet = 'http://hl7.org/fhir/monomerSet' satisfies OwlObjectProperty;

/**
 * ingredient
 *
 * Medication.ingredient: Identifies a particular constituent of interest in the product.
 *
 * http://hl7.org/fhir/ingredient
 */
export const ingredient = 'http://hl7.org/fhir/ingredient' satisfies OwlObjectProperty;

/**
 * _subPotentReason
 *
 * (Modified) MedicationAdministration.subPotentReason
 *
 * http://hl7.org/fhir/_subPotentReason
 */
export const _subPotentReason = 'http://hl7.org/fhir/_subPotentReason' satisfies OwlObjectProperty;

/**
 * _supportedMessage
 *
 * (Modified) CapabilityStatement.messaging.supportedMessage
 *
 * http://hl7.org/fhir/_supportedMessage
 */
export const _supportedMessage = 'http://hl7.org/fhir/_supportedMessage' satisfies OwlObjectProperty;

/**
 * DataRequirementDateFilterComponent
 *
 * DataRequirementDateFilterComponent: Date filters specify additional constraints on the data in terms of the applicable date range for specific elements. Each date filter specifies an additional constraint on the data, i.e. date filters are AND'ed, not OR'ed.
 *
 * http://hl7.org/fhir/DataRequirementDateFilterComponent
 */
export const DataRequirementDateFilterComponent = 'http://hl7.org/fhir/DataRequirementDateFilterComponent' satisfies OwlClass;

/**
 * _performedActivity
 *
 * (Modified) CarePlan.activity.performedActivity
 *
 * http://hl7.org/fhir/_performedActivity
 */
export const _performedActivity = 'http://hl7.org/fhir/_performedActivity' satisfies OwlObjectProperty;

/**
 * _specialty
 *
 * (Modified) Claim.careTeam.specialty
 *
 * http://hl7.org/fhir/_specialty
 */
export const _specialty = 'http://hl7.org/fhir/_specialty' satisfies OwlObjectProperty;

/**
 * _weekInterval
 *
 * (Modified) Appointment.recurrenceTemplate.weeklyTemplate.weekInterval
 *
 * http://hl7.org/fhir/_weekInterval
 */
export const _weekInterval = 'http://hl7.org/fhir/_weekInterval' satisfies OwlObjectProperty;

/**
 * publicationDate
 *
 * Contract.contentDefinition.publicationDate: The date (and optionally time) when the contract was last significantly changed. The date must change when the business version changes and it must change if the status code changes. In addition, it should change when the substantive content of the contract changes.
 *
 * http://hl7.org/fhir/publicationDate
 */
export const publicationDate = 'http://hl7.org/fhir/publicationDate' satisfies OwlObjectProperty;

/**
 * administrationInstruction
 *
 * NutritionOrder.enteralFormula.administrationInstruction: Free text formula administration, feeding instructions or additional instructions or information.
 *
 * http://hl7.org/fhir/administrationInstruction
 */
export const administrationInstruction = 'http://hl7.org/fhir/administrationInstruction' satisfies OwlObjectProperty;

/**
 * fivePrime
 *
 * SubstanceNucleicAcid.subunit.fivePrime: The nucleotide present at the 5’ terminal shall be specified based on a controlled vocabulary. Since the sequence is represented from the 5' to the 3' end, the 5’ prime nucleotide is the letter at the first position in the sequence. A separate representation would be redundant.
 *
 * http://hl7.org/fhir/fivePrime
 */
export const fivePrime = 'http://hl7.org/fhir/fivePrime' satisfies OwlObjectProperty;

/**
 * _points
 *
 * (Modified) Contract.term.group.asset.valuedItem.points
 *
 * http://hl7.org/fhir/_points
 */
export const _points = 'http://hl7.org/fhir/_points' satisfies OwlObjectProperty;

/**
 * TestScriptSetupActionAssertComponent
 *
 * TestScriptSetupComponent.SetupAction.TestScriptSetupActionAssertComponent: Evaluates the results of previous operations to determine if the server under test behaves appropriately.
 *
 * http://hl7.org/fhir/TestScriptSetupActionAssertComponent
 */
export const TestScriptSetupActionAssertComponent = 'http://hl7.org/fhir/TestScriptSetupActionAssertComponent' satisfies OwlClass;

/**
 * referralRequest
 *
 * EpisodeOfCare.referralRequest: Referral Request(s) that are fulfilled by this EpisodeOfCare, incoming referrals.
 *
 * http://hl7.org/fhir/referralRequest
 */
export const referralRequest = 'http://hl7.org/fhir/referralRequest' satisfies OwlObjectProperty;

/**
 * _timeAspect
 *
 * (Modified) SpecimenDefinition.timeAspect
 *
 * http://hl7.org/fhir/_timeAspect
 */
export const _timeAspect = 'http://hl7.org/fhir/_timeAspect' satisfies OwlObjectProperty;

/**
 * _presentedForm
 *
 * (Modified) DiagnosticReport.presentedForm
 *
 * http://hl7.org/fhir/_presentedForm
 */
export const _presentedForm = 'http://hl7.org/fhir/_presentedForm' satisfies OwlObjectProperty;

/**
 * _seriesDoses
 *
 * (Modified) ImmunizationRecommendation.recommendation.seriesDoses
 *
 * http://hl7.org/fhir/_seriesDoses
 */
export const _seriesDoses = 'http://hl7.org/fhir/_seriesDoses' satisfies OwlObjectProperty;

/**
 * milestone
 *
 * ResearchSubject.progress.milestone: The milestones the subject has passed through.
 *
 * http://hl7.org/fhir/milestone
 */
export const milestone = 'http://hl7.org/fhir/milestone' satisfies OwlObjectProperty;

/**
 * MedicationAdministrationPerformerComponent
 *
 * MedicationAdministrationPerformerComponent: The performer of the medication treatment.  For devices this is the device that performed the administration of the medication.  An IV Pump would be an example of a device that is performing the administration. Both the IV Pump and the practitioner that set the rate or bolus on the pump can be listed as performers.
 *
 * http://hl7.org/fhir/MedicationAdministrationPerformerComponent
 */
export const MedicationAdministrationPerformerComponent = 'http://hl7.org/fhir/MedicationAdministrationPerformerComponent' satisfies OwlClass;

/**
 * Invoice
 *
 * Invoice containing collected ChargeItems from an Account with calculated individual and total price for Billing purpose.
 *
 * http://hl7.org/fhir/Invoice
 */
export const Invoice = 'http://hl7.org/fhir/Invoice' satisfies OwlClass;

/**
 * additionalContext
 *
 * SubscriptionStatus.notificationEvent.additionalContext: Additional context information for this event. Generally, this will contain references to additional resources included with the event (e.g., the Patient relevant to an Encounter), however it MAY refer to non-FHIR objects.
 *
 * http://hl7.org/fhir/additionalContext
 */
export const additionalContext = 'http://hl7.org/fhir/additionalContext' satisfies OwlObjectProperty;

/**
 * _satisfiedBy
 *
 * (Modified) Requirements.statement.satisfiedBy
 *
 * http://hl7.org/fhir/_satisfiedBy
 */
export const _satisfiedBy = 'http://hl7.org/fhir/_satisfiedBy' satisfies OwlObjectProperty;

/**
 * identifier
 *
 * ImplementationGuide.identifier: A formal identifier that is used to identify this implementation guide when it is represented in other formats, or referenced in a specification, model, design or an instance.
 *
 * http://hl7.org/fhir/identifier
 */
export const identifier = 'http://hl7.org/fhir/identifier' satisfies OwlObjectProperty;

/**
 * SubstanceNucleicAcid
 *
 * Nucleic acids are defined by three distinct elements: the base, sugar and linkage. Individual substance/moiety IDs will be created for each of these elements. The nucleotide sequence will be always entered in the 5’-3’ direction.
 *
 * http://hl7.org/fhir/SubstanceNucleicAcid
 */
export const SubstanceNucleicAcid = 'http://hl7.org/fhir/SubstanceNucleicAcid' satisfies OwlClass;

/**
 * resourceTrigger
 *
 * SubscriptionTopic.resourceTrigger: A definition of a resource-based event that triggers a notification based on the SubscriptionTopic. The criteria may be just a human readable description and/or a full FHIR search string or FHIRPath expression. Multiple triggers are considered OR joined (e.g., a resource update matching ANY of the definitions will trigger a notification).
 *
 * http://hl7.org/fhir/resourceTrigger
 */
export const resourceTrigger = 'http://hl7.org/fhir/resourceTrigger' satisfies OwlObjectProperty;

/**
 * _overload
 *
 * (Modified) OperationDefinition.overload
 *
 * http://hl7.org/fhir/_overload
 */
export const _overload = 'http://hl7.org/fhir/_overload' satisfies OwlObjectProperty;

/**
 * organization
 *
 * VerificationResult.validator.organization: Reference to the organization validating information.
 *
 * http://hl7.org/fhir/organization
 */
export const organization = 'http://hl7.org/fhir/organization' satisfies OwlObjectProperty;

/**
 * PlanDefinitionActionConditionComponent
 *
 * PlanDefinitionActionComponentAction.PlanDefinitionActionConditionComponent: An expression that describes applicability criteria or start/stop conditions for the action.
 *
 * http://hl7.org/fhir/PlanDefinitionActionConditionComponent
 */
export const PlanDefinitionActionConditionComponent = 'http://hl7.org/fhir/PlanDefinitionActionConditionComponent' satisfies OwlClass;

/**
 * RegulatedAuthorizationCaseComponentCaseCase
 *
 * A regulatory submission from an organization to a regulator, as part of an assessing case. Multiple applications may occur over time, with more or different information to support or modify the submission or the authorization. The applications can be considered as steps within the longer running case or procedure for this authorization process.
 *
 * http://hl7.org/fhir/RegulatedAuthorizationCaseComponentCaseCase
 */
export const RegulatedAuthorizationCaseComponentCaseCase = 'http://hl7.org/fhir/RegulatedAuthorizationCaseComponentCaseCase' satisfies OwlClass;

/**
 * sliceIsConstraining
 *
 * ElementDefinition.sliceIsConstraining: If true, indicates that this slice definition is constraining a slice definition with the same name in an inherited profile. If false, the slice is not overriding any slice in an inherited profile. If missing, the slice might or might not be overriding a slice in an inherited profile, depending on the sliceName.
 *
 * http://hl7.org/fhir/sliceIsConstraining
 */
export const sliceIsConstraining = 'http://hl7.org/fhir/sliceIsConstraining' satisfies OwlObjectProperty;

/**
 * _dataUpdateType
 *
 * (Modified) MeasureReport.dataUpdateType
 *
 * http://hl7.org/fhir/_dataUpdateType
 */
export const _dataUpdateType = 'http://hl7.org/fhir/_dataUpdateType' satisfies OwlObjectProperty;

/**
 * noteNumber
 *
 * ClaimResponse.item.detail.noteNumber: The numbers associated with notes below which apply to the adjudication of this item.
 *
 * http://hl7.org/fhir/noteNumber
 */
export const noteNumber = 'http://hl7.org/fhir/noteNumber' satisfies OwlObjectProperty;

/**
 * installDate
 *
 * Device.version.installDate: The date the version was installed on the device.
 *
 * http://hl7.org/fhir/installDate
 */
export const installDate = 'http://hl7.org/fhir/installDate' satisfies OwlObjectProperty;

/**
 * cardBrand
 *
 * PaymentReconciliation.cardBrand: The card brand such as debit, Visa, Amex etc. used if a card is the method of payment.
 *
 * http://hl7.org/fhir/cardBrand
 */
export const cardBrand = 'http://hl7.org/fhir/cardBrand' satisfies OwlObjectProperty;

/**
 * _fullUrl
 *
 * (Modified) Bundle.entry.fullUrl
 *
 * http://hl7.org/fhir/_fullUrl
 */
export const _fullUrl = 'http://hl7.org/fhir/_fullUrl' satisfies OwlObjectProperty;

/**
 * codeMap
 *
 * SampledData.codeMap: Reference to ConceptMap that defines the codes used in the data.
 *
 * http://hl7.org/fhir/codeMap
 */
export const codeMap = 'http://hl7.org/fhir/codeMap' satisfies OwlObjectProperty;

/**
 * ConditionDefinitionObservationComponent
 *
 * ConditionDefinitionObservationComponent: Observations particularly relevant to this condition.
 *
 * http://hl7.org/fhir/ConditionDefinitionObservationComponent
 */
export const ConditionDefinitionObservationComponent = 'http://hl7.org/fhir/ConditionDefinitionObservationComponent' satisfies OwlClass;

/**
 * FamilyMemberHistory
 *
 * Significant health conditions for a person related to the patient relevant in the context of care for the patient.
 *
 * http://hl7.org/fhir/FamilyMemberHistory
 */
export const FamilyMemberHistory = 'http://hl7.org/fhir/FamilyMemberHistory' satisfies OwlClass;

/**
 * operationTypeReason
 *
 * InventoryReport.operationTypeReason: The reason for this count - regular count, ad-hoc count, new arrivals, etc.
 *
 * http://hl7.org/fhir/operationTypeReason
 */
export const operationTypeReason = 'http://hl7.org/fhir/operationTypeReason' satisfies OwlObjectProperty;

/**
 * SpecimenDefinitionTypeTestedContainerAdditiveComponent
 *
 * SpecimenDefinitionTypeTestedComponent.SpecimenDefinitionTypeTestedContainerComponent.SpecimenDefinitionTypeTestedContainerAdditiveComponent: Substance introduced in the kind of container to preserve, maintain or enhance the specimen. Examples: Formalin, Citrate, EDTA.
 *
 * http://hl7.org/fhir/SpecimenDefinitionTypeTestedContainerAdditiveComponent
 */
export const SpecimenDefinitionTypeTestedContainerAdditiveComponent = 'http://hl7.org/fhir/SpecimenDefinitionTypeTestedContainerAdditiveComponent' satisfies OwlClass;

/**
 * _element
 *
 * (Modified) StructureDefinition.differential.element
 *
 * http://hl7.org/fhir/_element
 */
export const _element = 'http://hl7.org/fhir/_element' satisfies OwlObjectProperty;

/**
 * _attachedDocument
 *
 * (Modified) RegulatedAuthorization.attachedDocument
 *
 * http://hl7.org/fhir/_attachedDocument
 */
export const _attachedDocument = 'http://hl7.org/fhir/_attachedDocument' satisfies OwlObjectProperty;

/**
 * _implementation
 *
 * (Modified) TerminologyCapabilities.implementation
 *
 * http://hl7.org/fhir/_implementation
 */
export const _implementation = 'http://hl7.org/fhir/_implementation' satisfies OwlObjectProperty;

/**
 * sourceMaterialType
 *
 * SubstanceSourceMaterial.sourceMaterialType: The type of the source material shall be specified based on a controlled vocabulary. For vaccines, this subclause refers to the class of infectious agent.
 *
 * http://hl7.org/fhir/sourceMaterialType
 */
export const sourceMaterialType = 'http://hl7.org/fhir/sourceMaterialType' satisfies OwlObjectProperty;

/**
 * _substance
 *
 * (Modified) Substance.ingredient.substance
 *
 * http://hl7.org/fhir/_substance
 */
export const _substance = 'http://hl7.org/fhir/_substance' satisfies OwlObjectProperty;

/**
 * _qualification
 *
 * (Modified) Practitioner.qualification
 *
 * http://hl7.org/fhir/_qualification
 */
export const _qualification = 'http://hl7.org/fhir/_qualification' satisfies OwlObjectProperty;

/**
 * _countType
 *
 * (Modified) InventoryReport.countType
 *
 * http://hl7.org/fhir/_countType
 */
export const _countType = 'http://hl7.org/fhir/_countType' satisfies OwlObjectProperty;

/**
 * sourceMaterialState
 *
 * SubstanceSourceMaterial.sourceMaterialState: The state of the source material when extracted.
 *
 * http://hl7.org/fhir/sourceMaterialState
 */
export const sourceMaterialState = 'http://hl7.org/fhir/sourceMaterialState' satisfies OwlObjectProperty;

/**
 * _observationResultRequirement
 *
 * (Modified) ActivityDefinition.observationResultRequirement
 *
 * http://hl7.org/fhir/_observationResultRequirement
 */
export const _observationResultRequirement = 'http://hl7.org/fhir/_observationResultRequirement' satisfies OwlObjectProperty;

/**
 * attestationSignature
 *
 * VerificationResult.validator.attestationSignature: Signed assertion by the validator that they have validated the information.
 *
 * http://hl7.org/fhir/attestationSignature
 */
export const attestationSignature = 'http://hl7.org/fhir/attestationSignature' satisfies OwlObjectProperty;

/**
 * PackagedProductDefinitionPackagingComponentPackagingPackaging
 *
 * Allows containers (and parts of containers) within containers, still as a part of a single packaged product. See also PackagedProductDefinition.packaging.containedItem.item(PackagedProductDefinition).
 *
 * http://hl7.org/fhir/PackagedProductDefinitionPackagingComponentPackagingPackaging
 */
export const PackagedProductDefinitionPackagingComponentPackagingPackaging = 'http://hl7.org/fhir/PackagedProductDefinitionPackagingComponentPackagingPackaging' satisfies OwlClass;

/**
 * _marketingAuthorizationHolder
 *
 * (Modified) Medication.marketingAuthorizationHolder
 *
 * http://hl7.org/fhir/_marketingAuthorizationHolder
 */
export const _marketingAuthorizationHolder = 'http://hl7.org/fhir/_marketingAuthorizationHolder' satisfies OwlObjectProperty;

/**
 * _decisionMode
 *
 * (Modified) Contract.term.group.offer.decisionMode
 *
 * http://hl7.org/fhir/_decisionMode
 */
export const _decisionMode = 'http://hl7.org/fhir/_decisionMode' satisfies OwlObjectProperty;

/**
 * repeats
 *
 * Questionnaire.item.item.repeats: An indication, if true, that a QuestionnaireResponse for this item may include multiple answers associated with a single instance of this item (for question-type items) or multiple repetitions of the item (for group-type items).
 *
 * http://hl7.org/fhir/repeats
 */
export const repeats = 'http://hl7.org/fhir/repeats' satisfies OwlObjectProperty;

/**
 * typeTested
 *
 * SpecimenDefinition.typeTested: Specimen conditioned in a container as expected by the testing laboratory.
 *
 * http://hl7.org/fhir/typeTested
 */
export const typeTested = 'http://hl7.org/fhir/typeTested' satisfies OwlObjectProperty;

/**
 * _rankingOrder
 *
 * (Modified) Citation.citedArtifact.contributorship.entry.rankingOrder
 *
 * http://hl7.org/fhir/_rankingOrder
 */
export const _rankingOrder = 'http://hl7.org/fhir/_rankingOrder' satisfies OwlObjectProperty;

/**
 * end
 *
 * MolecularSequence.relative.edit.end: End position of the edit on the starting sequence. If the coordinate system is 0-based then end is exclusive and does not include the last position. If the coordinate system is 1-base, then end is inclusive and includes the last position.
 *
 * http://hl7.org/fhir/end
 */
export const end = 'http://hl7.org/fhir/end' satisfies OwlObjectProperty;

/**
 * GenomicStudyAnalysisComponent
 *
 * GenomicStudyAnalysisComponent: The details about a specific analysis that was performed in this GenomicStudy.
 *
 * http://hl7.org/fhir/GenomicStudyAnalysisComponent
 */
export const GenomicStudyAnalysisComponent = 'http://hl7.org/fhir/GenomicStudyAnalysisComponent' satisfies OwlClass;

/**
 * excluded
 *
 * ExplanationOfBenefit.benefitBalance.excluded: True if the indicated class of service is excluded from the plan, missing or False indicates the product or service is included in the coverage.
 *
 * http://hl7.org/fhir/excluded
 */
export const excluded = 'http://hl7.org/fhir/excluded' satisfies OwlObjectProperty;

/**
 * BundleEntryRequestComponent
 *
 * BundleEntryComponent.BundleEntryRequestComponent: Additional information about how this entry should be processed as part of a transaction or batch.  For history, it shows how the entry was processed to create the version contained in the entry.
 *
 * http://hl7.org/fhir/BundleEntryRequestComponent
 */
export const BundleEntryRequestComponent = 'http://hl7.org/fhir/BundleEntryRequestComponent' satisfies OwlClass;

/**
 * DeviceDefinitionDeviceNameComponent
 *
 * DeviceDefinitionDeviceNameComponent: The name or names of the device as given by the manufacturer.
 *
 * http://hl7.org/fhir/DeviceDefinitionDeviceNameComponent
 */
export const DeviceDefinitionDeviceNameComponent = 'http://hl7.org/fhir/DeviceDefinitionDeviceNameComponent' satisfies OwlClass;

/**
 * _eventNumber
 *
 * (Modified) SubscriptionStatus.notificationEvent.eventNumber
 *
 * http://hl7.org/fhir/_eventNumber
 */
export const _eventNumber = 'http://hl7.org/fhir/_eventNumber' satisfies OwlObjectProperty;

/**
 * FormularyItem
 *
 * This resource describes a product or service that is available through a program and includes the conditions and constraints of availability.  All of the information in this resource is specific to the inclusion of the item in the formulary and is not inherent to the item itself.
 *
 * http://hl7.org/fhir/FormularyItem
 */
export const FormularyItem = 'http://hl7.org/fhir/FormularyItem' satisfies OwlClass;

/**
 * _marketDistribution
 *
 * (Modified) DeviceDefinition.packaging.packaging.udiDeviceIdentifier.marketDistribution
 *
 * http://hl7.org/fhir/_marketDistribution
 */
export const _marketDistribution = 'http://hl7.org/fhir/_marketDistribution' satisfies OwlObjectProperty;

/**
 * _searchParam
 *
 * (Modified) CapabilityStatement.rest.searchParam
 *
 * http://hl7.org/fhir/_searchParam
 */
export const _searchParam = 'http://hl7.org/fhir/_searchParam' satisfies OwlObjectProperty;

/**
 * countryOfOrigin
 *
 * SubstanceSourceMaterial.countryOfOrigin: The country where the plant material is harvested or the countries where the plasma is sourced from as laid down in accordance with the Plasma Master File. For “Plasma-derived substances” the attribute country of origin provides information about the countries used for the manufacturing of the Cryopoor plama or Crioprecipitate.
 *
 * http://hl7.org/fhir/countryOfOrigin
 */
export const countryOfOrigin = 'http://hl7.org/fhir/countryOfOrigin' satisfies OwlObjectProperty;

/**
 * AuditEventAgentComponent
 *
 * AuditEventAgentComponent: An actor taking an active role in the event or activity that is logged.
 *
 * http://hl7.org/fhir/AuditEventAgentComponent
 */
export const AuditEventAgentComponent = 'http://hl7.org/fhir/AuditEventAgentComponent' satisfies OwlClass;

/**
 * _regulatoryAuthority
 *
 * (Modified) MedicationKnowledge.regulatory.regulatoryAuthority
 *
 * http://hl7.org/fhir/_regulatoryAuthority
 */
export const _regulatoryAuthority = 'http://hl7.org/fhir/_regulatoryAuthority' satisfies OwlObjectProperty;

/**
 * _subjectState
 *
 * (Modified) ResearchSubject.progress.subjectState
 *
 * http://hl7.org/fhir/_subjectState
 */
export const _subjectState = 'http://hl7.org/fhir/_subjectState' satisfies OwlObjectProperty;

/**
 * actualComparisonGroup
 *
 * ResearchSubject.actualComparisonGroup: The name of the arm in the study the subject actually followed as part of this study.
 *
 * http://hl7.org/fhir/actualComparisonGroup
 */
export const actualComparisonGroup = 'http://hl7.org/fhir/actualComparisonGroup' satisfies OwlObjectProperty;

/**
 * _focusReference
 *
 * (Modified) EvidenceReport.section.section.focusReference
 *
 * http://hl7.org/fhir/_focusReference
 */
export const _focusReference = 'http://hl7.org/fhir/_focusReference' satisfies OwlObjectProperty;

/**
 * _statusReason
 *
 * (Modified) Transport.statusReason
 *
 * http://hl7.org/fhir/_statusReason
 */
export const _statusReason = 'http://hl7.org/fhir/_statusReason' satisfies OwlObjectProperty;

/**
 * ingredientLabel
 *
 * NutritionIntake.ingredientLabel: Total nutrient amounts for the whole meal, product, serving, etc.
 *
 * http://hl7.org/fhir/ingredientLabel
 */
export const ingredientLabel = 'http://hl7.org/fhir/ingredientLabel' satisfies OwlObjectProperty;

/**
 * _whenPrepared
 *
 * (Modified) MedicationDispense.whenPrepared
 *
 * http://hl7.org/fhir/_whenPrepared
 */
export const _whenPrepared = 'http://hl7.org/fhir/_whenPrepared' satisfies OwlObjectProperty;

/**
 * costCenter
 *
 * ChargeItem.costCenter: The financial cost center permits the tracking of charge attribution.
 *
 * http://hl7.org/fhir/costCenter
 */
export const costCenter = 'http://hl7.org/fhir/costCenter' satisfies OwlObjectProperty;

/**
 * outputParameters
 *
 * GuidanceResponse.outputParameters: The output parameters of the evaluation, if any. Many modules will result in the return of specific resources such as procedure or communication requests that are returned as part of the operation result. However, modules may define specific outputs that would be returned as the result of the evaluation, and these would be returned in this element.
 *
 * http://hl7.org/fhir/outputParameters
 */
export const outputParameters = 'http://hl7.org/fhir/outputParameters' satisfies OwlObjectProperty;

/**
 * DevicePropertyComponent
 *
 * DevicePropertyComponent: Static or essentially fixed characteristics or features of the device (e.g., time or timing attributes, resolution, accuracy, intended use or instructions for use, and physical attributes) that are not otherwise captured in more specific attributes.
 *
 * http://hl7.org/fhir/DevicePropertyComponent
 */
export const DevicePropertyComponent = 'http://hl7.org/fhir/DevicePropertyComponent' satisfies OwlClass;

/**
 * productCategory
 *
 * BiologicallyDerivedProduct.productCategory: Broad category of this product.
 *
 * http://hl7.org/fhir/productCategory
 */
export const productCategory = 'http://hl7.org/fhir/productCategory' satisfies OwlObjectProperty;

/**
 * serviceType
 *
 * Schedule.serviceType: The specific service that is to be performed during this appointment.
 *
 * http://hl7.org/fhir/serviceType
 */
export const serviceType = 'http://hl7.org/fhir/serviceType' satisfies OwlObjectProperty;

/**
 * _verification
 *
 * (Modified) Consent.verification
 *
 * http://hl7.org/fhir/_verification
 */
export const _verification = 'http://hl7.org/fhir/_verification' satisfies OwlObjectProperty;

/**
 * reliableCache
 *
 * CapabilityStatement.messaging.reliableCache: Length if the receiver's reliable messaging cache in minutes (if a receiver) or how long the cache length on the receiver should be (if a sender).
 *
 * http://hl7.org/fhir/reliableCache
 */
export const reliableCache = 'http://hl7.org/fhir/reliableCache' satisfies OwlObjectProperty;

/**
 * _Flag
 *
 * (Modified) Flag
 *
 * http://hl7.org/fhir/_Flag
 */
export const _Flag = 'http://hl7.org/fhir/_Flag' satisfies OwlClass;

/**
 * numberAffected
 *
 * Evidence.statistic.numberAffected: The number of participants affected where the unit of analysis is the same as sampleSize.knownDataCount and sampleSize.numberOfParticipants.
 *
 * http://hl7.org/fhir/numberAffected
 */
export const numberAffected = 'http://hl7.org/fhir/numberAffected' satisfies OwlObjectProperty;

/**
 * StructureMapGroupRuleDependentComponent
 *
 * StructureMapGroupComponent.StructureMapGroupRuleComponentRule.StructureMapGroupRuleDependentComponent: Which other rules to apply in the context of this rule.
 *
 * http://hl7.org/fhir/StructureMapGroupRuleDependentComponent
 */
export const StructureMapGroupRuleDependentComponent = 'http://hl7.org/fhir/StructureMapGroupRuleDependentComponent' satisfies OwlClass;

/**
 * relationshipType
 *
 * ClinicalUseDefinition.indication.otherTherapy.relationshipType: The type of relationship between the medicinal product indication or contraindication and another therapy.
 *
 * http://hl7.org/fhir/relationshipType
 */
export const relationshipType = 'http://hl7.org/fhir/relationshipType' satisfies OwlObjectProperty;

/**
 * _statement
 *
 * (Modified) Requirements.statement
 *
 * http://hl7.org/fhir/_statement
 */
export const _statement = 'http://hl7.org/fhir/_statement' satisfies OwlObjectProperty;

/**
 * _Goal
 *
 * (Modified) Goal
 *
 * http://hl7.org/fhir/_Goal
 */
export const _Goal = 'http://hl7.org/fhir/_Goal' satisfies OwlClass;

/**
 * issued
 *
 * TestReport.issued: When the TestScript was executed and this TestReport was generated.
 *
 * http://hl7.org/fhir/issued
 */
export const issued = 'http://hl7.org/fhir/issued' satisfies OwlObjectProperty;

/**
 * _instruction
 *
 * (Modified) SpecimenDefinition.typeTested.handling.instruction
 *
 * http://hl7.org/fhir/_instruction
 */
export const _instruction = 'http://hl7.org/fhir/_instruction' satisfies OwlObjectProperty;

/**
 * inclusionCriteria
 *
 * ValueSet.scope.inclusionCriteria: Criteria describing which concepts or codes should be included and why.
 *
 * http://hl7.org/fhir/inclusionCriteria
 */
export const inclusionCriteria = 'http://hl7.org/fhir/inclusionCriteria' satisfies OwlObjectProperty;

/**
 * about
 *
 * CommunicationRequest.about: Other resources that pertain to this communication request and to which this communication request should be associated.
 *
 * http://hl7.org/fhir/about
 */
export const about = 'http://hl7.org/fhir/about' satisfies OwlObjectProperty;

/**
 * Practitioner
 *
 * A person who is directly or indirectly involved in the provisioning of healthcare or related services.
 *
 * http://hl7.org/fhir/Practitioner
 */
export const Practitioner = 'http://hl7.org/fhir/Practitioner' satisfies OwlClass;

/**
 * prognosisCodeableConcept
 *
 * ClinicalImpression.prognosisCodeableConcept: Estimate of likely outcome.
 *
 * http://hl7.org/fhir/prognosisCodeableConcept
 */
export const prognosisCodeableConcept = 'http://hl7.org/fhir/prognosisCodeableConcept' satisfies OwlObjectProperty;

/**
 * AdverseEventParticipantComponent
 *
 * AdverseEventParticipantComponent: Indicates who or what participated in the adverse event and how they were involved.
 *
 * http://hl7.org/fhir/AdverseEventParticipantComponent
 */
export const AdverseEventParticipantComponent = 'http://hl7.org/fhir/AdverseEventParticipantComponent' satisfies OwlClass;

/**
 * _maxValue
 *
 * (Modified) ElementDefinition.maxValue
 *
 * http://hl7.org/fhir/_maxValue
 */
export const _maxValue = 'http://hl7.org/fhir/_maxValue' satisfies OwlObjectProperty;

/**
 * ItemDetail
 *
 * ClaimResponse.Item.ItemDetail: A claim detail. Either a simple (a product or service) or a 'group' of sub-details which are simple items.
 *
 * http://hl7.org/fhir/ItemDetail
 */
export const ItemDetail = 'http://hl7.org/fhir/ItemDetail' satisfies OwlClass;

/**
 * _hasBodySite
 *
 * (Modified) ConditionDefinition.hasBodySite
 *
 * http://hl7.org/fhir/_hasBodySite
 */
export const _hasBodySite = 'http://hl7.org/fhir/_hasBodySite' satisfies OwlObjectProperty;

/**
 * _metadata
 *
 * (Modified) TestScript.metadata
 *
 * http://hl7.org/fhir/_metadata
 */
export const _metadata = 'http://hl7.org/fhir/_metadata' satisfies OwlObjectProperty;

/**
 * rejectionCriterion
 *
 * SpecimenDefinition.typeTested.rejectionCriterion: Criterion for rejection of the specimen in its container by the laboratory.
 *
 * http://hl7.org/fhir/rejectionCriterion
 */
export const rejectionCriterion = 'http://hl7.org/fhir/rejectionCriterion' satisfies OwlObjectProperty;

/**
 * cors
 *
 * CapabilityStatement.rest.security.cors: Server adds CORS headers when responding to requests - this enables Javascript applications to use the server.
 *
 * http://hl7.org/fhir/cors
 */
export const cors = 'http://hl7.org/fhir/cors' satisfies OwlObjectProperty;

/**
 * _option
 *
 * (Modified) PlanDefinition.actor.option
 *
 * http://hl7.org/fhir/_option
 */
export const _option = 'http://hl7.org/fhir/_option' satisfies OwlObjectProperty;

/**
 * TypeRefComponent
 *
 * ElementDefinition.TypeRefComponent: The data type or resource that the value of this element is permitted to be.
 *
 * http://hl7.org/fhir/TypeRefComponent
 */
export const TypeRefComponent = 'http://hl7.org/fhir/TypeRefComponent' satisfies OwlClass;

/**
 * minValue
 *
 * ElementDefinition.minValue
 *
 * http://hl7.org/fhir/minValue
 */
export const minValue = 'http://hl7.org/fhir/minValue' satisfies OwlObjectProperty;

/**
 * _tuesday
 *
 * (Modified) Appointment.recurrenceTemplate.weeklyTemplate.tuesday
 *
 * http://hl7.org/fhir/_tuesday
 */
export const _tuesday = 'http://hl7.org/fhir/_tuesday' satisfies OwlObjectProperty;

/**
 * _offset
 *
 * (Modified) ValueSet.expansion.offset
 *
 * http://hl7.org/fhir/_offset
 */
export const _offset = 'http://hl7.org/fhir/_offset' satisfies OwlObjectProperty;

/**
 * report
 *
 * Procedure.report: This could be a histology result, pathology report, surgical report, etc.
 *
 * http://hl7.org/fhir/report
 */
export const report = 'http://hl7.org/fhir/report' satisfies OwlObjectProperty;

/**
 * _fhirPathCriteria
 *
 * (Modified) SubscriptionTopic.resourceTrigger.fhirPathCriteria
 *
 * http://hl7.org/fhir/_fhirPathCriteria
 */
export const _fhirPathCriteria = 'http://hl7.org/fhir/_fhirPathCriteria' satisfies OwlObjectProperty;

/**
 * editor
 *
 * ValueSet.editor: An individual or organization primarily responsible for internal coherence of the ValueSet.
 *
 * http://hl7.org/fhir/editor
 */
export const editor = 'http://hl7.org/fhir/editor' satisfies OwlObjectProperty;

/**
 * _firstDose
 *
 * (Modified) AdministrableProductDefinition.routeOfAdministration.firstDose
 *
 * http://hl7.org/fhir/_firstDose
 */
export const _firstDose = 'http://hl7.org/fhir/_firstDose' satisfies OwlObjectProperty;

/**
 * procedureSequence
 *
 * ExplanationOfBenefit.item.procedureSequence: Procedures applicable for this service or product.
 *
 * http://hl7.org/fhir/procedureSequence
 */
export const procedureSequence = 'http://hl7.org/fhir/procedureSequence' satisfies OwlObjectProperty;

/**
 * MedicinalProductDefinitionContactComponent
 *
 * MedicinalProductDefinitionContactComponent: A product specific contact, person (in a role), or an organization.
 *
 * http://hl7.org/fhir/MedicinalProductDefinitionContactComponent
 */
export const MedicinalProductDefinitionContactComponent = 'http://hl7.org/fhir/MedicinalProductDefinitionContactComponent' satisfies OwlClass;

/**
 * _Communication
 *
 * (Modified) Communication
 *
 * http://hl7.org/fhir/_Communication
 */
export const _Communication = 'http://hl7.org/fhir/_Communication' satisfies OwlClass;

/**
 * _controller
 *
 * (Modified) Consent.controller
 *
 * http://hl7.org/fhir/_controller
 */
export const _controller = 'http://hl7.org/fhir/_controller' satisfies OwlObjectProperty;

/**
 * TestScriptSetupActionAssertRequirementComponent
 *
 * TestScriptTestComponent.TestActionAssert.TestScriptSetupActionAssertRequirementComponent: Links or references providing traceability to the testing requirements for this assert.
 *
 * http://hl7.org/fhir/TestScriptSetupActionAssertRequirementComponent
 */
export const TestScriptSetupActionAssertRequirementComponent = 'http://hl7.org/fhir/TestScriptSetupActionAssertRequirementComponent' satisfies OwlClass;

/**
 * _allocation
 *
 * (Modified) PaymentReconciliation.allocation
 *
 * http://hl7.org/fhir/_allocation
 */
export const _allocation = 'http://hl7.org/fhir/_allocation' satisfies OwlObjectProperty;

/**
 * otherTherapy
 *
 * ClinicalUseDefinition.indication.otherTherapy: Information about the use of the medicinal product in relation to other therapies described as part of the indication.
 *
 * http://hl7.org/fhir/otherTherapy
 */
export const otherTherapy = 'http://hl7.org/fhir/otherTherapy' satisfies OwlObjectProperty;

/**
 * _requestedLocation
 *
 * (Modified) Transport.requestedLocation
 *
 * http://hl7.org/fhir/_requestedLocation
 */
export const _requestedLocation = 'http://hl7.org/fhir/_requestedLocation' satisfies OwlObjectProperty;

/**
 * _referencedFrom
 *
 * (Modified) OperationDefinition.parameter.part.referencedFrom
 *
 * http://hl7.org/fhir/_referencedFrom
 */
export const _referencedFrom = 'http://hl7.org/fhir/_referencedFrom' satisfies OwlObjectProperty;

/**
 * eventsSinceSubscriptionStart
 *
 * SubscriptionStatus.eventsSinceSubscriptionStart: The total number of actual events which have been generated since the Subscription was created (inclusive of this notification) - regardless of how many have been successfully communicated.  This number is NOT incremented for handshake and heartbeat notifications.
 *
 * http://hl7.org/fhir/eventsSinceSubscriptionStart
 */
export const eventsSinceSubscriptionStart = 'http://hl7.org/fhir/eventsSinceSubscriptionStart' satisfies OwlObjectProperty;

/**
 * _question
 *
 * (Modified) Questionnaire.item.item.enableWhen.question
 *
 * http://hl7.org/fhir/_question
 */
export const _question = 'http://hl7.org/fhir/_question' satisfies OwlObjectProperty;

/**
 * _drugCharacteristic
 *
 * (Modified) MedicationKnowledge.definitional.drugCharacteristic
 *
 * http://hl7.org/fhir/_drugCharacteristic
 */
export const _drugCharacteristic = 'http://hl7.org/fhir/_drugCharacteristic' satisfies OwlObjectProperty;

/**
 * _total
 *
 * (Modified) ValueSet.expansion.total
 *
 * http://hl7.org/fhir/_total
 */
export const _total = 'http://hl7.org/fhir/_total' satisfies OwlObjectProperty;

/**
 * AuditEvent
 *
 * A record of an event relevant for purposes such as operations, privacy, security, maintenance, and performance analysis.
 *
 * http://hl7.org/fhir/AuditEvent
 */
export const AuditEvent = 'http://hl7.org/fhir/AuditEvent' satisfies OwlClass;

/**
 * _environmentType
 *
 * (Modified) Endpoint.environmentType
 *
 * http://hl7.org/fhir/_environmentType
 */
export const _environmentType = 'http://hl7.org/fhir/_environmentType' satisfies OwlObjectProperty;

/**
 * AssetContext
 *
 * Contract.TermTerm.ContractAsset.AssetContext: Circumstance of the asset.
 *
 * http://hl7.org/fhir/AssetContext
 */
export const AssetContext = 'http://hl7.org/fhir/AssetContext' satisfies OwlClass;

/**
 * _rangeCategory
 *
 * (Modified) ObservationDefinition.component.qualifiedValue.rangeCategory
 *
 * http://hl7.org/fhir/_rangeCategory
 */
export const _rangeCategory = 'http://hl7.org/fhir/_rangeCategory' satisfies OwlObjectProperty;

/**
 * Location
 *
 * Details and position information for a place where services are provided and resources and participants may be stored, found, contained, or accommodated.
 *
 * http://hl7.org/fhir/Location
 */
export const Location = 'http://hl7.org/fhir/Location' satisfies OwlClass;

/**
 * rank
 *
 * ContactPoint.rank: Specifies a preferred order in which to use a set of contacts. ContactPoints with lower rank values are more preferred than those with higher rank values.
 *
 * http://hl7.org/fhir/rank
 */
export const rank = 'http://hl7.org/fhir/rank' satisfies OwlObjectProperty;

/**
 * PlanDefinitionActionComponentActionAction
 *
 * Sub actions that are contained within the action. The behavior of this action determines the functionality of the sub-actions. For example, a selection behavior of at-most-one indicates that of the sub-actions, at most one may be chosen as part of realizing the action definition.
 *
 * http://hl7.org/fhir/PlanDefinitionActionComponentActionAction
 */
export const PlanDefinitionActionComponentActionAction = 'http://hl7.org/fhir/PlanDefinitionActionComponentActionAction' satisfies OwlClass;

/**
 * _occurrenceCount
 *
 * (Modified) Appointment.recurrenceTemplate.occurrenceCount
 *
 * http://hl7.org/fhir/_occurrenceCount
 */
export const _occurrenceCount = 'http://hl7.org/fhir/_occurrenceCount' satisfies OwlObjectProperty;

/**
 * entryType
 *
 * Device.udiCarrier.entryType: A coded entry to indicate how the data was entered.
 *
 * http://hl7.org/fhir/entryType
 */
export const entryType = 'http://hl7.org/fhir/entryType' satisfies OwlObjectProperty;

/**
 * _trigger
 *
 * (Modified) PlanDefinition.action.action.trigger
 *
 * http://hl7.org/fhir/_trigger
 */
export const _trigger = 'http://hl7.org/fhir/_trigger' satisfies OwlObjectProperty;

/**
 * _contextInvariant
 *
 * (Modified) StructureDefinition.contextInvariant
 *
 * http://hl7.org/fhir/_contextInvariant
 */
export const _contextInvariant = 'http://hl7.org/fhir/_contextInvariant' satisfies OwlObjectProperty;

/**
 * id
 *
 * Element.id: Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.
 *
 * http://hl7.org/fhir/id
 */
export const id = 'http://hl7.org/fhir/id' satisfies OwlObjectProperty;

/**
 * _productionIdentifierInUDI
 *
 * (Modified) DeviceDefinition.productionIdentifierInUDI
 *
 * http://hl7.org/fhir/_productionIdentifierInUDI
 */
export const _productionIdentifierInUDI = 'http://hl7.org/fhir/_productionIdentifierInUDI' satisfies OwlObjectProperty;

/**
 * _variable
 *
 * (Modified) TestScript.variable
 *
 * http://hl7.org/fhir/_variable
 */
export const _variable = 'http://hl7.org/fhir/_variable' satisfies OwlObjectProperty;

/**
 * occurrence
 *
 * Immunization.occurrence
 *
 * http://hl7.org/fhir/occurrence
 */
export const occurrence = 'http://hl7.org/fhir/occurrence' satisfies OwlObjectProperty;

/**
 * dayOfMonth
 *
 * Appointment.recurrenceTemplate.monthlyTemplate.dayOfMonth: Indicates that appointments in the series of recurring appointments should occur on a specific day of the month.
 *
 * http://hl7.org/fhir/dayOfMonth
 */
export const dayOfMonth = 'http://hl7.org/fhir/dayOfMonth' satisfies OwlObjectProperty;

/**
 * _maxDosePerPeriod
 *
 * (Modified) Dosage.maxDosePerPeriod
 *
 * http://hl7.org/fhir/_maxDosePerPeriod
 */
export const _maxDosePerPeriod = 'http://hl7.org/fhir/_maxDosePerPeriod' satisfies OwlObjectProperty;

/**
 * _MeasureReport
 *
 * (Modified) MeasureReport
 *
 * http://hl7.org/fhir/_MeasureReport
 */
export const _MeasureReport = 'http://hl7.org/fhir/_MeasureReport' satisfies OwlClass;

/**
 * MedicationKnowledgeCostComponent
 *
 * MedicationKnowledgeCostComponent: The price of the medication.
 *
 * http://hl7.org/fhir/MedicationKnowledgeCostComponent
 */
export const MedicationKnowledgeCostComponent = 'http://hl7.org/fhir/MedicationKnowledgeCostComponent' satisfies OwlClass;

/**
 * uuid
 *
 * A UUID, represented as a URI
 *
 * http://hl7.org/fhir/uuid
 */
export const uuid = 'http://hl7.org/fhir/uuid' satisfies OwlClass;

/**
 * _range
 *
 * (Modified) ObservationDefinition.component.qualifiedValue.range
 *
 * http://hl7.org/fhir/_range
 */
export const _range = 'http://hl7.org/fhir/_range' satisfies OwlObjectProperty;

/**
 * related
 *
 * ExplanationOfBenefit.related: Other claims which are related to this claim such as prior submissions or claims for related services or for the same event.
 *
 * http://hl7.org/fhir/related
 */
export const related = 'http://hl7.org/fhir/related' satisfies OwlObjectProperty;

/**
 * endpoint
 *
 * ImagingStudy.endpoint: The network service providing access (e.g., query, view, or retrieval) for the study. See implementation notes for information about using DICOM endpoints. A study-level endpoint applies to each series in the study, unless overridden by a series-level endpoint with the same Endpoint.connectionType.
 *
 * http://hl7.org/fhir/endpoint
 */
export const endpoint = 'http://hl7.org/fhir/endpoint' satisfies OwlObjectProperty;

/**
 * ValueSetExpansionParameterComponent
 *
 * ValueSetExpansionComponent.ValueSetExpansionParameterComponent: A parameter that controlled the expansion process. These parameters may be used by users of expanded value sets to check whether the expansion is suitable for a particular purpose, or to pick the correct expansion.
 *
 * http://hl7.org/fhir/ValueSetExpansionParameterComponent
 */
export const ValueSetExpansionParameterComponent = 'http://hl7.org/fhir/ValueSetExpansionParameterComponent' satisfies OwlClass;

/**
 * _logMessage
 *
 * (Modified) StructureMap.group.rule.rule.source.logMessage
 *
 * http://hl7.org/fhir/_logMessage
 */
export const _logMessage = 'http://hl7.org/fhir/_logMessage' satisfies OwlObjectProperty;

/**
 * SubscriptionTopicResourceTriggerQueryCriteriaComponent
 *
 * SubscriptionTopicResourceTriggerComponent.SubscriptionTopicResourceTriggerQueryCriteriaComponent: The FHIR query based rules that the server should use to determine when to trigger a notification for this subscription topic.
 *
 * http://hl7.org/fhir/SubscriptionTopicResourceTriggerQueryCriteriaComponent
 */
export const SubscriptionTopicResourceTriggerQueryCriteriaComponent = 'http://hl7.org/fhir/SubscriptionTopicResourceTriggerQueryCriteriaComponent' satisfies OwlClass;

/**
 * _supportingImmunization
 *
 * (Modified) ImmunizationRecommendation.recommendation.supportingImmunization
 *
 * http://hl7.org/fhir/_supportingImmunization
 */
export const _supportingImmunization = 'http://hl7.org/fhir/_supportingImmunization' satisfies OwlObjectProperty;

/**
 * StructureMapConstComponent
 *
 * StructureMapConstComponent: Definition of a constant value used in the map rules.
 *
 * http://hl7.org/fhir/StructureMapConstComponent
 */
export const StructureMapConstComponent = 'http://hl7.org/fhir/StructureMapConstComponent' satisfies OwlClass;

/**
 * NutritionIntakeConsumedItemComponent
 *
 * NutritionIntakeConsumedItemComponent: What food or fluid product or item was consumed.
 *
 * http://hl7.org/fhir/NutritionIntakeConsumedItemComponent
 */
export const NutritionIntakeConsumedItemComponent = 'http://hl7.org/fhir/NutritionIntakeConsumedItemComponent' satisfies OwlClass;

/**
 * PlanDefinitionGoalComponent
 *
 * PlanDefinitionGoalComponent: A goal describes an expected outcome that activities within the plan are intended to achieve. For example, weight loss, restoring an activity of daily living, obtaining herd immunity via immunization, meeting a process improvement objective, meeting the acceptance criteria for a test as specified by a quality specification, etc.
 *
 * http://hl7.org/fhir/PlanDefinitionGoalComponent
 */
export const PlanDefinitionGoalComponent = 'http://hl7.org/fhir/PlanDefinitionGoalComponent' satisfies OwlClass;

/**
 * precondition
 *
 * ConditionDefinition.precondition: An observation that suggests that this condition applies.
 *
 * http://hl7.org/fhir/precondition
 */
export const precondition = 'http://hl7.org/fhir/precondition' satisfies OwlObjectProperty;

/**
 * _CoverageEligibilityResponse
 *
 * (Modified) CoverageEligibilityResponse
 *
 * http://hl7.org/fhir/_CoverageEligibilityResponse
 */
export const _CoverageEligibilityResponse = 'http://hl7.org/fhir/_CoverageEligibilityResponse' satisfies OwlClass;

/**
 * _duration
 *
 * (Modified) Attachment.duration
 *
 * http://hl7.org/fhir/_duration
 */
export const _duration = 'http://hl7.org/fhir/_duration' satisfies OwlObjectProperty;

/**
 * _routeOfAdministration
 *
 * (Modified) NutritionOrder.enteralFormula.routeOfAdministration
 *
 * http://hl7.org/fhir/_routeOfAdministration
 */
export const _routeOfAdministration = 'http://hl7.org/fhir/_routeOfAdministration' satisfies OwlObjectProperty;

/**
 * _legallyBinding
 *
 * (Modified) Contract.legallyBinding
 *
 * http://hl7.org/fhir/_legallyBinding
 */
export const _legallyBinding = 'http://hl7.org/fhir/_legallyBinding' satisfies OwlObjectProperty;

/**
 * rendering
 *
 * ImplementationGuide.manifest.rendering: A pointer to official web page, PDF or other rendering of the implementation guide.
 *
 * http://hl7.org/fhir/rendering
 */
export const rendering = 'http://hl7.org/fhir/rendering' satisfies OwlObjectProperty;

/**
 * _hierarchical
 *
 * (Modified) TerminologyCapabilities.expansion.hierarchical
 *
 * http://hl7.org/fhir/_hierarchical
 */
export const _hierarchical = 'http://hl7.org/fhir/_hierarchical' satisfies OwlObjectProperty;

/**
 * _nameType
 *
 * (Modified) InventoryItem.name.nameType
 *
 * http://hl7.org/fhir/_nameType
 */
export const _nameType = 'http://hl7.org/fhir/_nameType' satisfies OwlObjectProperty;

/**
 * _businessStatus
 *
 * (Modified) Task.businessStatus
 *
 * http://hl7.org/fhir/_businessStatus
 */
export const _businessStatus = 'http://hl7.org/fhir/_businessStatus' satisfies OwlObjectProperty;

/**
 * _maxLength
 *
 * (Modified) Questionnaire.item.item.maxLength
 *
 * http://hl7.org/fhir/_maxLength
 */
export const _maxLength = 'http://hl7.org/fhir/_maxLength' satisfies OwlObjectProperty;

/**
 * SubstancePolymerRepeatComponent
 *
 * SubstancePolymerRepeatComponent: Specifies and quantifies the repeated units and their configuration.
 *
 * http://hl7.org/fhir/SubstancePolymerRepeatComponent
 */
export const SubstancePolymerRepeatComponent = 'http://hl7.org/fhir/SubstancePolymerRepeatComponent' satisfies OwlClass;

/**
 * responsibleParty
 *
 * MedicationDispense.substitution.responsibleParty: The person or organization that has primary responsibility for the substitution.
 *
 * http://hl7.org/fhir/responsibleParty
 */
export const responsibleParty = 'http://hl7.org/fhir/responsibleParty' satisfies OwlObjectProperty;

/**
 * BundleEntryComponent
 *
 * BundleEntryComponent: An entry in a bundle resource - will either contain a resource or information about a resource (transactions and history only).
 *
 * http://hl7.org/fhir/BundleEntryComponent
 */
export const BundleEntryComponent = 'http://hl7.org/fhir/BundleEntryComponent' satisfies OwlClass;

/**
 * _input
 *
 * (Modified) RequestOrchestration.action.input
 *
 * http://hl7.org/fhir/_input
 */
export const _input = 'http://hl7.org/fhir/_input' satisfies OwlObjectProperty;

/**
 * _languageCode
 *
 * (Modified) DeviceDefinition.languageCode
 *
 * http://hl7.org/fhir/_languageCode
 */
export const _languageCode = 'http://hl7.org/fhir/_languageCode' satisfies OwlObjectProperty;

/**
 * _patient
 *
 * (Modified) SupplyDelivery.patient
 *
 * http://hl7.org/fhir/_patient
 */
export const _patient = 'http://hl7.org/fhir/_patient' satisfies OwlObjectProperty;

/**
 * direction
 *
 * TestScript.test.action.assert.direction: The direction to use for the assertion.
 *
 * http://hl7.org/fhir/direction
 */
export const direction = 'http://hl7.org/fhir/direction' satisfies OwlObjectProperty;

/**
 * _publicationDateSeason
 *
 * (Modified) Citation.citedArtifact.publicationForm.publicationDateSeason
 *
 * http://hl7.org/fhir/_publicationDateSeason
 */
export const _publicationDateSeason = 'http://hl7.org/fhir/_publicationDateSeason' satisfies OwlObjectProperty;

/**
 * maritalStatus
 *
 * Person.maritalStatus: This field contains a person's most recent marital (civil) status.
 *
 * http://hl7.org/fhir/maritalStatus
 */
export const maritalStatus = 'http://hl7.org/fhir/maritalStatus' satisfies OwlObjectProperty;

/**
 * AllergyIntoleranceReactionComponent
 *
 * AllergyIntoleranceReactionComponent: Details about each adverse reaction event linked to exposure to the identified substance.
 *
 * http://hl7.org/fhir/AllergyIntoleranceReactionComponent
 */
export const AllergyIntoleranceReactionComponent = 'http://hl7.org/fhir/AllergyIntoleranceReactionComponent' satisfies OwlClass;

/**
 * _observer
 *
 * (Modified) AuditEvent.source.observer
 *
 * http://hl7.org/fhir/_observer
 */
export const _observer = 'http://hl7.org/fhir/_observer' satisfies OwlObjectProperty;

/**
 * SubscriptionParameterComponent
 *
 * SubscriptionParameterComponent: Channel-dependent information to send as part of the notification (e.g., HTTP Headers).
 *
 * http://hl7.org/fhir/SubscriptionParameterComponent
 */
export const SubscriptionParameterComponent = 'http://hl7.org/fhir/SubscriptionParameterComponent' satisfies OwlClass;

/**
 * doseAdministrationAid
 *
 * MedicationRequest.dispenseRequest.doseAdministrationAid: Provides information about the type of adherence packaging to be supplied for the medication dispense.
 *
 * http://hl7.org/fhir/doseAdministrationAid
 */
export const doseAdministrationAid = 'http://hl7.org/fhir/doseAdministrationAid' satisfies OwlObjectProperty;

/**
 * DeviceDefinitionClassificationComponent
 *
 * DeviceDefinitionClassificationComponent: What kind of device or device system this is.
 *
 * http://hl7.org/fhir/DeviceDefinitionClassificationComponent
 */
export const DeviceDefinitionClassificationComponent = 'http://hl7.org/fhir/DeviceDefinitionClassificationComponent' satisfies OwlClass;

/**
 * _measure
 *
 * (Modified) PlanDefinition.goal.target.measure
 *
 * http://hl7.org/fhir/_measure
 */
export const _measure = 'http://hl7.org/fhir/_measure' satisfies OwlObjectProperty;

/**
 * _maxDosePerAdministration
 *
 * (Modified) Dosage.maxDosePerAdministration
 *
 * http://hl7.org/fhir/_maxDosePerAdministration
 */
export const _maxDosePerAdministration = 'http://hl7.org/fhir/_maxDosePerAdministration' satisfies OwlObjectProperty;

/**
 * CompositionAttesterComponent
 *
 * CompositionAttesterComponent: A participant who has attested to the accuracy of the composition/document.
 *
 * http://hl7.org/fhir/CompositionAttesterComponent
 */
export const CompositionAttesterComponent = 'http://hl7.org/fhir/CompositionAttesterComponent' satisfies OwlClass;

/**
 * _valueFilter
 *
 * (Modified) DataRequirement.valueFilter
 *
 * http://hl7.org/fhir/_valueFilter
 */
export const _valueFilter = 'http://hl7.org/fhir/_valueFilter' satisfies OwlObjectProperty;

/**
 * studyDesign
 *
 * ResearchStudy.studyDesign: Codes categorizing the type of study such as investigational vs. observational, type of blinding, type of randomization, safety vs. efficacy, etc.
 *
 * http://hl7.org/fhir/studyDesign
 */
export const studyDesign = 'http://hl7.org/fhir/studyDesign' satisfies OwlObjectProperty;

/**
 * _relation
 *
 * (Modified) DeviceDefinition.link.relation
 *
 * http://hl7.org/fhir/_relation
 */
export const _relation = 'http://hl7.org/fhir/_relation' satisfies OwlObjectProperty;

/**
 * _priority
 *
 * (Modified) ExplanationOfBenefit.priority
 *
 * http://hl7.org/fhir/_priority
 */
export const _priority = 'http://hl7.org/fhir/_priority' satisfies OwlObjectProperty;

/**
 * MessageDefinition
 *
 * Defines the characteristics of a message that can be shared between systems, including the type of event that initiates the message, the content to be transmitted and what response(s), if any, are permitted.
 *
 * http://hl7.org/fhir/MessageDefinition
 */
export const MessageDefinition = 'http://hl7.org/fhir/MessageDefinition' satisfies OwlClass;

/**
 * _description
 *
 * (Modified) RequestOrchestration.action.action.description
 *
 * http://hl7.org/fhir/_description
 */
export const _description = 'http://hl7.org/fhir/_description' satisfies OwlObjectProperty;

/**
 * TestPlanTestCaseTestDataComponent
 *
 * TestPlanTestCaseComponent.TestPlanTestCaseTestDataComponent: The test data used in the test case.
 *
 * http://hl7.org/fhir/TestPlanTestCaseTestDataComponent
 */
export const TestPlanTestCaseTestDataComponent = 'http://hl7.org/fhir/TestPlanTestCaseTestDataComponent' satisfies OwlClass;

/**
 * HealthcareServiceEligibilityComponent
 *
 * HealthcareServiceEligibilityComponent: Does this service have specific eligibility requirements that need to be met in order to use the service?
 *
 * http://hl7.org/fhir/HealthcareServiceEligibilityComponent
 */
export const HealthcareServiceEligibilityComponent = 'http://hl7.org/fhir/HealthcareServiceEligibilityComponent' satisfies OwlClass;

/**
 * category
 *
 * Flag.category: Allows a flag to be divided into different categories like clinical, administrative etc. Intended to be used as a means of filtering which flags are displayed to particular user or in a given context.
 *
 * http://hl7.org/fhir/category
 */
export const category = 'http://hl7.org/fhir/category' satisfies OwlObjectProperty;

/**
 * Details
 *
 * CoverageEligibilityRequest.Details: Service categories or billable services for which benefit details and/or an authorization prior to service delivery may be required by the payor.
 *
 * http://hl7.org/fhir/Details
 */
export const Details = 'http://hl7.org/fhir/Details' satisfies OwlClass;

/**
 * verificationDate
 *
 * Consent.verification.verificationDate: Date(s) verification was collected.
 *
 * http://hl7.org/fhir/verificationDate
 */
export const verificationDate = 'http://hl7.org/fhir/verificationDate' satisfies OwlObjectProperty;

/**
 * ExampleScenarioActorComponent
 *
 * ExampleScenarioActorComponent: A system or person who shares or receives an instance within the scenario.
 *
 * http://hl7.org/fhir/ExampleScenarioActorComponent
 */
export const ExampleScenarioActorComponent = 'http://hl7.org/fhir/ExampleScenarioActorComponent' satisfies OwlClass;

/**
 * _specimenQuantity
 *
 * (Modified) Specimen.container.specimenQuantity
 *
 * http://hl7.org/fhir/_specimenQuantity
 */
export const _specimenQuantity = 'http://hl7.org/fhir/_specimenQuantity' satisfies OwlObjectProperty;

/**
 * DeviceDefinitionPackagingComponent
 *
 * DeviceDefinitionPackagingComponent: Information about the packaging of the device, i.e. how the device is packaged.
 *
 * http://hl7.org/fhir/DeviceDefinitionPackagingComponent
 */
export const DeviceDefinitionPackagingComponent = 'http://hl7.org/fhir/DeviceDefinitionPackagingComponent' satisfies OwlClass;

/**
 * autocreate
 *
 * TestScript.fixture.autocreate: Whether or not to implicitly create the fixture during setup. If true, the fixture is automatically created on each server being tested during setup, therefore no create operation is required for this fixture in the TestScript.setup section.
 *
 * http://hl7.org/fhir/autocreate
 */
export const autocreate = 'http://hl7.org/fhir/autocreate' satisfies OwlObjectProperty;

/**
 * _structuralRepresentation
 *
 * (Modified) SubstancePolymer.repeat.repeatUnit.structuralRepresentation
 *
 * http://hl7.org/fhir/_structuralRepresentation
 */
export const _structuralRepresentation = 'http://hl7.org/fhir/_structuralRepresentation' satisfies OwlObjectProperty;

/**
 * agent
 *
 * AuditEvent.entity.agent: The entity is attributed to an agent to express the agent's responsibility for that entity in the activity. This is most used to indicate when persistence media (the entity) are used by an agent. For example when importing data from a device, the device would be described in an entity, and the user importing data from that media would be indicated as the entity.agent.
 *
 * http://hl7.org/fhir/agent
 */
export const agent = 'http://hl7.org/fhir/agent' satisfies OwlObjectProperty;

/**
 * _request
 *
 * (Modified) ExplanationOfBenefit.item.request
 *
 * http://hl7.org/fhir/_request
 */
export const _request = 'http://hl7.org/fhir/_request' satisfies OwlObjectProperty;

/**
 * _deliverTo
 *
 * (Modified) SupplyRequest.deliverTo
 *
 * http://hl7.org/fhir/_deliverTo
 */
export const _deliverTo = 'http://hl7.org/fhir/_deliverTo' satisfies OwlObjectProperty;

/**
 * _textConcentration
 *
 * (Modified) Ingredient.substance.strength.textConcentration
 *
 * http://hl7.org/fhir/_textConcentration
 */
export const _textConcentration = 'http://hl7.org/fhir/_textConcentration' satisfies OwlObjectProperty;

/**
 * benefitPeriod
 *
 * ExplanationOfBenefit.benefitPeriod: The term of the benefits documented in this response.
 *
 * http://hl7.org/fhir/benefitPeriod
 */
export const benefitPeriod = 'http://hl7.org/fhir/benefitPeriod' satisfies OwlObjectProperty;

/**
 * SpecimenDefinitionTypeTestedContainerComponent
 *
 * SpecimenDefinitionTypeTestedComponent.SpecimenDefinitionTypeTestedContainerComponent: The specimen's container.
 *
 * http://hl7.org/fhir/SpecimenDefinitionTypeTestedContainerComponent
 */
export const SpecimenDefinitionTypeTestedContainerComponent = 'http://hl7.org/fhir/SpecimenDefinitionTypeTestedContainerComponent' satisfies OwlClass;

/**
 * ServiceRequestPatientInstructionComponent
 *
 * ServiceRequestPatientInstructionComponent: Instructions in terms that are understood by the patient or consumer.
 *
 * http://hl7.org/fhir/ServiceRequestPatientInstructionComponent
 */
export const ServiceRequestPatientInstructionComponent = 'http://hl7.org/fhir/ServiceRequestPatientInstructionComponent' satisfies OwlClass;

/**
 * _adjustment
 *
 * (Modified) ExplanationOfBenefit.payment.adjustment
 *
 * http://hl7.org/fhir/_adjustment
 */
export const _adjustment = 'http://hl7.org/fhir/_adjustment' satisfies OwlObjectProperty;

/**
 * _guidance
 *
 * (Modified) Measure.guidance
 *
 * http://hl7.org/fhir/_guidance
 */
export const _guidance = 'http://hl7.org/fhir/_guidance' satisfies OwlObjectProperty;

/**
 * productReference
 *
 * InventoryItem.productReference: Link to a product resource used in clinical workflows.
 *
 * http://hl7.org/fhir/productReference
 */
export const productReference = 'http://hl7.org/fhir/productReference' satisfies OwlObjectProperty;

/**
 * _for
 *
 * (Modified) Transport.for
 *
 * http://hl7.org/fhir/_for
 */
export const _for = 'http://hl7.org/fhir/_for' satisfies OwlObjectProperty;

/**
 * _intended
 *
 * (Modified) Evidence.variableDefinition.intended
 *
 * http://hl7.org/fhir/_intended
 */
export const _intended = 'http://hl7.org/fhir/_intended' satisfies OwlObjectProperty;

/**
 * _additionalUse
 *
 * (Modified) ValueSet.expansion.contains.contains.designation.additionalUse
 *
 * http://hl7.org/fhir/_additionalUse
 */
export const _additionalUse = 'http://hl7.org/fhir/_additionalUse' satisfies OwlObjectProperty;

/**
 * MetadataResource
 *
 * Common Interface declaration for conformance and knowledge artifact resources.
 *
 * http://hl7.org/fhir/MetadataResource
 */
export const MetadataResource = 'http://hl7.org/fhir/MetadataResource' satisfies OwlClass;

/**
 * _startingSequence
 *
 * (Modified) MolecularSequence.relative.startingSequence
 *
 * http://hl7.org/fhir/_startingSequence
 */
export const _startingSequence = 'http://hl7.org/fhir/_startingSequence' satisfies OwlObjectProperty;

/**
 * MedicationStatement
 *
 * A record of a medication that is being consumed by a patient.   A MedicationStatement may indicate that the patient may be taking the medication now or has taken the medication in the past or will be taking the medication in the future.  The source of this information can be the patient, significant other (such as a family member or spouse), or a clinician.  A common scenario where this information is captured is during the history taking process during a patient visit or stay.   The medication information may come from sources such as the patient's memory, from a prescription bottle,  or from a list of medications the patient, clinician or other party maintains. 
 * 
 * The primary difference between a medicationstatement and a medicationadministration is that the medication administration has complete administration information and is based on actual administration information from the person who administered the medication.  A medicationstatement is often, if not always, less specific.  There is no required date/time when the medication was administered, in fact we only know that a source has reported the patient is taking this medication, where details such as time, quantity, or rate or even medication product may be incomplete or missing or less precise.  As stated earlier, the Medication Statement information may come from the patient's memory, from a prescription bottle or from a list of medications the patient, clinician or other party maintains.  Medication administration is more formal and is not missing detailed information.
 *
 * http://hl7.org/fhir/MedicationStatement
 */
export const MedicationStatement = 'http://hl7.org/fhir/MedicationStatement' satisfies OwlClass;

/**
 * medium
 *
 * CommunicationRequest.medium: A channel that was used for this communication (e.g. email, fax).
 *
 * http://hl7.org/fhir/medium
 */
export const medium = 'http://hl7.org/fhir/medium' satisfies OwlObjectProperty;

/**
 * _baseUnit
 *
 * (Modified) InventoryItem.baseUnit
 *
 * http://hl7.org/fhir/_baseUnit
 */
export const _baseUnit = 'http://hl7.org/fhir/_baseUnit' satisfies OwlObjectProperty;

/**
 * _doseStatusReason
 *
 * (Modified) ImmunizationEvaluation.doseStatusReason
 *
 * http://hl7.org/fhir/_doseStatusReason
 */
export const _doseStatusReason = 'http://hl7.org/fhir/_doseStatusReason' satisfies OwlObjectProperty;

/**
 * unitOfPresentation
 *
 * ManufacturedItemDefinition.unitOfPresentation: The “real-world” units in which the quantity of the manufactured item is described.
 *
 * http://hl7.org/fhir/unitOfPresentation
 */
export const unitOfPresentation = 'http://hl7.org/fhir/unitOfPresentation' satisfies OwlObjectProperty;

/**
 * CareTeam
 *
 * ExplanationOfBenefit.CareTeam: The members of the team who provided the products and services.
 *
 * http://hl7.org/fhir/CareTeam
 */
export const CareTeam = 'http://hl7.org/fhir/CareTeam' satisfies OwlClass;

/**
 * sourceSignature
 *
 * VerificationResult.attestation.sourceSignature: Signed assertion by the attestation source that they have attested to the information.
 *
 * http://hl7.org/fhir/sourceSignature
 */
export const sourceSignature = 'http://hl7.org/fhir/sourceSignature' satisfies OwlObjectProperty;

/**
 * availableStartTime
 *
 * Availability.availableTime.availableStartTime: Opening time of day (ignored if allDay = true).
 *
 * http://hl7.org/fhir/availableStartTime
 */
export const availableStartTime = 'http://hl7.org/fhir/availableStartTime' satisfies OwlObjectProperty;

/**
 * _effectiveDate
 *
 * (Modified) MedicinalProductDefinition.operation.effectiveDate
 *
 * http://hl7.org/fhir/_effectiveDate
 */
export const _effectiveDate = 'http://hl7.org/fhir/_effectiveDate' satisfies OwlObjectProperty;

/**
 * _relevantHistory
 *
 * (Modified) Transport.relevantHistory
 *
 * http://hl7.org/fhir/_relevantHistory
 */
export const _relevantHistory = 'http://hl7.org/fhir/_relevantHistory' satisfies OwlObjectProperty;

/**
 * ParametersParameterComponent
 *
 * ParametersParameterComponent: A parameter passed to or received from the operation.
 *
 * http://hl7.org/fhir/ParametersParameterComponent
 */
export const ParametersParameterComponent = 'http://hl7.org/fhir/ParametersParameterComponent' satisfies OwlClass;

/**
 * MessageDefinitionFocusComponent
 *
 * MessageDefinitionFocusComponent: Identifies the resource (or resources) that are being addressed by the event.  For example, the Encounter for an admit message or two Account records for a merge.
 *
 * http://hl7.org/fhir/MessageDefinitionFocusComponent
 */
export const MessageDefinitionFocusComponent = 'http://hl7.org/fhir/MessageDefinitionFocusComponent' satisfies OwlClass;

/**
 * EnrollmentResponse
 *
 * This resource provides enrollment and plan details from the processing of an EnrollmentRequest resource.
 *
 * http://hl7.org/fhir/EnrollmentResponse
 */
export const EnrollmentResponse = 'http://hl7.org/fhir/EnrollmentResponse' satisfies OwlClass;

/**
 * ListEntryComponent
 *
 * ListEntryComponent: Entries in this list.
 *
 * http://hl7.org/fhir/ListEntryComponent
 */
export const ListEntryComponent = 'http://hl7.org/fhir/ListEntryComponent' satisfies OwlClass;

/**
 * _subset
 *
 * (Modified) ImagingSelection.instance.subset
 *
 * http://hl7.org/fhir/_subset
 */
export const _subset = 'http://hl7.org/fhir/_subset' satisfies OwlObjectProperty;

/**
 * dimensions
 *
 * SampledData.dimensions: The number of sample points at each time point. If this value is greater than one, then the dimensions will be interlaced - all the sample points for a point in time will be recorded at once.
 *
 * http://hl7.org/fhir/dimensions
 */
export const dimensions = 'http://hl7.org/fhir/dimensions' satisfies OwlObjectProperty;

/**
 * _function
 *
 * (Modified) ManufacturedItemDefinition.component.component.function
 *
 * http://hl7.org/fhir/_function
 */
export const _function = 'http://hl7.org/fhir/_function' satisfies OwlObjectProperty;

/**
 * recommendation
 *
 * ImmunizationRecommendation.recommendation: Vaccine administration recommendations.
 *
 * http://hl7.org/fhir/recommendation
 */
export const recommendation = 'http://hl7.org/fhir/recommendation' satisfies OwlObjectProperty;

/**
 * _prescription
 *
 * (Modified) ExplanationOfBenefit.prescription
 *
 * http://hl7.org/fhir/_prescription
 */
export const _prescription = 'http://hl7.org/fhir/_prescription' satisfies OwlObjectProperty;

/**
 * prognosisReference
 *
 * ClinicalImpression.prognosisReference: RiskAssessment expressing likely outcome.
 *
 * http://hl7.org/fhir/prognosisReference
 */
export const prognosisReference = 'http://hl7.org/fhir/prognosisReference' satisfies OwlObjectProperty;

/**
 * _hint
 *
 * (Modified) TestScript.variable.hint
 *
 * http://hl7.org/fhir/_hint
 */
export const _hint = 'http://hl7.org/fhir/_hint' satisfies OwlObjectProperty;

/**
 * _ownedBy
 *
 * (Modified) InsurancePlan.ownedBy
 *
 * http://hl7.org/fhir/_ownedBy
 */
export const _ownedBy = 'http://hl7.org/fhir/_ownedBy' satisfies OwlObjectProperty;

/**
 * measurementFrequency
 *
 * DeviceMetric.measurementFrequency: The frequency at which the metric is taken or recorded. Devices measure metrics at a wide range of frequencies; for example, an ECG might sample measurements in the millisecond range, while an NIBP might trigger only once an hour. Less often, the measurementFrequency may be based on a unit other than time, such as distance (e.g. for a measuring wheel). The update period may be different than the measurement frequency, if the device does not update the published observed value with the same frequency as it was measured.
 *
 * http://hl7.org/fhir/measurementFrequency
 */
export const measurementFrequency = 'http://hl7.org/fhir/measurementFrequency' satisfies OwlObjectProperty;

/**
 * _traceNumber
 *
 * (Modified) ClaimResponse.addItem.detail.traceNumber
 *
 * http://hl7.org/fhir/_traceNumber
 */
export const _traceNumber = 'http://hl7.org/fhir/_traceNumber' satisfies OwlObjectProperty;

/**
 * _excludingDate
 *
 * (Modified) Appointment.recurrenceTemplate.excludingDate
 *
 * http://hl7.org/fhir/_excludingDate
 */
export const _excludingDate = 'http://hl7.org/fhir/_excludingDate' satisfies OwlObjectProperty;

/**
 * _required
 *
 * (Modified) TestScript.metadata.capability.required
 *
 * http://hl7.org/fhir/_required
 */
export const _required = 'http://hl7.org/fhir/_required' satisfies OwlObjectProperty;

/**
 * correctiveAction
 *
 * DeviceDefinition.correctiveAction: Tracking of latest field safety corrective action.
 *
 * http://hl7.org/fhir/correctiveAction
 */
export const correctiveAction = 'http://hl7.org/fhir/correctiveAction' satisfies OwlObjectProperty;

/**
 * schedule
 *
 * MedicationKnowledge.regulatory.schedule: Specifies the schedule of a medication in jurisdiction.
 *
 * http://hl7.org/fhir/schedule
 */
export const schedule = 'http://hl7.org/fhir/schedule' satisfies OwlObjectProperty;

/**
 * _referral
 *
 * (Modified) ExplanationOfBenefit.referral
 *
 * http://hl7.org/fhir/_referral
 */
export const _referral = 'http://hl7.org/fhir/_referral' satisfies OwlObjectProperty;

/**
 * alternate
 *
 * DeviceDefinition.material.alternate: Indicates an alternative material of the device.
 *
 * http://hl7.org/fhir/alternate
 */
export const alternate = 'http://hl7.org/fhir/alternate' satisfies OwlObjectProperty;

/**
 * intendedExposure
 *
 * ResearchStudy.comparisonGroup.intendedExposure: Interventions or exposures in this comparisonGroup or cohort.
 *
 * http://hl7.org/fhir/intendedExposure
 */
export const intendedExposure = 'http://hl7.org/fhir/intendedExposure' satisfies OwlObjectProperty;

/**
 * threePrime
 *
 * SubstanceNucleicAcid.subunit.threePrime: The nucleotide present at the 3’ terminal shall be specified based on a controlled vocabulary. Since the sequence is represented from the 5' to the 3' end, the 5’ prime nucleotide is the letter at the last position in the sequence. A separate representation would be redundant.
 *
 * http://hl7.org/fhir/threePrime
 */
export const threePrime = 'http://hl7.org/fhir/threePrime' satisfies OwlObjectProperty;

/**
 * param
 *
 * CompartmentDefinition.resource.param: The name of a search parameter that represents the link to the compartment. More than one may be listed because a resource may be linked to a compartment in more than one way,.
 *
 * http://hl7.org/fhir/param
 */
export const param = 'http://hl7.org/fhir/param' satisfies OwlObjectProperty;

/**
 * _proposedNewTime
 *
 * (Modified) AppointmentResponse.proposedNewTime
 *
 * http://hl7.org/fhir/_proposedNewTime
 */
export const _proposedNewTime = 'http://hl7.org/fhir/_proposedNewTime' satisfies OwlObjectProperty;

/**
 * power
 *
 * VisionPrescription.lensSpecification.power: Contact lens power measured in dioptres (0.25 units).
 *
 * http://hl7.org/fhir/power
 */
export const power = 'http://hl7.org/fhir/power' satisfies OwlObjectProperty;

/**
 * cardinalityBehavior
 *
 * RequestOrchestration.action.action.cardinalityBehavior: Defines whether the action can be selected multiple times.
 *
 * http://hl7.org/fhir/cardinalityBehavior
 */
export const cardinalityBehavior = 'http://hl7.org/fhir/cardinalityBehavior' satisfies OwlObjectProperty;

/**
 * supportingPatientInformation
 *
 * ImmunizationRecommendation.recommendation.supportingPatientInformation: Patient Information that supports the status and recommendation.  This includes patient observations, adverse reactions and allergy/intolerance information.
 *
 * http://hl7.org/fhir/supportingPatientInformation
 */
export const supportingPatientInformation = 'http://hl7.org/fhir/supportingPatientInformation' satisfies OwlObjectProperty;

/**
 * _predecessor
 *
 * (Modified) TestPlan.testCase.dependency.predecessor
 *
 * http://hl7.org/fhir/_predecessor
 */
export const _predecessor = 'http://hl7.org/fhir/_predecessor' satisfies OwlObjectProperty;

/**
 * allergenicIndicator
 *
 * Ingredient.allergenicIndicator: If the ingredient is a known or suspected allergen. Note that this is a property of the substance, so if a reference to a SubstanceDefinition is used to decribe that (rather than just a code), the allergen information should go there, not here.
 *
 * http://hl7.org/fhir/allergenicIndicator
 */
export const allergenicIndicator = 'http://hl7.org/fhir/allergenicIndicator' satisfies OwlObjectProperty;

/**
 * _regulator
 *
 * (Modified) RegulatedAuthorization.regulator
 *
 * http://hl7.org/fhir/_regulator
 */
export const _regulator = 'http://hl7.org/fhir/_regulator' satisfies OwlObjectProperty;

/**
 * issue
 *
 * OperationOutcome.issue: An error, warning, or information message that results from a system action.
 *
 * http://hl7.org/fhir/issue
 */
export const issue = 'http://hl7.org/fhir/issue' satisfies OwlObjectProperty;

/**
 * _admission
 *
 * (Modified) Encounter.admission
 *
 * http://hl7.org/fhir/_admission
 */
export const _admission = 'http://hl7.org/fhir/_admission' satisfies OwlObjectProperty;

/**
 * _extension
 *
 * (Modified) DomainResource.extension
 *
 * http://hl7.org/fhir/_extension
 */
export const _extension = 'http://hl7.org/fhir/_extension' satisfies OwlObjectProperty;

/**
 * _notificationShape
 *
 * (Modified) SubscriptionTopic.notificationShape
 *
 * http://hl7.org/fhir/_notificationShape
 */
export const _notificationShape = 'http://hl7.org/fhir/_notificationShape' satisfies OwlObjectProperty;

/**
 * Device
 *
 * This resource describes the properties (regulated, has real time clock, etc.), adminstrative (manufacturer name, model number, serial number, firmware, etc.), and type (knee replacement, blood pressure cuff, MRI, etc.) of a physical unit (these values do not change much within a given module, for example the serail number, manufacturer name, and model number). An actual unit may consist of several modules in a distinct hierarchy and these are represented by multiple Device resources and bound through the 'parent' element.
 *
 * http://hl7.org/fhir/Device
 */
export const Device = 'http://hl7.org/fhir/Device' satisfies OwlClass;

/**
 * Range
 *
 * A set of ordered Quantities defined by a low and high limit.
 *
 * http://hl7.org/fhir/Range
 */
export const Range = 'http://hl7.org/fhir/Range' satisfies OwlClass;

/**
 * ItemBodySite
 *
 * ExplanationOfBenefit.Item.ItemBodySite: Physical location where the service is performed or applies.
 *
 * http://hl7.org/fhir/ItemBodySite
 */
export const ItemBodySite = 'http://hl7.org/fhir/ItemBodySite' satisfies OwlClass;

/**
 * average
 *
 * SubstancePolymer.repeat.repeatUnit.degreeOfPolymerisation.average: An average amount of polymerisation.
 *
 * http://hl7.org/fhir/average
 */
export const average = 'http://hl7.org/fhir/average' satisfies OwlObjectProperty;

/**
 * SubstanceNucleicAcidSubunitSugarComponent
 *
 * SubstanceNucleicAcidSubunitComponent.SubstanceNucleicAcidSubunitSugarComponent: 5.3.6.8.1 Sugar ID (Mandatory).
 *
 * http://hl7.org/fhir/SubstanceNucleicAcidSubunitSugarComponent
 */
export const SubstanceNucleicAcidSubunitSugarComponent = 'http://hl7.org/fhir/SubstanceNucleicAcidSubunitSugarComponent' satisfies OwlClass;

/**
 * Composition
 *
 * A set of healthcare-related information that is assembled together into a single logical package that provides a single coherent statement of meaning, establishes its own context and that has clinical attestation with regard to who is making the statement. A Composition defines the structure and narrative content necessary for a document. However, a Composition alone does not constitute a document. Rather, the Composition must be the first entry in a Bundle where Bundle.type=document, and any other resources referenced from Composition must be included as subsequent entries in the Bundle (for example Patient, Practitioner, Encounter, etc.).
 *
 * http://hl7.org/fhir/Composition
 */
export const Composition = 'http://hl7.org/fhir/Composition' satisfies OwlClass;

/**
 * _otherMap
 *
 * (Modified) ConceptMap.group.unmapped.otherMap
 *
 * http://hl7.org/fhir/_otherMap
 */
export const _otherMap = 'http://hl7.org/fhir/_otherMap' satisfies OwlObjectProperty;

/**
 * Rule
 *
 * Permission.Rule: A set of rules.
 *
 * http://hl7.org/fhir/Rule
 */
export const Rule = 'http://hl7.org/fhir/Rule' satisfies OwlClass;

/**
 * testScript
 *
 * TestReport.testScript: Ideally this is an absolute URL that is used to identify the version-specific TestScript that was executed, matching the `TestScript.url`.
 *
 * http://hl7.org/fhir/testScript
 */
export const testScript = 'http://hl7.org/fhir/testScript' satisfies OwlObjectProperty;

/**
 * targetId
 *
 * GraphDefinition.link.targetId: The target node for this link.
 *
 * http://hl7.org/fhir/targetId
 */
export const targetId = 'http://hl7.org/fhir/targetId' satisfies OwlObjectProperty;

/**
 * _additionalAttribute
 *
 * (Modified) ConceptMap.additionalAttribute
 *
 * http://hl7.org/fhir/_additionalAttribute
 */
export const _additionalAttribute = 'http://hl7.org/fhir/_additionalAttribute' satisfies OwlObjectProperty;

/**
 * _validity
 *
 * (Modified) Permission.validity
 *
 * http://hl7.org/fhir/_validity
 */
export const _validity = 'http://hl7.org/fhir/_validity' satisfies OwlObjectProperty;

/**
 * _product
 *
 * (Modified) VisionPrescription.lensSpecification.product
 *
 * http://hl7.org/fhir/_product
 */
export const _product = 'http://hl7.org/fhir/_product' satisfies OwlObjectProperty;

/**
 * objective
 *
 * ResearchStudy.objective: A goal that the study is aiming to achieve in terms of a scientific question to be answered by the analysis of data collected during the study.
 *
 * http://hl7.org/fhir/objective
 */
export const objective = 'http://hl7.org/fhir/objective' satisfies OwlObjectProperty;

/**
 * _containedItem
 *
 * (Modified) PackagedProductDefinition.packaging.packaging.containedItem
 *
 * http://hl7.org/fhir/_containedItem
 */
export const _containedItem = 'http://hl7.org/fhir/_containedItem' satisfies OwlObjectProperty;

/**
 * MedicationKnowledgePackagingComponentCost
 *
 * The cost of the packaged medication.
 *
 * http://hl7.org/fhir/MedicationKnowledgePackagingComponentCost
 */
export const MedicationKnowledgePackagingComponentCost = 'http://hl7.org/fhir/MedicationKnowledgePackagingComponentCost' satisfies OwlClass;

/**
 * relatedDevice
 *
 * DeviceDefinition.link.relatedDevice: A reference to the linked device.
 *
 * http://hl7.org/fhir/relatedDevice
 */
export const relatedDevice = 'http://hl7.org/fhir/relatedDevice' satisfies OwlObjectProperty;

/**
 * QuestionnaireItemEnableWhenComponent
 *
 * QuestionnaireItemComponentItem.QuestionnaireItemEnableWhenComponent: A constraint indicating that this item should only be enabled (displayed/allow answers to be captured) when the specified condition is true.
 *
 * http://hl7.org/fhir/QuestionnaireItemEnableWhenComponent
 */
export const QuestionnaireItemEnableWhenComponent = 'http://hl7.org/fhir/QuestionnaireItemEnableWhenComponent' satisfies OwlClass;

/**
 * _numberAffected
 *
 * (Modified) Evidence.statistic.numberAffected
 *
 * http://hl7.org/fhir/_numberAffected
 */
export const _numberAffected = 'http://hl7.org/fhir/_numberAffected' satisfies OwlObjectProperty;

/**
 * _batch
 *
 * (Modified) Medication.batch
 *
 * http://hl7.org/fhir/_batch
 */
export const _batch = 'http://hl7.org/fhir/_batch' satisfies OwlObjectProperty;

/**
 * preparationInstruction
 *
 * MedicationKnowledge.preparationInstruction: The instructions for preparing the medication.
 *
 * http://hl7.org/fhir/preparationInstruction
 */
export const preparationInstruction = 'http://hl7.org/fhir/preparationInstruction' satisfies OwlObjectProperty;

/**
 * EpisodeOfCare
 *
 * An association between a patient and an organization / healthcare provider(s) during which time encounters may occur. The managing organization assumes a level of responsibility for the patient during this time.
 *
 * http://hl7.org/fhir/EpisodeOfCare
 */
export const EpisodeOfCare = 'http://hl7.org/fhir/EpisodeOfCare' satisfies OwlClass;

/**
 * _entity
 *
 * (Modified) Provenance.entity
 *
 * http://hl7.org/fhir/_entity
 */
export const _entity = 'http://hl7.org/fhir/_entity' satisfies OwlObjectProperty;

/**
 * _initiator
 *
 * (Modified) ExampleScenario.process.step.alternative.step.operation.initiator
 *
 * http://hl7.org/fhir/_initiator
 */
export const _initiator = 'http://hl7.org/fhir/_initiator' satisfies OwlObjectProperty;

/**
 * _communication
 *
 * (Modified) RelatedPerson.communication
 *
 * http://hl7.org/fhir/_communication
 */
export const _communication = 'http://hl7.org/fhir/_communication' satisfies OwlObjectProperty;

/**
 * programEligibility
 *
 * Immunization.programEligibility: Indicates a patient's eligibility for a funding program.
 *
 * http://hl7.org/fhir/programEligibility
 */
export const programEligibility = 'http://hl7.org/fhir/programEligibility' satisfies OwlObjectProperty;

/**
 * addItem
 *
 * ExplanationOfBenefit.addItem: The first-tier service adjudications for payor added product or service lines.
 *
 * http://hl7.org/fhir/addItem
 */
export const addItem = 'http://hl7.org/fhir/addItem' satisfies OwlObjectProperty;

/**
 * _details
 *
 * (Modified) OperationOutcome.issue.details
 *
 * http://hl7.org/fhir/_details
 */
export const _details = 'http://hl7.org/fhir/_details' satisfies OwlObjectProperty;

/**
 * pageString
 *
 * Citation.citedArtifact.publicationForm.pageString: Used for full display of pagination.
 *
 * http://hl7.org/fhir/pageString
 */
export const pageString = 'http://hl7.org/fhir/pageString' satisfies OwlObjectProperty;

/**
 * expansion
 *
 * ValueSet.expansion: A value set can also be "expanded", where the value set is turned into a simple collection of enumerated codes. This element holds the expansion, if it has been performed.
 *
 * http://hl7.org/fhir/expansion
 */
export const expansion = 'http://hl7.org/fhir/expansion' satisfies OwlObjectProperty;

/**
 * MedicationKnowledgeRegulatoryComponent
 *
 * MedicationKnowledgeRegulatoryComponent: Regulatory information about a medication.
 *
 * http://hl7.org/fhir/MedicationKnowledgeRegulatoryComponent
 */
export const MedicationKnowledgeRegulatoryComponent = 'http://hl7.org/fhir/MedicationKnowledgeRegulatoryComponent' satisfies OwlClass;

/**
 * _affiliation
 *
 * (Modified) Citation.citedArtifact.contributorship.entry.affiliation
 *
 * http://hl7.org/fhir/_affiliation
 */
export const _affiliation = 'http://hl7.org/fhir/_affiliation' satisfies OwlObjectProperty;

/**
 * _contentDefinition
 *
 * (Modified) Contract.contentDefinition
 *
 * http://hl7.org/fhir/_contentDefinition
 */
export const _contentDefinition = 'http://hl7.org/fhir/_contentDefinition' satisfies OwlObjectProperty;

/**
 * marketPeriod
 *
 * DeviceDefinition.packaging.packaging.udiDeviceIdentifier.marketDistribution.marketPeriod: Begin and end dates for the commercial distribution of the device.
 *
 * http://hl7.org/fhir/marketPeriod
 */
export const marketPeriod = 'http://hl7.org/fhir/marketPeriod' satisfies OwlObjectProperty;

/**
 * _reportingPeriod
 *
 * (Modified) InventoryReport.reportingPeriod
 *
 * http://hl7.org/fhir/_reportingPeriod
 */
export const _reportingPeriod = 'http://hl7.org/fhir/_reportingPeriod' satisfies OwlObjectProperty;

/**
 * _accountNumber
 *
 * (Modified) PaymentReconciliation.accountNumber
 *
 * http://hl7.org/fhir/_accountNumber
 */
export const _accountNumber = 'http://hl7.org/fhir/_accountNumber' satisfies OwlObjectProperty;

/**
 * _geneSequenceOrigin
 *
 * (Modified) SubstanceReferenceInformation.gene.geneSequenceOrigin
 *
 * http://hl7.org/fhir/_geneSequenceOrigin
 */
export const _geneSequenceOrigin = 'http://hl7.org/fhir/_geneSequenceOrigin' satisfies OwlObjectProperty;

/**
 * subpotentReason
 *
 * Immunization.subpotentReason: Reason why a dose is considered to be subpotent.
 *
 * http://hl7.org/fhir/subpotentReason
 */
export const subpotentReason = 'http://hl7.org/fhir/subpotentReason' satisfies OwlObjectProperty;

/**
 * inventoryStatus
 *
 * InventoryItem.inventoryStatus: The usage status e.g. recalled, in use, discarded... This can be used to indicate that the items have been taken out of inventory, or are in use, etc.
 *
 * http://hl7.org/fhir/inventoryStatus
 */
export const inventoryStatus = 'http://hl7.org/fhir/inventoryStatus' satisfies OwlObjectProperty;

/**
 * subunit
 *
 * SubstanceProtein.subunit: This subclause refers to the description of each subunit constituting the SubstanceProtein. A subunit is a linear sequence of amino acids linked through peptide bonds. The Subunit information shall be provided when the finished SubstanceProtein is a complex of multiple sequences; subunits are not used to delineate domains within a single sequence. Subunits are listed in order of decreasing length; sequences of the same length will be ordered by decreasing molecular weight; subunits that have identical sequences will be repeated multiple times.
 *
 * http://hl7.org/fhir/subunit
 */
export const subunit = 'http://hl7.org/fhir/subunit' satisfies OwlObjectProperty;

/**
 * orderer
 *
 * NutritionOrder.orderer: The practitioner that holds legal responsibility for ordering the diet, nutritional supplement, or formula feedings.
 *
 * http://hl7.org/fhir/orderer
 */
export const orderer = 'http://hl7.org/fhir/orderer' satisfies OwlObjectProperty;

/**
 * ExampleScenarioInstanceVersionComponent
 *
 * ExampleScenarioInstanceComponent.ExampleScenarioInstanceVersionComponent: Represents the instance as it was at a specific time-point.
 *
 * http://hl7.org/fhir/ExampleScenarioInstanceVersionComponent
 */
export const ExampleScenarioInstanceVersionComponent = 'http://hl7.org/fhir/ExampleScenarioInstanceVersionComponent' satisfies OwlClass;

/**
 * itemStatus
 *
 * InventoryReport.inventoryListing.itemStatus: The status of the items.
 *
 * http://hl7.org/fhir/itemStatus
 */
export const itemStatus = 'http://hl7.org/fhir/itemStatus' satisfies OwlObjectProperty;

/**
 * _ResearchStudy
 *
 * (Modified) ResearchStudy
 *
 * http://hl7.org/fhir/_ResearchStudy
 */
export const _ResearchStudy = 'http://hl7.org/fhir/_ResearchStudy' satisfies OwlClass;

/**
 * resourceType
 *
 * Subscription.filterBy.resourceType: A resource listed in the `SubscriptionTopic` this `Subscription` references (`SubscriptionTopic.canFilterBy.resource`). This element can be used to differentiate filters for topics that include more than one resource type.
 *
 * http://hl7.org/fhir/resourceType
 */
export const resourceType = 'http://hl7.org/fhir/resourceType' satisfies OwlObjectProperty;

/**
 * Quantity
 *
 * A measured amount (or an amount that can potentially be measured). Note that measured amounts include amounts that are not precisely quantified, including amounts involving arbitrary units and floating currencies.
 *
 * http://hl7.org/fhir/Quantity
 */
export const Quantity = 'http://hl7.org/fhir/Quantity' satisfies OwlClass;

/**
 * contained
 *
 * DomainResource.contained: These resources do not have an independent existence apart from the resource that contains them - they cannot be identified independently, nor can they have their own independent transaction scope. This is allowed to be a Parameters resource if and only if it is referenced by a resource that provides context/meaning.
 *
 * http://hl7.org/fhir/contained
 */
export const contained = 'http://hl7.org/fhir/contained' satisfies OwlObjectProperty;

/**
 * _appointmentType
 *
 * (Modified) Slot.appointmentType
 *
 * http://hl7.org/fhir/_appointmentType
 */
export const _appointmentType = 'http://hl7.org/fhir/_appointmentType' satisfies OwlObjectProperty;

/**
 * SpecimenDefinitionTypeTestedComponent
 *
 * SpecimenDefinitionTypeTestedComponent: Specimen conditioned in a container as expected by the testing laboratory.
 *
 * http://hl7.org/fhir/SpecimenDefinitionTypeTestedComponent
 */
export const SpecimenDefinitionTypeTestedComponent = 'http://hl7.org/fhir/SpecimenDefinitionTypeTestedComponent' satisfies OwlClass;

/**
 * _actual
 *
 * (Modified) ResearchStudy.progressStatus.actual
 *
 * http://hl7.org/fhir/_actual
 */
export const _actual = 'http://hl7.org/fhir/_actual' satisfies OwlObjectProperty;

/**
 * CostToBeneficiary
 *
 * Coverage.CostToBeneficiary: A suite of codes indicating the cost category and associated amount which have been detailed in the policy and may have been  included on the health card.
 *
 * http://hl7.org/fhir/CostToBeneficiary
 */
export const CostToBeneficiary = 'http://hl7.org/fhir/CostToBeneficiary' satisfies OwlClass;

/**
 * _Schedule
 *
 * (Modified) Schedule
 *
 * http://hl7.org/fhir/_Schedule
 */
export const _Schedule = 'http://hl7.org/fhir/_Schedule' satisfies OwlClass;

/**
 * programCode
 *
 * ExplanationOfBenefit.addItem.programCode: Identifies the program under which this may be recovered.
 *
 * http://hl7.org/fhir/programCode
 */
export const programCode = 'http://hl7.org/fhir/programCode' satisfies OwlObjectProperty;

/**
 * _PractitionerRole
 *
 * (Modified) PractitionerRole
 *
 * http://hl7.org/fhir/_PractitionerRole
 */
export const _PractitionerRole = 'http://hl7.org/fhir/_PractitionerRole' satisfies OwlClass;

/**
 * guarantor
 *
 * Account.guarantor: The parties responsible for balancing the account if other payment options fall short.
 *
 * http://hl7.org/fhir/guarantor
 */
export const guarantor = 'http://hl7.org/fhir/guarantor' satisfies OwlObjectProperty;

/**
 * _FamilyMemberHistory
 *
 * (Modified) FamilyMemberHistory
 *
 * http://hl7.org/fhir/_FamilyMemberHistory
 */
export const _FamilyMemberHistory = 'http://hl7.org/fhir/_FamilyMemberHistory' satisfies OwlClass;

/**
 * _operationTypeReason
 *
 * (Modified) InventoryReport.operationTypeReason
 *
 * http://hl7.org/fhir/_operationTypeReason
 */
export const _operationTypeReason = 'http://hl7.org/fhir/_operationTypeReason' satisfies OwlObjectProperty;

/**
 * _programStatus
 *
 * (Modified) Immunization.programEligibility.programStatus
 *
 * http://hl7.org/fhir/_programStatus
 */
export const _programStatus = 'http://hl7.org/fhir/_programStatus' satisfies OwlObjectProperty;

/**
 * _performerLinkId
 *
 * (Modified) Contract.term.group.action.performerLinkId
 *
 * http://hl7.org/fhir/_performerLinkId
 */
export const _performerLinkId = 'http://hl7.org/fhir/_performerLinkId' satisfies OwlObjectProperty;

/**
 * onHold
 *
 * Account.guarantor.onHold: A guarantor may be placed on credit hold or otherwise have their role temporarily suspended.
 *
 * http://hl7.org/fhir/onHold
 */
export const onHold = 'http://hl7.org/fhir/onHold' satisfies OwlObjectProperty;

/**
 * _copackagedIndicator
 *
 * (Modified) PackagedProductDefinition.copackagedIndicator
 *
 * http://hl7.org/fhir/_copackagedIndicator
 */
export const _copackagedIndicator = 'http://hl7.org/fhir/_copackagedIndicator' satisfies OwlObjectProperty;

/**
 * storageGuideline
 *
 * MedicationKnowledge.storageGuideline: Information on how the medication should be stored, for example, refrigeration temperatures and length of stability at a given temperature.
 *
 * http://hl7.org/fhir/storageGuideline
 */
export const storageGuideline = 'http://hl7.org/fhir/storageGuideline' satisfies OwlObjectProperty;

/**
 * _receiver
 *
 * (Modified) SupplyDelivery.receiver
 *
 * http://hl7.org/fhir/_receiver
 */
export const _receiver = 'http://hl7.org/fhir/_receiver' satisfies OwlObjectProperty;

/**
 * _whyStopped
 *
 * (Modified) ResearchStudy.whyStopped
 *
 * http://hl7.org/fhir/_whyStopped
 */
export const _whyStopped = 'http://hl7.org/fhir/_whyStopped' satisfies OwlObjectProperty;

/**
 * _packageFor
 *
 * (Modified) PackagedProductDefinition.packageFor
 *
 * http://hl7.org/fhir/_packageFor
 */
export const _packageFor = 'http://hl7.org/fhir/_packageFor' satisfies OwlObjectProperty;

/**
 * action
 *
 * RequestOrchestration.action.action: Sub actions.
 *
 * http://hl7.org/fhir/action
 */
export const action = 'http://hl7.org/fhir/action' satisfies OwlObjectProperty;

/**
 * _sourceMaterialState
 *
 * (Modified) SubstanceSourceMaterial.sourceMaterialState
 *
 * http://hl7.org/fhir/_sourceMaterialState
 */
export const _sourceMaterialState = 'http://hl7.org/fhir/_sourceMaterialState' satisfies OwlObjectProperty;

/**
 * indicationGuideline
 *
 * MedicationKnowledge.indicationGuideline: Guidelines or protocols that are applicable for the administration of the medication based on indication.
 *
 * http://hl7.org/fhir/indicationGuideline
 */
export const indicationGuideline = 'http://hl7.org/fhir/indicationGuideline' satisfies OwlObjectProperty;

/**
 * _interaction
 *
 * (Modified) SubstanceReferenceInformation.target.interaction
 *
 * http://hl7.org/fhir/_interaction
 */
export const _interaction = 'http://hl7.org/fhir/_interaction' satisfies OwlObjectProperty;

/**
 * aggregateMethod
 *
 * Measure.group.population.aggregateMethod: Specifies which method should be used to aggregate measure observation values. For most scoring types, this is implied by scoring (e.g. a proportion measure counts members of the populations). For continuous variables, however, this information must be specified to ensure correct calculation.
 *
 * http://hl7.org/fhir/aggregateMethod
 */
export const aggregateMethod = 'http://hl7.org/fhir/aggregateMethod' satisfies OwlObjectProperty;

/**
 * _authorizingPrescription
 *
 * (Modified) MedicationDispense.authorizingPrescription
 *
 * http://hl7.org/fhir/_authorizingPrescription
 */
export const _authorizingPrescription = 'http://hl7.org/fhir/_authorizingPrescription' satisfies OwlObjectProperty;

/**
 * _authoritative
 *
 * (Modified) NamingSystem.uniqueId.authoritative
 *
 * http://hl7.org/fhir/_authoritative
 */
export const _authoritative = 'http://hl7.org/fhir/_authoritative' satisfies OwlObjectProperty;

/**
 * timeAspect
 *
 * SpecimenDefinition.timeAspect: Time aspect of specimen collection (duration or offset).
 *
 * http://hl7.org/fhir/timeAspect
 */
export const timeAspect = 'http://hl7.org/fhir/timeAspect' satisfies OwlObjectProperty;

/**
 * _valueSet
 *
 * (Modified) ElementDefinition.binding.additional.valueSet
 *
 * http://hl7.org/fhir/_valueSet
 */
export const _valueSet = 'http://hl7.org/fhir/_valueSet' satisfies OwlObjectProperty;

/**
 * OperationOutcome
 *
 * A collection of error, warning, or information messages that result from a system action.
 *
 * http://hl7.org/fhir/OperationOutcome
 */
export const OperationOutcome = 'http://hl7.org/fhir/OperationOutcome' satisfies OwlClass;

/**
 * Contributor
 *
 * A contributor to the content of a knowledge asset, including authors, editors, reviewers, and endorsers.
 *
 * http://hl7.org/fhir/Contributor
 */
export const Contributor = 'http://hl7.org/fhir/Contributor' satisfies OwlClass;

/**
 * _message
 *
 * (Modified) TestReport.teardown.action.operation.message
 *
 * http://hl7.org/fhir/_message
 */
export const _message = 'http://hl7.org/fhir/_message' satisfies OwlObjectProperty;

/**
 * import
 *
 * StructureMap.import: Other maps used by this map (canonical URLs).
 * Note that `import` is a reserved Javascript keyword, and is therefore suffixed by `__workaround`.
 * For a list of reserved keywords, see https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Lexical_grammar#Keywords.
 *
 * http://hl7.org/fhir/import
 */
export const import__workaround = 'http://hl7.org/fhir/import' satisfies OwlObjectProperty;

/**
 * definitionByTypeAndValue
 *
 * EvidenceVariable.characteristic.definitionByCombination.characteristic.definitionByTypeAndValue: Defines the characteristic using both a type and value[x] elements.
 *
 * http://hl7.org/fhir/definitionByTypeAndValue
 */
export const definitionByTypeAndValue = 'http://hl7.org/fhir/definitionByTypeAndValue' satisfies OwlObjectProperty;

/**
 * TestScriptSetupActionOperationComponent
 *
 * TestScriptSetupComponent.SetupAction.TestScriptSetupActionOperationComponent: The operation to perform.
 *
 * http://hl7.org/fhir/TestScriptSetupActionOperationComponent
 */
export const TestScriptSetupActionOperationComponent = 'http://hl7.org/fhir/TestScriptSetupActionOperationComponent' satisfies OwlClass;

/**
 * mitigatingAction
 *
 * AdverseEvent.mitigatingAction: The ameliorating action taken after the adverse event occured in order to reduce the extent of harm.
 *
 * http://hl7.org/fhir/mitigatingAction
 */
export const mitigatingAction = 'http://hl7.org/fhir/mitigatingAction' satisfies OwlObjectProperty;

/**
 * validationDate
 *
 * VerificationResult.primarySource.validationDate: When the target was validated against the primary source.
 *
 * http://hl7.org/fhir/validationDate
 */
export const validationDate = 'http://hl7.org/fhir/validationDate' satisfies OwlObjectProperty;

/**
 * healthcareService
 *
 * PractitionerRole.healthcareService: The list of healthcare services that this worker provides for this role's Organization/Location(s).
 *
 * http://hl7.org/fhir/healthcareService
 */
export const healthcareService = 'http://hl7.org/fhir/healthcareService' satisfies OwlObjectProperty;

/**
 * conditionalPatch
 *
 * CapabilityStatement.rest.resource.conditionalPatch: A flag that indicates that the server supports conditional patch.
 *
 * http://hl7.org/fhir/conditionalPatch
 */
export const conditionalPatch = 'http://hl7.org/fhir/conditionalPatch' satisfies OwlObjectProperty;

/**
 * minimumVolume
 *
 * SpecimenDefinition.typeTested.container.minimumVolume
 *
 * http://hl7.org/fhir/minimumVolume
 */
export const minimumVolume = 'http://hl7.org/fhir/minimumVolume' satisfies OwlObjectProperty;

/**
 * _practiceSetting
 *
 * (Modified) DocumentReference.practiceSetting
 *
 * http://hl7.org/fhir/_practiceSetting
 */
export const _practiceSetting = 'http://hl7.org/fhir/_practiceSetting' satisfies OwlObjectProperty;

/**
 * protocol
 *
 * ResearchStudy.protocol: The set of steps expected to be performed as part of the execution of the study.
 *
 * http://hl7.org/fhir/protocol
 */
export const protocol = 'http://hl7.org/fhir/protocol' satisfies OwlObjectProperty;

/**
 * _structureProfile
 *
 * (Modified) ExampleScenario.instance.structureProfile
 *
 * http://hl7.org/fhir/_structureProfile
 */
export const _structureProfile = 'http://hl7.org/fhir/_structureProfile' satisfies OwlObjectProperty;

/**
 * _Coverage
 *
 * (Modified) Coverage
 *
 * http://hl7.org/fhir/_Coverage
 */
export const _Coverage = 'http://hl7.org/fhir/_Coverage' satisfies OwlClass;

/**
 * _issuerType
 *
 * (Modified) PaymentReconciliation.issuerType
 *
 * http://hl7.org/fhir/_issuerType
 */
export const _issuerType = 'http://hl7.org/fhir/_issuerType' satisfies OwlObjectProperty;

/**
 * MedicationRequest
 *
 * An order or request for both supply of the medication and the instructions for administration of the medication to a patient. The resource is called "MedicationRequest" rather than "MedicationPrescription" or "MedicationOrder" to generalize the use across inpatient and outpatient settings, including care plans, etc., and to harmonize with workflow patterns.
 *
 * http://hl7.org/fhir/MedicationRequest
 */
export const MedicationRequest = 'http://hl7.org/fhir/MedicationRequest' satisfies OwlClass;

/**
 * _pattern
 *
 * (Modified) ElementDefinition.pattern
 *
 * http://hl7.org/fhir/_pattern
 */
export const _pattern = 'http://hl7.org/fhir/_pattern' satisfies OwlObjectProperty;

/**
 * processingFacility
 *
 * BiologicallyDerivedProduct.processingFacility: Processing facilities responsible for the labeling and distribution of this biologically derived product.
 *
 * http://hl7.org/fhir/processingFacility
 */
export const processingFacility = 'http://hl7.org/fhir/processingFacility' satisfies OwlObjectProperty;

/**
 * _situation
 *
 * (Modified) MessageDefinition.allowedResponse.situation
 *
 * http://hl7.org/fhir/_situation
 */
export const _situation = 'http://hl7.org/fhir/_situation' satisfies OwlObjectProperty;

/**
 * _patchFormat
 *
 * (Modified) CapabilityStatement.patchFormat
 *
 * http://hl7.org/fhir/_patchFormat
 */
export const _patchFormat = 'http://hl7.org/fhir/_patchFormat' satisfies OwlObjectProperty;

/**
 * alternateMaterial
 *
 * PackagedProductDefinition.packaging.packaging.alternateMaterial: A possible alternate material for this part of the packaging, that is allowed to be used instead of the usual material (e.g. different types of plastic for a blister sleeve).
 *
 * http://hl7.org/fhir/alternateMaterial
 */
export const alternateMaterial = 'http://hl7.org/fhir/alternateMaterial' satisfies OwlObjectProperty;

/**
 * responsible
 *
 * NamingSystem.responsible: The name of the organization that is responsible for issuing identifiers or codes for this namespace and ensuring their non-collision.
 *
 * http://hl7.org/fhir/responsible
 */
export const responsible = 'http://hl7.org/fhir/responsible' satisfies OwlObjectProperty;

/**
 * PlanDefinitionActionRelatedActionComponent
 *
 * PlanDefinitionActionComponent.PlanDefinitionActionRelatedActionComponent: A relationship to another action such as "before" or "30-60 minutes after start of".
 *
 * http://hl7.org/fhir/PlanDefinitionActionRelatedActionComponent
 */
export const PlanDefinitionActionRelatedActionComponent = 'http://hl7.org/fhir/PlanDefinitionActionRelatedActionComponent' satisfies OwlClass;

/**
 * _security
 *
 * (Modified) Permission.rule.data.security
 *
 * http://hl7.org/fhir/_security
 */
export const _security = 'http://hl7.org/fhir/_security' satisfies OwlObjectProperty;

/**
 * combined
 *
 * Specimen.combined: This element signifies if the specimen is part of a group or pooled.
 *
 * http://hl7.org/fhir/combined
 */
export const combined = 'http://hl7.org/fhir/combined' satisfies OwlObjectProperty;

/**
 * contains
 *
 * ValueSet.expansion.contains: The codes that are contained in the value set expansion.
 *
 * http://hl7.org/fhir/contains
 */
export const contains = 'http://hl7.org/fhir/contains' satisfies OwlObjectProperty;

/**
 * _addresses
 *
 * (Modified) PlanDefinition.goal.addresses
 *
 * http://hl7.org/fhir/_addresses
 */
export const _addresses = 'http://hl7.org/fhir/_addresses' satisfies OwlObjectProperty;

/**
 * expirationDate
 *
 * Immunization.expirationDate: Date vaccine batch expires.
 *
 * http://hl7.org/fhir/expirationDate
 */
export const expirationDate = 'http://hl7.org/fhir/expirationDate' satisfies OwlObjectProperty;

/**
 * compartment
 *
 * GraphDefinition.link.compartment: Compartment Consistency Rules.
 *
 * http://hl7.org/fhir/compartment
 */
export const compartment = 'http://hl7.org/fhir/compartment' satisfies OwlObjectProperty;

/**
 * _scoring
 *
 * (Modified) MeasureReport.scoring
 *
 * http://hl7.org/fhir/_scoring
 */
export const _scoring = 'http://hl7.org/fhir/_scoring' satisfies OwlObjectProperty;

/**
 * policy
 *
 * AuditEvent.agent.policy: Where the policy(ies) are known that authorized the agent participation in the event. Typically, a single activity may have multiple applicable policies, such as patient consent, guarantor funding, etc. The policy would also indicate the security token used.
 *
 * http://hl7.org/fhir/policy
 */
export const policy = 'http://hl7.org/fhir/policy' satisfies OwlObjectProperty;

/**
 * recordedDate
 *
 * AdverseEvent.recordedDate: The date on which the existence of the AdverseEvent was first recorded.
 *
 * http://hl7.org/fhir/recordedDate
 */
export const recordedDate = 'http://hl7.org/fhir/recordedDate' satisfies OwlObjectProperty;

/**
 * _sourceScope
 *
 * (Modified) ConceptMap.sourceScope
 *
 * http://hl7.org/fhir/_sourceScope
 */
export const _sourceScope = 'http://hl7.org/fhir/_sourceScope' satisfies OwlObjectProperty;

/**
 * _chain
 *
 * (Modified) SearchParameter.chain
 *
 * http://hl7.org/fhir/_chain
 */
export const _chain = 'http://hl7.org/fhir/_chain' satisfies OwlObjectProperty;

/**
 * ImplementationGuideManifestComponent
 *
 * ImplementationGuideManifestComponent: Information about an assembled implementation guide, created by the publication tooling.
 *
 * http://hl7.org/fhir/ImplementationGuideManifestComponent
 */
export const ImplementationGuideManifestComponent = 'http://hl7.org/fhir/ImplementationGuideManifestComponent' satisfies OwlClass;

/**
 * _contributedToDeath
 *
 * (Modified) FamilyMemberHistory.procedure.contributedToDeath
 *
 * http://hl7.org/fhir/_contributedToDeath
 */
export const _contributedToDeath = 'http://hl7.org/fhir/_contributedToDeath' satisfies OwlObjectProperty;

/**
 * _diagnosisRelatedGroup
 *
 * (Modified) ExplanationOfBenefit.diagnosisRelatedGroup
 *
 * http://hl7.org/fhir/_diagnosisRelatedGroup
 */
export const _diagnosisRelatedGroup = 'http://hl7.org/fhir/_diagnosisRelatedGroup' satisfies OwlObjectProperty;

/**
 * _referenceNumber
 *
 * (Modified) PaymentReconciliation.referenceNumber
 *
 * http://hl7.org/fhir/_referenceNumber
 */
export const _referenceNumber = 'http://hl7.org/fhir/_referenceNumber' satisfies OwlObjectProperty;

/**
 * _template
 *
 * (Modified) ImplementationGuide.definition.template
 *
 * http://hl7.org/fhir/_template
 */
export const _template = 'http://hl7.org/fhir/_template' satisfies OwlObjectProperty;

/**
 * _preConditions
 *
 * (Modified) ExampleScenario.process.step.alternative.step.process.preConditions
 *
 * http://hl7.org/fhir/_preConditions
 */
export const _preConditions = 'http://hl7.org/fhir/_preConditions' satisfies OwlObjectProperty;

/**
 * _score
 *
 * (Modified) TestReport.score
 *
 * http://hl7.org/fhir/_score
 */
export const _score = 'http://hl7.org/fhir/_score' satisfies OwlObjectProperty;

/**
 * SubstancePolymerMonomerSetComponent
 *
 * SubstancePolymerMonomerSetComponent: Todo.
 *
 * http://hl7.org/fhir/SubstancePolymerMonomerSetComponent
 */
export const SubstancePolymerMonomerSetComponent = 'http://hl7.org/fhir/SubstancePolymerMonomerSetComponent' satisfies OwlClass;

/**
 * _requiredBehavior
 *
 * (Modified) RequestOrchestration.action.action.requiredBehavior
 *
 * http://hl7.org/fhir/_requiredBehavior
 */
export const _requiredBehavior = 'http://hl7.org/fhir/_requiredBehavior' satisfies OwlObjectProperty;

/**
 * _statusHistory
 *
 * (Modified) EpisodeOfCare.statusHistory
 *
 * http://hl7.org/fhir/_statusHistory
 */
export const _statusHistory = 'http://hl7.org/fhir/_statusHistory' satisfies OwlObjectProperty;

/**
 * replacementSequence
 *
 * MolecularSequence.relative.edit.replacementSequence: Allele that was observed. Nucleotide(s)/amino acids from start position of sequence to stop position of sequence on the positive (+) strand of the observed sequence. When the sequence type is DNA, it should be the sequence on the positive (+) strand. This will lay in the range between variant.start and variant.end.
 *
 * http://hl7.org/fhir/replacementSequence
 */
export const replacementSequence = 'http://hl7.org/fhir/replacementSequence' satisfies OwlObjectProperty;

/**
 * _file
 *
 * (Modified) SubstanceDefinition.characterization.file
 *
 * http://hl7.org/fhir/_file
 */
export const _file = 'http://hl7.org/fhir/_file' satisfies OwlObjectProperty;

/**
 * _height
 *
 * (Modified) Attachment.height
 *
 * http://hl7.org/fhir/_height
 */
export const _height = 'http://hl7.org/fhir/_height' satisfies OwlObjectProperty;

/**
 * _groupSize
 *
 * (Modified) InsurancePlan.plan.generalCost.groupSize
 *
 * http://hl7.org/fhir/_groupSize
 */
export const _groupSize = 'http://hl7.org/fhir/_groupSize' satisfies OwlObjectProperty;

/**
 * observedGroup
 *
 * ResearchStudy.comparisonGroup.observedGroup: Group of participants who were enrolled in study comparisonGroup.
 *
 * http://hl7.org/fhir/observedGroup
 */
export const observedGroup = 'http://hl7.org/fhir/observedGroup' satisfies OwlObjectProperty;

/**
 * receivedTime
 *
 * Specimen.receivedTime: Time when specimen is received by the testing laboratory for processing or testing.
 *
 * http://hl7.org/fhir/receivedTime
 */
export const receivedTime = 'http://hl7.org/fhir/receivedTime' satisfies OwlObjectProperty;

/**
 * _doseAndRate
 *
 * (Modified) Dosage.doseAndRate
 *
 * http://hl7.org/fhir/_doseAndRate
 */
export const _doseAndRate = 'http://hl7.org/fhir/_doseAndRate' satisfies OwlObjectProperty;

/**
 * definitionCanonical
 *
 * EvidenceVariable.characteristic.definitionByCombination.characteristic.definitionCanonical: Defines the characteristic using Canonical.
 *
 * http://hl7.org/fhir/definitionCanonical
 */
export const definitionCanonical = 'http://hl7.org/fhir/definitionCanonical' satisfies OwlObjectProperty;

/**
 * QuestionnaireResponseItemComponent
 *
 * QuestionnaireResponseItemComponent: A group or question item from the original questionnaire for which answers are provided.
 *
 * http://hl7.org/fhir/QuestionnaireResponseItemComponent
 */
export const QuestionnaireResponseItemComponent = 'http://hl7.org/fhir/QuestionnaireResponseItemComponent' satisfies OwlClass;

/**
 * _typeReference
 *
 * (Modified) PlanDefinition.actor.option.typeReference
 *
 * http://hl7.org/fhir/_typeReference
 */
export const _typeReference = 'http://hl7.org/fhir/_typeReference' satisfies OwlObjectProperty;

/**
 * PractitionerQualificationComponent
 *
 * PractitionerQualificationComponent: The official qualifications, certifications, accreditations, training, licenses (and other types of educations/skills/capabilities) that authorize or otherwise pertain to the provision of care by the practitioner.

For example, a medical license issued by a medical board of licensure authorizing the practitioner to practice medicine within a certain locality.
 *
 * http://hl7.org/fhir/PractitionerQualificationComponent
 */
export const PractitionerQualificationComponent = 'http://hl7.org/fhir/PractitionerQualificationComponent' satisfies OwlClass;

/**
 * cTerminalModificationId
 *
 * SubstanceProtein.subunit.cTerminalModificationId: Unique identifier for molecular fragment modification based on the ISO 11238 Substance ID.
 *
 * http://hl7.org/fhir/cTerminalModificationId
 */
export const cTerminalModificationId = 'http://hl7.org/fhir/cTerminalModificationId' satisfies OwlObjectProperty;

/**
 * _requireBoth
 *
 * (Modified) SubscriptionTopic.resourceTrigger.queryCriteria.requireBoth
 *
 * http://hl7.org/fhir/_requireBoth
 */
export const _requireBoth = 'http://hl7.org/fhir/_requireBoth' satisfies OwlObjectProperty;

/**
 * dataAbsentReason
 *
 * Observation.component.dataAbsentReason: Provides a reason why the expected value in the element Observation.component.value[x] is missing.
 *
 * http://hl7.org/fhir/dataAbsentReason
 */
export const dataAbsentReason = 'http://hl7.org/fhir/dataAbsentReason' satisfies OwlObjectProperty;

/**
 * _criticality
 *
 * (Modified) AllergyIntolerance.criticality
 *
 * http://hl7.org/fhir/_criticality
 */
export const _criticality = 'http://hl7.org/fhir/_criticality' satisfies OwlObjectProperty;

/**
 * _subjectStatus
 *
 * (Modified) EncounterHistory.subjectStatus
 *
 * http://hl7.org/fhir/_subjectStatus
 */
export const _subjectStatus = 'http://hl7.org/fhir/_subjectStatus' satisfies OwlObjectProperty;

/**
 * _expiry
 *
 * (Modified) Substance.expiry
 *
 * http://hl7.org/fhir/_expiry
 */
export const _expiry = 'http://hl7.org/fhir/_expiry' satisfies OwlObjectProperty;

/**
 * usage
 *
 * ActivityDefinition.usage: A detailed description of how the activity definition is used from a clinical perspective.
 *
 * http://hl7.org/fhir/usage
 */
export const usage = 'http://hl7.org/fhir/usage' satisfies OwlObjectProperty;

/**
 * city
 *
 * Address.city: The name of the city, town, suburb, village or other community or delivery center.
 *
 * http://hl7.org/fhir/city
 */
export const city = 'http://hl7.org/fhir/city' satisfies OwlObjectProperty;

/**
 * _instances
 *
 * (Modified) EvidenceVariable.characteristic.instances
 *
 * http://hl7.org/fhir/_instances
 */
export const _instances = 'http://hl7.org/fhir/_instances' satisfies OwlObjectProperty;

/**
 * stratum
 *
 * MeasureReport.group.stratifier.stratum: This element contains the results for a single stratum within the stratifier. For example, when stratifying on administrative gender, there will be four strata, one for each possible gender value.
 *
 * http://hl7.org/fhir/stratum
 */
export const stratum = 'http://hl7.org/fhir/stratum' satisfies OwlObjectProperty;

/**
 * MeasureReportGroupStratifierComponent
 *
 * MeasureReportGroupComponent.MeasureReportGroupStratifierComponent: When a measure includes multiple stratifiers, there will be a stratifier group for each stratifier defined by the measure.
 *
 * http://hl7.org/fhir/MeasureReportGroupStratifierComponent
 */
export const MeasureReportGroupStratifierComponent = 'http://hl7.org/fhir/MeasureReportGroupStratifierComponent' satisfies OwlClass;

/**
 * _ratioHighLimitAmount
 *
 * (Modified) SubstanceDefinition.relationship.ratioHighLimitAmount
 *
 * http://hl7.org/fhir/_ratioHighLimitAmount
 */
export const _ratioHighLimitAmount = 'http://hl7.org/fhir/_ratioHighLimitAmount' satisfies OwlObjectProperty;

/**
 * route
 *
 * Dosage.route: How drug should enter body.
 *
 * http://hl7.org/fhir/route
 */
export const route = 'http://hl7.org/fhir/route' satisfies OwlObjectProperty;

/**
 * TestScriptMetadataLinkComponent
 *
 * TestScriptMetadataComponent.TestScriptMetadataLinkComponent: A link to the FHIR specification that this test is covering.
 *
 * http://hl7.org/fhir/TestScriptMetadataLinkComponent
 */
export const TestScriptMetadataLinkComponent = 'http://hl7.org/fhir/TestScriptMetadataLinkComponent' satisfies OwlClass;

/**
 * DeviceDispensePerformerComponent
 *
 * DeviceDispensePerformerComponent: Indicates who or what performed the event.
 *
 * http://hl7.org/fhir/DeviceDispensePerformerComponent
 */
export const DeviceDispensePerformerComponent = 'http://hl7.org/fhir/DeviceDispensePerformerComponent' satisfies OwlClass;

/**
 * frequencyMax
 *
 * Timing.repeat.frequencyMax: If present, indicates that the frequency is a range - so to repeat between [frequency] and [frequencyMax] times within the period or period range.
 *
 * http://hl7.org/fhir/frequencyMax
 */
export const frequencyMax = 'http://hl7.org/fhir/frequencyMax' satisfies OwlObjectProperty;

/**
 * _number
 *
 * (Modified) ExampleScenario.process.step.process.step.number
 *
 * http://hl7.org/fhir/_number
 */
export const _number = 'http://hl7.org/fhir/_number' satisfies OwlObjectProperty;

/**
 * QuestionnaireResponse
 *
 * A structured set of questions and their answers. The questions are ordered and grouped into coherent subsets, corresponding to the structure of the grouping of the questionnaire being responded to.
 *
 * http://hl7.org/fhir/QuestionnaireResponse
 */
export const QuestionnaireResponse = 'http://hl7.org/fhir/QuestionnaireResponse' satisfies OwlClass;

/**
 * MappingProperty
 *
 * ConceptMapGroupComponent.SourceElement.TargetElement.MappingProperty: A property value for this source -> target mapping.
 *
 * http://hl7.org/fhir/MappingProperty
 */
export const MappingProperty = 'http://hl7.org/fhir/MappingProperty' satisfies OwlClass;

/**
 * _securityContext
 *
 * (Modified) Binary.securityContext
 *
 * http://hl7.org/fhir/_securityContext
 */
export const _securityContext = 'http://hl7.org/fhir/_securityContext' satisfies OwlObjectProperty;

/**
 * display
 *
 * TestReport.participant.display: The display name of the participant.
 *
 * http://hl7.org/fhir/display
 */
export const display = 'http://hl7.org/fhir/display' satisfies OwlObjectProperty;

/**
 * yearlyTemplate
 *
 * Appointment.recurrenceTemplate.yearlyTemplate: Information about yearly recurring appointments.
 *
 * http://hl7.org/fhir/yearlyTemplate
 */
export const yearlyTemplate = 'http://hl7.org/fhir/yearlyTemplate' satisfies OwlObjectProperty;

/**
 * ChargeItemPerformerComponent
 *
 * ChargeItemPerformerComponent: Indicates who or what performed or participated in the charged service.
 *
 * http://hl7.org/fhir/ChargeItemPerformerComponent
 */
export const ChargeItemPerformerComponent = 'http://hl7.org/fhir/ChargeItemPerformerComponent' satisfies OwlClass;

/**
 * Contact
 *
 * Patient.Contact: A contact party (e.g. guardian, partner, friend) for the patient.
 *
 * http://hl7.org/fhir/Contact
 */
export const Contact = 'http://hl7.org/fhir/Contact' satisfies OwlClass;

/**
 * EndpointPayloadComponent
 *
 * EndpointPayloadComponent: The set of payloads that are provided/available at this endpoint.
 *
 * http://hl7.org/fhir/EndpointPayloadComponent
 */
export const EndpointPayloadComponent = 'http://hl7.org/fhir/EndpointPayloadComponent' satisfies OwlClass;

/**
 * _relatedArtifact
 *
 * (Modified) ChargeItemDefinition.propertyGroup.applicability.relatedArtifact
 *
 * http://hl7.org/fhir/_relatedArtifact
 */
export const _relatedArtifact = 'http://hl7.org/fhir/_relatedArtifact' satisfies OwlObjectProperty;

/**
 * updateCreate
 *
 * CapabilityStatement.rest.resource.updateCreate: A flag to indicate that the server allows or needs to allow the client to create new identities on the server (that is, the client PUTs to a location where there is no existing resource). Allowing this operation means that the server allows the client to create new identities on the server.
 *
 * http://hl7.org/fhir/updateCreate
 */
export const updateCreate = 'http://hl7.org/fhir/updateCreate' satisfies OwlObjectProperty;

/**
 * _subtype
 *
 * (Modified) Contract.term.group.asset.subtype
 *
 * http://hl7.org/fhir/_subtype
 */
export const _subtype = 'http://hl7.org/fhir/_subtype' satisfies OwlObjectProperty;

/**
 * _stereochemistry
 *
 * (Modified) SubstanceDefinition.structure.stereochemistry
 *
 * http://hl7.org/fhir/_stereochemistry
 */
export const _stereochemistry = 'http://hl7.org/fhir/_stereochemistry' satisfies OwlObjectProperty;

/**
 * _upperLimit
 *
 * (Modified) SampledData.upperLimit
 *
 * http://hl7.org/fhir/_upperLimit
 */
export const _upperLimit = 'http://hl7.org/fhir/_upperLimit' satisfies OwlObjectProperty;

/**
 * routeOfAdministration
 *
 * NutritionOrder.enteralFormula.routeOfAdministration: The route or physiological path of administration into the patient's gastrointestinal  tract for purposes of providing the formula feeding, e.g. nasogastric tube.
 *
 * http://hl7.org/fhir/routeOfAdministration
 */
export const routeOfAdministration = 'http://hl7.org/fhir/routeOfAdministration' satisfies OwlObjectProperty;

/**
 * _amountType
 *
 * (Modified) SubstanceReferenceInformation.target.amountType
 *
 * http://hl7.org/fhir/_amountType
 */
export const _amountType = 'http://hl7.org/fhir/_amountType' satisfies OwlObjectProperty;

/**
 * _organismType
 *
 * (Modified) SubstanceReferenceInformation.target.organismType
 *
 * http://hl7.org/fhir/_organismType
 */
export const _organismType = 'http://hl7.org/fhir/_organismType' satisfies OwlObjectProperty;

/**
 * bodySite
 *
 * Specimen.collection.bodySite: Anatomical location from which the specimen was collected (if subject is a patient). This is the target site.  This element is not used for environmental specimens.
 *
 * http://hl7.org/fhir/bodySite
 */
export const bodySite = 'http://hl7.org/fhir/bodySite' satisfies OwlObjectProperty;

/**
 * _moiety
 *
 * (Modified) SubstanceDefinition.moiety
 *
 * http://hl7.org/fhir/_moiety
 */
export const _moiety = 'http://hl7.org/fhir/_moiety' satisfies OwlObjectProperty;

/**
 * _recommendation
 *
 * (Modified) ImmunizationRecommendation.recommendation
 *
 * http://hl7.org/fhir/_recommendation
 */
export const _recommendation = 'http://hl7.org/fhir/_recommendation' satisfies OwlObjectProperty;

/**
 * grouping
 *
 * ImplementationGuide.definition.grouping: A logical group of resources. Logical groups can be used when building pages.
 *
 * http://hl7.org/fhir/grouping
 */
export const grouping = 'http://hl7.org/fhir/grouping' satisfies OwlObjectProperty;

/**
 * _pause
 *
 * (Modified) ExampleScenario.process.step.pause
 *
 * http://hl7.org/fhir/_pause
 */
export const _pause = 'http://hl7.org/fhir/_pause' satisfies OwlObjectProperty;

/**
 * _primaryPurposeType
 *
 * (Modified) ResearchStudy.primaryPurposeType
 *
 * http://hl7.org/fhir/_primaryPurposeType
 */
export const _primaryPurposeType = 'http://hl7.org/fhir/_primaryPurposeType' satisfies OwlObjectProperty;

/**
 * ConceptSubProperty
 *
 * ValueSetExpansionComponent.ValueSetExpansionContainsComponentContains.ConceptProperty.ConceptSubProperty: A subproperty value for this concept.
 *
 * http://hl7.org/fhir/ConceptSubProperty
 */
export const ConceptSubProperty = 'http://hl7.org/fhir/ConceptSubProperty' satisfies OwlClass;

/**
 * subscription
 *
 * SubscriptionStatus.subscription: The reference to the Subscription which generated this notification.
 *
 * http://hl7.org/fhir/subscription
 */
export const subscription = 'http://hl7.org/fhir/subscription' satisfies OwlObjectProperty;

/**
 * _lastPage
 *
 * (Modified) Citation.citedArtifact.publicationForm.lastPage
 *
 * http://hl7.org/fhir/_lastPage
 */
export const _lastPage = 'http://hl7.org/fhir/_lastPage' satisfies OwlObjectProperty;

/**
 * partLocation
 *
 * SubstanceSourceMaterial.partDescription.partLocation: The detailed anatomic location when the part can be extracted from different anatomical locations of the organism. Multiple alternative locations may apply.
 *
 * http://hl7.org/fhir/partLocation
 */
export const partLocation = 'http://hl7.org/fhir/partLocation' satisfies OwlObjectProperty;

/**
 * controller
 *
 * Consent.controller: The actor that controls/enforces the access according to the consent.
 *
 * http://hl7.org/fhir/controller
 */
export const controller = 'http://hl7.org/fhir/controller' satisfies OwlObjectProperty;

/**
 * publicationDateSeason
 *
 * Citation.citedArtifact.publicationForm.publicationDateSeason: Spring, Summer, Fall/Autumn, Winter.
 *
 * http://hl7.org/fhir/publicationDateSeason
 */
export const publicationDateSeason = 'http://hl7.org/fhir/publicationDateSeason' satisfies OwlObjectProperty;

/**
 * imports
 *
 * CapabilityStatement.imports: Reference to a canonical URL of another CapabilityStatement that this software adds to. The capability statement automatically includes everything in the other statement, and it is not duplicated, though the server may repeat the same resources, interactions and operations to add additional details to them.
 *
 * http://hl7.org/fhir/imports
 */
export const imports = 'http://hl7.org/fhir/imports' satisfies OwlObjectProperty;

/**
 * allocation
 *
 * PaymentReconciliation.allocation: Distribution of the payment amount for a previously acknowledged payable.
 *
 * http://hl7.org/fhir/allocation
 */
export const allocation = 'http://hl7.org/fhir/allocation' satisfies OwlObjectProperty;

/**
 * _pageCount
 *
 * (Modified) Citation.citedArtifact.publicationForm.pageCount
 *
 * http://hl7.org/fhir/_pageCount
 */
export const _pageCount = 'http://hl7.org/fhir/_pageCount' satisfies OwlObjectProperty;

/**
 * _failureAction
 *
 * (Modified) VerificationResult.failureAction
 *
 * http://hl7.org/fhir/_failureAction
 */
export const _failureAction = 'http://hl7.org/fhir/_failureAction' satisfies OwlObjectProperty;

/**
 * profile
 *
 * ImplementationGuide.global.profile: A reference to the profile that all instances must conform to.
 *
 * http://hl7.org/fhir/profile
 */
export const profile = 'http://hl7.org/fhir/profile' satisfies OwlObjectProperty;

/**
 * cylinder
 *
 * VisionPrescription.lensSpecification.cylinder: Power adjustment for astigmatism measured in dioptres (0.25 units).
 *
 * http://hl7.org/fhir/cylinder
 */
export const cylinder = 'http://hl7.org/fhir/cylinder' satisfies OwlObjectProperty;

/**
 * deleted
 *
 * List.entry.deleted: True if this item is marked as deleted in the list.
 *
 * http://hl7.org/fhir/deleted
 */
export const deleted = 'http://hl7.org/fhir/deleted' satisfies OwlObjectProperty;

/**
 * episodeOfCare
 *
 * Encounter.episodeOfCare: Where a specific encounter should be classified as a part of a specific episode(s) of care this field should be used. This association can facilitate grouping of related encounters together for a specific purpose, such as government reporting, issue tracking, association via a common problem.  The association is recorded on the encounter as these are typically created after the episode of care and grouped on entry rather than editing the episode of care to append another encounter to it (the episode of care could span years).
 *
 * http://hl7.org/fhir/episodeOfCare
 */
export const episodeOfCare = 'http://hl7.org/fhir/episodeOfCare' satisfies OwlObjectProperty;

/**
 * saturday
 *
 * Appointment.recurrenceTemplate.weeklyTemplate.saturday: Indicates that recurring appointments should occur on Saturdays.
 *
 * http://hl7.org/fhir/saturday
 */
export const saturday = 'http://hl7.org/fhir/saturday' satisfies OwlObjectProperty;

/**
 * _expectedInResearchStudy
 *
 * (Modified) AdverseEvent.expectedInResearchStudy
 *
 * http://hl7.org/fhir/_expectedInResearchStudy
 */
export const _expectedInResearchStudy = 'http://hl7.org/fhir/_expectedInResearchStudy' satisfies OwlObjectProperty;

/**
 * CommunicationRequestPayloadComponent
 *
 * CommunicationRequestPayloadComponent: Text, attachment(s), or resource(s) to be communicated to the recipient.
 *
 * http://hl7.org/fhir/CommunicationRequestPayloadComponent
 */
export const CommunicationRequestPayloadComponent = 'http://hl7.org/fhir/CommunicationRequestPayloadComponent' satisfies OwlClass;

/**
 * _calculatedAt
 *
 * (Modified) Account.calculatedAt
 *
 * http://hl7.org/fhir/_calculatedAt
 */
export const _calculatedAt = 'http://hl7.org/fhir/_calculatedAt' satisfies OwlObjectProperty;

/**
 * _impurity
 *
 * (Modified) MedicinalProductDefinition.impurity
 *
 * http://hl7.org/fhir/_impurity
 */
export const _impurity = 'http://hl7.org/fhir/_impurity' satisfies OwlObjectProperty;

/**
 * type
 *
 * NamingSystem.type: Categorizes a naming system for easier search by grouping related naming systems.
 *
 * http://hl7.org/fhir/type
 */
export const type = 'http://hl7.org/fhir/type' satisfies OwlObjectProperty;

/**
 * goalId
 *
 * PlanDefinition.action.action.goalId: Identifies goals that this action supports. The reference must be to a goal element defined within this plan definition. In pharmaceutical quality, a goal represents acceptance criteria (Goal) for a given action (Test), so the goalId would be the unique id of a defined goal element establishing the acceptance criteria for the action.
 *
 * http://hl7.org/fhir/goalId
 */
export const goalId = 'http://hl7.org/fhir/goalId' satisfies OwlObjectProperty;

/**
 * ObservationDefinitionComponentComponent
 *
 * ObservationDefinitionComponentComponent: Some observations have multiple component observations, expressed as separate code value pairs.
 *
 * http://hl7.org/fhir/ObservationDefinitionComponentComponent
 */
export const ObservationDefinitionComponentComponent = 'http://hl7.org/fhir/ObservationDefinitionComponentComponent' satisfies OwlClass;

/**
 * TestScriptSetupComponent
 *
 * TestScriptSetupComponent: A series of required setup operations before tests are executed.
 *
 * http://hl7.org/fhir/TestScriptSetupComponent
 */
export const TestScriptSetupComponent = 'http://hl7.org/fhir/TestScriptSetupComponent' satisfies OwlClass;

/**
 * Appointment
 *
 * A booking of a healthcare event among patient(s), practitioner(s), related person(s) and/or device(s) for a specific date/time. This may result in one or more Encounter(s).
 *
 * http://hl7.org/fhir/Appointment
 */
export const Appointment = 'http://hl7.org/fhir/Appointment' satisfies OwlClass;

/**
 * _groupIdentifier
 *
 * (Modified) Transport.groupIdentifier
 *
 * http://hl7.org/fhir/_groupIdentifier
 */
export const _groupIdentifier = 'http://hl7.org/fhir/_groupIdentifier' satisfies OwlObjectProperty;

/**
 * _countMax
 *
 * (Modified) Timing.repeat.countMax
 *
 * http://hl7.org/fhir/_countMax
 */
export const _countMax = 'http://hl7.org/fhir/_countMax' satisfies OwlObjectProperty;

/**
 * patientCharacteristic
 *
 * MedicationKnowledge.indicationGuideline.dosingGuideline.patientCharacteristic: Characteristics of the patient that are relevant to the administration guidelines (for example, height, weight, gender, etc.).
 *
 * http://hl7.org/fhir/patientCharacteristic
 */
export const patientCharacteristic = 'http://hl7.org/fhir/patientCharacteristic' satisfies OwlObjectProperty;

/**
 * lowNumerator
 *
 * RatioRange.lowNumerator: The value of the low limit numerator.
 *
 * http://hl7.org/fhir/lowNumerator
 */
export const lowNumerator = 'http://hl7.org/fhir/lowNumerator' satisfies OwlObjectProperty;

/**
 * _texture
 *
 * (Modified) NutritionOrder.oralDiet.texture
 *
 * http://hl7.org/fhir/_texture
 */
export const _texture = 'http://hl7.org/fhir/_texture' satisfies OwlObjectProperty;

/**
 * _causality
 *
 * (Modified) AdverseEvent.suspectEntity.causality
 *
 * http://hl7.org/fhir/_causality
 */
export const _causality = 'http://hl7.org/fhir/_causality' satisfies OwlObjectProperty;

/**
 * operator
 *
 * CodeSystem.filter.operator: A list of operators that can be used with the filter.
 *
 * http://hl7.org/fhir/operator
 */
export const operator = 'http://hl7.org/fhir/operator' satisfies OwlObjectProperty;

/**
 * fixed
 *
 * http://hl7.org/fhir/fixed
 */
export const fixed = 'http://hl7.org/fhir/fixed' satisfies OwlObjectProperty;

/**
 * nTerminalModificationId
 *
 * SubstanceProtein.subunit.nTerminalModificationId: Unique identifier for molecular fragment modification based on the ISO 11238 Substance ID.
 *
 * http://hl7.org/fhir/nTerminalModificationId
 */
export const nTerminalModificationId = 'http://hl7.org/fhir/nTerminalModificationId' satisfies OwlObjectProperty;

/**
 * InventoryItemNameComponent
 *
 * InventoryItemNameComponent: The item name(s) - the brand name, or common name, functional name, generic name.
 *
 * http://hl7.org/fhir/InventoryItemNameComponent
 */
export const InventoryItemNameComponent = 'http://hl7.org/fhir/InventoryItemNameComponent' satisfies OwlClass;

/**
 * _minimumId
 *
 * (Modified) TestScript.test.action.assert.minimumId
 *
 * http://hl7.org/fhir/_minimumId
 */
export const _minimumId = 'http://hl7.org/fhir/_minimumId' satisfies OwlObjectProperty;

/**
 * verificationStatus
 *
 * Condition.verificationStatus: The verification status to support the clinical status of the condition.  The verification status pertains to the condition, itself, not to any specific condition attribute.
 *
 * http://hl7.org/fhir/verificationStatus
 */
export const verificationStatus = 'http://hl7.org/fhir/verificationStatus' satisfies OwlObjectProperty;

/**
 * _PaymentNotice
 *
 * (Modified) PaymentNotice
 *
 * http://hl7.org/fhir/_PaymentNotice
 */
export const _PaymentNotice = 'http://hl7.org/fhir/_PaymentNotice' satisfies OwlClass;

/**
 * _dateAccessed
 *
 * (Modified) Citation.citedArtifact.dateAccessed
 *
 * http://hl7.org/fhir/_dateAccessed
 */
export const _dateAccessed = 'http://hl7.org/fhir/_dateAccessed' satisfies OwlObjectProperty;

/**
 * logMessage
 *
 * StructureMap.group.rule.rule.source.logMessage: A FHIRPath expression which specifies a message to put in the transform log when content matching the source rule is found.
 *
 * http://hl7.org/fhir/logMessage
 */
export const logMessage = 'http://hl7.org/fhir/logMessage' satisfies OwlObjectProperty;

/**
 * ResearchStudyProgressStatusComponent
 *
 * ResearchStudyProgressStatusComponent: Status of study with time for that status.
 *
 * http://hl7.org/fhir/ResearchStudyProgressStatusComponent
 */
export const ResearchStudyProgressStatusComponent = 'http://hl7.org/fhir/ResearchStudyProgressStatusComponent' satisfies OwlClass;

/**
 * _residueSite
 *
 * (Modified) SubstanceNucleicAcid.subunit.sugar.residueSite
 *
 * http://hl7.org/fhir/_residueSite
 */
export const _residueSite = 'http://hl7.org/fhir/_residueSite' satisfies OwlObjectProperty;

/**
 * MonetaryComponent
 *
 * Availability data for an {item}.
 *
 * http://hl7.org/fhir/MonetaryComponent
 */
export const MonetaryComponent = 'http://hl7.org/fhir/MonetaryComponent' satisfies OwlClass;

/**
 * TeardownAction
 *
 * TestScriptTeardownComponent.TeardownAction: The teardown action will only contain an operation.
 *
 * http://hl7.org/fhir/TeardownAction
 */
export const TeardownAction = 'http://hl7.org/fhir/TeardownAction' satisfies OwlClass;

/**
 * clinicalUseIssue
 *
 * MedicationKnowledge.clinicalUseIssue: Potential clinical issue with or between medication(s) (for example, drug-drug interaction, drug-disease contraindication, drug-allergy interaction, etc.).
 *
 * http://hl7.org/fhir/clinicalUseIssue
 */
export const clinicalUseIssue = 'http://hl7.org/fhir/clinicalUseIssue' satisfies OwlObjectProperty;

/**
 * classification
 *
 * MedicinalProductDefinition.classification: Allows the product to be classified by various systems, commonly WHO ATC.
 *
 * http://hl7.org/fhir/classification
 */
export const classification = 'http://hl7.org/fhir/classification' satisfies OwlObjectProperty;

/**
 * _lifecycleStatus
 *
 * (Modified) Goal.lifecycleStatus
 *
 * http://hl7.org/fhir/_lifecycleStatus
 */
export const _lifecycleStatus = 'http://hl7.org/fhir/_lifecycleStatus' satisfies OwlObjectProperty;

/**
 * signature
 *
 * Bundle.signature: Digital Signature - base64 encoded. XML-DSig or a JWS.
 *
 * http://hl7.org/fhir/signature
 */
export const signature = 'http://hl7.org/fhir/signature' satisfies OwlObjectProperty;

/**
 * reviewer
 *
 * EvidenceVariable.reviewer: An individual or organization asserted by the publisher to be primarily responsible for review of some aspect of the content.
 *
 * http://hl7.org/fhir/reviewer
 */
export const reviewer = 'http://hl7.org/fhir/reviewer' satisfies OwlObjectProperty;

/**
 * _usePeriod
 *
 * (Modified) Contract.term.group.asset.usePeriod
 *
 * http://hl7.org/fhir/_usePeriod
 */
export const _usePeriod = 'http://hl7.org/fhir/_usePeriod' satisfies OwlObjectProperty;

/**
 * BodyStructureIncludedStructureComponent
 *
 * BodyStructureIncludedStructureComponent: The anatomical location(s) or region(s) of the specimen, lesion, or body structure.
 *
 * http://hl7.org/fhir/BodyStructureIncludedStructureComponent
 */
export const BodyStructureIncludedStructureComponent = 'http://hl7.org/fhir/BodyStructureIncludedStructureComponent' satisfies OwlClass;

/**
 * next
 *
 * ValueSet.expansion.next: As per paging Search results, the next URLs are opaque to the client, have no dictated structure, and only the server understands them.
 *
 * http://hl7.org/fhir/next
 */
export const next = 'http://hl7.org/fhir/next' satisfies OwlObjectProperty;

/**
 * _changeType
 *
 * (Modified) GenomicStudy.analysis.changeType
 *
 * http://hl7.org/fhir/_changeType
 */
export const _changeType = 'http://hl7.org/fhir/_changeType' satisfies OwlObjectProperty;

/**
 * _ImmunizationEvaluation
 *
 * (Modified) ImmunizationEvaluation
 *
 * http://hl7.org/fhir/_ImmunizationEvaluation
 */
export const _ImmunizationEvaluation = 'http://hl7.org/fhir/_ImmunizationEvaluation' satisfies OwlClass;

/**
 * requestingOrganization
 *
 * ChargeItem.requestingOrganization: The organization requesting the service.
 *
 * http://hl7.org/fhir/requestingOrganization
 */
export const requestingOrganization = 'http://hl7.org/fhir/requestingOrganization' satisfies OwlObjectProperty;

/**
 * _unitOfPresentation
 *
 * (Modified) ManufacturedItemDefinition.unitOfPresentation
 *
 * http://hl7.org/fhir/_unitOfPresentation
 */
export const _unitOfPresentation = 'http://hl7.org/fhir/_unitOfPresentation' satisfies OwlObjectProperty;

/**
 * requestedPeriod
 *
 * Task.requestedPeriod: Indicates the start and/or end of the period of time when completion of the task is desired to take place.
 *
 * http://hl7.org/fhir/requestedPeriod
 */
export const requestedPeriod = 'http://hl7.org/fhir/requestedPeriod' satisfies OwlObjectProperty;

/**
 * Answer
 *
 * Contract.TermTerm.ContractOffer.Answer: Response to offer text.
 *
 * http://hl7.org/fhir/Answer
 */
export const Answer = 'http://hl7.org/fhir/Answer' satisfies OwlClass;

/**
 * count
 *
 * MeasureReport.group.stratifier.stratum.population.count: The number of members of the population in this stratum.
 *
 * http://hl7.org/fhir/count
 */
export const count = 'http://hl7.org/fhir/count' satisfies OwlObjectProperty;

/**
 * ContractOffer
 *
 * Contract.TermTerm.ContractOffer: The matter of concern in the context of this provision of the agrement.
 *
 * http://hl7.org/fhir/ContractOffer
 */
export const ContractOffer = 'http://hl7.org/fhir/ContractOffer' satisfies OwlClass;

/**
 * composition
 *
 * DiagnosticReport.composition: Reference to a Composition resource instance that provides structure for organizing the contents of the DiagnosticReport.
 *
 * http://hl7.org/fhir/composition
 */
export const composition = 'http://hl7.org/fhir/composition' satisfies OwlObjectProperty;

/**
 * _EnrollmentResponse
 *
 * (Modified) EnrollmentResponse
 *
 * http://hl7.org/fhir/_EnrollmentResponse
 */
export const _EnrollmentResponse = 'http://hl7.org/fhir/_EnrollmentResponse' satisfies OwlClass;

/**
 * ConditionStageComponent
 *
 * ConditionStageComponent: A simple summary of the stage such as "Stage 3" or "Early Onset". The determination of the stage is disease-specific, such as cancer, retinopathy of prematurity, kidney diseases, Alzheimer's, or Parkinson disease.
 *
 * http://hl7.org/fhir/ConditionStageComponent
 */
export const ConditionStageComponent = 'http://hl7.org/fhir/ConditionStageComponent' satisfies OwlClass;

/**
 * ResearchSubjectProgressComponent
 *
 * ResearchSubjectProgressComponent: The current state (status) of the subject and resons for status change where appropriate.
 *
 * http://hl7.org/fhir/ResearchSubjectProgressComponent
 */
export const ResearchSubjectProgressComponent = 'http://hl7.org/fhir/ResearchSubjectProgressComponent' satisfies OwlClass;

/**
 * key
 *
 * ExampleScenario.instance.key: A unique string within the scenario that is used to reference the instance.
 *
 * http://hl7.org/fhir/key
 */
export const key = 'http://hl7.org/fhir/key' satisfies OwlObjectProperty;

/**
 * assertion
 *
 * TestPlan.testCase.assertion: The test assertions - the expectations of test results from the execution of the test case.
 *
 * http://hl7.org/fhir/assertion
 */
export const assertion = 'http://hl7.org/fhir/assertion' satisfies OwlObjectProperty;

/**
 * MedicationKnowledgeIndicationGuidelineDosingGuidelinePatientCharacteristicComponent
 *
 * MedicationKnowledgeIndicationGuidelineComponent.MedicationKnowledgeIndicationGuidelineDosingGuidelineComponent.MedicationKnowledgeIndicationGuidelineDosingGuidelinePatientCharacteristicComponent: Characteristics of the patient that are relevant to the administration guidelines (for example, height, weight, gender, etc.).
 *
 * http://hl7.org/fhir/MedicationKnowledgeIndicationGuidelineDosingGuidelinePatientCharacteristicComponent
 */
export const MedicationKnowledgeIndicationGuidelineDosingGuidelinePatientCharacteristicComponent = 'http://hl7.org/fhir/MedicationKnowledgeIndicationGuidelineDosingGuidelinePatientCharacteristicComponent' satisfies OwlClass;

/**
 * alternative
 *
 * ExampleScenario.process.step.alternative: Indicates an alternative step that can be taken instead of the sub-process, scenario or operation.  E.g. to represent non-happy-path/exceptional/atypical circumstances.
 *
 * http://hl7.org/fhir/alternative
 */
export const alternative = 'http://hl7.org/fhir/alternative' satisfies OwlObjectProperty;

/**
 * plan
 *
 * InsurancePlan.plan: Details about an insurance plan.
 *
 * http://hl7.org/fhir/plan
 */
export const plan = 'http://hl7.org/fhir/plan' satisfies OwlObjectProperty;

/**
 * _criteria
 *
 * (Modified) Measure.supplementalData.criteria
 *
 * http://hl7.org/fhir/_criteria
 */
export const _criteria = 'http://hl7.org/fhir/_criteria' satisfies OwlObjectProperty;

/**
 * cycle
 *
 * Device.cycle: The series of occurrences that repeats during the operation of the device.
 *
 * http://hl7.org/fhir/cycle
 */
export const cycle = 'http://hl7.org/fhir/cycle' satisfies OwlObjectProperty;

/**
 * _latitude
 *
 * (Modified) Location.position.latitude
 *
 * http://hl7.org/fhir/_latitude
 */
export const _latitude = 'http://hl7.org/fhir/_latitude' satisfies OwlObjectProperty;

/**
 * modifier
 *
 * SubscriptionTopic.canFilterBy.modifier: Modifiers allowed for the filter parameter.
 *
 * http://hl7.org/fhir/modifier
 */
export const modifier = 'http://hl7.org/fhir/modifier' satisfies OwlObjectProperty;

/**
 * _scoringUnit
 *
 * (Modified) Measure.group.scoringUnit
 *
 * http://hl7.org/fhir/_scoringUnit
 */
export const _scoringUnit = 'http://hl7.org/fhir/_scoringUnit' satisfies OwlObjectProperty;

/**
 * subJurisdiction
 *
 * DeviceDefinition.packaging.packaging.udiDeviceIdentifier.marketDistribution.subJurisdiction: National state or territory to which the marketDistribution recers, typically where the device is commercialized.
 *
 * http://hl7.org/fhir/subJurisdiction
 */
export const subJurisdiction = 'http://hl7.org/fhir/subJurisdiction' satisfies OwlObjectProperty;

/**
 * _search
 *
 * (Modified) CompartmentDefinition.search
 *
 * http://hl7.org/fhir/_search
 */
export const _search = 'http://hl7.org/fhir/_search' satisfies OwlObjectProperty;

/**
 * assignedComparisonGroup
 *
 * ResearchSubject.assignedComparisonGroup: The name of the arm in the study the subject is expected to follow as part of this study.
 *
 * http://hl7.org/fhir/assignedComparisonGroup
 */
export const assignedComparisonGroup = 'http://hl7.org/fhir/assignedComparisonGroup' satisfies OwlObjectProperty;

/**
 * _alias
 *
 * (Modified) StructureMap.structure.alias
 *
 * http://hl7.org/fhir/_alias
 */
export const _alias = 'http://hl7.org/fhir/_alias' satisfies OwlObjectProperty;

/**
 * _status
 *
 * (Modified) ActorDefinition.status
 *
 * http://hl7.org/fhir/_status
 */
export const _status = 'http://hl7.org/fhir/_status' satisfies OwlObjectProperty;

/**
 * recurring
 *
 * AppointmentResponse.recurring: Indicates that this AppointmentResponse applies to all occurrences in a recurring request.
 *
 * http://hl7.org/fhir/recurring
 */
export const recurring = 'http://hl7.org/fhir/recurring' satisfies OwlObjectProperty;

/**
 * InventoryItemInstanceComponent
 *
 * InventoryItemInstanceComponent: Instances or occurrences of the product.
 *
 * http://hl7.org/fhir/InventoryItemInstanceComponent
 */
export const InventoryItemInstanceComponent = 'http://hl7.org/fhir/InventoryItemInstanceComponent' satisfies OwlClass;

/**
 * frameOfReferenceUid
 *
 * ImagingSelection.frameOfReferenceUid: The Frame of Reference UID identifying the coordinate system that conveys spatial and/or temporal information for the selected images or frames.
 *
 * http://hl7.org/fhir/frameOfReferenceUid
 */
export const frameOfReferenceUid = 'http://hl7.org/fhir/frameOfReferenceUid' satisfies OwlObjectProperty;

/**
 * _validationDate
 *
 * (Modified) VerificationResult.primarySource.validationDate
 *
 * http://hl7.org/fhir/_validationDate
 */
export const _validationDate = 'http://hl7.org/fhir/_validationDate' satisfies OwlObjectProperty;

/**
 * NutritionOrderEnteralFormulaComponent
 *
 * NutritionOrderEnteralFormulaComponent: Feeding provided through the gastrointestinal tract via a tube, catheter, or stoma that delivers nutrition distal to the oral cavity.
 *
 * http://hl7.org/fhir/NutritionOrderEnteralFormulaComponent
 */
export const NutritionOrderEnteralFormulaComponent = 'http://hl7.org/fhir/NutritionOrderEnteralFormulaComponent' satisfies OwlClass;

/**
 * deliveryDevice
 *
 * NutritionOrder.enteralFormula.deliveryDevice: The intended type of device that is to be used for the administration of the enteral formula.
 *
 * http://hl7.org/fhir/deliveryDevice
 */
export const deliveryDevice = 'http://hl7.org/fhir/deliveryDevice' satisfies OwlObjectProperty;

/**
 * _cardBrand
 *
 * (Modified) PaymentReconciliation.cardBrand
 *
 * http://hl7.org/fhir/_cardBrand
 */
export const _cardBrand = 'http://hl7.org/fhir/_cardBrand' satisfies OwlObjectProperty;

/**
 * adjustment
 *
 * ExplanationOfBenefit.payment.adjustment: Total amount of all adjustments to this payment included in this transaction which are not related to this claim's adjudication.
 *
 * http://hl7.org/fhir/adjustment
 */
export const adjustment = 'http://hl7.org/fhir/adjustment' satisfies OwlObjectProperty;

/**
 * _cors
 *
 * (Modified) CapabilityStatement.rest.security.cors
 *
 * http://hl7.org/fhir/_cors
 */
export const _cors = 'http://hl7.org/fhir/_cors' satisfies OwlObjectProperty;

/**
 * _allergenicIndicator
 *
 * (Modified) Ingredient.allergenicIndicator
 *
 * http://hl7.org/fhir/_allergenicIndicator
 */
export const _allergenicIndicator = 'http://hl7.org/fhir/_allergenicIndicator' satisfies OwlObjectProperty;

/**
 * _timezone
 *
 * (Modified) Appointment.recurrenceTemplate.timezone
 *
 * http://hl7.org/fhir/_timezone
 */
export const _timezone = 'http://hl7.org/fhir/_timezone' satisfies OwlObjectProperty;

/**
 * _actor
 *
 * (Modified) Consent.provision.actor
 *
 * http://hl7.org/fhir/_actor
 */
export const _actor = 'http://hl7.org/fhir/_actor' satisfies OwlObjectProperty;

/**
 * valueQuantity
 *
 * Evidence.statistic.modelCharacteristic.variable.valueQuantity: Discrete value for grouping of ordinal or polychotomous variables.
 *
 * http://hl7.org/fhir/valueQuantity
 */
export const valueQuantity = 'http://hl7.org/fhir/valueQuantity' satisfies OwlObjectProperty;

/**
 * _versionId
 *
 * (Modified) Meta.versionId
 *
 * http://hl7.org/fhir/_versionId
 */
export const _versionId = 'http://hl7.org/fhir/_versionId' satisfies OwlObjectProperty;

/**
 * requester
 *
 * SupplyRequest.requester: The device, practitioner, etc. who initiated the request.
 *
 * http://hl7.org/fhir/requester
 */
export const requester = 'http://hl7.org/fhir/requester' satisfies OwlObjectProperty;

/**
 * _SupplyRequest
 *
 * (Modified) SupplyRequest
 *
 * http://hl7.org/fhir/_SupplyRequest
 */
export const _SupplyRequest = 'http://hl7.org/fhir/_SupplyRequest' satisfies OwlClass;

/**
 * MeasureTermComponent
 *
 * MeasureTermComponent: Provides a description of an individual term used within the measure.
 *
 * http://hl7.org/fhir/MeasureTermComponent
 */
export const MeasureTermComponent = 'http://hl7.org/fhir/MeasureTermComponent' satisfies OwlClass;

/**
 * _containedItemQuantity
 *
 * (Modified) PackagedProductDefinition.containedItemQuantity
 *
 * http://hl7.org/fhir/_containedItemQuantity
 */
export const _containedItemQuantity = 'http://hl7.org/fhir/_containedItemQuantity' satisfies OwlObjectProperty;

/**
 * _daysSupply
 *
 * (Modified) MedicationDispense.daysSupply
 *
 * http://hl7.org/fhir/_daysSupply
 */
export const _daysSupply = 'http://hl7.org/fhir/_daysSupply' satisfies OwlObjectProperty;

/**
 * reportingVendor
 *
 * MeasureReport.reportingVendor: A reference to the vendor who queried the data, calculated results and/or generated the report. The ‘reporting vendor’ is intended to represent the submitting entity when it is not the same as the reporting entity. This extension is used when the Receiver is interested in getting vendor information in the report.
 *
 * http://hl7.org/fhir/reportingVendor
 */
export const reportingVendor = 'http://hl7.org/fhir/reportingVendor' satisfies OwlObjectProperty;

/**
 * current
 *
 * SubscriptionTopic.resourceTrigger.queryCriteria.current: The FHIR query based rules are applied to the current resource state (e.g., state after an update).
 *
 * http://hl7.org/fhir/current
 */
export const current = 'http://hl7.org/fhir/current' satisfies OwlObjectProperty;

/**
 * uid
 *
 * ImagingStudy.series.instance.uid: The DICOM SOP Instance UID for this image or other DICOM content.
 *
 * http://hl7.org/fhir/uid
 */
export const uid = 'http://hl7.org/fhir/uid' satisfies OwlObjectProperty;

/**
 * order
 *
 * SubstanceSourceMaterial.organism.organismGeneral.order: The order of an organism shall be specified,.
 *
 * http://hl7.org/fhir/order
 */
export const order = 'http://hl7.org/fhir/order' satisfies OwlObjectProperty;

/**
 * priorPrescription
 *
 * MedicationRequest.priorPrescription: Reference to an order/prescription that is being replaced by this MedicationRequest.
 *
 * http://hl7.org/fhir/priorPrescription
 */
export const priorPrescription = 'http://hl7.org/fhir/priorPrescription' satisfies OwlObjectProperty;

/**
 * distanceFromLandmark
 *
 * BodyStructure.excludedStructure.bodyLandmarkOrientation.distanceFromLandmark: The distance in centimeters a certain observation is made from a body landmark.
 *
 * http://hl7.org/fhir/distanceFromLandmark
 */
export const distanceFromLandmark = 'http://hl7.org/fhir/distanceFromLandmark' satisfies OwlObjectProperty;

/**
 * VerificationResultValidatorComponent
 *
 * VerificationResultValidatorComponent: Information about the entity validating information.
 *
 * http://hl7.org/fhir/VerificationResultValidatorComponent
 */
export const VerificationResultValidatorComponent = 'http://hl7.org/fhir/VerificationResultValidatorComponent' satisfies OwlClass;

/**
 * _recurrenceTemplate
 *
 * (Modified) Appointment.recurrenceTemplate
 *
 * http://hl7.org/fhir/_recurrenceTemplate
 */
export const _recurrenceTemplate = 'http://hl7.org/fhir/_recurrenceTemplate' satisfies OwlObjectProperty;

/**
 * tenderedAmount
 *
 * PaymentReconciliation.tenderedAmount: The amount offered by the issuer, typically applies to cash when the issuer provides an amount in bank note denominations equal to or excess of the amount actually being paid.
 *
 * http://hl7.org/fhir/tenderedAmount
 */
export const tenderedAmount = 'http://hl7.org/fhir/tenderedAmount' satisfies OwlObjectProperty;

/**
 * _diseaseStatus
 *
 * (Modified) ClinicalUseDefinition.indication.diseaseStatus
 *
 * http://hl7.org/fhir/_diseaseStatus
 */
export const _diseaseStatus = 'http://hl7.org/fhir/_diseaseStatus' satisfies OwlObjectProperty;

/**
 * _expirationDate
 *
 * (Modified) PaymentReconciliation.expirationDate
 *
 * http://hl7.org/fhir/_expirationDate
 */
export const _expirationDate = 'http://hl7.org/fhir/_expirationDate' satisfies OwlObjectProperty;

/**
 * _dataPeriod
 *
 * (Modified) Consent.provision.provision.dataPeriod
 *
 * http://hl7.org/fhir/_dataPeriod
 */
export const _dataPeriod = 'http://hl7.org/fhir/_dataPeriod' satisfies OwlObjectProperty;

/**
 * note
 *
 * GenomicStudy.note: Comments related to the genomic study.
 *
 * http://hl7.org/fhir/note
 */
export const note = 'http://hl7.org/fhir/note' satisfies OwlObjectProperty;

/**
 * _manipulated
 *
 * (Modified) Procedure.focalDevice.manipulated
 *
 * http://hl7.org/fhir/_manipulated
 */
export const _manipulated = 'http://hl7.org/fhir/_manipulated' satisfies OwlObjectProperty;

/**
 * _Invoice
 *
 * (Modified) Invoice
 *
 * http://hl7.org/fhir/_Invoice
 */
export const _Invoice = 'http://hl7.org/fhir/_Invoice' satisfies OwlClass;

/**
 * RatioRange
 *
 * A range of ratios expressed as a low and high numerator and a denominator.
 *
 * http://hl7.org/fhir/RatioRange
 */
export const RatioRange = 'http://hl7.org/fhir/RatioRange' satisfies OwlClass;

/**
 * _requisition
 *
 * (Modified) ServiceRequest.requisition
 *
 * http://hl7.org/fhir/_requisition
 */
export const _requisition = 'http://hl7.org/fhir/_requisition' satisfies OwlObjectProperty;

/**
 * ClinicalImpression
 *
 * A record of a clinical assessment performed to determine what problem(s) may affect the patient and before planning the treatments or management strategies that are best to manage a patient's condition. Assessments are often 1:1 with a clinical consultation / encounter,  but this varies greatly depending on the clinical workflow. This resource is called "ClinicalImpression" rather than "ClinicalAssessment" to avoid confusion with the recording of assessment tools such as Apgar score.
 *
 * http://hl7.org/fhir/ClinicalImpression
 */
export const ClinicalImpression = 'http://hl7.org/fhir/ClinicalImpression' satisfies OwlClass;

/**
 * _claim
 *
 * (Modified) ExplanationOfBenefit.claim
 *
 * http://hl7.org/fhir/_claim
 */
export const _claim = 'http://hl7.org/fhir/_claim' satisfies OwlObjectProperty;

/**
 * need
 *
 * VerificationResult.need: The frequency with which the target must be validated (none; initial; periodic).
 *
 * http://hl7.org/fhir/need
 */
export const need = 'http://hl7.org/fhir/need' satisfies OwlObjectProperty;

/**
 * contributor
 *
 * Citation.citedArtifact.contributorship.entry.contributor: The identity of the individual contributor.
 *
 * http://hl7.org/fhir/contributor
 */
export const contributor = 'http://hl7.org/fhir/contributor' satisfies OwlObjectProperty;

/**
 * ConceptProperty
 *
 * ValueSetExpansionComponent.ValueSetExpansionContainsComponent.ConceptProperty: A property value for this concept.
 *
 * http://hl7.org/fhir/ConceptProperty
 */
export const ConceptProperty = 'http://hl7.org/fhir/ConceptProperty' satisfies OwlClass;

/**
 * ConsentVerificationComponent
 *
 * ConsentVerificationComponent: Whether a treatment instruction (e.g. artificial respiration: yes or no) was verified with the patient, his/her family or another authorized person.
 *
 * http://hl7.org/fhir/ConsentVerificationComponent
 */
export const ConsentVerificationComponent = 'http://hl7.org/fhir/ConsentVerificationComponent' satisfies OwlClass;

/**
 * TestReportTeardownComponent
 *
 * TestReportTeardownComponent: The results of the series of operations required to clean up after all the tests were executed (successfully or otherwise).
 *
 * http://hl7.org/fhir/TestReportTeardownComponent
 */
export const TestReportTeardownComponent = 'http://hl7.org/fhir/TestReportTeardownComponent' satisfies OwlClass;

/**
 * _genus
 *
 * (Modified) SubstanceSourceMaterial.organism.genus
 *
 * http://hl7.org/fhir/_genus
 */
export const _genus = 'http://hl7.org/fhir/_genus' satisfies OwlObjectProperty;

/**
 * extraDetails
 *
 * HealthcareService.extraDetails: Extra details about the service that can't be placed in the other fields.
 *
 * http://hl7.org/fhir/extraDetails
 */
export const extraDetails = 'http://hl7.org/fhir/extraDetails' satisfies OwlObjectProperty;

/**
 * _location
 *
 * (Modified) InventoryItem.instance.location
 *
 * http://hl7.org/fhir/_location
 */
export const _location = 'http://hl7.org/fhir/_location' satisfies OwlObjectProperty;

/**
 * _reported
 *
 * (Modified) Procedure.reported
 *
 * http://hl7.org/fhir/_reported
 */
export const _reported = 'http://hl7.org/fhir/_reported' satisfies OwlObjectProperty;

/**
 * _codeMap
 *
 * (Modified) SampledData.codeMap
 *
 * http://hl7.org/fhir/_codeMap
 */
export const _codeMap = 'http://hl7.org/fhir/_codeMap' satisfies OwlObjectProperty;

/**
 * firstPage
 *
 * Citation.citedArtifact.publicationForm.firstPage: Used for isolated representation of first page.
 *
 * http://hl7.org/fhir/firstPage
 */
export const firstPage = 'http://hl7.org/fhir/firstPage' satisfies OwlObjectProperty;

/**
 * _setup
 *
 * (Modified) TestScript.setup
 *
 * http://hl7.org/fhir/_setup
 */
export const _setup = 'http://hl7.org/fhir/_setup' satisfies OwlObjectProperty;

/**
 * _paymentBy
 *
 * (Modified) Coverage.paymentBy
 *
 * http://hl7.org/fhir/_paymentBy
 */
export const _paymentBy = 'http://hl7.org/fhir/_paymentBy' satisfies OwlObjectProperty;

/**
 * custodian
 *
 * DocumentReference.custodian: Identifies the organization or group who is responsible for ongoing maintenance of and access to the document.
 *
 * http://hl7.org/fhir/custodian
 */
export const custodian = 'http://hl7.org/fhir/custodian' satisfies OwlObjectProperty;

/**
 * estimatedAge
 *
 * FamilyMemberHistory.estimatedAge: If true, indicates that the age value specified is an estimated value.
 *
 * http://hl7.org/fhir/estimatedAge
 */
export const estimatedAge = 'http://hl7.org/fhir/estimatedAge' satisfies OwlObjectProperty;

/**
 * _observation
 *
 * (Modified) Observation.triggeredBy.observation
 *
 * http://hl7.org/fhir/_observation
 */
export const _observation = 'http://hl7.org/fhir/_observation' satisfies OwlObjectProperty;

/**
 * technique
 *
 * SubstanceDefinition.structure.technique: The method used to elucidate the structure of the drug substance. Examples: X-ray, NMR, Peptide mapping, Ligand binding assay.
 *
 * http://hl7.org/fhir/technique
 */
export const technique = 'http://hl7.org/fhir/technique' satisfies OwlObjectProperty;

/**
 * Requirements
 *
 * The Requirements resource is used to describe an actor - a human or an application that plays a role in data exchange, and that may have obligations associated with the role the actor plays.
 *
 * http://hl7.org/fhir/Requirements
 */
export const Requirements = 'http://hl7.org/fhir/Requirements' satisfies OwlClass;

/**
 * supplementalData
 *
 * MeasureReport.supplementalData: A reference to a Resource that represents additional information collected for the report. If the value of the supplemental data is not a Resource (i.e. evaluating the supplementalData expression for this case in the measure results in a value that is not a FHIR Resource), it is reported as a reference to a contained Observation resource.
 *
 * http://hl7.org/fhir/supplementalData
 */
export const supplementalData = 'http://hl7.org/fhir/supplementalData' satisfies OwlObjectProperty;

/**
 * SimpleQuantity
 *
 * The comparator is not used on a SimpleQuantity
 *
 * http://hl7.org/fhir/SimpleQuantity
 */
export const SimpleQuantity = 'http://hl7.org/fhir/SimpleQuantity' satisfies OwlClass;

/**
 * ProvenanceEntityComponent
 *
 * ProvenanceEntityComponent: An entity used in this activity.
 *
 * http://hl7.org/fhir/ProvenanceEntityComponent
 */
export const ProvenanceEntityComponent = 'http://hl7.org/fhir/ProvenanceEntityComponent' satisfies OwlClass;

/**
 * condition
 *
 * ObservationDefinition.component.qualifiedValue.condition: Text based condition for which the the set of qualified values is valid.
 *
 * http://hl7.org/fhir/condition
 */
export const condition = 'http://hl7.org/fhir/condition' satisfies OwlObjectProperty;

/**
 * excludeFoodModifier
 *
 * NutritionOrder.excludeFoodModifier: This modifier is used to convey Order-specific modifier about the type of oral food or oral fluids that should not be given. These can be derived from patient allergies, intolerances, or preferences such as No Red Meat, No Soy or No Wheat or  Gluten-Free.  While it should not be necessary to repeat allergy or intolerance information captured in the referenced AllergyIntolerance resource in the excludeFoodModifier, this element may be used to convey additional specificity related to foods that should be eliminated from the patient’s diet for any reason.  This modifier applies to the entire nutrition order inclusive of the oral diet, nutritional supplements and enteral formula feedings.
 *
 * http://hl7.org/fhir/excludeFoodModifier
 */
export const excludeFoodModifier = 'http://hl7.org/fhir/excludeFoodModifier' satisfies OwlObjectProperty;

/**
 * coverageArea
 *
 * InsurancePlan.plan.coverageArea: The geographic region in which a health insurance plan's benefits apply.
 *
 * http://hl7.org/fhir/coverageArea
 */
export const coverageArea = 'http://hl7.org/fhir/coverageArea' satisfies OwlObjectProperty;

/**
 * contributionInstance
 *
 * Citation.citedArtifact.contributorship.entry.contributionInstance: Contributions with accounting for time or number.
 *
 * http://hl7.org/fhir/contributionInstance
 */
export const contributionInstance = 'http://hl7.org/fhir/contributionInstance' satisfies OwlObjectProperty;

/**
 * _productCode
 *
 * (Modified) BiologicallyDerivedProduct.productCode
 *
 * http://hl7.org/fhir/_productCode
 */
export const _productCode = 'http://hl7.org/fhir/_productCode' satisfies OwlObjectProperty;

/**
 * _language
 *
 * (Modified) Attachment.language
 *
 * http://hl7.org/fhir/_language
 */
export const _language = 'http://hl7.org/fhir/_language' satisfies OwlObjectProperty;

/**
 * base
 *
 * VisionPrescription.lensSpecification.prism.base: The relative base, or reference lens edge, for the prism.
 *
 * http://hl7.org/fhir/base
 */
export const base = 'http://hl7.org/fhir/base' satisfies OwlObjectProperty;

/**
 * _windowStart
 *
 * (Modified) MolecularSequence.relative.startingSequence.windowStart
 *
 * http://hl7.org/fhir/_windowStart
 */
export const _windowStart = 'http://hl7.org/fhir/_windowStart' satisfies OwlObjectProperty;

/**
 * district
 *
 * Address.district: The name of the administrative area (county).
 *
 * http://hl7.org/fhir/district
 */
export const district = 'http://hl7.org/fhir/district' satisfies OwlObjectProperty;

/**
 * forenameInitials
 *
 * Citation.citedArtifact.contributorship.entry.forenameInitials: For citation styles that use initials.
 *
 * http://hl7.org/fhir/forenameInitials
 */
export const forenameInitials = 'http://hl7.org/fhir/forenameInitials' satisfies OwlObjectProperty;

/**
 * _state
 *
 * (Modified) ResearchStudy.progressStatus.state
 *
 * http://hl7.org/fhir/_state
 */
export const _state = 'http://hl7.org/fhir/_state' satisfies OwlObjectProperty;

/**
 * friendly
 *
 * Contract.friendly: The "patient friendly language" versionof the Contract in whole or in parts. "Patient friendly language" means the representation of the Contract and Contract Provisions in a manner that is readily accessible and understandable by a layperson in accordance with best practices for communication styles that ensure that those agreeing to or signing the Contract understand the roles, actions, obligations, responsibilities, and implication of the agreement.
 *
 * http://hl7.org/fhir/friendly
 */
export const friendly = 'http://hl7.org/fhir/friendly' satisfies OwlObjectProperty;

/**
 * AdditionalAttribute
 *
 * ConceptMap.AdditionalAttribute: An additionalAttribute defines an additional data element found in the source or target data model where the data will come from or be mapped to. Some mappings are based on data in addition to the source data element, where codes in multiple fields are combined to a single field (or vice versa).
 *
 * http://hl7.org/fhir/AdditionalAttribute
 */
export const AdditionalAttribute = 'http://hl7.org/fhir/AdditionalAttribute' satisfies OwlClass;

/**
 * _Transport
 *
 * (Modified) Transport
 *
 * http://hl7.org/fhir/_Transport
 */
export const _Transport = 'http://hl7.org/fhir/_Transport' satisfies OwlClass;

/**
 * xhtml
 *
 * http://hl7.org/fhir/xhtml
 */
export const xhtml = 'http://hl7.org/fhir/xhtml' satisfies OwlClass;

/**
 * _official
 *
 * (Modified) SubstanceDefinition.name.official
 *
 * http://hl7.org/fhir/_official
 */
export const _official = 'http://hl7.org/fhir/_official' satisfies OwlObjectProperty;

/**
 * CodeSystemConceptDesignationComponent
 *
 * CodeSystem.ConceptDefinition.CodeSystemConceptDesignationComponent: Additional representations for the concept - other languages, aliases, specialized purposes, used for particular purposes, etc.
 *
 * http://hl7.org/fhir/CodeSystemConceptDesignationComponent
 */
export const CodeSystemConceptDesignationComponent = 'http://hl7.org/fhir/CodeSystemConceptDesignationComponent' satisfies OwlClass;

/**
 * _precedence
 *
 * (Modified) ExplanationOfBenefit.precedence
 *
 * http://hl7.org/fhir/_precedence
 */
export const _precedence = 'http://hl7.org/fhir/_precedence' satisfies OwlObjectProperty;

/**
 * _result
 *
 * (Modified) TestPlan.testCase.assertion.result
 *
 * http://hl7.org/fhir/_result
 */
export const _result = 'http://hl7.org/fhir/_result' satisfies OwlObjectProperty;

/**
 * _sliceName
 *
 * (Modified) GraphDefinition.link.sliceName
 *
 * http://hl7.org/fhir/_sliceName
 */
export const _sliceName = 'http://hl7.org/fhir/_sliceName' satisfies OwlObjectProperty;

/**
 * points
 *
 * Contract.term.group.asset.valuedItem.points: An amount that expresses the weighting (based on difficulty, cost and/or resource intensiveness) associated with the Contract Valued Item delivered. The concept of Points allows for assignment of point values for a Contract Valued Item, such that a monetary amount can be assigned to each point.
 *
 * http://hl7.org/fhir/points
 */
export const points = 'http://hl7.org/fhir/points' satisfies OwlObjectProperty;

/**
 * finding
 *
 * ClinicalImpression.finding: Specific findings or diagnoses that were considered likely or relevant to ongoing treatment.
 *
 * http://hl7.org/fhir/finding
 */
export const finding = 'http://hl7.org/fhir/finding' satisfies OwlObjectProperty;

/**
 * _yearlyTemplate
 *
 * (Modified) Appointment.recurrenceTemplate.yearlyTemplate
 *
 * http://hl7.org/fhir/_yearlyTemplate
 */
export const _yearlyTemplate = 'http://hl7.org/fhir/_yearlyTemplate' satisfies OwlObjectProperty;

/**
 * _isModifierReason
 *
 * (Modified) ElementDefinition.isModifierReason
 *
 * http://hl7.org/fhir/_isModifierReason
 */
export const _isModifierReason = 'http://hl7.org/fhir/_isModifierReason' satisfies OwlObjectProperty;

/**
 * _experimental
 *
 * (Modified) StructureDefinition.experimental
 *
 * http://hl7.org/fhir/_experimental
 */
export const _experimental = 'http://hl7.org/fhir/_experimental' satisfies OwlObjectProperty;

/**
 * _overbooked
 *
 * (Modified) Slot.overbooked
 *
 * http://hl7.org/fhir/_overbooked
 */
export const _overbooked = 'http://hl7.org/fhir/_overbooked' satisfies OwlObjectProperty;

/**
 * ExampleScenario
 *
 * A walkthrough of a workflow showing the interaction between systems and the instances shared, possibly including the evolution of instances over time.
 *
 * http://hl7.org/fhir/ExampleScenario
 */
export const ExampleScenario = 'http://hl7.org/fhir/ExampleScenario' satisfies OwlClass;

/**
 * AvailabilityNotAvailableTimeComponent
 *
 * AvailabilityNotAvailableTimeComponent: Not available during this time due to provided reason.
 *
 * http://hl7.org/fhir/AvailabilityNotAvailableTimeComponent
 */
export const AvailabilityNotAvailableTimeComponent = 'http://hl7.org/fhir/AvailabilityNotAvailableTimeComponent' satisfies OwlClass;

/**
 * derivedFrom
 *
 * DeviceUsage.derivedFrom: Allows linking the DeviceUsage to the underlying Request, or to other information that supports or is used to derive the DeviceUsage.
 *
 * http://hl7.org/fhir/derivedFrom
 */
export const derivedFrom = 'http://hl7.org/fhir/derivedFrom' satisfies OwlObjectProperty;

/**
 * _postalCode
 *
 * (Modified) Address.postalCode
 *
 * http://hl7.org/fhir/_postalCode
 */
export const _postalCode = 'http://hl7.org/fhir/_postalCode' satisfies OwlObjectProperty;

/**
 * _endorser
 *
 * (Modified) EvidenceVariable.endorser
 *
 * http://hl7.org/fhir/_endorser
 */
export const _endorser = 'http://hl7.org/fhir/_endorser' satisfies OwlObjectProperty;

/**
 * modifierExtension
 *
 * DomainResource.modifierExtension: May be used to represent additional information that is not part of the basic definition of the resource and that modifies the understanding of the element that contains it and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and managable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer is allowed to define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.
 * 
 * Modifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself).
 *
 * http://hl7.org/fhir/modifierExtension
 */
export const modifierExtension = 'http://hl7.org/fhir/modifierExtension' satisfies OwlObjectProperty;

/**
 * verified
 *
 * Consent.verification.verified: Has the instruction been verified.
 *
 * http://hl7.org/fhir/verified
 */
export const verified = 'http://hl7.org/fhir/verified' satisfies OwlObjectProperty;

/**
 * warning
 *
 * DeviceDefinition.guideline.warning: Specific hazard alert information that a user needs to know before using the device.
 *
 * http://hl7.org/fhir/warning
 */
export const warning = 'http://hl7.org/fhir/warning' satisfies OwlObjectProperty;

/**
 * _color
 *
 * (Modified) VisionPrescription.lensSpecification.color
 *
 * http://hl7.org/fhir/_color
 */
export const _color = 'http://hl7.org/fhir/_color' satisfies OwlObjectProperty;

/**
 * _global
 *
 * (Modified) ImplementationGuide.global
 *
 * http://hl7.org/fhir/_global
 */
export const _global = 'http://hl7.org/fhir/_global' satisfies OwlObjectProperty;

/**
 * _policyBasis
 *
 * (Modified) Consent.policyBasis
 *
 * http://hl7.org/fhir/_policyBasis
 */
export const _policyBasis = 'http://hl7.org/fhir/_policyBasis' satisfies OwlObjectProperty;

/**
 * timeFromEvent
 *
 * EvidenceVariable.characteristic.timeFromEvent: Timing in which the characteristic is determined.
 *
 * http://hl7.org/fhir/timeFromEvent
 */
export const timeFromEvent = 'http://hl7.org/fhir/timeFromEvent' satisfies OwlObjectProperty;

/**
 * costToBeneficiary
 *
 * Coverage.costToBeneficiary: A suite of codes indicating the cost category and associated amount which have been detailed in the policy and may have been  included on the health card.
 *
 * http://hl7.org/fhir/costToBeneficiary
 */
export const costToBeneficiary = 'http://hl7.org/fhir/costToBeneficiary' satisfies OwlObjectProperty;

/**
 * Questionnaire
 *
 * A structured set of questions intended to guide the collection of answers from end-users. Questionnaires provide detailed control over order, presentation, phraseology and grouping to allow coherent, consistent data collection.
 *
 * http://hl7.org/fhir/Questionnaire
 */
export const Questionnaire = 'http://hl7.org/fhir/Questionnaire' satisfies OwlClass;

/**
 * _FormularyItem
 *
 * (Modified) FormularyItem
 *
 * http://hl7.org/fhir/_FormularyItem
 */
export const _FormularyItem = 'http://hl7.org/fhir/_FormularyItem' satisfies OwlClass;

/**
 * _permittedUnit
 *
 * (Modified) ObservationDefinition.component.permittedUnit
 *
 * http://hl7.org/fhir/_permittedUnit
 */
export const _permittedUnit = 'http://hl7.org/fhir/_permittedUnit' satisfies OwlObjectProperty;

/**
 * data
 *
 * Signature.data: The base64 encoding of the Signature content. When signature is not recorded electronically this element would be empty.
 *
 * http://hl7.org/fhir/data
 */
export const data = 'http://hl7.org/fhir/data' satisfies OwlObjectProperty;

/**
 * _targetItem
 *
 * (Modified) PaymentReconciliation.allocation.targetItem
 *
 * http://hl7.org/fhir/_targetItem
 */
export const _targetItem = 'http://hl7.org/fhir/_targetItem' satisfies OwlObjectProperty;

/**
 * whyStopped
 *
 * ResearchStudy.whyStopped: A description and/or code explaining the premature termination of the study.
 *
 * http://hl7.org/fhir/whyStopped
 */
export const whyStopped = 'http://hl7.org/fhir/whyStopped' satisfies OwlObjectProperty;

/**
 * _practitioner
 *
 * (Modified) PractitionerRole.practitioner
 *
 * http://hl7.org/fhir/_practitioner
 */
export const _practitioner = 'http://hl7.org/fhir/_practitioner' satisfies OwlObjectProperty;

/**
 * packageFor
 *
 * PackagedProductDefinition.packageFor: The product this package model relates to, not the contents of the package (for which see package.containedItem).
 *
 * http://hl7.org/fhir/packageFor
 */
export const packageFor = 'http://hl7.org/fhir/packageFor' satisfies OwlObjectProperty;

/**
 * _informationSource
 *
 * (Modified) SubstanceDefinition.informationSource
 *
 * http://hl7.org/fhir/_informationSource
 */
export const _informationSource = 'http://hl7.org/fhir/_informationSource' satisfies OwlObjectProperty;

/**
 * hasMember
 *
 * ObservationDefinition.hasMember: This ObservationDefinition defines a group  observation (e.g. a battery, a panel of tests, a set of vital sign measurements) that includes the target as a member of the group.
 *
 * http://hl7.org/fhir/hasMember
 */
export const hasMember = 'http://hl7.org/fhir/hasMember' satisfies OwlObjectProperty;

/**
 * _paymentIdentifier
 *
 * (Modified) PaymentReconciliation.paymentIdentifier
 *
 * http://hl7.org/fhir/_paymentIdentifier
 */
export const _paymentIdentifier = 'http://hl7.org/fhir/_paymentIdentifier' satisfies OwlObjectProperty;

/**
 * allowedType
 *
 * OperationDefinition.parameter.part.allowedType: Support for polymorphic types. If the parameter type is abstract, this element lists allowed sub-types for the parameter.
 *
 * http://hl7.org/fhir/allowedType
 */
export const allowedType = 'http://hl7.org/fhir/allowedType' satisfies OwlObjectProperty;

/**
 * _intraspecificType
 *
 * (Modified) SubstanceSourceMaterial.organism.intraspecificType
 *
 * http://hl7.org/fhir/_intraspecificType
 */
export const _intraspecificType = 'http://hl7.org/fhir/_intraspecificType' satisfies OwlObjectProperty;

/**
 * _isDefault
 *
 * (Modified) TerminologyCapabilities.codeSystem.version.isDefault
 *
 * http://hl7.org/fhir/_isDefault
 */
export const _isDefault = 'http://hl7.org/fhir/_isDefault' satisfies OwlObjectProperty;

/**
 * _supportedProfile
 *
 * (Modified) CapabilityStatement.rest.resource.supportedProfile
 *
 * http://hl7.org/fhir/_supportedProfile
 */
export const _supportedProfile = 'http://hl7.org/fhir/_supportedProfile' satisfies OwlObjectProperty;

/**
 * _authored
 *
 * (Modified) QuestionnaireResponse.authored
 *
 * http://hl7.org/fhir/_authored
 */
export const _authored = 'http://hl7.org/fhir/_authored' satisfies OwlObjectProperty;

/**
 * stabilityDuration
 *
 * MedicationKnowledge.storageGuideline.stabilityDuration: Duration that the medication remains stable if the environmentalSetting is respected.
 *
 * http://hl7.org/fhir/stabilityDuration
 */
export const stabilityDuration = 'http://hl7.org/fhir/stabilityDuration' satisfies OwlObjectProperty;

/**
 * InsurancePlanCoverageBenefitLimitComponent
 *
 * InsurancePlanCoverageComponent.CoverageBenefit.InsurancePlanCoverageBenefitLimitComponent: The specific limits on the benefit.
 *
 * http://hl7.org/fhir/InsurancePlanCoverageBenefitLimitComponent
 */
export const InsurancePlanCoverageBenefitLimitComponent = 'http://hl7.org/fhir/InsurancePlanCoverageBenefitLimitComponent' satisfies OwlClass;

/**
 * compareToSourcePath
 *
 * TestScript.test.action.assert.compareToSourcePath: XPath or JSONPath expression to evaluate against the source fixture. When compareToSourceId is defined, either compareToSourceExpression or compareToSourcePath must be defined, but not both.
 *
 * http://hl7.org/fhir/compareToSourcePath
 */
export const compareToSourcePath = 'http://hl7.org/fhir/compareToSourcePath' satisfies OwlObjectProperty;

/**
 * _dosageInstruction
 *
 * (Modified) MedicationRequest.dosageInstruction
 *
 * http://hl7.org/fhir/_dosageInstruction
 */
export const _dosageInstruction = 'http://hl7.org/fhir/_dosageInstruction' satisfies OwlObjectProperty;

/**
 * sequence
 *
 * SubstanceNucleicAcid.subunit.sequence: Actual nucleotide sequence notation from 5' to 3' end using standard single letter codes. In addition to the base sequence, sugar and type of phosphate or non-phosphate linkage should also be captured.
 *
 * http://hl7.org/fhir/sequence
 */
export const sequence = 'http://hl7.org/fhir/sequence' satisfies OwlObjectProperty;

/**
 * revenue
 *
 * ExplanationOfBenefit.item.revenue: The type of revenue or cost center providing the product and/or service.
 *
 * http://hl7.org/fhir/revenue
 */
export const revenue = 'http://hl7.org/fhir/revenue' satisfies OwlObjectProperty;

/**
 * SystemInteraction
 *
 * CapabilityStatementRestComponent.SystemInteraction: A specification of restful operations supported by the system.
 *
 * http://hl7.org/fhir/SystemInteraction
 */
export const SystemInteraction = 'http://hl7.org/fhir/SystemInteraction' satisfies OwlClass;

/**
 * SubscriptionFilterByComponent
 *
 * SubscriptionFilterByComponent: The filter properties to be applied to narrow the subscription topic stream.  When multiple filters are applied, evaluates to true if all the conditions applicable to that resource are met; otherwise it returns false (i.e., logical AND).
 *
 * http://hl7.org/fhir/SubscriptionFilterByComponent
 */
export const SubscriptionFilterByComponent = 'http://hl7.org/fhir/SubscriptionFilterByComponent' satisfies OwlClass;

/**
 * _requirement
 *
 * (Modified) TestReport.setup.action.assert.requirement
 *
 * http://hl7.org/fhir/_requirement
 */
export const _requirement = 'http://hl7.org/fhir/_requirement' satisfies OwlObjectProperty;

/**
 * _reliableCache
 *
 * (Modified) CapabilityStatement.messaging.reliableCache
 *
 * http://hl7.org/fhir/_reliableCache
 */
export const _reliableCache = 'http://hl7.org/fhir/_reliableCache' satisfies OwlObjectProperty;

/**
 * nextScheduled
 *
 * VerificationResult.nextScheduled: The date when target is next validated, if appropriate.
 *
 * http://hl7.org/fhir/nextScheduled
 */
export const nextScheduled = 'http://hl7.org/fhir/nextScheduled' satisfies OwlObjectProperty;

/**
 * MeasureGroupComponent
 *
 * MeasureGroupComponent: A group of population criteria for the measure.
 *
 * http://hl7.org/fhir/MeasureGroupComponent
 */
export const MeasureGroupComponent = 'http://hl7.org/fhir/MeasureGroupComponent' satisfies OwlClass;

/**
 * processNote
 *
 * PaymentReconciliation.processNote: A note that describes or explains the processing in a human readable form.
 *
 * http://hl7.org/fhir/processNote
 */
export const processNote = 'http://hl7.org/fhir/processNote' satisfies OwlObjectProperty;

/**
 * StratifierGroupPopulation
 *
 * MeasureReportGroupComponent.MeasureReportGroupStratifierComponent.StratifierGroup.StratifierGroupPopulation: The populations that make up the stratum, one for each type of population appropriate to the measure.
 *
 * http://hl7.org/fhir/StratifierGroupPopulation
 */
export const StratifierGroupPopulation = 'http://hl7.org/fhir/StratifierGroupPopulation' satisfies OwlClass;

/**
 * issuerType
 *
 * PaymentReconciliation.issuerType: The type of the source such as patient or insurance.
 *
 * http://hl7.org/fhir/issuerType
 */
export const issuerType = 'http://hl7.org/fhir/issuerType' satisfies OwlObjectProperty;

/**
 * capacity
 *
 * SpecimenDefinition.typeTested.container.capacity: The capacity (volume or other measure) of this kind of container.
 *
 * http://hl7.org/fhir/capacity
 */
export const capacity = 'http://hl7.org/fhir/capacity' satisfies OwlObjectProperty;

/**
 * _rendering
 *
 * (Modified) ImplementationGuide.manifest.rendering
 *
 * http://hl7.org/fhir/_rendering
 */
export const _rendering = 'http://hl7.org/fhir/_rendering' satisfies OwlObjectProperty;

/**
 * TestScriptTeardownComponent
 *
 * TestScriptTeardownComponent: A series of operations required to clean up after all the tests are executed (successfully or otherwise).
 *
 * http://hl7.org/fhir/TestScriptTeardownComponent
 */
export const TestScriptTeardownComponent = 'http://hl7.org/fhir/TestScriptTeardownComponent' satisfies OwlClass;

/**
 * requestIdentifier
 *
 * GuidanceResponse.requestIdentifier: The identifier of the request associated with this response. If an identifier was given as part of the request, it will be reproduced here to enable the requester to more easily identify the response in a multi-request scenario.
 *
 * http://hl7.org/fhir/requestIdentifier
 */
export const requestIdentifier = 'http://hl7.org/fhir/requestIdentifier' satisfies OwlObjectProperty;

/**
 * _definitionCanonical
 *
 * (Modified) EvidenceVariable.characteristic.definitionByCombination.characteristic.definitionCanonical
 *
 * http://hl7.org/fhir/_definitionCanonical
 */
export const _definitionCanonical = 'http://hl7.org/fhir/_definitionCanonical' satisfies OwlObjectProperty;

/**
 * fhir:v
 *
 * http://hl7.org/fhir/v
 */
export const v = 'http://hl7.org/fhir/v' satisfies OwlDatatypeProperty;

/**
 * _classification
 *
 * (Modified) Citation.classification
 *
 * http://hl7.org/fhir/_classification
 */
export const _classification = 'http://hl7.org/fhir/_classification' satisfies OwlObjectProperty;

/**
 * Claim
 *
 * A provider issued list of professional services and products which have been provided, or are to be provided, to a patient which is sent to an insurer for reimbursement.
 *
 * http://hl7.org/fhir/Claim
 */
export const Claim = 'http://hl7.org/fhir/Claim' satisfies OwlClass;

/**
 * asNeeded
 *
 * PlanDefinition.asNeeded
 *
 * http://hl7.org/fhir/asNeeded
 */
export const asNeeded = 'http://hl7.org/fhir/asNeeded' satisfies OwlObjectProperty;

/**
 * defaultManualCompletion
 *
 * TestScript.test.action.assert.defaultManualCompletion: The default manual completion outcome applied to this assertion.
 *
 * http://hl7.org/fhir/defaultManualCompletion
 */
export const defaultManualCompletion = 'http://hl7.org/fhir/defaultManualCompletion' satisfies OwlObjectProperty;

/**
 * partDescription
 *
 * SubstanceSourceMaterial.partDescription: To do.
 *
 * http://hl7.org/fhir/partDescription
 */
export const partDescription = 'http://hl7.org/fhir/partDescription' satisfies OwlObjectProperty;

/**
 * articleDate
 *
 * Citation.citedArtifact.publicationForm.articleDate: The date the article was added to the database, or the date the article was released.
 *
 * http://hl7.org/fhir/articleDate
 */
export const articleDate = 'http://hl7.org/fhir/articleDate' satisfies OwlObjectProperty;

/**
 * narrative
 *
 * TestPlan.testCase.testRun.narrative: The narrative description of the tests.
 *
 * http://hl7.org/fhir/narrative
 */
export const narrative = 'http://hl7.org/fhir/narrative' satisfies OwlObjectProperty;

/**
 * participant
 *
 * AllergyIntolerance.participant: Indicates who or what participated in the activities related to the allergy or intolerance and how they were involved.
 *
 * http://hl7.org/fhir/participant
 */
export const participant = 'http://hl7.org/fhir/participant' satisfies OwlObjectProperty;

/**
 * incidence
 *
 * ClinicalUseDefinition.interaction.incidence: The incidence of the interaction, e.g. theoretical, observed.
 *
 * http://hl7.org/fhir/incidence
 */
export const incidence = 'http://hl7.org/fhir/incidence' satisfies OwlObjectProperty;

/**
 * div
 *
 * Narrative.div: The actual narrative content, a stripped down version of XHTML.
 *
 * http://hl7.org/fhir/div
 */
export const div = 'http://hl7.org/fhir/div' satisfies OwlDatatypeProperty;

/**
 * _versioning
 *
 * (Modified) CapabilityStatement.rest.resource.versioning
 *
 * http://hl7.org/fhir/_versioning
 */
export const _versioning = 'http://hl7.org/fhir/_versioning' satisfies OwlObjectProperty;

/**
 * RelatedClaim
 *
 * ExplanationOfBenefit.RelatedClaim: Other claims which are related to this claim such as prior submissions or claims for related services or for the same event.
 *
 * http://hl7.org/fhir/RelatedClaim
 */
export const RelatedClaim = 'http://hl7.org/fhir/RelatedClaim' satisfies OwlClass;

/**
 * _page
 *
 * (Modified) ImplementationGuide.manifest.page
 *
 * http://hl7.org/fhir/_page
 */
export const _page = 'http://hl7.org/fhir/_page' satisfies OwlObjectProperty;

/**
 * appointment
 *
 * Encounter.appointment: The appointment that scheduled this encounter.
 *
 * http://hl7.org/fhir/appointment
 */
export const appointment = 'http://hl7.org/fhir/appointment' satisfies OwlObjectProperty;

/**
 * AuditEventEntityDetailComponent
 *
 * AuditEventEntityComponent.AuditEventEntityDetailComponent: Tagged value pairs for conveying additional information about the entity.
 *
 * http://hl7.org/fhir/AuditEventEntityDetailComponent
 */
export const AuditEventEntityDetailComponent = 'http://hl7.org/fhir/AuditEventEntityDetailComponent' satisfies OwlClass;

/**
 * productionIdentifierInUDI
 *
 * DeviceDefinition.productionIdentifierInUDI: Indicates the production identifier(s) that are expected to appear in the UDI carrier on the device label.
 *
 * http://hl7.org/fhir/productionIdentifierInUDI
 */
export const productionIdentifierInUDI = 'http://hl7.org/fhir/productionIdentifierInUDI' satisfies OwlObjectProperty;

/**
 * _photo
 *
 * (Modified) RelatedPerson.photo
 *
 * http://hl7.org/fhir/_photo
 */
export const _photo = 'http://hl7.org/fhir/_photo' satisfies OwlObjectProperty;

/**
 * formOf
 *
 * AdministrableProductDefinition.formOf: References a product from which one or more of the constituent parts of that product can be prepared and used as described by this administrable product.  If this administrable product describes the administration of a crushed tablet, the 'formOf' would be the product representing a distribution containing tablets and possibly also a cream.  This is distinct from the 'producedFrom' which refers to the specific components of the product that are used in this preparation, rather than the product as a whole.
 *
 * http://hl7.org/fhir/formOf
 */
export const formOf = 'http://hl7.org/fhir/formOf' satisfies OwlObjectProperty;

/**
 * referrer
 *
 * ImagingStudy.referrer: The requesting/referring physician.
 *
 * http://hl7.org/fhir/referrer
 */
export const referrer = 'http://hl7.org/fhir/referrer' satisfies OwlObjectProperty;

/**
 * _subdetailSequence
 *
 * (Modified) ClaimResponse.addItem.subdetailSequence
 *
 * http://hl7.org/fhir/_subdetailSequence
 */
export const _subdetailSequence = 'http://hl7.org/fhir/_subdetailSequence' satisfies OwlObjectProperty;

/**
 * CareTeamParticipantComponent
 *
 * CareTeamParticipantComponent: Identifies all people and organizations who are expected to be involved in the care team.
 *
 * http://hl7.org/fhir/CareTeamParticipantComponent
 */
export const CareTeamParticipantComponent = 'http://hl7.org/fhir/CareTeamParticipantComponent' satisfies OwlClass;

/**
 * SpecimenDefinition
 *
 * A kind of specimen with associated set of requirements.
 *
 * http://hl7.org/fhir/SpecimenDefinition
 */
export const SpecimenDefinition = 'http://hl7.org/fhir/SpecimenDefinition' satisfies OwlClass;

/**
 * _affectsState
 *
 * (Modified) OperationDefinition.affectsState
 *
 * http://hl7.org/fhir/_affectsState
 */
export const _affectsState = 'http://hl7.org/fhir/_affectsState' satisfies OwlObjectProperty;

/**
 * _inputPopulationId
 *
 * (Modified) Measure.group.population.inputPopulationId
 *
 * http://hl7.org/fhir/_inputPopulationId
 */
export const _inputPopulationId = 'http://hl7.org/fhir/_inputPopulationId' satisfies OwlObjectProperty;

/**
 * outputProfile
 *
 * OperationDefinition.outputProfile: Additional validation information for the out parameters - a single profile that covers all the parameters. The profile is a constraint on the parameters resource.
 *
 * http://hl7.org/fhir/outputProfile
 */
export const outputProfile = 'http://hl7.org/fhir/outputProfile' satisfies OwlObjectProperty;

/**
 * MessageDefinitionAllowedResponseComponent
 *
 * MessageDefinitionAllowedResponseComponent: Indicates what types of messages may be sent as an application-level response to this message.
 *
 * http://hl7.org/fhir/MessageDefinitionAllowedResponseComponent
 */
export const MessageDefinitionAllowedResponseComponent = 'http://hl7.org/fhir/MessageDefinitionAllowedResponseComponent' satisfies OwlClass;

/**
 * numberOfInstances
 *
 * ImagingStudy.series.numberOfInstances: Number of SOP Instances in the Study. The value given may be larger than the number of instance elements this resource contains due to resource availability, security, or other factors. This element should be present if any instance elements are present.
 *
 * http://hl7.org/fhir/numberOfInstances
 */
export const numberOfInstances = 'http://hl7.org/fhir/numberOfInstances' satisfies OwlObjectProperty;

/**
 * Term
 *
 * Contract.Term: One or more Contract Provisions, which may be related and conveyed as a group, and may contain nested groups.
 *
 * http://hl7.org/fhir/Term
 */
export const Term = 'http://hl7.org/fhir/Term' satisfies OwlClass;

/**
 * supportingImmunization
 *
 * ImmunizationRecommendation.recommendation.supportingImmunization: Immunization event history and/or evaluation that supports the status and recommendation.
 *
 * http://hl7.org/fhir/supportingImmunization
 */
export const supportingImmunization = 'http://hl7.org/fhir/supportingImmunization' satisfies OwlObjectProperty;

/**
 * previousAppointment
 *
 * Appointment.previousAppointment: The previous appointment in a series of related appointments.
 *
 * http://hl7.org/fhir/previousAppointment
 */
export const previousAppointment = 'http://hl7.org/fhir/previousAppointment' satisfies OwlObjectProperty;

/**
 * seriesDoses
 *
 * ImmunizationRecommendation.recommendation.seriesDoses: The recommended number of doses to achieve immunity as determined by the evaluation and forecasting process.
 *
 * http://hl7.org/fhir/seriesDoses
 */
export const seriesDoses = 'http://hl7.org/fhir/seriesDoses' satisfies OwlObjectProperty;

/**
 * propertyGroup
 *
 * ChargeItemDefinition.propertyGroup: Group of properties which are applicable under the same conditions. If no applicability rules are established for the group, then all properties always apply.
 *
 * http://hl7.org/fhir/propertyGroup
 */
export const propertyGroup = 'http://hl7.org/fhir/propertyGroup' satisfies OwlObjectProperty;

/**
 * option
 *
 * PlanDefinition.actor.option: The characteristics of the candidates that could serve as the actor.
 *
 * http://hl7.org/fhir/option
 */
export const option = 'http://hl7.org/fhir/option' satisfies OwlObjectProperty;

/**
 * component
 *
 * ArtifactAssessment.content.component.component: If the informationType is container, the components of the content.
 *
 * http://hl7.org/fhir/component
 */
export const component = 'http://hl7.org/fhir/component' satisfies OwlObjectProperty;

/**
 * offset
 *
 * Timing.repeat.offset: The number of minutes from the event. If the event code does not indicate whether the minutes is before or after the event, then the offset is assumed to be after the event.
 *
 * http://hl7.org/fhir/offset
 */
export const offset = 'http://hl7.org/fhir/offset' satisfies OwlObjectProperty;

/**
 * materialType
 *
 * SubstanceSourceMaterial.fractionDescription.materialType: The specific type of the material constituting the component. For Herbal preparations the particulars of the extracts (liquid/dry) is described in Specified Substance Group 1.
 *
 * http://hl7.org/fhir/materialType
 */
export const materialType = 'http://hl7.org/fhir/materialType' satisfies OwlObjectProperty;

/**
 * marketingAuthorizationHolder
 *
 * Medication.marketingAuthorizationHolder: The company or other legal entity that has authorization, from the appropriate drug regulatory authority,  to market a medicine in one or more jurisdictions.  Typically abbreviated MAH.Note:  The MAH may manufacture the product and may also contract the manufacturing of the product to one or more companies (organizations).
 *
 * http://hl7.org/fhir/marketingAuthorizationHolder
 */
export const marketingAuthorizationHolder = 'http://hl7.org/fhir/marketingAuthorizationHolder' satisfies OwlObjectProperty;

/**
 * requestedPerformer
 *
 * Task.requestedPerformer: The kind of participant or specific participant that should perform the task.
 *
 * http://hl7.org/fhir/requestedPerformer
 */
export const requestedPerformer = 'http://hl7.org/fhir/requestedPerformer' satisfies OwlObjectProperty;

/**
 * developmentStage
 *
 * SubstanceSourceMaterial.developmentStage: Stage of life for animals, plants, insects and microorganisms. This information shall be provided only when the substance is significantly different in these stages (e.g. foetal bovine serum).
 *
 * http://hl7.org/fhir/developmentStage
 */
export const developmentStage = 'http://hl7.org/fhir/developmentStage' satisfies OwlObjectProperty;

/**
 * _deliveryDevice
 *
 * (Modified) NutritionOrder.enteralFormula.deliveryDevice
 *
 * http://hl7.org/fhir/_deliveryDevice
 */
export const _deliveryDevice = 'http://hl7.org/fhir/_deliveryDevice' satisfies OwlObjectProperty;

/**
 * _Timing
 *
 * (Modified) Timing
 *
 * http://hl7.org/fhir/_Timing
 */
export const _Timing = 'http://hl7.org/fhir/_Timing' satisfies OwlClass;

/**
 * AdverseEventSuspectEntityCausalityComponent
 *
 * AdverseEventSuspectEntityComponent.AdverseEventSuspectEntityCausalityComponent: Information on the possible cause of the event.
 *
 * http://hl7.org/fhir/AdverseEventSuspectEntityCausalityComponent
 */
export const AdverseEventSuspectEntityCausalityComponent = 'http://hl7.org/fhir/AdverseEventSuspectEntityCausalityComponent' satisfies OwlClass;

/**
 * add
 *
 * VisionPrescription.lensSpecification.add: Power adjustment for multifocal lenses measured in dioptres (0.25 units).
 *
 * http://hl7.org/fhir/add
 */
export const add = 'http://hl7.org/fhir/add' satisfies OwlObjectProperty;

/**
 * ImmunizationPerformerComponent
 *
 * ImmunizationPerformerComponent: Indicates who performed the immunization event.
 *
 * http://hl7.org/fhir/ImmunizationPerformerComponent
 */
export const ImmunizationPerformerComponent = 'http://hl7.org/fhir/ImmunizationPerformerComponent' satisfies OwlClass;

/**
 * _BodyStructure
 *
 * (Modified) BodyStructure
 *
 * http://hl7.org/fhir/_BodyStructure
 */
export const _BodyStructure = 'http://hl7.org/fhir/_BodyStructure' satisfies OwlClass;

/**
 * _organismName
 *
 * (Modified) SubstanceSourceMaterial.organismName
 *
 * http://hl7.org/fhir/_organismName
 */
export const _organismName = 'http://hl7.org/fhir/_organismName' satisfies OwlObjectProperty;

/**
 * _monthlyTemplate
 *
 * (Modified) Appointment.recurrenceTemplate.monthlyTemplate
 *
 * http://hl7.org/fhir/_monthlyTemplate
 */
export const _monthlyTemplate = 'http://hl7.org/fhir/_monthlyTemplate' satisfies OwlObjectProperty;

/**
 * versionAlgorithm
 *
 * ObservationDefinition.versionAlgorithm
 *
 * http://hl7.org/fhir/versionAlgorithm
 */
export const versionAlgorithm = 'http://hl7.org/fhir/versionAlgorithm' satisfies OwlObjectProperty;

/**
 * _deliverFor
 *
 * (Modified) SupplyRequest.deliverFor
 *
 * http://hl7.org/fhir/_deliverFor
 */
export const _deliverFor = 'http://hl7.org/fhir/_deliverFor' satisfies OwlObjectProperty;

/**
 * ElementDefinitionSlicingComponent
 *
 * ElementDefinitionSlicingComponent: Indicates that the element is sliced into a set of alternative definitions (i.e. in a structure definition, there are multiple different constraints on a single element in the base resource). Slicing can be used in any resource that has cardinality ..* on the base resource, or any resource with a choice of types. The set of slices is any elements that come after this in the element sequence that have the same path, until a shorter path occurs (the shorter path terminates the set).
 *
 * http://hl7.org/fhir/ElementDefinitionSlicingComponent
 */
export const ElementDefinitionSlicingComponent = 'http://hl7.org/fhir/ElementDefinitionSlicingComponent' satisfies OwlClass;

/**
 * _responseId
 *
 * (Modified) TestScript.teardown.action.operation.responseId
 *
 * http://hl7.org/fhir/_responseId
 */
export const _responseId = 'http://hl7.org/fhir/_responseId' satisfies OwlObjectProperty;

/**
 * _tenderedAmount
 *
 * (Modified) PaymentReconciliation.tenderedAmount
 *
 * http://hl7.org/fhir/_tenderedAmount
 */
export const _tenderedAmount = 'http://hl7.org/fhir/_tenderedAmount' satisfies OwlObjectProperty;

/**
 * upperLimit
 *
 * SampledData.upperLimit: The upper limit of detection of the measured points. This is needed if any of the data points have the value "U" (higher than detection limit).
 *
 * http://hl7.org/fhir/upperLimit
 */
export const upperLimit = 'http://hl7.org/fhir/upperLimit' satisfies OwlObjectProperty;

/**
 * _verificationStatus
 *
 * (Modified) Condition.verificationStatus
 *
 * http://hl7.org/fhir/_verificationStatus
 */
export const _verificationStatus = 'http://hl7.org/fhir/_verificationStatus' satisfies OwlObjectProperty;

/**
 * amountType
 *
 * SubstanceReferenceInformation.target.amountType: Todo.
 *
 * http://hl7.org/fhir/amountType
 */
export const amountType = 'http://hl7.org/fhir/amountType' satisfies OwlObjectProperty;

/**
 * _patientPaid
 *
 * (Modified) ExplanationOfBenefit.addItem.detail.subDetail.patientPaid
 *
 * http://hl7.org/fhir/_patientPaid
 */
export const _patientPaid = 'http://hl7.org/fhir/_patientPaid' satisfies OwlObjectProperty;

/**
 * RequestOrchestrationActionOutputComponent
 *
 * RequestOrchestrationActionComponentAction.RequestOrchestrationActionOutputComponent: Defines the outputs of the action, if any.
 *
 * http://hl7.org/fhir/RequestOrchestrationActionOutputComponent
 */
export const RequestOrchestrationActionOutputComponent = 'http://hl7.org/fhir/RequestOrchestrationActionOutputComponent' satisfies OwlClass;

/**
 * _quantity
 *
 * (Modified) Contract.term.group.asset.valuedItem.quantity
 *
 * http://hl7.org/fhir/_quantity
 */
export const _quantity = 'http://hl7.org/fhir/_quantity' satisfies OwlObjectProperty;

/**
 * InsurancePlanPlanSpecificCostBenefitCostComponent
 *
 * InsurancePlanPlanComponent.InsurancePlanPlanSpecificCostComponent.PlanBenefit.InsurancePlanPlanSpecificCostBenefitCostComponent: List of the costs associated with a specific benefit.
 *
 * http://hl7.org/fhir/InsurancePlanPlanSpecificCostBenefitCostComponent
 */
export const InsurancePlanPlanSpecificCostBenefitCostComponent = 'http://hl7.org/fhir/InsurancePlanPlanSpecificCostBenefitCostComponent' satisfies OwlClass;

/**
 * _alternate
 *
 * (Modified) DeviceDefinition.material.alternate
 *
 * http://hl7.org/fhir/_alternate
 */
export const _alternate = 'http://hl7.org/fhir/_alternate' satisfies OwlObjectProperty;

/**
 * _contributingFactor
 *
 * (Modified) AdverseEvent.contributingFactor
 *
 * http://hl7.org/fhir/_contributingFactor
 */
export const _contributingFactor = 'http://hl7.org/fhir/_contributingFactor' satisfies OwlObjectProperty;

/**
 * _sourceIdentityCertificate
 *
 * (Modified) VerificationResult.attestation.sourceIdentityCertificate
 *
 * http://hl7.org/fhir/_sourceIdentityCertificate
 */
export const _sourceIdentityCertificate = 'http://hl7.org/fhir/_sourceIdentityCertificate' satisfies OwlObjectProperty;

/**
 * eventNumber
 *
 * SubscriptionStatus.notificationEvent.eventNumber: Either the sequential number of this event in this subscription context or a relative event number for this notification.
 *
 * http://hl7.org/fhir/eventNumber
 */
export const eventNumber = 'http://hl7.org/fhir/eventNumber' satisfies OwlObjectProperty;

/**
 * AdministrableProductDefinitionPropertyComponent
 *
 * AdministrableProductDefinitionPropertyComponent: Characteristics e.g. a product's onset of action.
 *
 * http://hl7.org/fhir/AdministrableProductDefinitionPropertyComponent
 */
export const AdministrableProductDefinitionPropertyComponent = 'http://hl7.org/fhir/AdministrableProductDefinitionPropertyComponent' satisfies OwlClass;

/**
 * responseRequired
 *
 * MessageDefinition.responseRequired: Declare at a message definition level whether a response is required or only upon error or success, or never.
 *
 * http://hl7.org/fhir/responseRequired
 */
export const responseRequired = 'http://hl7.org/fhir/responseRequired' satisfies OwlObjectProperty;

/**
 * _verifiedBy
 *
 * (Modified) Consent.verification.verifiedBy
 *
 * http://hl7.org/fhir/_verifiedBy
 */
export const _verifiedBy = 'http://hl7.org/fhir/_verifiedBy' satisfies OwlObjectProperty;

/**
 * _maritalStatus
 *
 * (Modified) Person.maritalStatus
 *
 * http://hl7.org/fhir/_maritalStatus
 */
export const _maritalStatus = 'http://hl7.org/fhir/_maritalStatus' satisfies OwlObjectProperty;

/**
 * _timeOfDay
 *
 * (Modified) Timing.repeat.timeOfDay
 *
 * http://hl7.org/fhir/_timeOfDay
 */
export const _timeOfDay = 'http://hl7.org/fhir/_timeOfDay' satisfies OwlObjectProperty;

/**
 * contraindication
 *
 * DeviceDefinition.guideline.contraindication: A specific situation when a device should not be used because it may cause harm.
 *
 * http://hl7.org/fhir/contraindication
 */
export const contraindication = 'http://hl7.org/fhir/contraindication' satisfies OwlObjectProperty;

/**
 * patientPreparation
 *
 * SpecimenDefinition.patientPreparation: Preparation of the patient for specimen collection.
 *
 * http://hl7.org/fhir/patientPreparation
 */
export const patientPreparation = 'http://hl7.org/fhir/patientPreparation' satisfies OwlObjectProperty;

/**
 * _expression
 *
 * (Modified) Permission.rule.data.expression
 *
 * http://hl7.org/fhir/_expression
 */
export const _expression = 'http://hl7.org/fhir/_expression' satisfies OwlObjectProperty;

/**
 * _min
 *
 * (Modified) ElementDefinition.base.min
 *
 * http://hl7.org/fhir/_min
 */
export const _min = 'http://hl7.org/fhir/_min' satisfies OwlObjectProperty;

/**
 * _attester
 *
 * (Modified) DocumentReference.attester
 *
 * http://hl7.org/fhir/_attester
 */
export const _attester = 'http://hl7.org/fhir/_attester' satisfies OwlObjectProperty;

/**
 * _progress
 *
 * (Modified) ResearchSubject.progress
 *
 * http://hl7.org/fhir/_progress
 */
export const _progress = 'http://hl7.org/fhir/_progress' satisfies OwlObjectProperty;

/**
 * _collection
 *
 * (Modified) SpecimenDefinition.collection
 *
 * http://hl7.org/fhir/_collection
 */
export const _collection = 'http://hl7.org/fhir/_collection' satisfies OwlObjectProperty;

/**
 * base64Binary
 *
 * A stream of bytes
 *
 * http://hl7.org/fhir/base64Binary
 */
export const base64Binary = 'http://hl7.org/fhir/base64Binary' satisfies OwlClass;

/**
 * ExampleScenarioProcessStepComponent
 *
 * ExampleScenarioProcessComponent.ExampleScenarioProcessStepComponent.ExampleScenarioProcessStepAlternativeComponentStepProcess.ExampleScenarioProcessStepComponent: A significant action that occurs as part of the process.
 *
 * http://hl7.org/fhir/ExampleScenarioProcessStepComponent
 */
export const ExampleScenarioProcessStepComponent = 'http://hl7.org/fhir/ExampleScenarioProcessStepComponent' satisfies OwlClass;

/**
 * _comprisedOf
 *
 * (Modified) MedicinalProductDefinition.comprisedOf
 *
 * http://hl7.org/fhir/_comprisedOf
 */
export const _comprisedOf = 'http://hl7.org/fhir/_comprisedOf' satisfies OwlObjectProperty;

/**
 * _factor
 *
 * (Modified) ClaimResponse.addItem.detail.factor
 *
 * http://hl7.org/fhir/_factor
 */
export const _factor = 'http://hl7.org/fhir/_factor' satisfies OwlObjectProperty;

/**
 * _endRelationship
 *
 * (Modified) RequestOrchestration.action.action.relatedAction.endRelationship
 *
 * http://hl7.org/fhir/_endRelationship
 */
export const _endRelationship = 'http://hl7.org/fhir/_endRelationship' satisfies OwlObjectProperty;

/**
 * _startingMaterial
 *
 * (Modified) SubstancePolymer.monomerSet.startingMaterial
 *
 * http://hl7.org/fhir/_startingMaterial
 */
export const _startingMaterial = 'http://hl7.org/fhir/_startingMaterial' satisfies OwlObjectProperty;

/**
 * expectedSupplyDuration
 *
 * MedicationRequest.dispenseRequest.expectedSupplyDuration: Identifies the period time over which the supplied product is expected to be used, or the length of time the dispense is expected to last.
 *
 * http://hl7.org/fhir/expectedSupplyDuration
 */
export const expectedSupplyDuration = 'http://hl7.org/fhir/expectedSupplyDuration' satisfies OwlObjectProperty;

/**
 * totalPriceComponent
 *
 * Invoice.totalPriceComponent: The total amount for the Invoice may be calculated as the sum of the line items with surcharges/deductions that apply in certain conditions.  The priceComponent element can be used to offer transparency to the recipient of the Invoice of how the total price was calculated.
 *
 * http://hl7.org/fhir/totalPriceComponent
 */
export const totalPriceComponent = 'http://hl7.org/fhir/totalPriceComponent' satisfies OwlObjectProperty;

/**
 * _signer
 *
 * (Modified) Contract.signer
 *
 * http://hl7.org/fhir/_signer
 */
export const _signer = 'http://hl7.org/fhir/_signer' satisfies OwlObjectProperty;

/**
 * enableBehavior
 *
 * Questionnaire.item.item.enableBehavior: Controls how multiple enableWhen values are interpreted -  whether all or any must be true.
 *
 * http://hl7.org/fhir/enableBehavior
 */
export const enableBehavior = 'http://hl7.org/fhir/enableBehavior' satisfies OwlObjectProperty;

/**
 * Contract
 *
 * Legally enforceable, formally recorded unilateral or bilateral directive i.e., a policy or agreement.
 *
 * http://hl7.org/fhir/Contract
 */
export const Contract = 'http://hl7.org/fhir/Contract' satisfies OwlClass;

/**
 * _cTerminalModificationId
 *
 * (Modified) SubstanceProtein.subunit.cTerminalModificationId
 *
 * http://hl7.org/fhir/_cTerminalModificationId
 */
export const _cTerminalModificationId = 'http://hl7.org/fhir/_cTerminalModificationId' satisfies OwlObjectProperty;

/**
 * ObservationReferenceRangeComponent
 *
 * ObservationReferenceRangeComponent: Guidance on how to interpret the value by comparison to a normal or recommended range.  Multiple reference ranges are interpreted as an "OR".   In other words, to represent two distinct target populations, two `referenceRange` elements would be used.
 *
 * http://hl7.org/fhir/ObservationReferenceRangeComponent
 */
export const ObservationReferenceRangeComponent = 'http://hl7.org/fhir/ObservationReferenceRangeComponent' satisfies OwlClass;

/**
 * maxVolumeToDeliver
 *
 * NutritionOrder.enteralFormula.maxVolumeToDeliver: The maximum total quantity of formula that may be administered to a subject over the period of time, e.g. 1440 mL over 24 hours.
 *
 * http://hl7.org/fhir/maxVolumeToDeliver
 */
export const maxVolumeToDeliver = 'http://hl7.org/fhir/maxVolumeToDeliver' satisfies OwlObjectProperty;

/**
 * CapabilityStatementRestResourceOperationComponent
 *
 * CapabilityStatementRestComponent.CapabilityStatementRestResourceComponent.CapabilityStatementRestResourceOperationComponent: Definition of an operation or a named query together with its parameters and their meaning and type. Consult the definition of the operation for details about how to invoke the operation, and the parameters.
 *
 * http://hl7.org/fhir/CapabilityStatementRestResourceOperationComponent
 */
export const CapabilityStatementRestResourceOperationComponent = 'http://hl7.org/fhir/CapabilityStatementRestResourceOperationComponent' satisfies OwlClass;

/**
 * isDerived
 *
 * SpecimenDefinition.typeTested.isDerived: Primary of secondary specimen.
 *
 * http://hl7.org/fhir/isDerived
 */
export const isDerived = 'http://hl7.org/fhir/isDerived' satisfies OwlObjectProperty;

/**
 * conditionalUpdate
 *
 * CapabilityStatement.rest.resource.conditionalUpdate: A flag that indicates that the server supports conditional update.
 *
 * http://hl7.org/fhir/conditionalUpdate
 */
export const conditionalUpdate = 'http://hl7.org/fhir/conditionalUpdate' satisfies OwlObjectProperty;

/**
 * repeatUnitAmountType
 *
 * SubstancePolymer.repeat.repeatUnitAmountType: How the quantitative amount of Structural Repeat Units is captured (e.g. Exact, Numeric, Average).
 *
 * http://hl7.org/fhir/repeatUnitAmountType
 */
export const repeatUnitAmountType = 'http://hl7.org/fhir/repeatUnitAmountType' satisfies OwlObjectProperty;

/**
 * subjects
 *
 * MeasureReport.group.stratifier.stratum.population.subjects: Optional Group identifying the individuals that make up the population.
 *
 * http://hl7.org/fhir/subjects
 */
export const subjects = 'http://hl7.org/fhir/subjects' satisfies OwlObjectProperty;

/**
 * EvidenceVariableCharacteristicTimeFromEventComponent
 *
 * EvidenceVariableCharacteristicComponent.EvidenceVariableCharacteristicTimeFromEventComponent: Timing in which the characteristic is determined.
 *
 * http://hl7.org/fhir/EvidenceVariableCharacteristicTimeFromEventComponent
 */
export const EvidenceVariableCharacteristicTimeFromEventComponent = 'http://hl7.org/fhir/EvidenceVariableCharacteristicTimeFromEventComponent' satisfies OwlClass;

/**
 * _expansion
 *
 * (Modified) ValueSet.expansion
 *
 * http://hl7.org/fhir/_expansion
 */
export const _expansion = 'http://hl7.org/fhir/_expansion' satisfies OwlObjectProperty;

/**
 * _Ingredient
 *
 * (Modified) Ingredient
 *
 * http://hl7.org/fhir/_Ingredient
 */
export const _Ingredient = 'http://hl7.org/fhir/_Ingredient' satisfies OwlClass;

/**
 * _phase
 *
 * (Modified) TestScript.scope.phase
 *
 * http://hl7.org/fhir/_phase
 */
export const _phase = 'http://hl7.org/fhir/_phase' satisfies OwlObjectProperty;

/**
 * _benefitPeriod
 *
 * (Modified) ExplanationOfBenefit.benefitPeriod
 *
 * http://hl7.org/fhir/_benefitPeriod
 */
export const _benefitPeriod = 'http://hl7.org/fhir/_benefitPeriod' satisfies OwlObjectProperty;

/**
 * Organization
 *
 * A formally or informally recognized grouping of people or organizations formed for the purpose of achieving some form of collective action.  Includes companies, institutions, corporations, departments, community groups, healthcare practice groups, payer/insurer, etc.
 *
 * http://hl7.org/fhir/Organization
 */
export const Organization = 'http://hl7.org/fhir/Organization' satisfies OwlClass;

/**
 * _referenceStrength
 *
 * (Modified) Ingredient.substance.strength.referenceStrength
 *
 * http://hl7.org/fhir/_referenceStrength
 */
export const _referenceStrength = 'http://hl7.org/fhir/_referenceStrength' satisfies OwlObjectProperty;

/**
 * StructureMapGroupComponent
 *
 * StructureMapGroupComponent: Organizes the mapping into managable chunks for human review/ease of maintenance.
 *
 * http://hl7.org/fhir/StructureMapGroupComponent
 */
export const StructureMapGroupComponent = 'http://hl7.org/fhir/StructureMapGroupComponent' satisfies OwlClass;

/**
 * referencePolicy
 *
 * CapabilityStatement.rest.resource.referencePolicy: A set of flags that defines how references are supported.
 *
 * http://hl7.org/fhir/referencePolicy
 */
export const referencePolicy = 'http://hl7.org/fhir/referencePolicy' satisfies OwlObjectProperty;

/**
 * previous
 *
 * SubscriptionTopic.resourceTrigger.queryCriteria.previous: The FHIR query based rules are applied to the previous resource state (e.g., state before an update).
 *
 * http://hl7.org/fhir/previous
 */
export const previous = 'http://hl7.org/fhir/previous' satisfies OwlObjectProperty;

/**
 * _stage
 *
 * (Modified) ConditionDefinition.stage
 *
 * http://hl7.org/fhir/_stage
 */
export const _stage = 'http://hl7.org/fhir/_stage' satisfies OwlObjectProperty;

/**
 * PlanDefinitionActionOutputComponent
 *
 * PlanDefinitionActionComponentAction.PlanDefinitionActionOutputComponent: Defines the outputs of the action, if any.
 *
 * http://hl7.org/fhir/PlanDefinitionActionOutputComponent
 */
export const PlanDefinitionActionOutputComponent = 'http://hl7.org/fhir/PlanDefinitionActionOutputComponent' satisfies OwlClass;

/**
 * _publisherLocation
 *
 * (Modified) Citation.citedArtifact.publicationForm.publishedIn.publisherLocation
 *
 * http://hl7.org/fhir/_publisherLocation
 */
export const _publisherLocation = 'http://hl7.org/fhir/_publisherLocation' satisfies OwlObjectProperty;

/**
 * MedicationKnowledgeIndicationGuidelineDosingGuidelineDosageComponent
 *
 * MedicationKnowledgeIndicationGuidelineComponent.MedicationKnowledgeIndicationGuidelineDosingGuidelineComponent.MedicationKnowledgeIndicationGuidelineDosingGuidelineDosageComponent: Dosage for the medication for the specific guidelines.
 *
 * http://hl7.org/fhir/MedicationKnowledgeIndicationGuidelineDosingGuidelineDosageComponent
 */
export const MedicationKnowledgeIndicationGuidelineDosingGuidelineDosageComponent = 'http://hl7.org/fhir/MedicationKnowledgeIndicationGuidelineDosingGuidelineDosageComponent' satisfies OwlClass;

/**
 * containedItemQuantity
 *
 * PackagedProductDefinition.containedItemQuantity: A total of the complete count of contained items of a particular type/form, independent of sub-packaging or organization. This can be considered as the pack size. This attribute differs from containedItem.amount in that it can give a single aggregated count of all tablet types in a pack, even when these are different manufactured items. For example a pill pack of 21 tablets plus 7 sugar tablets, can be denoted here as '28 tablets'. This attribute is repeatable so that the different item types in one pack type can be counted (e.g. a count of vials and count of syringes). Each repeat must have different units, so that it is clear what the different sets of counted items are, and it is not intended to allow different counts of similar items (e.g. not '2 tubes and 3 tubes'). Repeats are not to be used to represent different pack sizes (e.g. 20 pack vs. 50 pack) - which would be different instances of this resource.
 *
 * http://hl7.org/fhir/containedItemQuantity
 */
export const containedItemQuantity = 'http://hl7.org/fhir/containedItemQuantity' satisfies OwlObjectProperty;

/**
 * copyrightLabel
 *
 * GraphDefinition.copyrightLabel: A short string (<50 characters), suitable for inclusion in a page footer that identifies the copyright holder, effective period, and optionally whether rights are resctricted. (e.g. 'All rights reserved', 'Some rights reserved').
 *
 * http://hl7.org/fhir/copyrightLabel
 */
export const copyrightLabel = 'http://hl7.org/fhir/copyrightLabel' satisfies OwlObjectProperty;

/**
 * BodyStructureIncludedStructureBodyLandmarkOrientationComponent
 *
 * BodyStructureIncludedStructureBodyLandmarkOrientationComponent: Body locations in relation to a specific body landmark (tatoo, scar, other body structure).
 *
 * http://hl7.org/fhir/BodyStructureIncludedStructureBodyLandmarkOrientationComponent
 */
export const BodyStructureIncludedStructureBodyLandmarkOrientationComponent = 'http://hl7.org/fhir/BodyStructureIncludedStructureBodyLandmarkOrientationComponent' satisfies OwlClass;

/**
 * hasBodySite
 *
 * ConditionDefinition.hasBodySite: Whether bodySite is appropriate to collect for this condition.
 *
 * http://hl7.org/fhir/hasBodySite
 */
export const hasBodySite = 'http://hl7.org/fhir/hasBodySite' satisfies OwlObjectProperty;

/**
 * _valuedItem
 *
 * (Modified) Contract.term.group.asset.valuedItem
 *
 * http://hl7.org/fhir/_valuedItem
 */
export const _valuedItem = 'http://hl7.org/fhir/_valuedItem' satisfies OwlObjectProperty;

/**
 * Period
 *
 * A time period defined by a start and end date and optionally time.
 *
 * http://hl7.org/fhir/Period
 */
export const Period = 'http://hl7.org/fhir/Period' satisfies OwlClass;

/**
 * questionnaire
 *
 * QuestionnaireResponse.questionnaire: The Questionnaire that defines and organizes the questions for which answers are being provided.
 *
 * http://hl7.org/fhir/questionnaire
 */
export const questionnaire = 'http://hl7.org/fhir/questionnaire' satisfies OwlObjectProperty;

/**
 * specificCost
 *
 * InsurancePlan.plan.specificCost: Costs associated with the coverage provided by the product.
 *
 * http://hl7.org/fhir/specificCost
 */
export const specificCost = 'http://hl7.org/fhir/specificCost' satisfies OwlObjectProperty;

/**
 * _collected
 *
 * (Modified) Specimen.collection.collected
 *
 * http://hl7.org/fhir/_collected
 */
export const _collected = 'http://hl7.org/fhir/_collected' satisfies OwlObjectProperty;

/**
 * _notAvailableTime
 *
 * (Modified) Availability.notAvailableTime
 *
 * http://hl7.org/fhir/_notAvailableTime
 */
export const _notAvailableTime = 'http://hl7.org/fhir/_notAvailableTime' satisfies OwlObjectProperty;

/**
 * AllergyIntoleranceParticipantComponent
 *
 * AllergyIntoleranceParticipantComponent: Indicates who or what participated in the activities related to the allergy or intolerance and how they were involved.
 *
 * http://hl7.org/fhir/AllergyIntoleranceParticipantComponent
 */
export const AllergyIntoleranceParticipantComponent = 'http://hl7.org/fhir/AllergyIntoleranceParticipantComponent' satisfies OwlClass;

/**
 * headerField
 *
 * TestScript.test.action.assert.headerField: The HTTP header field name e.g. 'Location'.
 *
 * http://hl7.org/fhir/headerField
 */
export const headerField = 'http://hl7.org/fhir/headerField' satisfies OwlObjectProperty;

/**
 * _contained
 *
 * (Modified) DomainResource.contained
 *
 * http://hl7.org/fhir/_contained
 */
export const _contained = 'http://hl7.org/fhir/_contained' satisfies OwlObjectProperty;

/**
 * _assigner
 *
 * (Modified) Identifier.assigner
 *
 * http://hl7.org/fhir/_assigner
 */
export const _assigner = 'http://hl7.org/fhir/_assigner' satisfies OwlObjectProperty;

/**
 * _ifNoneMatch
 *
 * (Modified) Bundle.entry.request.ifNoneMatch
 *
 * http://hl7.org/fhir/_ifNoneMatch
 */
export const _ifNoneMatch = 'http://hl7.org/fhir/_ifNoneMatch' satisfies OwlObjectProperty;

/**
 * DeviceAssociationOperationComponent
 *
 * DeviceAssociationOperationComponent: The details about the device when it is in use to describe its operation.
 *
 * http://hl7.org/fhir/DeviceAssociationOperationComponent
 */
export const DeviceAssociationOperationComponent = 'http://hl7.org/fhir/DeviceAssociationOperationComponent' satisfies OwlClass;

/**
 * _graph
 *
 * (Modified) MessageDefinition.graph
 *
 * http://hl7.org/fhir/_graph
 */
export const _graph = 'http://hl7.org/fhir/_graph' satisfies OwlObjectProperty;

/**
 * changeType
 *
 * GenomicStudy.analysis.changeType: Type of the genomic changes studied in the analysis, e.g., DNA, RNA, or amino acid change.
 *
 * http://hl7.org/fhir/changeType
 */
export const changeType = 'http://hl7.org/fhir/changeType' satisfies OwlObjectProperty;

/**
 * _orientation
 *
 * (Modified) SubstancePolymer.repeat.repeatUnit.orientation
 *
 * http://hl7.org/fhir/_orientation
 */
export const _orientation = 'http://hl7.org/fhir/_orientation' satisfies OwlObjectProperty;

/**
 * parentSubstanceId
 *
 * SubstanceSourceMaterial.parentSubstanceId: The parent of the herbal drug Ginkgo biloba, Leaf is the substance ID of the substance (fresh) of Ginkgo biloba L. or Ginkgo biloba L. (Whole plant).
 *
 * http://hl7.org/fhir/parentSubstanceId
 */
export const parentSubstanceId = 'http://hl7.org/fhir/parentSubstanceId' satisfies OwlObjectProperty;

/**
 * recorded
 *
 * MedicationAdministration.recorded: The date the occurrence of the  MedicationAdministration was first captured in the record - potentially significantly after the occurrence of the event.
 *
 * http://hl7.org/fhir/recorded
 */
export const recorded = 'http://hl7.org/fhir/recorded' satisfies OwlObjectProperty;

/**
 * _contributionType
 *
 * (Modified) Citation.citedArtifact.contributorship.entry.contributionType
 *
 * http://hl7.org/fhir/_contributionType
 */
export const _contributionType = 'http://hl7.org/fhir/_contributionType' satisfies OwlObjectProperty;

/**
 * filterParameter
 *
 * SubscriptionTopic.canFilterBy.filterParameter: Either the canonical URL to a search parameter (like "http://hl7.org/fhir/SearchParameter/encounter-patient") or topic-defined parameter (like "hub.event") which is a label for the filter.
 *
 * http://hl7.org/fhir/filterParameter
 */
export const filterParameter = 'http://hl7.org/fhir/filterParameter' satisfies OwlObjectProperty;

/**
 * positiveInt
 *
 * An integer with a value that is positive (e.g. >0)
 *
 * http://hl7.org/fhir/positiveInt
 */
export const positiveInt = 'http://hl7.org/fhir/positiveInt' satisfies OwlClass;

/**
 * docStatus
 *
 * DocumentReference.docStatus: The status of the underlying document.
 *
 * http://hl7.org/fhir/docStatus
 */
export const docStatus = 'http://hl7.org/fhir/docStatus' satisfies OwlObjectProperty;

/**
 * CoverageBenefit
 *
 * InsurancePlanCoverageComponent.CoverageBenefit: Specific benefits under this type of coverage.
 *
 * http://hl7.org/fhir/CoverageBenefit
 */
export const CoverageBenefit = 'http://hl7.org/fhir/CoverageBenefit' satisfies OwlClass;

/**
 * durationUnit
 *
 * Timing.repeat.durationUnit: The units of time for the duration, in UCUM units
 * Normal practice is to use the 'mo' code as a calendar month when calculating the next occurrence.
 *
 * http://hl7.org/fhir/durationUnit
 */
export const durationUnit = 'http://hl7.org/fhir/durationUnit' satisfies OwlObjectProperty;

/**
 * contentType
 *
 * Attachment.contentType: Identifies the type of the data in the attachment and allows a method to be chosen to interpret or render the data. Includes mime type parameters such as charset where appropriate.
 *
 * http://hl7.org/fhir/contentType
 */
export const contentType = 'http://hl7.org/fhir/contentType' satisfies OwlObjectProperty;

/**
 * _addItem
 *
 * (Modified) ExplanationOfBenefit.addItem
 *
 * http://hl7.org/fhir/_addItem
 */
export const _addItem = 'http://hl7.org/fhir/_addItem' satisfies OwlObjectProperty;

/**
 * MedicationKnowledgeIndicationGuidelineDosingGuidelineComponent
 *
 * MedicationKnowledgeIndicationGuidelineComponent.MedicationKnowledgeIndicationGuidelineDosingGuidelineComponent: The guidelines for the dosage of the medication for the indication.
 *
 * http://hl7.org/fhir/MedicationKnowledgeIndicationGuidelineDosingGuidelineComponent
 */
export const MedicationKnowledgeIndicationGuidelineDosingGuidelineComponent = 'http://hl7.org/fhir/MedicationKnowledgeIndicationGuidelineDosingGuidelineComponent' satisfies OwlClass;

/**
 * dateRange
 *
 * MarketingStatus.dateRange: The date when the Medicinal Product is placed on the market by the Marketing Authorization Holder (or where applicable, the manufacturer/distributor) in a country and/or jurisdiction shall be provided A complete date consisting of day, month and year shall be specified using the ISO 8601 date format NOTE “Placed on the market” refers to the release of the Medicinal Product into the distribution chain.
 *
 * http://hl7.org/fhir/dateRange
 */
export const dateRange = 'http://hl7.org/fhir/dateRange' satisfies OwlObjectProperty;

/**
 * used
 *
 * Procedure.used: Identifies medications, devices and any other substance used as part of the procedure.
 *
 * http://hl7.org/fhir/used
 */
export const used = 'http://hl7.org/fhir/used' satisfies OwlObjectProperty;

/**
 * _city
 *
 * (Modified) Address.city
 *
 * http://hl7.org/fhir/_city
 */
export const _city = 'http://hl7.org/fhir/_city' satisfies OwlObjectProperty;

/**
 * reaction
 *
 * Immunization.reaction: Categorical data indicating that an adverse event is associated in time to an immunization.
 *
 * http://hl7.org/fhir/reaction
 */
export const reaction = 'http://hl7.org/fhir/reaction' satisfies OwlObjectProperty;

/**
 * subset
 *
 * ImagingSelection.instance.subset: Selected subset of the SOP Instance. The content and format of the subset item is determined by the SOP Class of the selected instance.
 *        May be one of:
 *        - A list of frame numbers selected from a multiframe SOP Instance.
 *        - A list of Content Item Observation UID values selected from a DICOM SR or other structured document SOP Instance.
 *        - A list of segment numbers selected from a segmentation SOP Instance.
 *        - A list of Region of Interest (ROI) numbers selected from a radiotherapy structure set SOP Instance.
 *
 * http://hl7.org/fhir/subset
 */
export const subset = 'http://hl7.org/fhir/subset' satisfies OwlObjectProperty;

/**
 * performerRole
 *
 * Contract.term.group.action.performerRole: The type of role or competency of an individual desired or required to perform or not perform the action.
 *
 * http://hl7.org/fhir/performerRole
 */
export const performerRole = 'http://hl7.org/fhir/performerRole' satisfies OwlObjectProperty;

/**
 * retentionTime
 *
 * SpecimenDefinition.typeTested.retentionTime: The usual time that a specimen of this kind is retained after the ordered tests are completed, for the purpose of additional testing.
 *
 * http://hl7.org/fhir/retentionTime
 */
export const retentionTime = 'http://hl7.org/fhir/retentionTime' satisfies OwlObjectProperty;

/**
 * _ClinicalImpression
 *
 * (Modified) ClinicalImpression
 *
 * http://hl7.org/fhir/_ClinicalImpression
 */
export const _ClinicalImpression = 'http://hl7.org/fhir/_ClinicalImpression' satisfies OwlClass;

/**
 * _generalCost
 *
 * (Modified) InsurancePlan.plan.generalCost
 *
 * http://hl7.org/fhir/_generalCost
 */
export const _generalCost = 'http://hl7.org/fhir/_generalCost' satisfies OwlObjectProperty;

/**
 * instanceReference
 *
 * ExampleScenario.process.step.alternative.step.operation.request.instanceReference: A reference to the key of an instance found within this one.
 *
 * http://hl7.org/fhir/instanceReference
 */
export const instanceReference = 'http://hl7.org/fhir/instanceReference' satisfies OwlObjectProperty;

/**
 * _history
 *
 * (Modified) Transport.history
 *
 * http://hl7.org/fhir/_history
 */
export const _history = 'http://hl7.org/fhir/_history' satisfies OwlObjectProperty;

/**
 * molecularFormulaByMoiety
 *
 * SubstanceDefinition.structure.molecularFormulaByMoiety: Specified per moiety according to the Hill system, i.e. first C, then H, then alphabetical, each moiety separated by a dot.
 *
 * http://hl7.org/fhir/molecularFormulaByMoiety
 */
export const molecularFormulaByMoiety = 'http://hl7.org/fhir/molecularFormulaByMoiety' satisfies OwlObjectProperty;

/**
 * _orderer
 *
 * (Modified) NutritionOrder.orderer
 *
 * http://hl7.org/fhir/_orderer
 */
export const _orderer = 'http://hl7.org/fhir/_orderer' satisfies OwlObjectProperty;

/**
 * _payee
 *
 * (Modified) PaymentReconciliation.allocation.payee
 *
 * http://hl7.org/fhir/_payee
 */
export const _payee = 'http://hl7.org/fhir/_payee' satisfies OwlObjectProperty;

/**
 * _windowEnd
 *
 * (Modified) MolecularSequence.relative.startingSequence.windowEnd
 *
 * http://hl7.org/fhir/_windowEnd
 */
export const _windowEnd = 'http://hl7.org/fhir/_windowEnd' satisfies OwlObjectProperty;

/**
 * _maxDosePerTreatmentPeriod
 *
 * (Modified) AdministrableProductDefinition.routeOfAdministration.maxDosePerTreatmentPeriod
 *
 * http://hl7.org/fhir/_maxDosePerTreatmentPeriod
 */
export const _maxDosePerTreatmentPeriod = 'http://hl7.org/fhir/_maxDosePerTreatmentPeriod' satisfies OwlObjectProperty;

/**
 * sopClass
 *
 * ImagingStudy.series.instance.sopClass: DICOM instance  type.
 *
 * http://hl7.org/fhir/sopClass
 */
export const sopClass = 'http://hl7.org/fhir/sopClass' satisfies OwlObjectProperty;

/**
 * PlanDefinitionActorOptionComponent
 *
 * PlanDefinitionActorComponent.PlanDefinitionActorOptionComponent: The characteristics of the candidates that could serve as the actor.
 *
 * http://hl7.org/fhir/PlanDefinitionActorOptionComponent
 */
export const PlanDefinitionActorOptionComponent = 'http://hl7.org/fhir/PlanDefinitionActorOptionComponent' satisfies OwlClass;

/**
 * ExampleScenarioInstanceComponent
 *
 * ExampleScenarioInstanceComponent: A single data collection that is shared as part of the scenario.
 *
 * http://hl7.org/fhir/ExampleScenarioInstanceComponent
 */
export const ExampleScenarioInstanceComponent = 'http://hl7.org/fhir/ExampleScenarioInstanceComponent' satisfies OwlClass;

/**
 * organismGeneral
 *
 * SubstanceSourceMaterial.organism.organismGeneral: 4.9.13.7.1 Kingdom (Conditional).
 *
 * http://hl7.org/fhir/organismGeneral
 */
export const organismGeneral = 'http://hl7.org/fhir/organismGeneral' satisfies OwlObjectProperty;

/**
 * abatement
 *
 * Condition.abatement
 *
 * http://hl7.org/fhir/abatement
 */
export const abatement = 'http://hl7.org/fhir/abatement' satisfies OwlObjectProperty;

/**
 * _relatedDevice
 *
 * (Modified) DeviceDefinition.link.relatedDevice
 *
 * http://hl7.org/fhir/_relatedDevice
 */
export const _relatedDevice = 'http://hl7.org/fhir/_relatedDevice' satisfies OwlObjectProperty;

/**
 * daysSupply
 *
 * MedicationDispense.daysSupply: The amount of medication expressed as a timing amount.
 *
 * http://hl7.org/fhir/daysSupply
 */
export const daysSupply = 'http://hl7.org/fhir/daysSupply' satisfies OwlObjectProperty;

/**
 * _legal
 *
 * (Modified) Contract.legal
 *
 * http://hl7.org/fhir/_legal
 */
export const _legal = 'http://hl7.org/fhir/_legal' satisfies OwlObjectProperty;

/**
 * _EpisodeOfCare
 *
 * (Modified) EpisodeOfCare
 *
 * http://hl7.org/fhir/_EpisodeOfCare
 */
export const _EpisodeOfCare = 'http://hl7.org/fhir/_EpisodeOfCare' satisfies OwlClass;

/**
 * _excludeFoodModifier
 *
 * (Modified) NutritionOrder.excludeFoodModifier
 *
 * http://hl7.org/fhir/_excludeFoodModifier
 */
export const _excludeFoodModifier = 'http://hl7.org/fhir/_excludeFoodModifier' satisfies OwlObjectProperty;

/**
 * weekInterval
 *
 * Appointment.recurrenceTemplate.weeklyTemplate.weekInterval: The interval defines if the recurrence is every nth week. The default is every week, so it is expected that this value will be 2 or more.

e.g. For recurring every second week this interval would be 2, or every third week the interval would be 3.
 *
 * http://hl7.org/fhir/weekInterval
 */
export const weekInterval = 'http://hl7.org/fhir/weekInterval' satisfies OwlObjectProperty;

/**
 * _measureScore
 *
 * (Modified) MeasureReport.group.stratifier.stratum.measureScore
 *
 * http://hl7.org/fhir/_measureScore
 */
export const _measureScore = 'http://hl7.org/fhir/_measureScore' satisfies OwlObjectProperty;

/**
 * _const
 *
 * (Modified) StructureMap.const
 *
 * http://hl7.org/fhir/_const
 */
export const _const = 'http://hl7.org/fhir/_const' satisfies OwlObjectProperty;

/**
 * _hybrid
 *
 * (Modified) SubstanceSourceMaterial.organism.hybrid
 *
 * http://hl7.org/fhir/_hybrid
 */
export const _hybrid = 'http://hl7.org/fhir/_hybrid' satisfies OwlObjectProperty;

/**
 * PackagedProductDefinitionPackagingComponent
 *
 * PackagedProductDefinitionPackagingComponent: A packaging item, as a container for medically related items, possibly with other packaging items within, or a packaging component, such as bottle cap (which is not a device or a medication manufactured item).
 *
 * http://hl7.org/fhir/PackagedProductDefinitionPackagingComponent
 */
export const PackagedProductDefinitionPackagingComponent = 'http://hl7.org/fhir/PackagedProductDefinitionPackagingComponent' satisfies OwlClass;

/**
 * _prefix
 *
 * (Modified) RequestOrchestration.action.action.prefix
 *
 * http://hl7.org/fhir/_prefix
 */
export const _prefix = 'http://hl7.org/fhir/_prefix' satisfies OwlObjectProperty;

/**
 * _publicationDateText
 *
 * (Modified) Citation.citedArtifact.publicationForm.publicationDateText
 *
 * http://hl7.org/fhir/_publicationDateText
 */
export const _publicationDateText = 'http://hl7.org/fhir/_publicationDateText' satisfies OwlObjectProperty;

/**
 * ConceptSet
 *
 * ValueSetComposeComponent.ConceptSet: Include one or more codes from a code system or other value set(s).
 *
 * http://hl7.org/fhir/ConceptSet
 */
export const ConceptSet = 'http://hl7.org/fhir/ConceptSet' satisfies OwlClass;

/**
 * payeeType
 *
 * ClaimResponse.payeeType: Type of Party to be reimbursed: subscriber, provider, other.
 *
 * http://hl7.org/fhir/payeeType
 */
export const payeeType = 'http://hl7.org/fhir/payeeType' satisfies OwlObjectProperty;

/**
 * _shelfLifeStorage
 *
 * (Modified) PackagedProductDefinition.packaging.packaging.shelfLifeStorage
 *
 * http://hl7.org/fhir/_shelfLifeStorage
 */
export const _shelfLifeStorage = 'http://hl7.org/fhir/_shelfLifeStorage' satisfies OwlObjectProperty;

/**
 * balance
 *
 * Account.balance: The calculated account balances - these are calculated and processed by the finance system.

The balances with a `term` that is not current are usually generated/updated by an invoicing or similar process.
 *
 * http://hl7.org/fhir/balance
 */
export const balance = 'http://hl7.org/fhir/balance' satisfies OwlObjectProperty;

/**
 * _type
 *
 * (Modified) ManufacturedItemDefinition.component.component.property.type
 *
 * http://hl7.org/fhir/_type
 */
export const _type = 'http://hl7.org/fhir/_type' satisfies OwlObjectProperty;

/**
 * dataPeriod
 *
 * Consent.provision.provision.dataPeriod: Clinical or Operational Relevant period of time that bounds the data controlled by this provision.
 *
 * http://hl7.org/fhir/dataPeriod
 */
export const dataPeriod = 'http://hl7.org/fhir/dataPeriod' satisfies OwlObjectProperty;

/**
 * _Immunization
 *
 * (Modified) Immunization
 *
 * http://hl7.org/fhir/_Immunization
 */
export const _Immunization = 'http://hl7.org/fhir/_Immunization' satisfies OwlClass;

/**
 * resourceReference
 *
 * Citation.citedArtifact.relatesTo.resourceReference: The related artifact, if the artifact is not a canonical resource, or a resource reference to a canonical resource.
 *
 * http://hl7.org/fhir/resourceReference
 */
export const resourceReference = 'http://hl7.org/fhir/resourceReference' satisfies OwlObjectProperty;

/**
 * _providedBy
 *
 * (Modified) HealthcareService.providedBy
 *
 * http://hl7.org/fhir/_providedBy
 */
export const _providedBy = 'http://hl7.org/fhir/_providedBy' satisfies OwlObjectProperty;

/**
 * _fhirVersion
 *
 * (Modified) StructureDefinition.fhirVersion
 *
 * http://hl7.org/fhir/_fhirVersion
 */
export const _fhirVersion = 'http://hl7.org/fhir/_fhirVersion' satisfies OwlObjectProperty;

/**
 * _HealthcareService
 *
 * (Modified) HealthcareService
 *
 * http://hl7.org/fhir/_HealthcareService
 */
export const _HealthcareService = 'http://hl7.org/fhir/_HealthcareService' satisfies OwlClass;

/**
 * submitter
 *
 * PaymentReconciliation.allocation.submitter: The party which submitted the claim or financial transaction.
 *
 * http://hl7.org/fhir/submitter
 */
export const submitter = 'http://hl7.org/fhir/submitter' satisfies OwlObjectProperty;

/**
 * description
 *
 * Availability.notAvailableTime.description: Reason presented to the user explaining why time not available.
 *
 * http://hl7.org/fhir/description
 */
export const description = 'http://hl7.org/fhir/description' satisfies OwlObjectProperty;

/**
 * combinedPharmaceuticalDoseForm
 *
 * MedicinalProductDefinition.combinedPharmaceuticalDoseForm: The dose form for a single part product, or combined form of a multiple part product. This is one concept that describes all the components. It does not represent the form with components physically mixed, if that might be necessary, for which see (AdministrableProductDefinition.administrableDoseForm).
 *
 * http://hl7.org/fhir/combinedPharmaceuticalDoseForm
 */
export const combinedPharmaceuticalDoseForm = 'http://hl7.org/fhir/combinedPharmaceuticalDoseForm' satisfies OwlObjectProperty;

/**
 * _targetScope
 *
 * (Modified) ConceptMap.targetScope
 *
 * http://hl7.org/fhir/_targetScope
 */
export const _targetScope = 'http://hl7.org/fhir/_targetScope' satisfies OwlObjectProperty;

/**
 * Parameter
 *
 * Transport.Parameter: Additional information that may be needed in the execution of the transport.
 *
 * http://hl7.org/fhir/Parameter
 */
export const Parameter = 'http://hl7.org/fhir/Parameter' satisfies OwlClass;

/**
 * BiologicallyDerivedProduct
 *
 * A biological material originating from a biological entity intended to be transplanted or infused into another (possibly the same) biological entity.
 *
 * http://hl7.org/fhir/BiologicallyDerivedProduct
 */
export const BiologicallyDerivedProduct = 'http://hl7.org/fhir/BiologicallyDerivedProduct' satisfies OwlClass;

/**
 * _GenomicStudy
 *
 * (Modified) GenomicStudy
 *
 * http://hl7.org/fhir/_GenomicStudy
 */
export const _GenomicStudy = 'http://hl7.org/fhir/_GenomicStudy' satisfies OwlClass;

/**
 * _NutritionProduct
 *
 * (Modified) NutritionProduct
 *
 * http://hl7.org/fhir/_NutritionProduct
 */
export const _NutritionProduct = 'http://hl7.org/fhir/_NutritionProduct' satisfies OwlClass;

/**
 * _additionalContext
 *
 * (Modified) SubscriptionStatus.notificationEvent.additionalContext
 *
 * http://hl7.org/fhir/_additionalContext
 */
export const _additionalContext = 'http://hl7.org/fhir/_additionalContext' satisfies OwlObjectProperty;

/**
 * version
 *
 * Measure.version: The identifier that is used to identify this version of the measure when it is referenced in a specification, model, design or instance. This is an arbitrary value managed by the measure author and is not expected to be globally unique. For example, it might be a timestamp (e.g. yyyymmdd) if a managed version is not available. There is also no expectation that versions can be placed in a lexicographical sequence. To provide a version consistent with the Decision Support Service specification, use the format Major.Minor.Revision (e.g. 1.0.0). For more information on versioning knowledge assets, refer to the Decision Support Service specification. Note that a version is required for non-experimental active artifacts.
 *
 * http://hl7.org/fhir/version
 */
export const version = 'http://hl7.org/fhir/version' satisfies OwlObjectProperty;

/**
 * detected
 *
 * AdverseEvent.detected: Estimated or actual date the AdverseEvent began, in the opinion of the reporter.
 *
 * http://hl7.org/fhir/detected
 */
export const detected = 'http://hl7.org/fhir/detected' satisfies OwlObjectProperty;

/**
 * _statistic
 *
 * (Modified) Evidence.statistic
 *
 * http://hl7.org/fhir/_statistic
 */
export const _statistic = 'http://hl7.org/fhir/_statistic' satisfies OwlObjectProperty;

/**
 * _bodyStructure
 *
 * (Modified) ServiceRequest.bodyStructure
 *
 * http://hl7.org/fhir/_bodyStructure
 */
export const _bodyStructure = 'http://hl7.org/fhir/_bodyStructure' satisfies OwlObjectProperty;

/**
 * _definitionExpression
 *
 * (Modified) EvidenceVariable.characteristic.definitionByCombination.characteristic.definitionExpression
 *
 * http://hl7.org/fhir/_definitionExpression
 */
export const _definitionExpression = 'http://hl7.org/fhir/_definitionExpression' satisfies OwlObjectProperty;

/**
 * translations
 *
 * TerminologyCapabilities.validateCode.translations: Whether translations are validated.
 *
 * http://hl7.org/fhir/translations
 */
export const translations = 'http://hl7.org/fhir/translations' satisfies OwlObjectProperty;

/**
 * _targetProfile
 *
 * (Modified) OperationDefinition.parameter.part.targetProfile
 *
 * http://hl7.org/fhir/_targetProfile
 */
export const _targetProfile = 'http://hl7.org/fhir/_targetProfile' satisfies OwlObjectProperty;

/**
 * _notPerformedReason
 *
 * (Modified) MedicationDispense.notPerformedReason
 *
 * http://hl7.org/fhir/_notPerformedReason
 */
export const _notPerformedReason = 'http://hl7.org/fhir/_notPerformedReason' satisfies OwlObjectProperty;

/**
 * ArtifactAssessmentContentComponent
 *
 * ArtifactAssessmentContentComponent: A component comment, classifier, or rating of the artifact.
 *
 * http://hl7.org/fhir/ArtifactAssessmentContentComponent
 */
export const ArtifactAssessmentContentComponent = 'http://hl7.org/fhir/ArtifactAssessmentContentComponent' satisfies OwlClass;

/**
 * cost
 *
 * MedicationKnowledge.packaging.cost.cost
 *
 * http://hl7.org/fhir/cost
 */
export const cost = 'http://hl7.org/fhir/cost' satisfies OwlObjectProperty;

/**
 * CanonicalResource
 *
 * Common Interface declaration for conformance and knowledge artifact resources.
 *
 * http://hl7.org/fhir/CanonicalResource
 */
export const CanonicalResource = 'http://hl7.org/fhir/CanonicalResource' satisfies OwlClass;

/**
 * _authorizationSupporting
 *
 * (Modified) CoverageEligibilityResponse.insurance.item.authorizationSupporting
 *
 * http://hl7.org/fhir/_authorizationSupporting
 */
export const _authorizationSupporting = 'http://hl7.org/fhir/_authorizationSupporting' satisfies OwlObjectProperty;

/**
 * team
 *
 * ConditionDefinition.team: Appropriate team for this condition.
 *
 * http://hl7.org/fhir/team
 */
export const team = 'http://hl7.org/fhir/team' satisfies OwlObjectProperty;

/**
 * actual
 *
 * Citation.statusDate.actual: Whether the status date is actual (has occurred) or expected (estimated or anticipated).
 *
 * http://hl7.org/fhir/actual
 */
export const actual = 'http://hl7.org/fhir/actual' satisfies OwlObjectProperty;

/**
 * landmarkDescription
 *
 * BodyStructure.excludedStructure.bodyLandmarkOrientation.landmarkDescription: A description of a landmark on the body used as a reference to locate something else.
 *
 * http://hl7.org/fhir/landmarkDescription
 */
export const landmarkDescription = 'http://hl7.org/fhir/landmarkDescription' satisfies OwlObjectProperty;

/**
 * typeCanonical
 *
 * RequestOrchestration.action.action.participant.typeCanonical: The type of participant in the action.
 *
 * http://hl7.org/fhir/typeCanonical
 */
export const typeCanonical = 'http://hl7.org/fhir/typeCanonical' satisfies OwlObjectProperty;

/**
 * ArtifactAssessmentContentComponentContent
 *
 * If the informationType is container, the components of the content.
 *
 * http://hl7.org/fhir/ArtifactAssessmentContentComponentContent
 */
export const ArtifactAssessmentContentComponentContent = 'http://hl7.org/fhir/ArtifactAssessmentContentComponentContent' satisfies OwlClass;

/**
 * _organizationReference
 *
 * (Modified) DeviceDefinition.packaging.packaging.distributor.organizationReference
 *
 * http://hl7.org/fhir/_organizationReference
 */
export const _organizationReference = 'http://hl7.org/fhir/_organizationReference' satisfies OwlObjectProperty;

/**
 * _minimumVolume
 *
 * (Modified) SpecimenDefinition.typeTested.container.minimumVolume
 *
 * http://hl7.org/fhir/_minimumVolume
 */
export const _minimumVolume = 'http://hl7.org/fhir/_minimumVolume' satisfies OwlObjectProperty;

/**
 * precedence
 *
 * ExplanationOfBenefit.precedence: This indicates the relative order of a series of EOBs related to different coverages for the same suite of services.
 *
 * http://hl7.org/fhir/precedence
 */
export const precedence = 'http://hl7.org/fhir/precedence' satisfies OwlObjectProperty;

/**
 * CitationSummaryComponent
 *
 * CitationSummaryComponent: A human-readable display of key concepts to represent the citation.
 *
 * http://hl7.org/fhir/CitationSummaryComponent
 */
export const CitationSummaryComponent = 'http://hl7.org/fhir/CitationSummaryComponent' satisfies OwlClass;

/**
 * decision
 *
 * ExplanationOfBenefit.decision: The result of the claim, predetermination, or preauthorization adjudication.
 *
 * http://hl7.org/fhir/decision
 */
export const decision = 'http://hl7.org/fhir/decision' satisfies OwlObjectProperty;

/**
 * role
 *
 * CareTeam.participant.role: Indicates specific responsibility of an individual within the care team, such as "Primary care physician", "Trained social worker counselor", "Caregiver", etc.
 *
 * http://hl7.org/fhir/role
 */
export const role = 'http://hl7.org/fhir/role' satisfies OwlObjectProperty;

/**
 * maternalOrganismId
 *
 * SubstanceSourceMaterial.organism.hybrid.maternalOrganismId: The identifier of the maternal species constituting the hybrid organism shall be specified based on a controlled vocabulary. For plants, the parents aren’t always known, and it is unlikely that it will be known which is maternal and which is paternal.
 *
 * http://hl7.org/fhir/maternalOrganismId
 */
export const maternalOrganismId = 'http://hl7.org/fhir/maternalOrganismId' satisfies OwlObjectProperty;

/**
 * _triggeredBy
 *
 * (Modified) Observation.triggeredBy
 *
 * http://hl7.org/fhir/_triggeredBy
 */
export const _triggeredBy = 'http://hl7.org/fhir/_triggeredBy' satisfies OwlObjectProperty;

/**
 * MedicationKnowledgeStorageGuidelineComponent
 *
 * MedicationKnowledgeStorageGuidelineComponent: Information on how the medication should be stored, for example, refrigeration temperatures and length of stability at a given temperature.
 *
 * http://hl7.org/fhir/MedicationKnowledgeStorageGuidelineComponent
 */
export const MedicationKnowledgeStorageGuidelineComponent = 'http://hl7.org/fhir/MedicationKnowledgeStorageGuidelineComponent' satisfies OwlClass;

/**
 * dischargeDisposition
 *
 * Encounter.admission.dischargeDisposition: Category or kind of location after discharge.
 *
 * http://hl7.org/fhir/dischargeDisposition
 */
export const dischargeDisposition = 'http://hl7.org/fhir/dischargeDisposition' satisfies OwlObjectProperty;

/**
 * _output
 *
 * (Modified) Transport.output
 *
 * http://hl7.org/fhir/_output
 */
export const _output = 'http://hl7.org/fhir/_output' satisfies OwlObjectProperty;

/**
 * QuestionnaireItemComponent
 *
 * QuestionnaireItemComponent: A particular question, question grouping or display text that is part of the questionnaire.
 *
 * http://hl7.org/fhir/QuestionnaireItemComponent
 */
export const QuestionnaireItemComponent = 'http://hl7.org/fhir/QuestionnaireItemComponent' satisfies OwlClass;

/**
 * _compareToSourcePath
 *
 * (Modified) TestScript.test.action.assert.compareToSourcePath
 *
 * http://hl7.org/fhir/_compareToSourcePath
 */
export const _compareToSourcePath = 'http://hl7.org/fhir/_compareToSourcePath' satisfies OwlObjectProperty;

/**
 * traceNumber
 *
 * ExplanationOfBenefit.item.detail.traceNumber: Trace number for tracking purposes. May be defined at the jurisdiction level or between trading partners.
 *
 * http://hl7.org/fhir/traceNumber
 */
export const traceNumber = 'http://hl7.org/fhir/traceNumber' satisfies OwlObjectProperty;

/**
 * InsurancePlanPlanComponent
 *
 * InsurancePlanPlanComponent: Details about an insurance plan.
 *
 * http://hl7.org/fhir/InsurancePlanPlanComponent
 */
export const InsurancePlanPlanComponent = 'http://hl7.org/fhir/InsurancePlanPlanComponent' satisfies OwlClass;

/**
 * object
 *
 * TestPlan.testCase.assertion.object: The focus or object of the assertion i.e. a resource.
 *
 * http://hl7.org/fhir/object
 */
export const object = 'http://hl7.org/fhir/object' satisfies OwlObjectProperty;

/**
 * statusReason
 *
 * Transport.statusReason: An explanation as to why this transport is held, failed, was refused, etc.
 *
 * http://hl7.org/fhir/statusReason
 */
export const statusReason = 'http://hl7.org/fhir/statusReason' satisfies OwlObjectProperty;

/**
 * recall
 *
 * DeviceDefinition.correctiveAction.recall: Whether the last corrective action known for this device was a recall.
 *
 * http://hl7.org/fhir/recall
 */
export const recall = 'http://hl7.org/fhir/recall' satisfies OwlObjectProperty;

/**
 * _codeSystem
 *
 * (Modified) TerminologyCapabilities.codeSystem
 *
 * http://hl7.org/fhir/_codeSystem
 */
export const _codeSystem = 'http://hl7.org/fhir/_codeSystem' satisfies OwlObjectProperty;

/**
 * _processing
 *
 * (Modified) Specimen.processing
 *
 * http://hl7.org/fhir/_processing
 */
export const _processing = 'http://hl7.org/fhir/_processing' satisfies OwlObjectProperty;

/**
 * gateway
 *
 * Device.gateway: The linked device acting as a communication controller, data collector, translator, or concentrator for the current device (e.g., mobile phone application that relays a blood pressure device's data).
 *
 * http://hl7.org/fhir/gateway
 */
export const gateway = 'http://hl7.org/fhir/gateway' satisfies OwlObjectProperty;

/**
 * _performerType
 *
 * (Modified) Transport.performerType
 *
 * http://hl7.org/fhir/_performerType
 */
export const _performerType = 'http://hl7.org/fhir/_performerType' satisfies OwlObjectProperty;

/**
 * _subcomponent
 *
 * (Modified) Evidence.certainty.subcomponent
 *
 * http://hl7.org/fhir/_subcomponent
 */
export const _subcomponent = 'http://hl7.org/fhir/_subcomponent' satisfies OwlObjectProperty;

/**
 * postalCode
 *
 * Address.postalCode: A postal code designating a region defined by the postal service.
 *
 * http://hl7.org/fhir/postalCode
 */
export const postalCode = 'http://hl7.org/fhir/postalCode' satisfies OwlObjectProperty;

/**
 * AddedItemDetail
 *
 * ExplanationOfBenefit.AddedItem.AddedItemDetail: The second-tier service adjudications for payor added services.
 *
 * http://hl7.org/fhir/AddedItemDetail
 */
export const AddedItemDetail = 'http://hl7.org/fhir/AddedItemDetail' satisfies OwlClass;

/**
 * instance
 *
 * ChargeItemDefinition.instance: The defined billing details in this resource pertain to the given product instance(s).
 *
 * http://hl7.org/fhir/instance
 */
export const instance = 'http://hl7.org/fhir/instance' satisfies OwlObjectProperty;

/**
 * _disposition
 *
 * (Modified) PaymentReconciliation.disposition
 *
 * http://hl7.org/fhir/_disposition
 */
export const _disposition = 'http://hl7.org/fhir/_disposition' satisfies OwlObjectProperty;

/**
 * _statusDate
 *
 * (Modified) MedicinalProductDefinition.statusDate
 *
 * http://hl7.org/fhir/_statusDate
 */
export const _statusDate = 'http://hl7.org/fhir/_statusDate' satisfies OwlObjectProperty;

/**
 * _facilityType
 *
 * (Modified) DocumentReference.facilityType
 *
 * http://hl7.org/fhir/_facilityType
 */
export const _facilityType = 'http://hl7.org/fhir/_facilityType' satisfies OwlObjectProperty;

/**
 * _stratum
 *
 * (Modified) MeasureReport.group.stratifier.stratum
 *
 * http://hl7.org/fhir/_stratum
 */
export const _stratum = 'http://hl7.org/fhir/_stratum' satisfies OwlObjectProperty;

/**
 * Payee
 *
 * Claim.Payee: The party to be reimbursed for cost of the products and services according to the terms of the policy.
 *
 * http://hl7.org/fhir/Payee
 */
export const Payee = 'http://hl7.org/fhir/Payee' satisfies OwlClass;

/**
 * _measurementType
 *
 * (Modified) SubstanceDefinition.moiety.measurementType
 *
 * http://hl7.org/fhir/_measurementType
 */
export const _measurementType = 'http://hl7.org/fhir/_measurementType' satisfies OwlObjectProperty;

/**
 * RelatedArtifact
 *
 * Related artifacts such as additional documentation, justification, or bibliographic references.
 *
 * http://hl7.org/fhir/RelatedArtifact
 */
export const RelatedArtifact = 'http://hl7.org/fhir/RelatedArtifact' satisfies OwlClass;

/**
 * RequestOrchestrationActionDynamicValueComponent
 *
 * RequestOrchestrationActionComponentAction.RequestOrchestrationActionDynamicValueComponent: Customizations that should be applied to the statically defined resource. For example, if the dosage of a medication must be computed based on the patient's weight, a customization would be used to specify an expression that calculated the weight, and the path on the resource that would contain the result.
 *
 * http://hl7.org/fhir/RequestOrchestrationActionDynamicValueComponent
 */
export const RequestOrchestrationActionDynamicValueComponent = 'http://hl7.org/fhir/RequestOrchestrationActionDynamicValueComponent' satisfies OwlClass;

/**
 * identity
 *
 * StructureDefinition.mapping.identity: An Internal id that is used to identify this mapping set when specific mappings are made.
 *
 * http://hl7.org/fhir/identity
 */
export const identity = 'http://hl7.org/fhir/identity' satisfies OwlObjectProperty;

/**
 * subType
 *
 * Claim.subType: A finer grained suite of claim type codes which may convey additional information such as Inpatient vs Outpatient and/or a specialty service.
 *
 * http://hl7.org/fhir/subType
 */
export const subType = 'http://hl7.org/fhir/subType' satisfies OwlObjectProperty;

/**
 * ValueSetExpansionContainsComponent
 *
 * ValueSetExpansionComponent.ValueSetExpansionContainsComponent: The codes that are contained in the value set expansion.
 *
 * http://hl7.org/fhir/ValueSetExpansionContainsComponent
 */
export const ValueSetExpansionContainsComponent = 'http://hl7.org/fhir/ValueSetExpansionContainsComponent' satisfies OwlClass;

/**
 * MedicationKnowledgePackagingComponent
 *
 * MedicationKnowledgePackagingComponent: Information that only applies to packages (not products).
 *
 * http://hl7.org/fhir/MedicationKnowledgePackagingComponent
 */
export const MedicationKnowledgePackagingComponent = 'http://hl7.org/fhir/MedicationKnowledgePackagingComponent' satisfies OwlClass;

/**
 * _display
 *
 * (Modified) ValueSet.expansion.contains.display
 *
 * http://hl7.org/fhir/_display
 */
export const _display = 'http://hl7.org/fhir/_display' satisfies OwlObjectProperty;

/**
 * ImplementationGuideGlobalComponent
 *
 * ImplementationGuideGlobalComponent: A set of profiles that all resources covered by this implementation guide must conform to.
 *
 * http://hl7.org/fhir/ImplementationGuideGlobalComponent
 */
export const ImplementationGuideGlobalComponent = 'http://hl7.org/fhir/ImplementationGuideGlobalComponent' satisfies OwlClass;

/**
 * _SubstanceNucleicAcid
 *
 * (Modified) SubstanceNucleicAcid
 *
 * http://hl7.org/fhir/_SubstanceNucleicAcid
 */
export const _SubstanceNucleicAcid = 'http://hl7.org/fhir/_SubstanceNucleicAcid' satisfies OwlClass;

/**
 * TestScriptSetupActionOperationRequestHeaderComponent
 *
 * TestScriptTestComponent.TestActionOperation.TestScriptSetupActionOperationRequestHeaderComponent: Header elements would be used to set HTTP headers.
 *
 * http://hl7.org/fhir/TestScriptSetupActionOperationRequestHeaderComponent
 */
export const TestScriptSetupActionOperationRequestHeaderComponent = 'http://hl7.org/fhir/TestScriptSetupActionOperationRequestHeaderComponent' satisfies OwlClass;

/**
 * targetItem
 *
 * PaymentReconciliation.allocation.targetItem
 *
 * http://hl7.org/fhir/targetItem
 */
export const targetItem = 'http://hl7.org/fhir/targetItem' satisfies OwlObjectProperty;

/**
 * _dosingGuideline
 *
 * (Modified) MedicationKnowledge.indicationGuideline.dosingGuideline
 *
 * http://hl7.org/fhir/_dosingGuideline
 */
export const _dosingGuideline = 'http://hl7.org/fhir/_dosingGuideline' satisfies OwlObjectProperty;

/**
 * _totalGross
 *
 * (Modified) Invoice.totalGross
 *
 * http://hl7.org/fhir/_totalGross
 */
export const _totalGross = 'http://hl7.org/fhir/_totalGross' satisfies OwlObjectProperty;

/**
 * Reference
 *
 * A reference from one resource to another.
 *
 * http://hl7.org/fhir/Reference
 */
export const Reference = 'http://hl7.org/fhir/Reference' satisfies OwlClass;

/**
 * _precheckBehavior
 *
 * (Modified) RequestOrchestration.action.action.precheckBehavior
 *
 * http://hl7.org/fhir/_precheckBehavior
 */
export const _precheckBehavior = 'http://hl7.org/fhir/_precheckBehavior' satisfies OwlObjectProperty;

/**
 * _enableBehavior
 *
 * (Modified) Questionnaire.item.item.enableBehavior
 *
 * http://hl7.org/fhir/_enableBehavior
 */
export const _enableBehavior = 'http://hl7.org/fhir/_enableBehavior' satisfies OwlObjectProperty;

/**
 * slot
 *
 * Appointment.slot: The slots from the participants' schedules that will be filled by the appointment.
 *
 * http://hl7.org/fhir/slot
 */
export const slot = 'http://hl7.org/fhir/slot' satisfies OwlObjectProperty;

/**
 * groupDefinition
 *
 * Measure.group.stratifier.component.groupDefinition: A Group resource that defines this population as a set of characteristics.
 *
 * http://hl7.org/fhir/groupDefinition
 */
export const groupDefinition = 'http://hl7.org/fhir/groupDefinition' satisfies OwlObjectProperty;

/**
 * _verifiedWith
 *
 * (Modified) Consent.verification.verifiedWith
 *
 * http://hl7.org/fhir/_verifiedWith
 */
export const _verifiedWith = 'http://hl7.org/fhir/_verifiedWith' satisfies OwlObjectProperty;

/**
 * ResourceInteraction
 *
 * CapabilityStatementRestComponent.CapabilityStatementRestResourceComponent.ResourceInteraction: Identifies a restful operation supported by the solution.
 *
 * http://hl7.org/fhir/ResourceInteraction
 */
export const ResourceInteraction = 'http://hl7.org/fhir/ResourceInteraction' satisfies OwlClass;

/**
 * _numberOfSubunits
 *
 * (Modified) SubstanceProtein.numberOfSubunits
 *
 * http://hl7.org/fhir/_numberOfSubunits
 */
export const _numberOfSubunits = 'http://hl7.org/fhir/_numberOfSubunits' satisfies OwlObjectProperty;

/**
 * numberOfSeries
 *
 * ImagingStudy.numberOfSeries: Number of Series in the Study. This value given may be larger than the number of series elements this Resource contains due to resource availability, security, or other factors. This element should be present if any series elements are present.
 *
 * http://hl7.org/fhir/numberOfSeries
 */
export const numberOfSeries = 'http://hl7.org/fhir/numberOfSeries' satisfies OwlObjectProperty;

/**
 * preAuthRefPeriod
 *
 * ExplanationOfBenefit.preAuthRefPeriod: The timeframe during which the supplied preauthorization reference may be quoted on claims to obtain the adjudication as provided.
 *
 * http://hl7.org/fhir/preAuthRefPeriod
 */
export const preAuthRefPeriod = 'http://hl7.org/fhir/preAuthRefPeriod' satisfies OwlObjectProperty;

/**
 * _excludingRecurrenceId
 *
 * (Modified) Appointment.recurrenceTemplate.excludingRecurrenceId
 *
 * http://hl7.org/fhir/_excludingRecurrenceId
 */
export const _excludingRecurrenceId = 'http://hl7.org/fhir/_excludingRecurrenceId' satisfies OwlObjectProperty;

/**
 * _baseCitation
 *
 * (Modified) Citation.citedArtifact.part.baseCitation
 *
 * http://hl7.org/fhir/_baseCitation
 */
export const _baseCitation = 'http://hl7.org/fhir/_baseCitation' satisfies OwlObjectProperty;

/**
 * ContractAsset
 *
 * Contract.Term.ContractAsset: Contract Term Asset List.
 *
 * http://hl7.org/fhir/ContractAsset
 */
export const ContractAsset = 'http://hl7.org/fhir/ContractAsset' satisfies OwlClass;

/**
 * ClinicalImpressionFindingComponent
 *
 * ClinicalImpressionFindingComponent: Specific findings or diagnoses that were considered likely or relevant to ongoing treatment.
 *
 * http://hl7.org/fhir/ClinicalImpressionFindingComponent
 */
export const ClinicalImpressionFindingComponent = 'http://hl7.org/fhir/ClinicalImpressionFindingComponent' satisfies OwlClass;

/**
 * stopTestOnFail
 *
 * TestScript.test.action.assert.stopTestOnFail: Whether or not the current test execution will stop on failure for this assert.
 *
 * http://hl7.org/fhir/stopTestOnFail
 */
export const stopTestOnFail = 'http://hl7.org/fhir/stopTestOnFail' satisfies OwlObjectProperty;

/**
 * _selectionBehavior
 *
 * (Modified) RequestOrchestration.action.action.selectionBehavior
 *
 * http://hl7.org/fhir/_selectionBehavior
 */
export const _selectionBehavior = 'http://hl7.org/fhir/_selectionBehavior' satisfies OwlObjectProperty;

/**
 * _imports
 *
 * (Modified) CapabilityStatement.imports
 *
 * http://hl7.org/fhir/_imports
 */
export const _imports = 'http://hl7.org/fhir/_imports' satisfies OwlObjectProperty;

/**
 * contextLinkId
 *
 * Contract.term.group.action.contextLinkId: Id [identifier??] of the clause or question text related to the requester of this action in the referenced form or QuestionnaireResponse.
 *
 * http://hl7.org/fhir/contextLinkId
 */
export const contextLinkId = 'http://hl7.org/fhir/contextLinkId' satisfies OwlObjectProperty;

/**
 * _eye
 *
 * (Modified) VisionPrescription.lensSpecification.eye
 *
 * http://hl7.org/fhir/_eye
 */
export const _eye = 'http://hl7.org/fhir/_eye' satisfies OwlObjectProperty;

/**
 * affiliation
 *
 * Citation.citedArtifact.contributorship.entry.affiliation: Organization affiliated with the contributor.
 *
 * http://hl7.org/fhir/affiliation
 */
export const affiliation = 'http://hl7.org/fhir/affiliation' satisfies OwlObjectProperty;

/**
 * defaultValue
 *
 * TestScript.variable.defaultValue: A default, hard-coded, or user-defined value for this variable.
 *
 * http://hl7.org/fhir/defaultValue
 */
export const defaultValue = 'http://hl7.org/fhir/defaultValue' satisfies OwlObjectProperty;

/**
 * MolecularSequence
 *
 * Representation of a molecular sequence.
 *
 * http://hl7.org/fhir/MolecularSequence
 */
export const MolecularSequence = 'http://hl7.org/fhir/MolecularSequence' satisfies OwlClass;

/**
 * overload
 *
 * OperationDefinition.overload: Defines an appropriate combination of parameters to use when invoking this operation, to help code generators when generating overloaded parameter sets for this operation.
 *
 * http://hl7.org/fhir/overload
 */
export const overload = 'http://hl7.org/fhir/overload' satisfies OwlObjectProperty;

/**
 * _productName
 *
 * (Modified) NutritionOrder.enteralFormula.additive.productName
 *
 * http://hl7.org/fhir/_productName
 */
export const _productName = 'http://hl7.org/fhir/_productName' satisfies OwlObjectProperty;

/**
 * _comment
 *
 * (Modified) OperationDefinition.overload.comment
 *
 * http://hl7.org/fhir/_comment
 */
export const _comment = 'http://hl7.org/fhir/_comment' satisfies OwlObjectProperty;

/**
 * _profile
 *
 * (Modified) Meta.profile
 *
 * http://hl7.org/fhir/_profile
 */
export const _profile = 'http://hl7.org/fhir/_profile' satisfies OwlObjectProperty;

/**
 * _deleted
 *
 * (Modified) List.entry.deleted
 *
 * http://hl7.org/fhir/_deleted
 */
export const _deleted = 'http://hl7.org/fhir/_deleted' satisfies OwlObjectProperty;

/**
 * _workflow
 *
 * (Modified) ExampleScenario.process.step.alternative.step.workflow
 *
 * http://hl7.org/fhir/_workflow
 */
export const _workflow = 'http://hl7.org/fhir/_workflow' satisfies OwlObjectProperty;

/**
 * _attestationSignature
 *
 * (Modified) VerificationResult.validator.attestationSignature
 *
 * http://hl7.org/fhir/_attestationSignature
 */
export const _attestationSignature = 'http://hl7.org/fhir/_attestationSignature' satisfies OwlObjectProperty;

/**
 * permittedDataType
 *
 * ObservationDefinition.component.permittedDataType: The data types allowed for the value element of the instance of this component observations.
 *
 * http://hl7.org/fhir/permittedDataType
 */
export const permittedDataType = 'http://hl7.org/fhir/permittedDataType' satisfies OwlObjectProperty;

/**
 * gene
 *
 * SubstanceReferenceInformation.gene: Todo.
 *
 * http://hl7.org/fhir/gene
 */
export const gene = 'http://hl7.org/fhir/gene' satisfies OwlObjectProperty;

/**
 * _prediction
 *
 * (Modified) RiskAssessment.prediction
 *
 * http://hl7.org/fhir/_prediction
 */
export const _prediction = 'http://hl7.org/fhir/_prediction' satisfies OwlObjectProperty;

/**
 * exposureRoute
 *
 * AllergyIntolerance.reaction.exposureRoute: Identification of the route by which the subject was exposed to the substance.
 *
 * http://hl7.org/fhir/exposureRoute
 */
export const exposureRoute = 'http://hl7.org/fhir/exposureRoute' satisfies OwlObjectProperty;

/**
 * height
 *
 * Attachment.height: Height of the image in pixels (photo/video).
 *
 * http://hl7.org/fhir/height
 */
export const height = 'http://hl7.org/fhir/height' satisfies OwlObjectProperty;

/**
 * _entryClassifier
 *
 * (Modified) EvidenceReport.section.section.entryClassifier
 *
 * http://hl7.org/fhir/_entryClassifier
 */
export const _entryClassifier = 'http://hl7.org/fhir/_entryClassifier' satisfies OwlObjectProperty;

/**
 * test
 *
 * TestScript.test: A test in this script.
 *
 * http://hl7.org/fhir/test
 */
export const test = 'http://hl7.org/fhir/test' satisfies OwlObjectProperty;

/**
 * _previousAppointment
 *
 * (Modified) Appointment.previousAppointment
 *
 * http://hl7.org/fhir/_previousAppointment
 */
export const _previousAppointment = 'http://hl7.org/fhir/_previousAppointment' satisfies OwlObjectProperty;

/**
 * implementationGuide
 *
 * CapabilityStatement.implementationGuide: A list of implementation guides that the server does (or should) support in their entirety.
 *
 * http://hl7.org/fhir/implementationGuide
 */
export const implementationGuide = 'http://hl7.org/fhir/implementationGuide' satisfies OwlObjectProperty;

/**
 * UsageContext
 *
 * Specifies clinical/business/etc. metadata that can be used to retrieve, index and/or categorize an artifact. This metadata can either be specific to the applicable population (e.g., age category, DRG) or the specific context of care (e.g., venue, care setting, provider of care).
 *
 * http://hl7.org/fhir/UsageContext
 */
export const UsageContext = 'http://hl7.org/fhir/UsageContext' satisfies OwlClass;

/**
 * EventDefinition
 *
 * The EventDefinition resource provides a reusable description of when a particular event can occur.
 *
 * http://hl7.org/fhir/EventDefinition
 */
export const EventDefinition = 'http://hl7.org/fhir/EventDefinition' satisfies OwlClass;

/**
 * relatedIdentifier
 *
 * EvidenceReport.relatedIdentifier: A formal identifier that is used to identify things closely related to this EvidenceReport.
 *
 * http://hl7.org/fhir/relatedIdentifier
 */
export const relatedIdentifier = 'http://hl7.org/fhir/relatedIdentifier' satisfies OwlObjectProperty;

/**
 * ImplementationGuideDependsOnComponent
 *
 * ImplementationGuideDependsOnComponent: Another implementation guide that this implementation depends on. Typically, an implementation guide uses value sets, profiles etc.defined in other implementation guides.
 *
 * http://hl7.org/fhir/ImplementationGuideDependsOnComponent
 */
export const ImplementationGuideDependsOnComponent = 'http://hl7.org/fhir/ImplementationGuideDependsOnComponent' satisfies OwlClass;

/**
 * _procedureSequence
 *
 * (Modified) ExplanationOfBenefit.item.procedureSequence
 *
 * http://hl7.org/fhir/_procedureSequence
 */
export const _procedureSequence = 'http://hl7.org/fhir/_procedureSequence' satisfies OwlObjectProperty;

/**
 * _copyrightLabel
 *
 * (Modified) ConceptMap.copyrightLabel
 *
 * http://hl7.org/fhir/_copyrightLabel
 */
export const _copyrightLabel = 'http://hl7.org/fhir/_copyrightLabel' satisfies OwlObjectProperty;

/**
 * _navigationLinks
 *
 * (Modified) TestScript.test.action.assert.navigationLinks
 *
 * http://hl7.org/fhir/_navigationLinks
 */
export const _navigationLinks = 'http://hl7.org/fhir/_navigationLinks' satisfies OwlObjectProperty;

/**
 * _generatedBy
 *
 * (Modified) GenomicStudy.analysis.input.generatedBy
 *
 * http://hl7.org/fhir/_generatedBy
 */
export const _generatedBy = 'http://hl7.org/fhir/_generatedBy' satisfies OwlObjectProperty;

/**
 * administeredProduct
 *
 * Immunization.administeredProduct: An indication of which product was administered to the patient. This is typically a more detailed representation of the concept conveyed by the vaccineCode data element. If a Medication resource is referenced, it may be to a stand-alone resource or a contained resource within the Immunization resource.
 *
 * http://hl7.org/fhir/administeredProduct
 */
export const administeredProduct = 'http://hl7.org/fhir/administeredProduct' satisfies OwlObjectProperty;

/**
 * validateProfileId
 *
 * TestScript.test.action.assert.validateProfileId: The ID of the Profile to validate against.
 *
 * http://hl7.org/fhir/validateProfileId
 */
export const validateProfileId = 'http://hl7.org/fhir/validateProfileId' satisfies OwlObjectProperty;

/**
 * MedicationKnowledgeIndicationGuidelineComponent
 *
 * MedicationKnowledgeIndicationGuidelineComponent: Guidelines or protocols that are applicable for the administration of the medication based on indication.
 *
 * http://hl7.org/fhir/MedicationKnowledgeIndicationGuidelineComponent
 */
export const MedicationKnowledgeIndicationGuidelineComponent = 'http://hl7.org/fhir/MedicationKnowledgeIndicationGuidelineComponent' satisfies OwlClass;

/**
 * intraspecificDescription
 *
 * SubstanceSourceMaterial.organism.intraspecificDescription: The intraspecific description of an organism shall be specified based on a controlled vocabulary. For Influenza Vaccine, the intraspecific description shall contain the syntax of the antigen in line with the WHO convention.
 *
 * http://hl7.org/fhir/intraspecificDescription
 */
export const intraspecificDescription = 'http://hl7.org/fhir/intraspecificDescription' satisfies OwlObjectProperty;

/**
 * _protocolApplied
 *
 * (Modified) Immunization.protocolApplied
 *
 * http://hl7.org/fhir/_protocolApplied
 */
export const _protocolApplied = 'http://hl7.org/fhir/_protocolApplied' satisfies OwlObjectProperty;

/**
 * _VerificationResult
 *
 * (Modified) VerificationResult
 *
 * http://hl7.org/fhir/_VerificationResult
 */
export const _VerificationResult = 'http://hl7.org/fhir/_VerificationResult' satisfies OwlClass;

/**
 * monthInterval
 *
 * Appointment.recurrenceTemplate.monthlyTemplate.monthInterval: Indicates that recurring appointments should occur every nth month.
 *
 * http://hl7.org/fhir/monthInterval
 */
export const monthInterval = 'http://hl7.org/fhir/monthInterval' satisfies OwlObjectProperty;

/**
 * expiry
 *
 * Substance.expiry: When the substance is no longer valid to use. For some substances, a single arbitrary date is used for expiry.
 *
 * http://hl7.org/fhir/expiry
 */
export const expiry = 'http://hl7.org/fhir/expiry' satisfies OwlObjectProperty;

/**
 * versioning
 *
 * CapabilityStatement.rest.resource.versioning: This field is set to no-version to specify that the system does not support (server) or use (client) versioning for this resource type. If this has some other value, the server must at least correctly track and populate the versionId meta-property on resources. If the value is 'versioned-update', then the server supports all the versioning features, including using e-tags for version integrity in the API.
 *
 * http://hl7.org/fhir/versioning
 */
export const versioning = 'http://hl7.org/fhir/versioning' satisfies OwlObjectProperty;

/**
 * pushTypeAvailable
 *
 * VerificationResult.primarySource.pushTypeAvailable: Type of alerts/updates the primary source can send (specific requested changes; any changes; as defined by source).
 *
 * http://hl7.org/fhir/pushTypeAvailable
 */
export const pushTypeAvailable = 'http://hl7.org/fhir/pushTypeAvailable' satisfies OwlObjectProperty;

/**
 * CitationCitedArtifactStatusDateComponent
 *
 * CitationCitedArtifactComponent.CitationCitedArtifactStatusDateComponent: An effective date or period, historical or future, actual or expected, for a status of the cited artifact.
 *
 * http://hl7.org/fhir/CitationCitedArtifactStatusDateComponent
 */
export const CitationCitedArtifactStatusDateComponent = 'http://hl7.org/fhir/CitationCitedArtifactStatusDateComponent' satisfies OwlClass;

/**
 * _assertion
 *
 * (Modified) TestPlan.testCase.assertion
 *
 * http://hl7.org/fhir/_assertion
 */
export const _assertion = 'http://hl7.org/fhir/_assertion' satisfies OwlObjectProperty;

/**
 * diagnosis
 *
 * ExplanationOfBenefit.diagnosis.diagnosis
 *
 * http://hl7.org/fhir/diagnosis
 */
export const diagnosis = 'http://hl7.org/fhir/diagnosis' satisfies OwlObjectProperty;

/**
 * _ifNoneExist
 *
 * (Modified) Bundle.entry.request.ifNoneExist
 *
 * http://hl7.org/fhir/_ifNoneExist
 */
export const _ifNoneExist = 'http://hl7.org/fhir/_ifNoneExist' satisfies OwlObjectProperty;

/**
 * _low
 *
 * (Modified) SubstancePolymer.repeat.repeatUnit.degreeOfPolymerisation.low
 *
 * http://hl7.org/fhir/_low
 */
export const _low = 'http://hl7.org/fhir/_low' satisfies OwlObjectProperty;

/**
 * undesirableEffect
 *
 * ClinicalUseDefinition.undesirableEffect: Describe the possible undesirable effects (negative outcomes) from the use of the medicinal product as treatment.
 *
 * http://hl7.org/fhir/undesirableEffect
 */
export const undesirableEffect = 'http://hl7.org/fhir/undesirableEffect' satisfies OwlObjectProperty;

/**
 * _base
 *
 * (Modified) VisionPrescription.lensSpecification.prism.base
 *
 * http://hl7.org/fhir/_base
 */
export const _base = 'http://hl7.org/fhir/_base' satisfies OwlObjectProperty;

/**
 * queryCriteria
 *
 * SubscriptionTopic.resourceTrigger.queryCriteria: The FHIR query based rules that the server should use to determine when to trigger a notification for this subscription topic.
 *
 * http://hl7.org/fhir/queryCriteria
 */
export const queryCriteria = 'http://hl7.org/fhir/queryCriteria' satisfies OwlObjectProperty;

/**
 * _availableEndTime
 *
 * (Modified) Availability.availableTime.availableEndTime
 *
 * http://hl7.org/fhir/_availableEndTime
 */
export const _availableEndTime = 'http://hl7.org/fhir/_availableEndTime' satisfies OwlObjectProperty;

/**
 * number
 *
 * ExampleScenario.process.step.process.step.alternative.step.number: The sequential number of the step, e.g. 1.2.5.
 *
 * http://hl7.org/fhir/number
 */
export const number = 'http://hl7.org/fhir/number' satisfies OwlObjectProperty;

/**
 * spatialReference
 *
 * BodyStructure.excludedStructure.spatialReference: XY or XYZ-coordinate orientation for structure.
 *
 * http://hl7.org/fhir/spatialReference
 */
export const spatialReference = 'http://hl7.org/fhir/spatialReference' satisfies OwlObjectProperty;

/**
 * conditionality
 *
 * Requirements.statement.conditionality: This boolean flag is set to true of the text of the requirement is conditional on something e.g. it includes lanauage like 'if x then y'. This conditionality flag is introduced for purposes of filtering and colour highlighting etc.
 *
 * http://hl7.org/fhir/conditionality
 */
export const conditionality = 'http://hl7.org/fhir/conditionality' satisfies OwlObjectProperty;

/**
 * _codeFilter
 *
 * (Modified) DataRequirement.codeFilter
 *
 * http://hl7.org/fhir/_codeFilter
 */
export const _codeFilter = 'http://hl7.org/fhir/_codeFilter' satisfies OwlObjectProperty;

/**
 * SubstanceDefinitionCharacterizationComponent
 *
 * SubstanceDefinitionCharacterizationComponent: General specifications for this substance.
 *
 * http://hl7.org/fhir/SubstanceDefinitionCharacterizationComponent
 */
export const SubstanceDefinitionCharacterizationComponent = 'http://hl7.org/fhir/SubstanceDefinitionCharacterizationComponent' satisfies OwlClass;

/**
 * offsets
 *
 * SampledData.offsets: A series of data points which are decimal values separated by a single space (character u20).  The units in which the offsets are expressed are found in intervalUnit.  The absolute point at which the measurements begin SHALL be conveyed outside the scope of this datatype, e.g. Observation.effectiveDateTime for a timing offset.
 *
 * http://hl7.org/fhir/offsets
 */
export const offsets = 'http://hl7.org/fhir/offsets' satisfies OwlObjectProperty;

/**
 * _orderedBy
 *
 * (Modified) List.orderedBy
 *
 * http://hl7.org/fhir/_orderedBy
 */
export const _orderedBy = 'http://hl7.org/fhir/_orderedBy' satisfies OwlObjectProperty;

/**
 * _authorizationUrl
 *
 * (Modified) CoverageEligibilityResponse.insurance.item.authorizationUrl
 *
 * http://hl7.org/fhir/_authorizationUrl
 */
export const _authorizationUrl = 'http://hl7.org/fhir/_authorizationUrl' satisfies OwlObjectProperty;

/**
 * _carrierAIDC
 *
 * (Modified) Device.udiCarrier.carrierAIDC
 *
 * http://hl7.org/fhir/_carrierAIDC
 */
export const _carrierAIDC = 'http://hl7.org/fhir/_carrierAIDC' satisfies OwlObjectProperty;

/**
 * _episodeOfCare
 *
 * (Modified) Encounter.episodeOfCare
 *
 * http://hl7.org/fhir/_episodeOfCare
 */
export const _episodeOfCare = 'http://hl7.org/fhir/_episodeOfCare' satisfies OwlObjectProperty;

/**
 * disabledDisplay
 *
 * Questionnaire.item.item.disabledDisplay: Indicates if and how items that are disabled (because enableWhen evaluates to 'false') should be displayed.
 *
 * http://hl7.org/fhir/disabledDisplay
 */
export const disabledDisplay = 'http://hl7.org/fhir/disabledDisplay' satisfies OwlObjectProperty;

/**
 * DocumentReference
 *
 * A reference to a document of any kind for any purpose. While the term “document” implies a more narrow focus, for this resource this “document” encompasses *any* serialized object with a mime-type, it includes formal patient-centric documents (CDA), clinical notes, scanned paper, non-patient specific documents like policy text, as well as a photo, video, or audio recording acquired or used in healthcare.  The DocumentReference resource provides metadata about the document so that the document can be discovered and managed.  The actual content may be inline base64 encoded data or provided by direct reference.
 *
 * http://hl7.org/fhir/DocumentReference
 */
export const DocumentReference = 'http://hl7.org/fhir/DocumentReference' satisfies OwlClass;

/**
 * compositeScoring
 *
 * Measure.compositeScoring: If this is a composite measure, the scoring method used to combine the component measures to determine the composite score.
 *
 * http://hl7.org/fhir/compositeScoring
 */
export const compositeScoring = 'http://hl7.org/fhir/compositeScoring' satisfies OwlObjectProperty;

/**
 * _yearInterval
 *
 * (Modified) Appointment.recurrenceTemplate.yearlyTemplate.yearInterval
 *
 * http://hl7.org/fhir/_yearInterval
 */
export const _yearInterval = 'http://hl7.org/fhir/_yearInterval' satisfies OwlObjectProperty;

/**
 * RelatedPersonCommunicationComponent
 *
 * RelatedPersonCommunicationComponent: A language which may be used to communicate with the related person about the patient's health.
 *
 * http://hl7.org/fhir/RelatedPersonCommunicationComponent
 */
export const RelatedPersonCommunicationComponent = 'http://hl7.org/fhir/RelatedPersonCommunicationComponent' satisfies OwlClass;

/**
 * _displayName
 *
 * (Modified) Device.displayName
 *
 * http://hl7.org/fhir/_displayName
 */
export const _displayName = 'http://hl7.org/fhir/_displayName' satisfies OwlObjectProperty;

/**
 * _monday
 *
 * (Modified) Appointment.recurrenceTemplate.weeklyTemplate.monday
 *
 * http://hl7.org/fhir/_monday
 */
export const _monday = 'http://hl7.org/fhir/_monday' satisfies OwlObjectProperty;

/**
 * messaging
 *
 * CapabilityStatement.messaging: A description of the messaging capabilities of the solution.
 *
 * http://hl7.org/fhir/messaging
 */
export const messaging = 'http://hl7.org/fhir/messaging' satisfies OwlObjectProperty;

/**
 * geneElement
 *
 * SubstanceReferenceInformation.geneElement: Todo.
 *
 * http://hl7.org/fhir/geneElement
 */
export const geneElement = 'http://hl7.org/fhir/geneElement' satisfies OwlObjectProperty;

/**
 * exclude
 *
 * EvidenceVariable.characteristic.exclude: When true, this characteristic is an exclusion criterion. In other words, not matching this characteristic definition is equivalent to meeting this criterion.
 *
 * http://hl7.org/fhir/exclude
 */
export const exclude = 'http://hl7.org/fhir/exclude' satisfies OwlObjectProperty;

/**
 * _itemSequence
 *
 * (Modified) ExplanationOfBenefit.addItem.itemSequence
 *
 * http://hl7.org/fhir/_itemSequence
 */
export const _itemSequence = 'http://hl7.org/fhir/_itemSequence' satisfies OwlObjectProperty;

/**
 * _artifactAssessment
 *
 * (Modified) Citation.citedArtifact.classification.artifactAssessment
 *
 * http://hl7.org/fhir/_artifactAssessment
 */
export const _artifactAssessment = 'http://hl7.org/fhir/_artifactAssessment' satisfies OwlObjectProperty;

/**
 * dispenseRequest
 *
 * MedicationRequest.dispenseRequest: Indicates the specific details for the dispense or medication supply part of a medication request (also known as a Medication Prescription or Medication Order).  Note that this information is not always sent with the order.  There may be in some settings (e.g. hospitals) institutional or system support for completing the dispense details in the pharmacy department.
 *
 * http://hl7.org/fhir/dispenseRequest
 */
export const dispenseRequest = 'http://hl7.org/fhir/dispenseRequest' satisfies OwlObjectProperty;

/**
 * intendedJurisdiction
 *
 * MedicationKnowledge.intendedJurisdiction: Lists the jurisdictions that this medication knowledge was written for.
 *
 * http://hl7.org/fhir/intendedJurisdiction
 */
export const intendedJurisdiction = 'http://hl7.org/fhir/intendedJurisdiction' satisfies OwlObjectProperty;

/**
 * _restriction
 *
 * (Modified) Transport.restriction
 *
 * http://hl7.org/fhir/_restriction
 */
export const _restriction = 'http://hl7.org/fhir/_restriction' satisfies OwlObjectProperty;

/**
 * ImmunizationEvaluation
 *
 * Describes a comparison of an immunization event against published recommendations to determine if the administration is "valid" in relation to those  recommendations.
 *
 * http://hl7.org/fhir/ImmunizationEvaluation
 */
export const ImmunizationEvaluation = 'http://hl7.org/fhir/ImmunizationEvaluation' satisfies OwlClass;

/**
 * Observation
 *
 * Measurements and simple assertions made about a patient, device or other subject.
 *
 * http://hl7.org/fhir/Observation
 */
export const Observation = 'http://hl7.org/fhir/Observation' satisfies OwlClass;

/**
 * _supplier
 *
 * (Modified) SupplyRequest.supplier
 *
 * http://hl7.org/fhir/_supplier
 */
export const _supplier = 'http://hl7.org/fhir/_supplier' satisfies OwlObjectProperty;

/**
 * NutritionIntakePerformerComponent
 *
 * NutritionIntakePerformerComponent: Who performed the intake and how they were involved.
 *
 * http://hl7.org/fhir/NutritionIntakePerformerComponent
 */
export const NutritionIntakePerformerComponent = 'http://hl7.org/fhir/NutritionIntakePerformerComponent' satisfies OwlClass;

/**
 * CapabilityStatementRestComponentSearchParam
 *
 * Search parameters that are supported for searching all resources for implementations to support and/or make use of - either references to ones defined in the specification, or additional ones defined for/by the implementation. This is only for searches executed against the system-level endpoint.
 *
 * http://hl7.org/fhir/CapabilityStatementRestComponentSearchParam
 */
export const CapabilityStatementRestComponentSearchParam = 'http://hl7.org/fhir/CapabilityStatementRestComponentSearchParam' satisfies OwlClass;

/**
 * _SubstanceReferenceInformation
 *
 * (Modified) SubstanceReferenceInformation
 *
 * http://hl7.org/fhir/_SubstanceReferenceInformation
 */
export const _SubstanceReferenceInformation = 'http://hl7.org/fhir/_SubstanceReferenceInformation' satisfies OwlClass;

/**
 * _CarePlan
 *
 * (Modified) CarePlan
 *
 * http://hl7.org/fhir/_CarePlan
 */
export const _CarePlan = 'http://hl7.org/fhir/_CarePlan' satisfies OwlClass;

/**
 * AdverseEventPreventiveActionComponent
 *
 * AdverseEventPreventiveActionComponent: Preventive actions that contributed to avoiding the adverse event.
 *
 * http://hl7.org/fhir/AdverseEventPreventiveActionComponent
 */
export const AdverseEventPreventiveActionComponent = 'http://hl7.org/fhir/AdverseEventPreventiveActionComponent' satisfies OwlClass;

/**
 * outsideFoodAllowed
 *
 * NutritionOrder.outsideFoodAllowed: This modifier is used to convey whether a food item is allowed to be brought in by the patient and/or family.  If set to true, indicates that the receiving system does not need to supply the food item.
 *
 * http://hl7.org/fhir/outsideFoodAllowed
 */
export const outsideFoodAllowed = 'http://hl7.org/fhir/outsideFoodAllowed' satisfies OwlObjectProperty;

/**
 * _maxVolumeToDeliver
 *
 * (Modified) NutritionOrder.enteralFormula.maxVolumeToDeliver
 *
 * http://hl7.org/fhir/_maxVolumeToDeliver
 */
export const _maxVolumeToDeliver = 'http://hl7.org/fhir/_maxVolumeToDeliver' satisfies OwlObjectProperty;

/**
 * InventoryItemAssociationComponent
 *
 * InventoryItemAssociationComponent: Association with other items or products.
 *
 * http://hl7.org/fhir/InventoryItemAssociationComponent
 */
export const InventoryItemAssociationComponent = 'http://hl7.org/fhir/InventoryItemAssociationComponent' satisfies OwlClass;

/**
 * deliverFor
 *
 * SupplyRequest.deliverFor: The patient to whom the supply will be given or for whom they will be used.
 *
 * http://hl7.org/fhir/deliverFor
 */
export const deliverFor = 'http://hl7.org/fhir/deliverFor' satisfies OwlObjectProperty;

/**
 * ElementDefinitionExampleComponent
 *
 * ElementDefinitionExampleComponent: A sample value for this element demonstrating the type of information that would typically be found in the element.
 *
 * http://hl7.org/fhir/ElementDefinitionExampleComponent
 */
export const ElementDefinitionExampleComponent = 'http://hl7.org/fhir/ElementDefinitionExampleComponent' satisfies OwlClass;

/**
 * _totalPriceComponent
 *
 * (Modified) Invoice.totalPriceComponent
 *
 * http://hl7.org/fhir/_totalPriceComponent
 */
export const _totalPriceComponent = 'http://hl7.org/fhir/_totalPriceComponent' satisfies OwlObjectProperty;

/**
 * _carrierHRF
 *
 * (Modified) Device.udiCarrier.carrierHRF
 *
 * http://hl7.org/fhir/_carrierHRF
 */
export const _carrierHRF = 'http://hl7.org/fhir/_carrierHRF' satisfies OwlObjectProperty;

/**
 * _subProperty
 *
 * (Modified) ValueSet.expansion.contains.contains.property.subProperty
 *
 * http://hl7.org/fhir/_subProperty
 */
export const _subProperty = 'http://hl7.org/fhir/_subProperty' satisfies OwlObjectProperty;

/**
 * allowed
 *
 * MedicationRequest.substitution.allowed
 *
 * http://hl7.org/fhir/allowed
 */
export const allowed = 'http://hl7.org/fhir/allowed' satisfies OwlObjectProperty;

/**
 * _searchType
 *
 * (Modified) OperationDefinition.parameter.part.searchType
 *
 * http://hl7.org/fhir/_searchType
 */
export const _searchType = 'http://hl7.org/fhir/_searchType' satisfies OwlObjectProperty;

/**
 * List
 *
 * A List is a curated collection of resources, for things such as problem lists, allergy lists, facility list, organization list, etc.
 *
 * http://hl7.org/fhir/List
 */
export const List = 'http://hl7.org/fhir/List' satisfies OwlClass;

/**
 * responseId
 *
 * TestScript.teardown.action.operation.responseId: The fixture id (maybe new) to map to the response.
 *
 * http://hl7.org/fhir/responseId
 */
export const responseId = 'http://hl7.org/fhir/responseId' satisfies OwlObjectProperty;

/**
 * _defaultManualCompletion
 *
 * (Modified) TestScript.test.action.assert.defaultManualCompletion
 *
 * http://hl7.org/fhir/_defaultManualCompletion
 */
export const _defaultManualCompletion = 'http://hl7.org/fhir/_defaultManualCompletion' satisfies OwlObjectProperty;

/**
 * _subscriberId
 *
 * (Modified) Coverage.subscriberId
 *
 * http://hl7.org/fhir/_subscriberId
 */
export const _subscriberId = 'http://hl7.org/fhir/_subscriberId' satisfies OwlObjectProperty;

/**
 * _groupingId
 *
 * (Modified) ImplementationGuide.definition.resource.groupingId
 *
 * http://hl7.org/fhir/_groupingId
 */
export const _groupingId = 'http://hl7.org/fhir/_groupingId' satisfies OwlObjectProperty;

/**
 * _protocolPerformed
 *
 * (Modified) GenomicStudy.analysis.protocolPerformed
 *
 * http://hl7.org/fhir/_protocolPerformed
 */
export const _protocolPerformed = 'http://hl7.org/fhir/_protocolPerformed' satisfies OwlObjectProperty;

/**
 * subPotentReason
 *
 * MedicationAdministration.subPotentReason: The reason or reasons why the full dose was not administered.
 *
 * http://hl7.org/fhir/subPotentReason
 */
export const subPotentReason = 'http://hl7.org/fhir/subPotentReason' satisfies OwlObjectProperty;

/**
 * maxValue
 *
 * ElementDefinition.maxValue
 *
 * http://hl7.org/fhir/maxValue
 */
export const maxValue = 'http://hl7.org/fhir/maxValue' satisfies OwlObjectProperty;

/**
 * _data
 *
 * (Modified) TriggerDefinition.data
 *
 * http://hl7.org/fhir/_data
 */
export const _data = 'http://hl7.org/fhir/_data' satisfies OwlObjectProperty;

/**
 * _disulfideLinkage
 *
 * (Modified) SubstanceProtein.disulfideLinkage
 *
 * http://hl7.org/fhir/_disulfideLinkage
 */
export const _disulfideLinkage = 'http://hl7.org/fhir/_disulfideLinkage' satisfies OwlObjectProperty;

/**
 * metadata
 *
 * TestScript.metadata: The required capability must exist and are assumed to function correctly on the FHIR server being tested.
 *
 * http://hl7.org/fhir/metadata
 */
export const metadata = 'http://hl7.org/fhir/metadata' satisfies OwlObjectProperty;

/**
 * ConditionParticipantComponent
 *
 * ConditionParticipantComponent: Indicates who or what participated in the activities related to the condition and how they were involved.
 *
 * http://hl7.org/fhir/ConditionParticipantComponent
 */
export const ConditionParticipantComponent = 'http://hl7.org/fhir/ConditionParticipantComponent' satisfies OwlClass;

/**
 * rationale
 *
 * RiskAssessment.prediction.rationale: Additional information explaining the basis for the prediction.
 *
 * http://hl7.org/fhir/rationale
 */
export const rationale = 'http://hl7.org/fhir/rationale' satisfies OwlObjectProperty;

/**
 * tax
 *
 * ClaimResponse.addItem.detail.tax: The total of taxes applicable for this product or service.
 *
 * http://hl7.org/fhir/tax
 */
export const tax = 'http://hl7.org/fhir/tax' satisfies OwlObjectProperty;

/**
 * _line
 *
 * (Modified) Address.line
 *
 * http://hl7.org/fhir/_line
 */
export const _line = 'http://hl7.org/fhir/_line' satisfies OwlObjectProperty;

/**
 * index
 *
 * TestScript.destination.index: Abstract name given to a destination server in this test script.  The name is provided as a number starting at 1.
 *
 * http://hl7.org/fhir/index
 */
export const index = 'http://hl7.org/fhir/index' satisfies OwlObjectProperty;

/**
 * _firstPage
 *
 * (Modified) Citation.citedArtifact.publicationForm.firstPage
 *
 * http://hl7.org/fhir/_firstPage
 */
export const _firstPage = 'http://hl7.org/fhir/_firstPage' satisfies OwlObjectProperty;

/**
 * verifiedBy
 *
 * Consent.verification.verifiedBy: The person who conducted the verification/validation of the Grantor decision.
 *
 * http://hl7.org/fhir/verifiedBy
 */
export const verifiedBy = 'http://hl7.org/fhir/verifiedBy' satisfies OwlObjectProperty;

/**
 * _requestProvider
 *
 * (Modified) EnrollmentResponse.requestProvider
 *
 * http://hl7.org/fhir/_requestProvider
 */
export const _requestProvider = 'http://hl7.org/fhir/_requestProvider' satisfies OwlObjectProperty;

/**
 * Diagnosis
 *
 * ExplanationOfBenefit.Diagnosis: Information about diagnoses relevant to the claim items.
 *
 * http://hl7.org/fhir/Diagnosis
 */
export const Diagnosis = 'http://hl7.org/fhir/Diagnosis' satisfies OwlClass;

/**
 * _hybridType
 *
 * (Modified) SubstanceSourceMaterial.organism.hybrid.hybridType
 *
 * http://hl7.org/fhir/_hybridType
 */
export const _hybridType = 'http://hl7.org/fhir/_hybridType' satisfies OwlObjectProperty;

/**
 * _abnormalCodedValueSet
 *
 * (Modified) ObservationDefinition.component.qualifiedValue.abnormalCodedValueSet
 *
 * http://hl7.org/fhir/_abnormalCodedValueSet
 */
export const _abnormalCodedValueSet = 'http://hl7.org/fhir/_abnormalCodedValueSet' satisfies OwlObjectProperty;

/**
 * Encounter
 *
 * An interaction between healthcare provider(s), and/or patient(s) for the purpose of providing healthcare service(s) or assessing the health status of patient(s).
 *
 * http://hl7.org/fhir/Encounter
 */
export const Encounter = 'http://hl7.org/fhir/Encounter' satisfies OwlClass;

/**
 * expression
 *
 * RequestOrchestration.action.condition.expression: An expression that returns true or false, indicating whether or not the condition is satisfied.
 *
 * http://hl7.org/fhir/expression
 */
export const expression = 'http://hl7.org/fhir/expression' satisfies OwlObjectProperty;

/**
 * _current
 *
 * (Modified) SubscriptionTopic.resourceTrigger.queryCriteria.current
 *
 * http://hl7.org/fhir/_current
 */
export const _current = 'http://hl7.org/fhir/_current' satisfies OwlObjectProperty;

/**
 * BackboneType
 *
 * Base definition for the few data types that are allowed to carry modifier extensions.
 *
 * http://hl7.org/fhir/BackboneType
 */
export const BackboneType = 'http://hl7.org/fhir/BackboneType' satisfies OwlClass;

/**
 * collection
 *
 * SpecimenDefinition.collection: The action to be performed for collecting the specimen.
 *
 * http://hl7.org/fhir/collection
 */
export const collection = 'http://hl7.org/fhir/collection' satisfies OwlObjectProperty;

/**
 * _family
 *
 * (Modified) SubstanceSourceMaterial.organism.family
 *
 * http://hl7.org/fhir/_family
 */
export const _family = 'http://hl7.org/fhir/_family' satisfies OwlObjectProperty;

/**
 * _validated
 *
 * (Modified) TestScript.metadata.capability.validated
 *
 * http://hl7.org/fhir/_validated
 */
export const _validated = 'http://hl7.org/fhir/_validated' satisfies OwlObjectProperty;

/**
 * question
 *
 * Questionnaire.item.item.enableWhen.question: The linkId for the question whose answer (or lack of answer) governs whether this item is enabled.
 *
 * http://hl7.org/fhir/question
 */
export const question = 'http://hl7.org/fhir/question' satisfies OwlObjectProperty;

/**
 * _noMap
 *
 * (Modified) ConceptMap.group.element.noMap
 *
 * http://hl7.org/fhir/_noMap
 */
export const _noMap = 'http://hl7.org/fhir/_noMap' satisfies OwlObjectProperty;

/**
 * _comparisonGroup
 *
 * (Modified) ResearchStudy.comparisonGroup
 *
 * http://hl7.org/fhir/_comparisonGroup
 */
export const _comparisonGroup = 'http://hl7.org/fhir/_comparisonGroup' satisfies OwlObjectProperty;

/**
 * EnrollmentRequest
 *
 * This resource provides the insurance enrollment details to the insurer regarding a specified coverage.
 *
 * http://hl7.org/fhir/EnrollmentRequest
 */
export const EnrollmentRequest = 'http://hl7.org/fhir/EnrollmentRequest' satisfies OwlClass;

/**
 * _surfaceOrientation
 *
 * (Modified) BodyStructure.excludedStructure.bodyLandmarkOrientation.surfaceOrientation
 *
 * http://hl7.org/fhir/_surfaceOrientation
 */
export const _surfaceOrientation = 'http://hl7.org/fhir/_surfaceOrientation' satisfies OwlObjectProperty;

/**
 * prescription
 *
 * ExplanationOfBenefit.prescription: Prescription is the document/authorization given to the claim author for them to provide products and services for which consideration (reimbursement) is sought. Could be a RX for medications, an 'order' for oxygen or wheelchair or physiotherapy treatments.
 *
 * http://hl7.org/fhir/prescription
 */
export const prescription = 'http://hl7.org/fhir/prescription' satisfies OwlObjectProperty;

/**
 * _contributorship
 *
 * (Modified) Citation.citedArtifact.contributorship
 *
 * http://hl7.org/fhir/_contributorship
 */
export const _contributorship = 'http://hl7.org/fhir/_contributorship' satisfies OwlObjectProperty;

/**
 * synthesisType
 *
 * Evidence.synthesisType: The method to combine studies.
 *
 * http://hl7.org/fhir/synthesisType
 */
export const synthesisType = 'http://hl7.org/fhir/synthesisType' satisfies OwlObjectProperty;

/**
 * _anchor
 *
 * (Modified) ImplementationGuide.manifest.page.anchor
 *
 * http://hl7.org/fhir/_anchor
 */
export const _anchor = 'http://hl7.org/fhir/_anchor' satisfies OwlObjectProperty;

/**
 * _suppress
 *
 * (Modified) ElementDefinition.constraint.suppress
 *
 * http://hl7.org/fhir/_suppress
 */
export const _suppress = 'http://hl7.org/fhir/_suppress' satisfies OwlObjectProperty;

/**
 * _other
 *
 * (Modified) Patient.link.other
 *
 * http://hl7.org/fhir/_other
 */
export const _other = 'http://hl7.org/fhir/_other' satisfies OwlObjectProperty;

/**
 * variable
 *
 * StructureMap.group.rule.target.variable: Named context for field, if desired, and a field is specified.
 *
 * http://hl7.org/fhir/variable
 */
export const variable = 'http://hl7.org/fhir/variable' satisfies OwlObjectProperty;

/**
 * MolecularSequenceRelativeComponent
 *
 * MolecularSequenceRelativeComponent: A sequence defined relative to another sequence.
 *
 * http://hl7.org/fhir/MolecularSequenceRelativeComponent
 */
export const MolecularSequenceRelativeComponent = 'http://hl7.org/fhir/MolecularSequenceRelativeComponent' satisfies OwlClass;

/**
 * Ingredient
 *
 * An ingredient of a manufactured item or pharmaceutical product.
 *
 * http://hl7.org/fhir/Ingredient
 */
export const Ingredient = 'http://hl7.org/fhir/Ingredient' satisfies OwlClass;

/**
 * _occurrenceDateTime
 *
 * (Modified) GuidanceResponse.occurrenceDateTime
 *
 * http://hl7.org/fhir/_occurrenceDateTime
 */
export const _occurrenceDateTime = 'http://hl7.org/fhir/_occurrenceDateTime' satisfies OwlObjectProperty;

/**
 * Annotation
 *
 * A  text note which also  contains information about who made the statement and when.
 *
 * http://hl7.org/fhir/Annotation
 */
export const Annotation = 'http://hl7.org/fhir/Annotation' satisfies OwlClass;

/**
 * SubstanceReferenceInformationGeneComponent
 *
 * SubstanceReferenceInformationGeneComponent: Todo.
 *
 * http://hl7.org/fhir/SubstanceReferenceInformationGeneComponent
 */
export const SubstanceReferenceInformationGeneComponent = 'http://hl7.org/fhir/SubstanceReferenceInformationGeneComponent' satisfies OwlClass;

/**
 * _valueQuantity
 *
 * (Modified) Evidence.statistic.modelCharacteristic.variable.valueQuantity
 *
 * http://hl7.org/fhir/_valueQuantity
 */
export const _valueQuantity = 'http://hl7.org/fhir/_valueQuantity' satisfies OwlObjectProperty;

/**
 * DeviceDefinitionCorrectiveActionComponent
 *
 * DeviceDefinitionCorrectiveActionComponent: Tracking of latest field safety corrective action.
 *
 * http://hl7.org/fhir/DeviceDefinitionCorrectiveActionComponent
 */
export const DeviceDefinitionCorrectiveActionComponent = 'http://hl7.org/fhir/DeviceDefinitionCorrectiveActionComponent' satisfies OwlClass;

/**
 * OperationDefinitionParameterComponent
 *
 * OperationDefinitionParameterComponent: The parameters for the operation/query.
 *
 * http://hl7.org/fhir/OperationDefinitionParameterComponent
 */
export const OperationDefinitionParameterComponent = 'http://hl7.org/fhir/OperationDefinitionParameterComponent' satisfies OwlClass;

/**
 * EvidenceVariableCharacteristicDefinitionByCombinationComponent
 *
 * EvidenceVariableCharacteristicComponent.EvidenceVariableCharacteristicDefinitionByCombinationComponent: Defines the characteristic as a combination of two or more characteristics.
 *
 * http://hl7.org/fhir/EvidenceVariableCharacteristicDefinitionByCombinationComponent
 */
export const EvidenceVariableCharacteristicDefinitionByCombinationComponent = 'http://hl7.org/fhir/EvidenceVariableCharacteristicDefinitionByCombinationComponent' satisfies OwlClass;

/**
 * SpecimenDefinitionTypeTestedHandlingComponent
 *
 * SpecimenDefinitionTypeTestedComponent.SpecimenDefinitionTypeTestedHandlingComponent: Set of instructions for preservation/transport of the specimen at a defined temperature interval, prior the testing process.
 *
 * http://hl7.org/fhir/SpecimenDefinitionTypeTestedHandlingComponent
 */
export const SpecimenDefinitionTypeTestedHandlingComponent = 'http://hl7.org/fhir/SpecimenDefinitionTypeTestedHandlingComponent' satisfies OwlClass;

/**
 * _testRun
 *
 * (Modified) TestPlan.testCase.testRun
 *
 * http://hl7.org/fhir/_testRun
 */
export const _testRun = 'http://hl7.org/fhir/_testRun' satisfies OwlObjectProperty;

/**
 * compareToSourceId
 *
 * TestScript.test.action.assert.compareToSourceId: Id of the source fixture used as the contents to be evaluated by either the "source/expression" or "sourceId/path" definition.
 *
 * http://hl7.org/fhir/compareToSourceId
 */
export const compareToSourceId = 'http://hl7.org/fhir/compareToSourceId' satisfies OwlObjectProperty;

/**
 * _definitional
 *
 * (Modified) MedicationKnowledge.definitional
 *
 * http://hl7.org/fhir/_definitional
 */
export const _definitional = 'http://hl7.org/fhir/_definitional' satisfies OwlObjectProperty;

/**
 * _testCase
 *
 * (Modified) TestPlan.testCase
 *
 * http://hl7.org/fhir/_testCase
 */
export const _testCase = 'http://hl7.org/fhir/_testCase' satisfies OwlObjectProperty;

/**
 * _PaymentReconciliation
 *
 * (Modified) PaymentReconciliation
 *
 * http://hl7.org/fhir/_PaymentReconciliation
 */
export const _PaymentReconciliation = 'http://hl7.org/fhir/_PaymentReconciliation' satisfies OwlClass;

/**
 * valuedItem
 *
 * Contract.term.group.asset.valuedItem: Contract Valued Item List.
 *
 * http://hl7.org/fhir/valuedItem
 */
export const valuedItem = 'http://hl7.org/fhir/valuedItem' satisfies OwlObjectProperty;

/**
 * relatedItem
 *
 * InventoryItem.association.relatedItem: The related item or product.
 *
 * http://hl7.org/fhir/relatedItem
 */
export const relatedItem = 'http://hl7.org/fhir/relatedItem' satisfies OwlObjectProperty;

/**
 * consumedItem
 *
 * NutritionIntake.consumedItem: What food or fluid product or item was consumed.
 *
 * http://hl7.org/fhir/consumedItem
 */
export const consumedItem = 'http://hl7.org/fhir/consumedItem' satisfies OwlObjectProperty;

/**
 * search
 *
 * CompartmentDefinition.search: Whether the search syntax is supported,.
 *
 * http://hl7.org/fhir/search
 */
export const search = 'http://hl7.org/fhir/search' satisfies OwlObjectProperty;

/**
 * duration
 *
 * EvidenceVariable.characteristic.definitionByCombination.characteristic.duration
 *
 * http://hl7.org/fhir/duration
 */
export const duration = 'http://hl7.org/fhir/duration' satisfies OwlObjectProperty;

/**
 * status
 *
 * PackagedProductDefinition.status: The status within the lifecycle of this item. A high level status, this is not intended to duplicate details carried elsewhere such as legal status, or authorization or marketing status.
 *
 * http://hl7.org/fhir/status
 */
export const status = 'http://hl7.org/fhir/status' satisfies OwlObjectProperty;

/**
 * _context
 *
 * (Modified) Contract.term.group.asset.context
 *
 * http://hl7.org/fhir/_context
 */
export const _context = 'http://hl7.org/fhir/_context' satisfies OwlObjectProperty;

/**
 * _requirements
 *
 * (Modified) ElementDefinition.constraint.requirements
 *
 * http://hl7.org/fhir/_requirements
 */
export const _requirements = 'http://hl7.org/fhir/_requirements' satisfies OwlObjectProperty;

/**
 * _subjectType
 *
 * (Modified) Questionnaire.subjectType
 *
 * http://hl7.org/fhir/_subjectType
 */
export const _subjectType = 'http://hl7.org/fhir/_subjectType' satisfies OwlObjectProperty;

/**
 * _use
 *
 * (Modified) OperationDefinition.parameter.use
 *
 * http://hl7.org/fhir/_use
 */
export const _use = 'http://hl7.org/fhir/_use' satisfies OwlObjectProperty;

/**
 * udi
 *
 * ExplanationOfBenefit.item.detail.udi: Unique Device Identifiers associated with this line item.
 *
 * http://hl7.org/fhir/udi
 */
export const udi = 'http://hl7.org/fhir/udi' satisfies OwlObjectProperty;

/**
 * nameType
 *
 * InventoryItem.name.nameType: The type of name e.g. 'brand-name', 'functional-name', 'common-name'.
 *
 * http://hl7.org/fhir/nameType
 */
export const nameType = 'http://hl7.org/fhir/nameType' satisfies OwlObjectProperty;

/**
 * _producedFrom
 *
 * (Modified) AdministrableProductDefinition.producedFrom
 *
 * http://hl7.org/fhir/_producedFrom
 */
export const _producedFrom = 'http://hl7.org/fhir/_producedFrom' satisfies OwlObjectProperty;

/**
 * _interval
 *
 * (Modified) SampledData.interval
 *
 * http://hl7.org/fhir/_interval
 */
export const _interval = 'http://hl7.org/fhir/_interval' satisfies OwlObjectProperty;

/**
 * summary
 *
 * Citation.summary: A human-readable display of key concepts to represent the citation.
 *
 * http://hl7.org/fhir/summary
 */
export const summary = 'http://hl7.org/fhir/summary' satisfies OwlObjectProperty;

/**
 * MedicinalProductDefinitionCharacteristicComponent
 *
 * MedicinalProductDefinitionCharacteristicComponent: Allows the key product features to be recorded, such as "sugar free", "modified release", "parallel import".
 *
 * http://hl7.org/fhir/MedicinalProductDefinitionCharacteristicComponent
 */
export const MedicinalProductDefinitionCharacteristicComponent = 'http://hl7.org/fhir/MedicinalProductDefinitionCharacteristicComponent' satisfies OwlClass;

/**
 * sex
 *
 * FamilyMemberHistory.sex: The birth sex of the family member.
 *
 * http://hl7.org/fhir/sex
 */
export const sex = 'http://hl7.org/fhir/sex' satisfies OwlObjectProperty;

/**
 * AdministrableProductDefinition
 *
 * A medicinal product in the final form which is suitable for administering to a patient (after any mixing of multiple components, dissolution etc. has been performed).
 *
 * http://hl7.org/fhir/AdministrableProductDefinition
 */
export const AdministrableProductDefinition = 'http://hl7.org/fhir/AdministrableProductDefinition' satisfies OwlClass;

/**
 * SecurityLabel
 *
 * Contract.Term.SecurityLabel: Security labels that protect the handling of information about the term and its elements, which may be specifically identified.
 *
 * http://hl7.org/fhir/SecurityLabel
 */
export const SecurityLabel = 'http://hl7.org/fhir/SecurityLabel' satisfies OwlClass;

/**
 * SubstanceDefinitionRelationshipComponent
 *
 * SubstanceDefinitionRelationshipComponent: A link between this substance and another, with details of the relationship.
 *
 * http://hl7.org/fhir/SubstanceDefinitionRelationshipComponent
 */
export const SubstanceDefinitionRelationshipComponent = 'http://hl7.org/fhir/SubstanceDefinitionRelationshipComponent' satisfies OwlClass;

/**
 * knownAllergen
 *
 * NutritionProduct.knownAllergen: Allergens that are known or suspected to be a part of this nutrition product.
 *
 * http://hl7.org/fhir/knownAllergen
 */
export const knownAllergen = 'http://hl7.org/fhir/knownAllergen' satisfies OwlObjectProperty;

/**
 * knownDataCount
 *
 * Evidence.statistic.sampleSize.knownDataCount: Number of participants with known results for measured variables.
 *
 * http://hl7.org/fhir/knownDataCount
 */
export const knownDataCount = 'http://hl7.org/fhir/knownDataCount' satisfies OwlObjectProperty;

/**
 * observer
 *
 * AuditEvent.source.observer: Identifier of the source where the event was detected.
 *
 * http://hl7.org/fhir/observer
 */
export const observer = 'http://hl7.org/fhir/observer' satisfies OwlObjectProperty;

/**
 * _subtitle
 *
 * (Modified) PlanDefinition.subtitle
 *
 * http://hl7.org/fhir/_subtitle
 */
export const _subtitle = 'http://hl7.org/fhir/_subtitle' satisfies OwlObjectProperty;

/**
 * accessionNumber
 *
 * Citation.citedArtifact.publicationForm.accessionNumber: Entry number or identifier for inclusion in a database.
 *
 * http://hl7.org/fhir/accessionNumber
 */
export const accessionNumber = 'http://hl7.org/fhir/accessionNumber' satisfies OwlObjectProperty;

/**
 * _finding
 *
 * (Modified) ClinicalImpression.finding
 *
 * http://hl7.org/fhir/_finding
 */
export const _finding = 'http://hl7.org/fhir/_finding' satisfies OwlObjectProperty;

/**
 * _style
 *
 * (Modified) Citation.citedArtifact.contributorship.summary.style
 *
 * http://hl7.org/fhir/_style
 */
export const _style = 'http://hl7.org/fhir/_style' satisfies OwlObjectProperty;

/**
 * relation
 *
 * DeviceDefinition.link.relation: The type indicates the relationship of the related device to the device instance.
 *
 * http://hl7.org/fhir/relation
 */
export const relation = 'http://hl7.org/fhir/relation' satisfies OwlObjectProperty;

/**
 * priority
 *
 * Transport.priority: Indicates how quickly the Transport should be addressed with respect to other requests.
 *
 * http://hl7.org/fhir/priority
 */
export const priority = 'http://hl7.org/fhir/priority' satisfies OwlObjectProperty;

/**
 * _requestId
 *
 * (Modified) TestScript.teardown.action.operation.requestId
 *
 * http://hl7.org/fhir/_requestId
 */
export const _requestId = 'http://hl7.org/fhir/_requestId' satisfies OwlObjectProperty;

/**
 * ElementDefinitionBindingComponent
 *
 * ElementDefinitionBindingComponent: Binds to a value set if this element is coded (code, Coding, CodeableConcept, Quantity), or the data types (string, uri).
 *
 * http://hl7.org/fhir/ElementDefinitionBindingComponent
 */
export const ElementDefinitionBindingComponent = 'http://hl7.org/fhir/ElementDefinitionBindingComponent' satisfies OwlClass;

/**
 * sequenceAttachment
 *
 * SubstanceProtein.subunit.sequenceAttachment: The sequence information shall be provided enumerating the amino acids from N- to C-terminal end using standard single-letter amino acid codes. Uppercase shall be used for L-amino acids and lowercase for D-amino acids. Transcribed SubstanceProteins will always be described using the translated sequence; for synthetic peptide containing amino acids that are not represented with a single letter code an X should be used within the sequence. The modified amino acids will be distinguished by their position in the sequence.
 *
 * http://hl7.org/fhir/sequenceAttachment
 */
export const sequenceAttachment = 'http://hl7.org/fhir/sequenceAttachment' satisfies OwlObjectProperty;

/**
 * AddedItemBodySite
 *
 * ExplanationOfBenefit.AddedItem.AddedItemBodySite: Physical location where the service is performed or applies.
 *
 * http://hl7.org/fhir/AddedItemBodySite
 */
export const AddedItemBodySite = 'http://hl7.org/fhir/AddedItemBodySite' satisfies OwlClass;

/**
 * _group
 *
 * (Modified) StructureMap.group
 *
 * http://hl7.org/fhir/_group
 */
export const _group = 'http://hl7.org/fhir/_group' satisfies OwlObjectProperty;

/**
 * publisher
 *
 * ConditionDefinition.publisher: The name of the organization or individual responsible for the release and ongoing maintenance of the condition definition.
 *
 * http://hl7.org/fhir/publisher
 */
export const publisher = 'http://hl7.org/fhir/publisher' satisfies OwlObjectProperty;

/**
 * consent
 *
 * ResearchSubject.consent: A record of the patient's informed agreement to participate in the study.
 *
 * http://hl7.org/fhir/consent
 */
export const consent = 'http://hl7.org/fhir/consent' satisfies OwlObjectProperty;

/**
 * site
 *
 * ExplanationOfBenefit.item.bodySite.site: Physical service site on the patient (limb, tooth, etc.).
 *
 * http://hl7.org/fhir/site
 */
export const site = 'http://hl7.org/fhir/site' satisfies OwlObjectProperty;

/**
 * canFilterBy
 *
 * SubscriptionTopic.canFilterBy: List of properties by which Subscriptions on the SubscriptionTopic can be filtered. May be defined Search Parameters (e.g., Encounter.patient) or parameters defined within this SubscriptionTopic context (e.g., hub.event).
 *
 * http://hl7.org/fhir/canFilterBy
 */
export const canFilterBy = 'http://hl7.org/fhir/canFilterBy' satisfies OwlObjectProperty;

/**
 * TerminologyCapabilitiesValidateCodeComponent
 *
 * TerminologyCapabilitiesValidateCodeComponent: Information about the [ValueSet/$validate-code](valueset-operation-validate-code.html) operation.
 *
 * http://hl7.org/fhir/TerminologyCapabilitiesValidateCodeComponent
 */
export const TerminologyCapabilitiesValidateCodeComponent = 'http://hl7.org/fhir/TerminologyCapabilitiesValidateCodeComponent' satisfies OwlClass;

/**
 * _isSubPotent
 *
 * (Modified) MedicationAdministration.isSubPotent
 *
 * http://hl7.org/fhir/_isSubPotent
 */
export const _isSubPotent = 'http://hl7.org/fhir/_isSubPotent' satisfies OwlObjectProperty;

/**
 * EncounterParticipantComponent
 *
 * EncounterParticipantComponent: The list of people responsible for providing the service.
 *
 * http://hl7.org/fhir/EncounterParticipantComponent
 */
export const EncounterParticipantComponent = 'http://hl7.org/fhir/EncounterParticipantComponent' satisfies OwlClass;

/**
 * _cancellationReason
 *
 * (Modified) Appointment.cancellationReason
 *
 * http://hl7.org/fhir/_cancellationReason
 */
export const _cancellationReason = 'http://hl7.org/fhir/_cancellationReason' satisfies OwlObjectProperty;

/**
 * _repetitions
 *
 * (Modified) Transport.restriction.repetitions
 *
 * http://hl7.org/fhir/_repetitions
 */
export const _repetitions = 'http://hl7.org/fhir/_repetitions' satisfies OwlObjectProperty;

/**
 * TestPlanTestCaseTestRunScriptComponent
 *
 * TestPlanTestCaseComponent.TestPlanTestCaseTestRunComponent.TestPlanTestCaseTestRunScriptComponent: The test cases in a structured language e.g. gherkin, Postman, or FHIR TestScript.
 *
 * http://hl7.org/fhir/TestPlanTestCaseTestRunScriptComponent
 */
export const TestPlanTestCaseTestRunScriptComponent = 'http://hl7.org/fhir/TestPlanTestCaseTestRunScriptComponent' satisfies OwlClass;

/**
 * distributor
 *
 * DeviceDefinition.packaging.packaging.distributor: An organization that distributes the packaged device.
 *
 * http://hl7.org/fhir/distributor
 */
export const distributor = 'http://hl7.org/fhir/distributor' satisfies OwlObjectProperty;

/**
 * _stopTestOnFail
 *
 * (Modified) TestScript.test.action.assert.stopTestOnFail
 *
 * http://hl7.org/fhir/_stopTestOnFail
 */
export const _stopTestOnFail = 'http://hl7.org/fhir/_stopTestOnFail' satisfies OwlObjectProperty;

/**
 * organizationReference
 *
 * DeviceDefinition.packaging.packaging.distributor.organizationReference: Distributor as an Organization resource.
 *
 * http://hl7.org/fhir/organizationReference
 */
export const organizationReference = 'http://hl7.org/fhir/organizationReference' satisfies OwlObjectProperty;

/**
 * residueSite
 *
 * SubstanceNucleicAcid.subunit.sugar.residueSite: The residues that contain a given sugar will be captured. The order of given residues will be captured in the 5‘-3‘direction consistent with the base sequences listed above.
 *
 * http://hl7.org/fhir/residueSite
 */
export const residueSite = 'http://hl7.org/fhir/residueSite' satisfies OwlObjectProperty;

/**
 * guidance
 *
 * Measure.guidance: Additional guidance for the measure including how it can be used in a clinical context, and the intent of the measure.
 *
 * http://hl7.org/fhir/guidance
 */
export const guidance = 'http://hl7.org/fhir/guidance' satisfies OwlObjectProperty;

/**
 * _originatingAppointment
 *
 * (Modified) Appointment.originatingAppointment
 *
 * http://hl7.org/fhir/_originatingAppointment
 */
export const _originatingAppointment = 'http://hl7.org/fhir/_originatingAppointment' satisfies OwlObjectProperty;

/**
 * intended
 *
 * Evidence.variableDefinition.intended: Definition of the intended variable related to the Evidence.
 *
 * http://hl7.org/fhir/intended
 */
export const intended = 'http://hl7.org/fhir/intended' satisfies OwlObjectProperty;

/**
 * _measurementFrequency
 *
 * (Modified) DeviceMetric.measurementFrequency
 *
 * http://hl7.org/fhir/_measurementFrequency
 */
export const _measurementFrequency = 'http://hl7.org/fhir/_measurementFrequency' satisfies OwlObjectProperty;

/**
 * _variableRole
 *
 * (Modified) Evidence.variableDefinition.variableRole
 *
 * http://hl7.org/fhir/_variableRole
 */
export const _variableRole = 'http://hl7.org/fhir/_variableRole' satisfies OwlObjectProperty;

/**
 * assurance
 *
 * Person.link.assurance: Level of assurance that this link is associated with the target resource.
 *
 * http://hl7.org/fhir/assurance
 */
export const assurance = 'http://hl7.org/fhir/assurance' satisfies OwlObjectProperty;

/**
 * literal
 *
 * MolecularSequence.literal: Sequence that was observed.
 *
 * http://hl7.org/fhir/literal
 */
export const literal = 'http://hl7.org/fhir/literal' satisfies OwlObjectProperty;

/**
 * _suppliedItem
 *
 * (Modified) SupplyDelivery.suppliedItem
 *
 * http://hl7.org/fhir/_suppliedItem
 */
export const _suppliedItem = 'http://hl7.org/fhir/_suppliedItem' satisfies OwlObjectProperty;

/**
 * ProcedurePerformerComponent
 *
 * ProcedurePerformerComponent: Indicates who or what performed the procedure and how they were involved.
 *
 * http://hl7.org/fhir/ProcedurePerformerComponent
 */
export const ProcedurePerformerComponent = 'http://hl7.org/fhir/ProcedurePerformerComponent' satisfies OwlClass;

/**
 * baseUnit
 *
 * InventoryItem.baseUnit: The base unit of measure - the unit in which the product is used or counted.
 *
 * http://hl7.org/fhir/baseUnit
 */
export const baseUnit = 'http://hl7.org/fhir/baseUnit' satisfies OwlObjectProperty;

/**
 * _translation
 *
 * (Modified) TerminologyCapabilities.closure.translation
 *
 * http://hl7.org/fhir/_translation
 */
export const _translation = 'http://hl7.org/fhir/_translation' satisfies OwlObjectProperty;

/**
 * StructureDefinitionSnapshotComponent
 *
 * StructureDefinitionSnapshotComponent: A snapshot view is expressed in a standalone form that can be used and interpreted without considering the base StructureDefinition.
 *
 * http://hl7.org/fhir/StructureDefinitionSnapshotComponent
 */
export const StructureDefinitionSnapshotComponent = 'http://hl7.org/fhir/StructureDefinitionSnapshotComponent' satisfies OwlClass;

/**
 * _name
 *
 * (Modified) InventoryItem.name.name
 *
 * http://hl7.org/fhir/_name
 */
export const _name = 'http://hl7.org/fhir/_name' satisfies OwlObjectProperty;

/**
 * MedicationRequestDispenseRequestInitialFillComponent
 *
 * MedicationRequestDispenseRequestComponent.MedicationRequestDispenseRequestInitialFillComponent: Indicates the quantity or duration for the first dispense of the medication.
 *
 * http://hl7.org/fhir/MedicationRequestDispenseRequestInitialFillComponent
 */
export const MedicationRequestDispenseRequestInitialFillComponent = 'http://hl7.org/fhir/MedicationRequestDispenseRequestInitialFillComponent' satisfies OwlClass;

/**
 * _incidence
 *
 * (Modified) ClinicalUseDefinition.interaction.incidence
 *
 * http://hl7.org/fhir/_incidence
 */
export const _incidence = 'http://hl7.org/fhir/_incidence' satisfies OwlObjectProperty;

/**
 * _during
 *
 * (Modified) Availability.notAvailableTime.during
 *
 * http://hl7.org/fhir/_during
 */
export const _during = 'http://hl7.org/fhir/_during' satisfies OwlObjectProperty;

/**
 * _snapshot
 *
 * (Modified) StructureDefinition.snapshot
 *
 * http://hl7.org/fhir/_snapshot
 */
export const _snapshot = 'http://hl7.org/fhir/_snapshot' satisfies OwlObjectProperty;

/**
 * SubstancePolymerRepeatRepeatUnitComponent
 *
 * SubstancePolymerRepeatComponent.SubstancePolymerRepeatRepeatUnitComponent: An SRU - Structural Repeat Unit.
 *
 * http://hl7.org/fhir/SubstancePolymerRepeatRepeatUnitComponent
 */
export const SubstancePolymerRepeatRepeatUnitComponent = 'http://hl7.org/fhir/SubstancePolymerRepeatRepeatUnitComponent' satisfies OwlClass;

/**
 * _format
 *
 * (Modified) SubstancePolymer.repeat.repeatUnit.structuralRepresentation.format
 *
 * http://hl7.org/fhir/_format
 */
export const _format = 'http://hl7.org/fhir/_format' satisfies OwlObjectProperty;

/**
 * PlanBenefit
 *
 * InsurancePlanPlanComponent.InsurancePlanPlanSpecificCostComponent.PlanBenefit: List of the specific benefits under this category of benefit.
 *
 * http://hl7.org/fhir/PlanBenefit
 */
export const PlanBenefit = 'http://hl7.org/fhir/PlanBenefit' satisfies OwlClass;

/**
 * _foodPreferenceModifier
 *
 * (Modified) NutritionOrder.foodPreferenceModifier
 *
 * http://hl7.org/fhir/_foodPreferenceModifier
 */
export const _foodPreferenceModifier = 'http://hl7.org/fhir/_foodPreferenceModifier' satisfies OwlObjectProperty;

/**
 * function
 *
 * ChargeItem.performer.function: Describes the type of performance or participation(e.g. primary surgeon, anesthesiologiest, etc.).
 * Note that `function` is a reserved Javascript keyword, and is therefore suffixed by `__workaround`.
 * For a list of reserved keywords, see https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Lexical_grammar#Keywords.
 *
 * http://hl7.org/fhir/function
 */
export const function__workaround = 'http://hl7.org/fhir/function' satisfies OwlObjectProperty;

/**
 * environmentType
 *
 * Endpoint.environmentType: The type of environment(s) exposed at this endpoint (dev, prod, test, etc.).
 *
 * http://hl7.org/fhir/environmentType
 */
export const environmentType = 'http://hl7.org/fhir/environmentType' satisfies OwlObjectProperty;

/**
 * SubscriptionTopicCanFilterByComponent
 *
 * SubscriptionTopicCanFilterByComponent: List of properties by which Subscriptions on the SubscriptionTopic can be filtered. May be defined Search Parameters (e.g., Encounter.patient) or parameters defined within this SubscriptionTopic context (e.g., hub.event).
 *
 * http://hl7.org/fhir/SubscriptionTopicCanFilterByComponent
 */
export const SubscriptionTopicCanFilterByComponent = 'http://hl7.org/fhir/SubscriptionTopicCanFilterByComponent' satisfies OwlClass;

/**
 * occurrenceCount
 *
 * Appointment.recurrenceTemplate.occurrenceCount: How many appointments are planned in the recurrence.
 *
 * http://hl7.org/fhir/occurrenceCount
 */
export const occurrenceCount = 'http://hl7.org/fhir/occurrenceCount' satisfies OwlObjectProperty;

/**
 * careTeamSequence
 *
 * ExplanationOfBenefit.item.careTeamSequence: Care team members related to this service or product.
 *
 * http://hl7.org/fhir/careTeamSequence
 */
export const careTeamSequence = 'http://hl7.org/fhir/careTeamSequence' satisfies OwlObjectProperty;

/**
 * _notConsumedReason
 *
 * (Modified) NutritionIntake.consumedItem.notConsumedReason
 *
 * http://hl7.org/fhir/_notConsumedReason
 */
export const _notConsumedReason = 'http://hl7.org/fhir/_notConsumedReason' satisfies OwlObjectProperty;

/**
 * _restoreDate
 *
 * (Modified) MarketingStatus.restoreDate
 *
 * http://hl7.org/fhir/_restoreDate
 */
export const _restoreDate = 'http://hl7.org/fhir/_restoreDate' satisfies OwlObjectProperty;

/**
 * providedBy
 *
 * HealthcareService.providedBy: The organization that provides this healthcare service.
 *
 * http://hl7.org/fhir/providedBy
 */
export const providedBy = 'http://hl7.org/fhir/providedBy' satisfies OwlObjectProperty;

/**
 * meta
 *
 * Resource.meta: The metadata about the resource. This is content that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.
 *
 * http://hl7.org/fhir/meta
 */
export const meta = 'http://hl7.org/fhir/meta' satisfies OwlObjectProperty;

/**
 * _subDetailSequence
 *
 * (Modified) ExplanationOfBenefit.addItem.subDetailSequence
 *
 * http://hl7.org/fhir/_subDetailSequence
 */
export const _subDetailSequence = 'http://hl7.org/fhir/_subDetailSequence' satisfies OwlObjectProperty;

/**
 * required
 *
 * Questionnaire.item.required: An indication, if true, that the item must be present in a "completed" QuestionnaireResponse.  If false, the item may be skipped when answering the questionnaire.
 *
 * http://hl7.org/fhir/required
 */
export const required = 'http://hl7.org/fhir/required' satisfies OwlObjectProperty;

/**
 * _dateWritten
 *
 * (Modified) VisionPrescription.dateWritten
 *
 * http://hl7.org/fhir/_dateWritten
 */
export const _dateWritten = 'http://hl7.org/fhir/_dateWritten' satisfies OwlObjectProperty;

/**
 * _deviceIdentifier
 *
 * (Modified) DeviceDefinition.packaging.packaging.udiDeviceIdentifier.deviceIdentifier
 *
 * http://hl7.org/fhir/_deviceIdentifier
 */
export const _deviceIdentifier = 'http://hl7.org/fhir/_deviceIdentifier' satisfies OwlObjectProperty;

/**
 * referral
 *
 * ExplanationOfBenefit.referral: The referral information received by the claim author, it is not to be used when the author generates a referral for a patient. A copy of that referral may be provided as supporting information. Some insurers require proof of referral to pay for services or to pay specialist rates for services.
 *
 * http://hl7.org/fhir/referral
 */
export const referral = 'http://hl7.org/fhir/referral' satisfies OwlObjectProperty;

/**
 * _conditionality
 *
 * (Modified) Requirements.statement.conditionality
 *
 * http://hl7.org/fhir/_conditionality
 */
export const _conditionality = 'http://hl7.org/fhir/_conditionality' satisfies OwlObjectProperty;

/**
 * AuditEventSourceComponent
 *
 * AuditEventSourceComponent: The actor that is reporting the event.
 *
 * http://hl7.org/fhir/AuditEventSourceComponent
 */
export const AuditEventSourceComponent = 'http://hl7.org/fhir/AuditEventSourceComponent' satisfies OwlClass;

/**
 * _component
 *
 * (Modified) DeviceDefinition.version.component
 *
 * http://hl7.org/fhir/_component
 */
export const _component = 'http://hl7.org/fhir/_component' satisfies OwlObjectProperty;

/**
 * link
 *
 * TestScript.test.action.assert.requirement.link
 *
 * http://hl7.org/fhir/link
 */
export const link = 'http://hl7.org/fhir/link' satisfies OwlObjectProperty;

/**
 * _hasStage
 *
 * (Modified) ConditionDefinition.hasStage
 *
 * http://hl7.org/fhir/_hasStage
 */
export const _hasStage = 'http://hl7.org/fhir/_hasStage' satisfies OwlObjectProperty;

/**
 * _contentReference
 *
 * (Modified) ElementDefinition.contentReference
 *
 * http://hl7.org/fhir/_contentReference
 */
export const _contentReference = 'http://hl7.org/fhir/_contentReference' satisfies OwlObjectProperty;

/**
 * program
 *
 * Immunization.programEligibility.program: Indicates which program the patient had their eligility evaluated for.
 *
 * http://hl7.org/fhir/program
 */
export const program = 'http://hl7.org/fhir/program' satisfies OwlObjectProperty;

/**
 * OtherElement
 *
 * ConceptMapGroupComponent.SourceElement.TargetElement.OtherElement: A set of additional dependencies for this mapping to hold. This mapping is only applicable if the specified data attribute can be resolved, and it has the specified value.
 *
 * http://hl7.org/fhir/OtherElement
 */
export const OtherElement = 'http://hl7.org/fhir/OtherElement' satisfies OwlClass;

/**
 * scoringUnit
 *
 * Measure.group.scoringUnit: Defines the expected units of measure for the measure score. This element SHOULD be specified as a UCUM unit.
 *
 * http://hl7.org/fhir/scoringUnit
 */
export const scoringUnit = 'http://hl7.org/fhir/scoringUnit' satisfies OwlObjectProperty;

/**
 * _maxCount
 *
 * (Modified) Subscription.maxCount
 *
 * http://hl7.org/fhir/_maxCount
 */
export const _maxCount = 'http://hl7.org/fhir/_maxCount' satisfies OwlObjectProperty;

/**
 * ExplanationOfBenefitEventComponent
 *
 * ExplanationOfBenefitEventComponent: Information code for an event with a corresponding date or period.
 *
 * http://hl7.org/fhir/ExplanationOfBenefitEventComponent
 */
export const ExplanationOfBenefitEventComponent = 'http://hl7.org/fhir/ExplanationOfBenefitEventComponent' satisfies OwlClass;

/**
 * _ArtifactAssessment
 *
 * (Modified) ArtifactAssessment
 *
 * http://hl7.org/fhir/_ArtifactAssessment
 */
export const _ArtifactAssessment = 'http://hl7.org/fhir/_ArtifactAssessment' satisfies OwlClass;

/**
 * scope
 *
 * Contract.term.group.asset.scope: Differentiates the kind of the asset .
 *
 * http://hl7.org/fhir/scope
 */
export const scope = 'http://hl7.org/fhir/scope' satisfies OwlObjectProperty;

/**
 * inventoryListing
 *
 * InventoryReport.inventoryListing: An inventory listing section (grouped by any of the attributes).
 *
 * http://hl7.org/fhir/inventoryListing
 */
export const inventoryListing = 'http://hl7.org/fhir/inventoryListing' satisfies OwlObjectProperty;

/**
 * concentration
 *
 * Ingredient.substance.strength.concentration
 *
 * http://hl7.org/fhir/concentration
 */
export const concentration = 'http://hl7.org/fhir/concentration' satisfies OwlObjectProperty;

/**
 * _device
 *
 * (Modified) Specimen.collection.device
 *
 * http://hl7.org/fhir/_device
 */
export const _device = 'http://hl7.org/fhir/_device' satisfies OwlObjectProperty;

/**
 * hierarchyMeaning
 *
 * CodeSystem.hierarchyMeaning: The meaning of the hierarchy of concepts as represented in this resource.
 *
 * http://hl7.org/fhir/hierarchyMeaning
 */
export const hierarchyMeaning = 'http://hl7.org/fhir/hierarchyMeaning' satisfies OwlObjectProperty;

/**
 * CapabilityStatementRestComponentOperation
 *
 * Definition of an operation or a named query together with its parameters and their meaning and type.
 *
 * http://hl7.org/fhir/CapabilityStatementRestComponentOperation
 */
export const CapabilityStatementRestComponentOperation = 'http://hl7.org/fhir/CapabilityStatementRestComponentOperation' satisfies OwlClass;

/**
 * otherMap
 *
 * ConceptMap.group.unmapped.otherMap: The canonical reference to an additional ConceptMap resource instance to use for mapping if this ConceptMap resource contains no matching mapping for the source concept.
 *
 * http://hl7.org/fhir/otherMap
 */
export const otherMap = 'http://hl7.org/fhir/otherMap' satisfies OwlObjectProperty;

/**
 * answerConstraint
 *
 * Questionnaire.item.item.answerConstraint: For items that have a defined set of allowed answers (via answerOption or answerValueSet), indicates whether values *other* than those specified can be selected.
 *
 * http://hl7.org/fhir/answerConstraint
 */
export const answerConstraint = 'http://hl7.org/fhir/answerConstraint' satisfies OwlObjectProperty;

/**
 * normalCodedValueSet
 *
 * ObservationDefinition.component.qualifiedValue.normalCodedValueSet: The set of normal coded results for qualitative observations  that match the criteria of this set of qualified values.
 *
 * http://hl7.org/fhir/normalCodedValueSet
 */
export const normalCodedValueSet = 'http://hl7.org/fhir/normalCodedValueSet' satisfies OwlObjectProperty;

/**
 * global
 *
 * ImplementationGuide.global: A set of profiles that all resources covered by this implementation guide must conform to.
 *
 * http://hl7.org/fhir/global
 */
export const global = 'http://hl7.org/fhir/global' satisfies OwlObjectProperty;

/**
 * excludingRecurrenceId
 *
 * Appointment.recurrenceTemplate.excludingRecurrenceId: Any dates, such as holidays, that should be excluded from the recurrence.
 *
 * http://hl7.org/fhir/excludingRecurrenceId
 */
export const excludingRecurrenceId = 'http://hl7.org/fhir/excludingRecurrenceId' satisfies OwlObjectProperty;

/**
 * _SubstanceSourceMaterial
 *
 * (Modified) SubstanceSourceMaterial
 *
 * http://hl7.org/fhir/_SubstanceSourceMaterial
 */
export const _SubstanceSourceMaterial = 'http://hl7.org/fhir/_SubstanceSourceMaterial' satisfies OwlClass;

/**
 * validity
 *
 * Permission.validity: The period in which the permission is active.
 *
 * http://hl7.org/fhir/validity
 */
export const validity = 'http://hl7.org/fhir/validity' satisfies OwlObjectProperty;

/**
 * subjectReport
 *
 * MeasureReport.group.stratifier.stratum.population.subjectReport: A reference to an individual level MeasureReport resource for a member of the population.
 *
 * http://hl7.org/fhir/subjectReport
 */
export const subjectReport = 'http://hl7.org/fhir/subjectReport' satisfies OwlObjectProperty;

/**
 * _any
 *
 * (Modified) ElementDefinition.binding.additional.any
 *
 * http://hl7.org/fhir/_any
 */
export const _any = 'http://hl7.org/fhir/_any' satisfies OwlObjectProperty;

/**
 * _nextScheduled
 *
 * (Modified) VerificationResult.nextScheduled
 *
 * http://hl7.org/fhir/_nextScheduled
 */
export const _nextScheduled = 'http://hl7.org/fhir/_nextScheduled' satisfies OwlObjectProperty;

/**
 * administration
 *
 * NutritionOrder.enteralFormula.administration: Formula administration instructions as structured data.  This repeating structure allows for changing the administration rate or volume over time for both bolus and continuous feeding.  An example of this would be an instruction to increase the rate of continuous feeding every 2 hours.
 *
 * http://hl7.org/fhir/administration
 */
export const administration = 'http://hl7.org/fhir/administration' satisfies OwlObjectProperty;

/**
 * sort
 *
 * DataRequirement.sort: Specifies the order of the results to be returned.
 *
 * http://hl7.org/fhir/sort
 */
export const sort = 'http://hl7.org/fhir/sort' satisfies OwlObjectProperty;

/**
 * ManufacturedItemDefinitionComponentComponentProperty
 *
 * General characteristics of this component.
 *
 * http://hl7.org/fhir/ManufacturedItemDefinitionComponentComponentProperty
 */
export const ManufacturedItemDefinitionComponentComponentProperty = 'http://hl7.org/fhir/ManufacturedItemDefinitionComponentComponentProperty' satisfies OwlClass;

/**
 * _sent
 *
 * (Modified) Communication.sent
 *
 * http://hl7.org/fhir/_sent
 */
export const _sent = 'http://hl7.org/fhir/_sent' satisfies OwlObjectProperty;

/**
 * _directnessMatch
 *
 * (Modified) Evidence.variableDefinition.directnessMatch
 *
 * http://hl7.org/fhir/_directnessMatch
 */
export const _directnessMatch = 'http://hl7.org/fhir/_directnessMatch' satisfies OwlObjectProperty;

/**
 * _targetFormat
 *
 * (Modified) Signature.targetFormat
 *
 * http://hl7.org/fhir/_targetFormat
 */
export const _targetFormat = 'http://hl7.org/fhir/_targetFormat' satisfies OwlObjectProperty;

/**
 * _used
 *
 * (Modified) Procedure.used
 *
 * http://hl7.org/fhir/_used
 */
export const _used = 'http://hl7.org/fhir/_used' satisfies OwlObjectProperty;

/**
 * _occurence
 *
 * (Modified) MedicationAdministration.occurence
 *
 * http://hl7.org/fhir/_occurence
 */
export const _occurence = 'http://hl7.org/fhir/_occurence' satisfies OwlObjectProperty;

/**
 * _partOf
 *
 * (Modified) Procedure.partOf
 *
 * http://hl7.org/fhir/_partOf
 */
export const _partOf = 'http://hl7.org/fhir/_partOf' satisfies OwlObjectProperty;

/**
 * relativeRisk
 *
 * RiskAssessment.prediction.relativeRisk: Indicates the risk for this particular subject (with their specific characteristics) divided by the risk of the population in general.  (Numbers greater than 1 = higher risk than the population, numbers less than 1 = lower risk.).
 *
 * http://hl7.org/fhir/relativeRisk
 */
export const relativeRisk = 'http://hl7.org/fhir/relativeRisk' satisfies OwlObjectProperty;

/**
 * supportedMessage
 *
 * CapabilityStatement.messaging.supportedMessage: References to message definitions for messages this system can send or receive.
 *
 * http://hl7.org/fhir/supportedMessage
 */
export const supportedMessage = 'http://hl7.org/fhir/supportedMessage' satisfies OwlObjectProperty;

/**
 * _dateOfDiagnosis
 *
 * (Modified) Account.diagnosis.dateOfDiagnosis
 *
 * http://hl7.org/fhir/_dateOfDiagnosis
 */
export const _dateOfDiagnosis = 'http://hl7.org/fhir/_dateOfDiagnosis' satisfies OwlObjectProperty;

/**
 * _seriesNumber
 *
 * (Modified) ImagingSelection.seriesNumber
 *
 * http://hl7.org/fhir/_seriesNumber
 */
export const _seriesNumber = 'http://hl7.org/fhir/_seriesNumber' satisfies OwlObjectProperty;

/**
 * DataRequirementSortComponent
 *
 * DataRequirementSortComponent: Specifies the order of the results to be returned.
 *
 * http://hl7.org/fhir/DataRequirementSortComponent
 */
export const DataRequirementSortComponent = 'http://hl7.org/fhir/DataRequirementSortComponent' satisfies OwlClass;

/**
 * ChargeItemDefinitionPropertyGroupComponentApplicability
 *
 * Expressions that describe applicability criteria for the priceComponent.
 *
 * http://hl7.org/fhir/ChargeItemDefinitionPropertyGroupComponentApplicability
 */
export const ChargeItemDefinitionPropertyGroupComponentApplicability = 'http://hl7.org/fhir/ChargeItemDefinitionPropertyGroupComponentApplicability' satisfies OwlClass;

/**
 * codeSystem
 *
 * TerminologyCapabilities.codeSystem: Identifies a code system that is supported by the server. If there is a no code system URL, then this declares the general assumptions a client can make about support for any CodeSystem resource.
 *
 * http://hl7.org/fhir/codeSystem
 */
export const codeSystem = 'http://hl7.org/fhir/codeSystem' satisfies OwlObjectProperty;

/**
 * processing
 *
 * Specimen.processing: Details concerning processing and processing steps for the specimen.
 *
 * http://hl7.org/fhir/processing
 */
export const processing = 'http://hl7.org/fhir/processing' satisfies OwlObjectProperty;

/**
 * _ResearchSubject
 *
 * (Modified) ResearchSubject
 *
 * http://hl7.org/fhir/_ResearchSubject
 */
export const _ResearchSubject = 'http://hl7.org/fhir/_ResearchSubject' satisfies OwlClass;

/**
 * _heartbeatPeriod
 *
 * (Modified) Subscription.heartbeatPeriod
 *
 * http://hl7.org/fhir/_heartbeatPeriod
 */
export const _heartbeatPeriod = 'http://hl7.org/fhir/_heartbeatPeriod' satisfies OwlObjectProperty;

/**
 * ValueSetExpansionPropertyComponent
 *
 * ValueSetExpansionComponent.ValueSetExpansionPropertyComponent: A property defines an additional slot through which additional information can be provided about a concept.
 *
 * http://hl7.org/fhir/ValueSetExpansionPropertyComponent
 */
export const ValueSetExpansionPropertyComponent = 'http://hl7.org/fhir/ValueSetExpansionPropertyComponent' satisfies OwlClass;

/**
 * orderDetail
 *
 * ServiceRequest.orderDetail: Additional details and instructions about the how the services are to be delivered.   For example, and order for a urinary catheter may have an order detail for an external or indwelling catheter, or an order for a bandage may require additional instructions specifying how the bandage should be applied.
 *
 * http://hl7.org/fhir/orderDetail
 */
export const orderDetail = 'http://hl7.org/fhir/orderDetail' satisfies OwlObjectProperty;

/**
 * Group
 *
 * Represents a defined collection of entities that may be discussed or acted upon collectively but which are not expected to act collectively, and are not formally or legally recognized; i.e. a collection of entities that isn't an Organization.
 *
 * http://hl7.org/fhir/Group
 */
export const Group = 'http://hl7.org/fhir/Group' satisfies OwlClass;

/**
 * statusDate
 *
 * VerificationResult.statusDate: When the validation status was updated.
 *
 * http://hl7.org/fhir/statusDate
 */
export const statusDate = 'http://hl7.org/fhir/statusDate' satisfies OwlObjectProperty;

/**
 * uri
 *
 * ConceptMap.property.uri: Reference to the formal meaning of the property.
 *
 * http://hl7.org/fhir/uri
 */
export const uri = 'http://hl7.org/fhir/uri' satisfies OwlObjectProperty;

/**
 * max
 *
 * StructureMap.group.rule.source.max: Specified maximum cardinality for the element - a number or a "*". This is optional; if present, it acts an implicit check on the input content (* just serves as documentation; it's the default value).
 *
 * http://hl7.org/fhir/max
 */
export const max = 'http://hl7.org/fhir/max' satisfies OwlObjectProperty;

/**
 * _conformance
 *
 * (Modified) TestScript.scope.conformance
 *
 * http://hl7.org/fhir/_conformance
 */
export const _conformance = 'http://hl7.org/fhir/_conformance' satisfies OwlObjectProperty;

/**
 * _unitPriceComponent
 *
 * (Modified) ChargeItem.unitPriceComponent
 *
 * http://hl7.org/fhir/_unitPriceComponent
 */
export const _unitPriceComponent = 'http://hl7.org/fhir/_unitPriceComponent' satisfies OwlObjectProperty;

/**
 * _availabilityStatus
 *
 * (Modified) Device.availabilityStatus
 *
 * http://hl7.org/fhir/_availabilityStatus
 */
export const _availabilityStatus = 'http://hl7.org/fhir/_availabilityStatus' satisfies OwlObjectProperty;

/**
 * _exitCriteria
 *
 * (Modified) TestPlan.exitCriteria
 *
 * http://hl7.org/fhir/_exitCriteria
 */
export const _exitCriteria = 'http://hl7.org/fhir/_exitCriteria' satisfies OwlObjectProperty;

/**
 * Schedule
 *
 * A container for slots of time that may be available for booking appointments.
 *
 * http://hl7.org/fhir/Schedule
 */
export const Schedule = 'http://hl7.org/fhir/Schedule' satisfies OwlClass;

/**
 * BiologicallyDerivedProductCollectionComponent
 *
 * BiologicallyDerivedProductCollectionComponent: How this product was collected.
 *
 * http://hl7.org/fhir/BiologicallyDerivedProductCollectionComponent
 */
export const BiologicallyDerivedProductCollectionComponent = 'http://hl7.org/fhir/BiologicallyDerivedProductCollectionComponent' satisfies OwlClass;

/**
 * DomainResource
 *
 * A resource that includes narrative, extensions, and contained resources.
 *
 * http://hl7.org/fhir/DomainResource
 */
export const DomainResource = 'http://hl7.org/fhir/DomainResource' satisfies OwlClass;

/**
 * _AdverseEvent
 *
 * (Modified) AdverseEvent
 *
 * http://hl7.org/fhir/_AdverseEvent
 */
export const _AdverseEvent = 'http://hl7.org/fhir/_AdverseEvent' satisfies OwlClass;

/**
 * focalDevice
 *
 * Procedure.focalDevice: A device that is implanted, removed or otherwise manipulated (calibration, battery replacement, fitting a prosthesis, attaching a wound-vac, etc.) as a focal portion of the Procedure.
 *
 * http://hl7.org/fhir/focalDevice
 */
export const focalDevice = 'http://hl7.org/fhir/focalDevice' satisfies OwlObjectProperty;

/**
 * _authorType
 *
 * (Modified) SubstanceSourceMaterial.organism.author.authorType
 *
 * http://hl7.org/fhir/_authorType
 */
export const _authorType = 'http://hl7.org/fhir/_authorType' satisfies OwlObjectProperty;

/**
 * mode
 *
 * EvidenceReport.section.section.mode: How the entry list was prepared - whether it is a working list that is suitable for being maintained on an ongoing basis, or if it represents a snapshot of a list of items from another source, or whether it is a prepared list where items may be marked as added, modified or deleted.
 *
 * http://hl7.org/fhir/mode
 */
export const mode = 'http://hl7.org/fhir/mode' satisfies OwlObjectProperty;

/**
 * observation
 *
 * Observation.triggeredBy.observation: Reference to the triggering observation.
 *
 * http://hl7.org/fhir/observation
 */
export const observation = 'http://hl7.org/fhir/observation' satisfies OwlObjectProperty;

/**
 * _issuer
 *
 * (Modified) Device.udiCarrier.issuer
 *
 * http://hl7.org/fhir/_issuer
 */
export const _issuer = 'http://hl7.org/fhir/_issuer' satisfies OwlObjectProperty;

/**
 * ClaimEventComponent
 *
 * ClaimEventComponent: Information code for an event with a corresponding date or period.
 *
 * http://hl7.org/fhir/ClaimEventComponent
 */
export const ClaimEventComponent = 'http://hl7.org/fhir/ClaimEventComponent' satisfies OwlClass;

/**
 * FamilyMemberHistoryParticipantComponent
 *
 * FamilyMemberHistoryParticipantComponent: Indicates who or what participated in the activities related to the family member history and how they were involved.
 *
 * http://hl7.org/fhir/FamilyMemberHistoryParticipantComponent
 */
export const FamilyMemberHistoryParticipantComponent = 'http://hl7.org/fhir/FamilyMemberHistoryParticipantComponent' satisfies OwlClass;

/**
 * _validationStatus
 *
 * (Modified) VerificationResult.primarySource.validationStatus
 *
 * http://hl7.org/fhir/_validationStatus
 */
export const _validationStatus = 'http://hl7.org/fhir/_validationStatus' satisfies OwlObjectProperty;

/**
 * string
 *
 * A sequence of Unicode characters
 *
 * http://hl7.org/fhir/string
 */
export const string = 'http://hl7.org/fhir/string' satisfies OwlClass;

/**
 * productCode
 *
 * BiologicallyDerivedProduct.productCode: A codified value that systematically supports characterization and classification of medical products of human origin inclusive of processing conditions such as additives, volumes and handling conditions.
 *
 * http://hl7.org/fhir/productCode
 */
export const productCode = 'http://hl7.org/fhir/productCode' satisfies OwlObjectProperty;

/**
 * receiver
 *
 * ExampleScenario.process.step.process.step.operation.receiver: The system on which the action is invoked/receives the data.
 *
 * http://hl7.org/fhir/receiver
 */
export const receiver = 'http://hl7.org/fhir/receiver' satisfies OwlObjectProperty;

/**
 * CitationCitedArtifactTitleComponent
 *
 * CitationCitedArtifactComponent.CitationCitedArtifactTitleComponent: The title details of the article or artifact.
 *
 * http://hl7.org/fhir/CitationCitedArtifactTitleComponent
 */
export const CitationCitedArtifactTitleComponent = 'http://hl7.org/fhir/CitationCitedArtifactTitleComponent' satisfies OwlClass;

/**
 * totalGross
 *
 * Invoice.totalGross: Invoice total, tax included.
 *
 * http://hl7.org/fhir/totalGross
 */
export const totalGross = 'http://hl7.org/fhir/totalGross' satisfies OwlObjectProperty;

/**
 * _outputProfile
 *
 * (Modified) OperationDefinition.outputProfile
 *
 * http://hl7.org/fhir/_outputProfile
 */
export const _outputProfile = 'http://hl7.org/fhir/_outputProfile' satisfies OwlObjectProperty;

/**
 * conditionalDelete
 *
 * CapabilityStatement.rest.resource.conditionalDelete: A code that indicates how the server supports conditional delete.
 *
 * http://hl7.org/fhir/conditionalDelete
 */
export const conditionalDelete = 'http://hl7.org/fhir/conditionalDelete' satisfies OwlObjectProperty;

/**
 * baseDefinition
 *
 * StructureDefinition.baseDefinition: An absolute URI that is the base structure from which this type is derived, either by specialization or constraint.
 *
 * http://hl7.org/fhir/baseDefinition
 */
export const baseDefinition = 'http://hl7.org/fhir/baseDefinition' satisfies OwlObjectProperty;

/**
 * NutritionProductInstanceComponent
 *
 * NutritionProductInstanceComponent: Conveys instance-level information about this product item. One or several physical, countable instances or occurrences of the product.
 *
 * http://hl7.org/fhir/NutritionProductInstanceComponent
 */
export const NutritionProductInstanceComponent = 'http://hl7.org/fhir/NutritionProductInstanceComponent' satisfies OwlClass;

/**
 * ClinicalUseDefinitionIndicationComponent
 *
 * ClinicalUseDefinitionIndicationComponent: Specifics for when this is an indication.
 *
 * http://hl7.org/fhir/ClinicalUseDefinitionIndicationComponent
 */
export const ClinicalUseDefinitionIndicationComponent = 'http://hl7.org/fhir/ClinicalUseDefinitionIndicationComponent' satisfies OwlClass;

/**
 * relevantHistory
 *
 * Task.relevantHistory: Links to Provenance records for past versions of this Task that identify key state transitions or updates that are likely to be relevant to a user looking at the current version of the task.
 *
 * http://hl7.org/fhir/relevantHistory
 */
export const relevantHistory = 'http://hl7.org/fhir/relevantHistory' satisfies OwlObjectProperty;

/**
 * referenceInformation
 *
 * SubstanceDefinition.referenceInformation: General information detailing this substance.
 *
 * http://hl7.org/fhir/referenceInformation
 */
export const referenceInformation = 'http://hl7.org/fhir/referenceInformation' satisfies OwlObjectProperty;

/**
 * valueSet
 *
 * OperationDefinition.parameter.part.binding.valueSet: Points to the value set or external definition (e.g. implicit value set) that identifies the set of codes to be used.
 *
 * http://hl7.org/fhir/valueSet
 */
export const valueSet = 'http://hl7.org/fhir/valueSet' satisfies OwlObjectProperty;

/**
 * library
 *
 * PlanDefinition.library: A reference to a Library resource containing any formal logic used by the plan definition.
 *
 * http://hl7.org/fhir/library
 */
export const library = 'http://hl7.org/fhir/library' satisfies OwlObjectProperty;

/**
 * InventoryReportInventoryListingItemComponent
 *
 * InventoryReportInventoryListingComponent.InventoryReportInventoryListingItemComponent: The item or items in this listing.
 *
 * http://hl7.org/fhir/InventoryReportInventoryListingItemComponent
 */
export const InventoryReportInventoryListingItemComponent = 'http://hl7.org/fhir/InventoryReportInventoryListingItemComponent' satisfies OwlClass;

/**
 * performedActivity
 *
 * CarePlan.activity.performedActivity: Identifies the activity that was performed. For example, an activity could be patient education, exercise, or a medication administration. The reference to an "event" resource, such as Procedure or Encounter or Observation, represents the activity that was performed. The requested activity can be conveyed using the CarePlan.activity.plannedActivityReference (a reference to a “request” resource).
 *
 * http://hl7.org/fhir/performedActivity
 */
export const performedActivity = 'http://hl7.org/fhir/performedActivity' satisfies OwlObjectProperty;

/**
 * Coverage
 *
 * Financial instrument which may be used to reimburse or pay for health care products and services. Includes both insurance and self-payment.
 *
 * http://hl7.org/fhir/Coverage
 */
export const Coverage = 'http://hl7.org/fhir/Coverage' satisfies OwlClass;

/**
 * probability
 *
 * RiskAssessment.prediction.probability
 *
 * http://hl7.org/fhir/probability
 */
export const probability = 'http://hl7.org/fhir/probability' satisfies OwlObjectProperty;

/**
 * TerminologyCapabilitiesSoftwareComponent
 *
 * TerminologyCapabilitiesSoftwareComponent: Software that is covered by this terminology capability statement.  It is used when the statement describes the capabilities of a particular software version, independent of an installation.
 *
 * http://hl7.org/fhir/TerminologyCapabilitiesSoftwareComponent
 */
export const TerminologyCapabilitiesSoftwareComponent = 'http://hl7.org/fhir/TerminologyCapabilitiesSoftwareComponent' satisfies OwlClass;

/**
 * _activity
 *
 * (Modified) Provenance.activity
 *
 * http://hl7.org/fhir/_activity
 */
export const _activity = 'http://hl7.org/fhir/_activity' satisfies OwlObjectProperty;

/**
 * prediction
 *
 * RiskAssessment.prediction: Describes the expected outcome for the subject.
 *
 * http://hl7.org/fhir/prediction
 */
export const prediction = 'http://hl7.org/fhir/prediction' satisfies OwlObjectProperty;

/**
 * _mimeType
 *
 * (Modified) Endpoint.payload.mimeType
 *
 * http://hl7.org/fhir/_mimeType
 */
export const _mimeType = 'http://hl7.org/fhir/_mimeType' satisfies OwlObjectProperty;

/**
 * exception
 *
 * Coverage.costToBeneficiary.exception: A suite of codes indicating exceptions or reductions to patient costs and their effective periods.
 *
 * http://hl7.org/fhir/exception
 */
export const exception = 'http://hl7.org/fhir/exception' satisfies OwlObjectProperty;

/**
 * ImplementationGuideDefinitionTemplateComponent
 *
 * ImplementationGuideDefinitionComponent.ImplementationGuideDefinitionTemplateComponent: A template for building resources.
 *
 * http://hl7.org/fhir/ImplementationGuideDefinitionTemplateComponent
 */
export const ImplementationGuideDefinitionTemplateComponent = 'http://hl7.org/fhir/ImplementationGuideDefinitionTemplateComponent' satisfies OwlClass;

/**
 * _edit
 *
 * (Modified) MolecularSequence.relative.edit
 *
 * http://hl7.org/fhir/_edit
 */
export const _edit = 'http://hl7.org/fhir/_edit' satisfies OwlObjectProperty;

/**
 * _usage
 *
 * (Modified) NamingSystem.usage
 *
 * http://hl7.org/fhir/_usage
 */
export const _usage = 'http://hl7.org/fhir/_usage' satisfies OwlObjectProperty;

/**
 * proposedNewTime
 *
 * AppointmentResponse.proposedNewTime: Indicates that the response is proposing a different time that was initially requested.  The new proposed time will be indicated in the start and end properties.
 *
 * http://hl7.org/fhir/proposedNewTime
 */
export const proposedNewTime = 'http://hl7.org/fhir/proposedNewTime' satisfies OwlObjectProperty;

/**
 * security
 *
 * Permission.rule.data.security: The data in scope are those with the given codes present in that data .meta.security element.
 *
 * http://hl7.org/fhir/security
 */
export const security = 'http://hl7.org/fhir/security' satisfies OwlObjectProperty;

/**
 * _parameter
 *
 * (Modified) ValueSet.expansion.parameter
 *
 * http://hl7.org/fhir/_parameter
 */
export const _parameter = 'http://hl7.org/fhir/_parameter' satisfies OwlObjectProperty;

/**
 * InventoryItemDescriptionComponent
 *
 * InventoryItemDescriptionComponent: The descriptive characteristics of the inventory item.
 *
 * http://hl7.org/fhir/InventoryItemDescriptionComponent
 */
export const InventoryItemDescriptionComponent = 'http://hl7.org/fhir/InventoryItemDescriptionComponent' satisfies OwlClass;

/**
 * ConditionDefinitionPreconditionComponent
 *
 * ConditionDefinitionPreconditionComponent: An observation that suggests that this condition applies.
 *
 * http://hl7.org/fhir/ConditionDefinitionPreconditionComponent
 */
export const ConditionDefinitionPreconditionComponent = 'http://hl7.org/fhir/ConditionDefinitionPreconditionComponent' satisfies OwlClass;

/**
 * LocationPositionComponent
 *
 * LocationPositionComponent: The absolute geographic location of the Location, expressed using the WGS84 datum (This is the same co-ordinate system used in KML).
 *
 * http://hl7.org/fhir/LocationPositionComponent
 */
export const LocationPositionComponent = 'http://hl7.org/fhir/LocationPositionComponent' satisfies OwlClass;

/**
 * sequenceRange
 *
 * MolecularSequence.relative.sequenceRange: Indicates the nucleotide range in the composed sequence when multiple 'relative' elements are used together.
 *
 * http://hl7.org/fhir/sequenceRange
 */
export const sequenceRange = 'http://hl7.org/fhir/sequenceRange' satisfies OwlObjectProperty;

/**
 * policyBasis
 *
 * Consent.policyBasis: A Reference or URL used to uniquely identify the policy the organization will enforce for this Consent. This Reference or URL should be specific to the version of the policy and should be dereferencable to a computable policy of some form.
 *
 * http://hl7.org/fhir/policyBasis
 */
export const policyBasis = 'http://hl7.org/fhir/policyBasis' satisfies OwlObjectProperty;

/**
 * _inputParameters
 *
 * (Modified) MeasureReport.inputParameters
 *
 * http://hl7.org/fhir/_inputParameters
 */
export const _inputParameters = 'http://hl7.org/fhir/_inputParameters' satisfies OwlObjectProperty;

/**
 * _dateRange
 *
 * (Modified) MarketingStatus.dateRange
 *
 * http://hl7.org/fhir/_dateRange
 */
export const _dateRange = 'http://hl7.org/fhir/_dateRange' satisfies OwlObjectProperty;

/**
 * _cost
 *
 * (Modified) MedicationKnowledge.packaging.cost
 *
 * http://hl7.org/fhir/_cost
 */
export const _cost = 'http://hl7.org/fhir/_cost' satisfies OwlObjectProperty;

/**
 * Timing
 *
 * Specifies an event that may occur multiple times. Timing schedules are used to record when things are planned, expected or requested to occur. The most common usage is in dosage instructions for medications. They are also used when planning care of various kinds, and may be used for reporting the schedule to which past regular activities were carried out.
 *
 * http://hl7.org/fhir/Timing
 */
export const Timing = 'http://hl7.org/fhir/Timing' satisfies OwlClass;

/**
 * _team
 *
 * (Modified) ConditionDefinition.team
 *
 * http://hl7.org/fhir/_team
 */
export const _team = 'http://hl7.org/fhir/_team' satisfies OwlObjectProperty;

/**
 * _paternalOrganismId
 *
 * (Modified) SubstanceSourceMaterial.organism.hybrid.paternalOrganismId
 *
 * http://hl7.org/fhir/_paternalOrganismId
 */
export const _paternalOrganismId = 'http://hl7.org/fhir/_paternalOrganismId' satisfies OwlObjectProperty;

/**
 * _statusChanged
 *
 * (Modified) MedicationRequest.statusChanged
 *
 * http://hl7.org/fhir/_statusChanged
 */
export const _statusChanged = 'http://hl7.org/fhir/_statusChanged' satisfies OwlObjectProperty;

/**
 * ActivityDefinitionDynamicValueComponent
 *
 * ActivityDefinitionDynamicValueComponent: Dynamic values that will be evaluated to produce values for elements of the resulting resource. For example, if the dosage of a medication must be computed based on the patient's weight, a dynamic value would be used to specify an expression that calculated the weight, and the path on the request resource that would contain the result.
 *
 * http://hl7.org/fhir/ActivityDefinitionDynamicValueComponent
 */
export const ActivityDefinitionDynamicValueComponent = 'http://hl7.org/fhir/ActivityDefinitionDynamicValueComponent' satisfies OwlClass;

/**
 * processor
 *
 * PaymentReconciliation.processor: The name of the card processor, etf processor, bank for checks.
 *
 * http://hl7.org/fhir/processor
 */
export const processor = 'http://hl7.org/fhir/processor' satisfies OwlObjectProperty;

/**
 * _constraint
 *
 * (Modified) SearchParameter.constraint
 *
 * http://hl7.org/fhir/_constraint
 */
export const _constraint = 'http://hl7.org/fhir/_constraint' satisfies OwlObjectProperty;

/**
 * _sampleSize
 *
 * (Modified) Evidence.statistic.sampleSize
 *
 * http://hl7.org/fhir/_sampleSize
 */
export const _sampleSize = 'http://hl7.org/fhir/_sampleSize' satisfies OwlObjectProperty;

/**
 * ClinicalUseDefinitionContraindicationComponent
 *
 * ClinicalUseDefinitionContraindicationComponent: Specifics for when this is a contraindication.
 *
 * http://hl7.org/fhir/ClinicalUseDefinitionContraindicationComponent
 */
export const ClinicalUseDefinitionContraindicationComponent = 'http://hl7.org/fhir/ClinicalUseDefinitionContraindicationComponent' satisfies OwlClass;

/**
 * _comorbidity
 *
 * (Modified) ClinicalUseDefinition.indication.comorbidity
 *
 * http://hl7.org/fhir/_comorbidity
 */
export const _comorbidity = 'http://hl7.org/fhir/_comorbidity' satisfies OwlObjectProperty;

/**
 * _knownDataCount
 *
 * (Modified) Evidence.statistic.sampleSize.knownDataCount
 *
 * http://hl7.org/fhir/_knownDataCount
 */
export const _knownDataCount = 'http://hl7.org/fhir/_knownDataCount' satisfies OwlObjectProperty;

/**
 * template
 *
 * ImplementationGuide.definition.template: A template for building resources.
 *
 * http://hl7.org/fhir/template
 */
export const template = 'http://hl7.org/fhir/template' satisfies OwlObjectProperty;

/**
 * codeFilter
 *
 * DataRequirement.codeFilter: Code filters specify additional constraints on the data, specifying the value set of interest for a particular element of the data. Each code filter defines an additional constraint on the data, i.e. code filters are AND'ed, not OR'ed.
 *
 * http://hl7.org/fhir/codeFilter
 */
export const codeFilter = 'http://hl7.org/fhir/codeFilter' satisfies OwlObjectProperty;

/**
 * dateAccessed
 *
 * Citation.citedArtifact.dateAccessed: When the cited artifact was accessed.
 *
 * http://hl7.org/fhir/dateAccessed
 */
export const dateAccessed = 'http://hl7.org/fhir/dateAccessed' satisfies OwlObjectProperty;

/**
 * _organization
 *
 * (Modified) MedicinalProductDefinition.operation.organization
 *
 * http://hl7.org/fhir/_organization
 */
export const _organization = 'http://hl7.org/fhir/_organization' satisfies OwlObjectProperty;

/**
 * _ifModifiedSince
 *
 * (Modified) Bundle.entry.request.ifModifiedSince
 *
 * http://hl7.org/fhir/_ifModifiedSince
 */
export const _ifModifiedSince = 'http://hl7.org/fhir/_ifModifiedSince' satisfies OwlObjectProperty;

/**
 * _lastRevisionDate
 *
 * (Modified) Citation.citedArtifact.publicationForm.lastRevisionDate
 *
 * http://hl7.org/fhir/_lastRevisionDate
 */
export const _lastRevisionDate = 'http://hl7.org/fhir/_lastRevisionDate' satisfies OwlObjectProperty;

/**
 * _strength
 *
 * (Modified) OperationDefinition.parameter.part.binding.strength
 *
 * http://hl7.org/fhir/_strength
 */
export const _strength = 'http://hl7.org/fhir/_strength' satisfies OwlObjectProperty;

/**
 * numerator
 *
 * Ratio.numerator: The value of the numerator.
 *
 * http://hl7.org/fhir/numerator
 */
export const numerator = 'http://hl7.org/fhir/numerator' satisfies OwlObjectProperty;

/**
 * _altitude
 *
 * (Modified) Location.position.altitude
 *
 * http://hl7.org/fhir/_altitude
 */
export const _altitude = 'http://hl7.org/fhir/_altitude' satisfies OwlObjectProperty;

/**
 * _countingDateTime
 *
 * (Modified) InventoryReport.inventoryListing.countingDateTime
 *
 * http://hl7.org/fhir/_countingDateTime
 */
export const _countingDateTime = 'http://hl7.org/fhir/_countingDateTime' satisfies OwlObjectProperty;

/**
 * MedicationDispense
 *
 * Indicates that a medication product is to be or has been dispensed for a named person/patient.  This includes a description of the medication product (supply) provided and the instructions for administering the medication.  The medication dispense is the result of a pharmacy system responding to a medication order.
 *
 * http://hl7.org/fhir/MedicationDispense
 */
export const MedicationDispense = 'http://hl7.org/fhir/MedicationDispense' satisfies OwlClass;

/**
 * _maxDuration
 *
 * (Modified) SpecimenDefinition.typeTested.handling.maxDuration
 *
 * http://hl7.org/fhir/_maxDuration
 */
export const _maxDuration = 'http://hl7.org/fhir/_maxDuration' satisfies OwlObjectProperty;

/**
 * requirement
 *
 * RequestOrchestration.action.input.requirement: Defines the data that is to be provided as input to the action.
 *
 * http://hl7.org/fhir/requirement
 */
export const requirement = 'http://hl7.org/fhir/requirement' satisfies OwlObjectProperty;

/**
 * SubstanceProteinSubunitComponent
 *
 * SubstanceProteinSubunitComponent: This subclause refers to the description of each subunit constituting the SubstanceProtein. A subunit is a linear sequence of amino acids linked through peptide bonds. The Subunit information shall be provided when the finished SubstanceProtein is a complex of multiple sequences; subunits are not used to delineate domains within a single sequence. Subunits are listed in order of decreasing length; sequences of the same length will be ordered by decreasing molecular weight; subunits that have identical sequences will be repeated multiple times.
 *
 * http://hl7.org/fhir/SubstanceProteinSubunitComponent
 */
export const SubstanceProteinSubunitComponent = 'http://hl7.org/fhir/SubstanceProteinSubunitComponent' satisfies OwlClass;

/**
 * _abatement
 *
 * (Modified) Condition.abatement
 *
 * http://hl7.org/fhir/_abatement
 */
export const _abatement = 'http://hl7.org/fhir/_abatement' satisfies OwlObjectProperty;

/**
 * reportingPeriod
 *
 * InventoryReport.reportingPeriod: The period the report refers to.
 *
 * http://hl7.org/fhir/reportingPeriod
 */
export const reportingPeriod = 'http://hl7.org/fhir/reportingPeriod' satisfies OwlObjectProperty;

/**
 * dosage
 *
 * MedicationKnowledge.indicationGuideline.dosingGuideline.dosage: Dosage for the medication for the specific guidelines.
 *
 * http://hl7.org/fhir/dosage
 */
export const dosage = 'http://hl7.org/fhir/dosage' satisfies OwlObjectProperty;

/**
 * _supplement
 *
 * (Modified) NutritionOrder.supplement
 *
 * http://hl7.org/fhir/_supplement
 */
export const _supplement = 'http://hl7.org/fhir/_supplement' satisfies OwlObjectProperty;

/**
 * _treatmentIntent
 *
 * (Modified) MedicationKnowledge.indicationGuideline.dosingGuideline.treatmentIntent
 *
 * http://hl7.org/fhir/_treatmentIntent
 */
export const _treatmentIntent = 'http://hl7.org/fhir/_treatmentIntent' satisfies OwlObjectProperty;

/**
 * performingOrganization
 *
 * ChargeItem.performingOrganization: The organization performing the service.
 *
 * http://hl7.org/fhir/performingOrganization
 */
export const performingOrganization = 'http://hl7.org/fhir/performingOrganization' satisfies OwlObjectProperty;

/**
 * _what
 *
 * (Modified) Provenance.entity.what
 *
 * http://hl7.org/fhir/_what
 */
export const _what = 'http://hl7.org/fhir/_what' satisfies OwlObjectProperty;

/**
 * intervalUnit
 *
 * SampledData.intervalUnit: The measurement unit in which the sample interval is expressed.
 *
 * http://hl7.org/fhir/intervalUnit
 */
export const intervalUnit = 'http://hl7.org/fhir/intervalUnit' satisfies OwlObjectProperty;

/**
 * preAuthPeriod
 *
 * ClaimResponse.item.detail.subDetail.reviewOutcome.preAuthPeriod: The time frame during which this authorization is effective.
 *
 * http://hl7.org/fhir/preAuthPeriod
 */
export const preAuthPeriod = 'http://hl7.org/fhir/preAuthPeriod' satisfies OwlObjectProperty;

/**
 * fhirPathCriteria
 *
 * SubscriptionTopic.resourceTrigger.fhirPathCriteria: The FHIRPath based rules that the server should use to determine when to trigger a notification for this topic.
 *
 * http://hl7.org/fhir/fhirPathCriteria
 */
export const fhirPathCriteria = 'http://hl7.org/fhir/fhirPathCriteria' satisfies OwlObjectProperty;

/**
 * administeredBy
 *
 * InsurancePlan.administeredBy: An organization which administer other services such as underwriting, customer service and/or claims processing on behalf of the health insurance product owner.
 *
 * http://hl7.org/fhir/administeredBy
 */
export const administeredBy = 'http://hl7.org/fhir/administeredBy' satisfies OwlObjectProperty;

/**
 * factor
 *
 * ClaimResponse.addItem.factor: A real number that represents a multiplier used in determining the overall value of services delivered and/or goods received. The concept of a Factor allows for a discount or surcharge multiplier to be applied to a monetary amount.
 *
 * http://hl7.org/fhir/factor
 */
export const factor = 'http://hl7.org/fhir/factor' satisfies OwlObjectProperty;

/**
 * ContactPoint
 *
 * Details for all kinds of technology mediated contact points for a person or organization, including telephone, email, etc.
 *
 * http://hl7.org/fhir/ContactPoint
 */
export const ContactPoint = 'http://hl7.org/fhir/ContactPoint' satisfies OwlClass;

/**
 * appointmentType
 *
 * Slot.appointmentType: The style of appointment or patient that may be booked in the slot (not service type).
 *
 * http://hl7.org/fhir/appointmentType
 */
export const appointmentType = 'http://hl7.org/fhir/appointmentType' satisfies OwlObjectProperty;

/**
 * _collector
 *
 * (Modified) Specimen.collection.collector
 *
 * http://hl7.org/fhir/_collector
 */
export const _collector = 'http://hl7.org/fhir/_collector' satisfies OwlObjectProperty;

/**
 * answerValueSet
 *
 * Questionnaire.item.item.answerValueSet: A reference to a value set containing a list of values representing permitted answers for a question.
 *
 * http://hl7.org/fhir/answerValueSet
 */
export const answerValueSet = 'http://hl7.org/fhir/answerValueSet' satisfies OwlObjectProperty;

/**
 * _achievementStatus
 *
 * (Modified) Goal.achievementStatus
 *
 * http://hl7.org/fhir/_achievementStatus
 */
export const _achievementStatus = 'http://hl7.org/fhir/_achievementStatus' satisfies OwlObjectProperty;

/**
 * carrierHRF
 *
 * Device.udiCarrier.carrierHRF: The full UDI carrier as the human readable form (HRF) representation of the barcode string as printed on the packaging of the device.
 *
 * http://hl7.org/fhir/carrierHRF
 */
export const carrierHRF = 'http://hl7.org/fhir/carrierHRF' satisfies OwlObjectProperty;

/**
 * _evaluatedResource
 *
 * (Modified) MeasureReport.evaluatedResource
 *
 * http://hl7.org/fhir/_evaluatedResource
 */
export const _evaluatedResource = 'http://hl7.org/fhir/_evaluatedResource' satisfies OwlObjectProperty;

/**
 * signer
 *
 * Contract.signer: Parties with legal standing in the Contract, including the principal parties, the grantor(s) and grantee(s), which are any person or organization bound by the contract, and any ancillary parties, which facilitate the execution of the contract such as a notary or witness.
 *
 * http://hl7.org/fhir/signer
 */
export const signer = 'http://hl7.org/fhir/signer' satisfies OwlObjectProperty;

/**
 * _usageReason
 *
 * (Modified) DeviceUsage.usageReason
 *
 * http://hl7.org/fhir/_usageReason
 */
export const _usageReason = 'http://hl7.org/fhir/_usageReason' satisfies OwlObjectProperty;

/**
 * variableDefinition
 *
 * Evidence.statistic.modelCharacteristic.variable.variableDefinition: Description of the variable.
 *
 * http://hl7.org/fhir/variableDefinition
 */
export const variableDefinition = 'http://hl7.org/fhir/variableDefinition' satisfies OwlObjectProperty;

/**
 * manifestation
 *
 * Immunization.reaction.manifestation: Details of the reaction.
 *
 * http://hl7.org/fhir/manifestation
 */
export const manifestation = 'http://hl7.org/fhir/manifestation' satisfies OwlObjectProperty;

/**
 * searchType
 *
 * OperationDefinition.parameter.part.searchType: How the parameter is understood if/when it used as search parameter. This is only used if the parameter is a string.
 *
 * http://hl7.org/fhir/searchType
 */
export const searchType = 'http://hl7.org/fhir/searchType' satisfies OwlObjectProperty;

/**
 * PaymentReconciliation
 *
 * This resource provides the details including amount of a payment and allocates the payment items being paid.
 *
 * http://hl7.org/fhir/PaymentReconciliation
 */
export const PaymentReconciliation = 'http://hl7.org/fhir/PaymentReconciliation' satisfies OwlClass;

/**
 * _modelNumber
 *
 * (Modified) DeviceDefinition.modelNumber
 *
 * http://hl7.org/fhir/_modelNumber
 */
export const _modelNumber = 'http://hl7.org/fhir/_modelNumber' satisfies OwlObjectProperty;

/**
 * groupingId
 *
 * ImplementationGuide.definition.resource.groupingId: Reference to the id of the grouping this resource appears in.
 *
 * http://hl7.org/fhir/groupingId
 */
export const groupingId = 'http://hl7.org/fhir/groupingId' satisfies OwlObjectProperty;

/**
 * _VisionPrescription
 *
 * (Modified) VisionPrescription
 *
 * http://hl7.org/fhir/_VisionPrescription
 */
export const _VisionPrescription = 'http://hl7.org/fhir/_VisionPrescription' satisfies OwlClass;

/**
 * performerLinkId
 *
 * Contract.term.group.action.performerLinkId: Id [identifier??] of the clause or question text related to the reason type or reference of this  action in the referenced form or QuestionnaireResponse.
 *
 * http://hl7.org/fhir/performerLinkId
 */
export const performerLinkId = 'http://hl7.org/fhir/performerLinkId' satisfies OwlObjectProperty;

/**
 * procedure
 *
 * ExplanationOfBenefit.procedure: Procedures performed on the patient relevant to the billing items with the claim.
 *
 * http://hl7.org/fhir/procedure
 */
export const procedure = 'http://hl7.org/fhir/procedure' satisfies OwlObjectProperty;

/**
 * implicitRules
 *
 * Resource.implicitRules: A reference to a set of rules that were followed when the resource was constructed, and which must be understood when processing the content. Often, this is a reference to an implementation guide that defines the special rules along with other profiles etc.
 *
 * http://hl7.org/fhir/implicitRules
 */
export const implicitRules = 'http://hl7.org/fhir/implicitRules' satisfies OwlObjectProperty;

/**
 * query
 *
 * AuditEvent.entity.query: The query parameters for a query-type entities.
 *
 * http://hl7.org/fhir/query
 */
export const query = 'http://hl7.org/fhir/query' satisfies OwlObjectProperty;

/**
 * Items
 *
 * CoverageEligibilityResponse.Insurance.Items: Benefits and optionally current balances, and authorization details by category or service.
 *
 * http://hl7.org/fhir/Items
 */
export const Items = 'http://hl7.org/fhir/Items' satisfies OwlClass;

/**
 * _slot
 *
 * (Modified) Appointment.slot
 *
 * http://hl7.org/fhir/_slot
 */
export const _slot = 'http://hl7.org/fhir/_slot' satisfies OwlObjectProperty;

/**
 * _conditionalCreate
 *
 * (Modified) CapabilityStatement.rest.resource.conditionalCreate
 *
 * http://hl7.org/fhir/_conditionalCreate
 */
export const _conditionalCreate = 'http://hl7.org/fhir/_conditionalCreate' satisfies OwlObjectProperty;

/**
 * PatientCommunicationComponent
 *
 * PatientCommunicationComponent: A language which may be used to communicate with the patient about his or her health.
 *
 * http://hl7.org/fhir/PatientCommunicationComponent
 */
export const PatientCommunicationComponent = 'http://hl7.org/fhir/PatientCommunicationComponent' satisfies OwlClass;

/**
 * ConditionDefinitionMedicationComponent
 *
 * ConditionDefinitionMedicationComponent: Medications particularly relevant for this condition.
 *
 * http://hl7.org/fhir/ConditionDefinitionMedicationComponent
 */
export const ConditionDefinitionMedicationComponent = 'http://hl7.org/fhir/ConditionDefinitionMedicationComponent' satisfies OwlClass;

/**
 * documentation
 *
 * ActorDefinition.documentation: Documentation about the functionality of the actor.
 *
 * http://hl7.org/fhir/documentation
 */
export const documentation = 'http://hl7.org/fhir/documentation' satisfies OwlObjectProperty;

/**
 * maxDosePerTreatmentPeriod
 *
 * AdministrableProductDefinition.routeOfAdministration.maxDosePerTreatmentPeriod: The maximum dose per treatment period that can be administered.
 *
 * http://hl7.org/fhir/maxDosePerTreatmentPeriod
 */
export const maxDosePerTreatmentPeriod = 'http://hl7.org/fhir/maxDosePerTreatmentPeriod' satisfies OwlObjectProperty;

/**
 * example
 *
 * ElementDefinition.example: A sample value for this element demonstrating the type of information that would typically be found in the element.
 *
 * http://hl7.org/fhir/example
 */
export const example = 'http://hl7.org/fhir/example' satisfies OwlObjectProperty;

/**
 * _sessionKey
 *
 * (Modified) VirtualServiceDetail.sessionKey
 *
 * http://hl7.org/fhir/_sessionKey
 */
export const _sessionKey = 'http://hl7.org/fhir/_sessionKey' satisfies OwlObjectProperty;

/**
 * lastPage
 *
 * Citation.citedArtifact.publicationForm.lastPage: Used for isolated representation of last page.
 *
 * http://hl7.org/fhir/lastPage
 */
export const lastPage = 'http://hl7.org/fhir/lastPage' satisfies OwlObjectProperty;

/**
 * hybridType
 *
 * SubstanceSourceMaterial.organism.hybrid.hybridType: The hybrid type of an organism shall be specified.
 *
 * http://hl7.org/fhir/hybridType
 */
export const hybridType = 'http://hl7.org/fhir/hybridType' satisfies OwlObjectProperty;

/**
 * field
 *
 * TestScript.teardown.action.operation.requestHeader.field: The HTTP header field e.g. "Accept".
 *
 * http://hl7.org/fhir/field
 */
export const field = 'http://hl7.org/fhir/field' satisfies OwlObjectProperty;

/**
 * maxDosePerPeriod
 *
 * Dosage.maxDosePerPeriod: Upper limit on medication per unit of time.
 *
 * http://hl7.org/fhir/maxDosePerPeriod
 */
export const maxDosePerPeriod = 'http://hl7.org/fhir/maxDosePerPeriod' satisfies OwlObjectProperty;

/**
 * _excludedStructure
 *
 * (Modified) BodyStructure.excludedStructure
 *
 * http://hl7.org/fhir/_excludedStructure
 */
export const _excludedStructure = 'http://hl7.org/fhir/_excludedStructure' satisfies OwlObjectProperty;

/**
 * _script
 *
 * (Modified) TestPlan.testCase.testRun.script
 *
 * http://hl7.org/fhir/_script
 */
export const _script = 'http://hl7.org/fhir/_script' satisfies OwlObjectProperty;

/**
 * acceptLanguage
 *
 * CapabilityStatement.acceptLanguage: A list of the languages supported by this implementation that are usefully supported in the ```Accept-Language``` header.
 *
 * http://hl7.org/fhir/acceptLanguage
 */
export const acceptLanguage = 'http://hl7.org/fhir/acceptLanguage' satisfies OwlObjectProperty;

/**
 * practiceSetting
 *
 * DocumentReference.practiceSetting: This property may convey specifics about the practice setting where the content was created, often reflecting the clinical specialty.
 *
 * http://hl7.org/fhir/practiceSetting
 */
export const practiceSetting = 'http://hl7.org/fhir/practiceSetting' satisfies OwlObjectProperty;

/**
 * brand
 *
 * VisionPrescription.lensSpecification.brand: Brand recommendations or restrictions.
 *
 * http://hl7.org/fhir/brand
 */
export const brand = 'http://hl7.org/fhir/brand' satisfies OwlObjectProperty;

/**
 * _attributeEstimate
 *
 * (Modified) Evidence.statistic.modelCharacteristic.attributeEstimate
 *
 * http://hl7.org/fhir/_attributeEstimate
 */
export const _attributeEstimate = 'http://hl7.org/fhir/_attributeEstimate' satisfies OwlObjectProperty;

/**
 * _end
 *
 * (Modified) Subscription.end
 *
 * http://hl7.org/fhir/_end
 */
export const _end = 'http://hl7.org/fhir/_end' satisfies OwlObjectProperty;

/**
 * diagnosisSequence
 *
 * ExplanationOfBenefit.item.diagnosisSequence: Diagnoses applicable for this service or product.
 *
 * http://hl7.org/fhir/diagnosisSequence
 */
export const diagnosisSequence = 'http://hl7.org/fhir/diagnosisSequence' satisfies OwlObjectProperty;

/**
 * _specification
 *
 * (Modified) DeviceDefinition.conformsTo.specification
 *
 * http://hl7.org/fhir/_specification
 */
export const _specification = 'http://hl7.org/fhir/_specification' satisfies OwlObjectProperty;

/**
 * _test
 *
 * (Modified) TestScript.test
 *
 * http://hl7.org/fhir/_test
 */
export const _test = 'http://hl7.org/fhir/_test' satisfies OwlObjectProperty;

/**
 * _durationMax
 *
 * (Modified) Timing.repeat.durationMax
 *
 * http://hl7.org/fhir/_durationMax
 */
export const _durationMax = 'http://hl7.org/fhir/_durationMax' satisfies OwlObjectProperty;

/**
 * impurity
 *
 * MedicinalProductDefinition.impurity: Any component of the drug product which is not the chemical entity defined as the drug substance, or an excipient in the drug product. This includes process-related impurities and contaminants, product-related impurities including degradation products.
 *
 * http://hl7.org/fhir/impurity
 */
export const impurity = 'http://hl7.org/fhir/impurity' satisfies OwlObjectProperty;

/**
 * _Practitioner
 *
 * (Modified) Practitioner
 *
 * http://hl7.org/fhir/_Practitioner
 */
export const _Practitioner = 'http://hl7.org/fhir/_Practitioner' satisfies OwlClass;

/**
 * SubstanceIngredientComponent
 *
 * SubstanceIngredientComponent: A substance can be composed of other substances.
 *
 * http://hl7.org/fhir/SubstanceIngredientComponent
 */
export const SubstanceIngredientComponent = 'http://hl7.org/fhir/SubstanceIngredientComponent' satisfies OwlClass;

/**
 * control
 *
 * Contract.term.group.securityLabel.control: Security label privacy tag that specifies the manner in which term and/or term elements are to be protected.
 *
 * http://hl7.org/fhir/control
 */
export const control = 'http://hl7.org/fhir/control' satisfies OwlObjectProperty;

/**
 * _enterer
 *
 * (Modified) PaymentReconciliation.enterer
 *
 * http://hl7.org/fhir/_enterer
 */
export const _enterer = 'http://hl7.org/fhir/_enterer' satisfies OwlObjectProperty;

/**
 * TransportOutputComponent
 *
 * TransportOutputComponent: Outputs produced by the Transport.
 *
 * http://hl7.org/fhir/TransportOutputComponent
 */
export const TransportOutputComponent = 'http://hl7.org/fhir/TransportOutputComponent' satisfies OwlClass;

/**
 * _retentionTime
 *
 * (Modified) SpecimenDefinition.typeTested.retentionTime
 *
 * http://hl7.org/fhir/_retentionTime
 */
export const _retentionTime = 'http://hl7.org/fhir/_retentionTime' satisfies OwlObjectProperty;

/**
 * _encodeRequestUrl
 *
 * (Modified) TestScript.teardown.action.operation.encodeRequestUrl
 *
 * http://hl7.org/fhir/_encodeRequestUrl
 */
export const _encodeRequestUrl = 'http://hl7.org/fhir/_encodeRequestUrl' satisfies OwlObjectProperty;

/**
 * countMax
 *
 * Timing.repeat.countMax: If present, indicates that the count is a range - so to perform the action between [count] and [countMax] times.
 *
 * http://hl7.org/fhir/countMax
 */
export const countMax = 'http://hl7.org/fhir/countMax' satisfies OwlObjectProperty;

/**
 * _netContent
 *
 * (Modified) InventoryItem.netContent
 *
 * http://hl7.org/fhir/_netContent
 */
export const _netContent = 'http://hl7.org/fhir/_netContent' satisfies OwlObjectProperty;

/**
 * AccountBalanceComponent
 *
 * AccountBalanceComponent: The calculated account balances - these are calculated and processed by the finance system.

The balances with a `term` that is not current are usually generated/updated by an invoicing or similar process.
 *
 * http://hl7.org/fhir/AccountBalanceComponent
 */
export const AccountBalanceComponent = 'http://hl7.org/fhir/AccountBalanceComponent' satisfies OwlClass;

/**
 * _sequenceAttachment
 *
 * (Modified) SubstanceProtein.subunit.sequenceAttachment
 *
 * http://hl7.org/fhir/_sequenceAttachment
 */
export const _sequenceAttachment = 'http://hl7.org/fhir/_sequenceAttachment' satisfies OwlObjectProperty;

/**
 * requestedLocation
 *
 * Transport.requestedLocation: The desired or final location for the transport.
 *
 * http://hl7.org/fhir/requestedLocation
 */
export const requestedLocation = 'http://hl7.org/fhir/requestedLocation' satisfies OwlObjectProperty;

/**
 * DeviceDefinitionRegulatoryIdentifierComponent
 *
 * DeviceDefinitionRegulatoryIdentifierComponent: Identifier associated with the regulatory documentation (certificates, technical documentation, post-market surveillance documentation and reports) of a set of device models sharing the same intended purpose, risk class and essential design and manufacturing characteristics. One example is the Basic UDI-DI in Europe.
 *
 * http://hl7.org/fhir/DeviceDefinitionRegulatoryIdentifierComponent
 */
export const DeviceDefinitionRegulatoryIdentifierComponent = 'http://hl7.org/fhir/DeviceDefinitionRegulatoryIdentifierComponent' satisfies OwlClass;

/**
 * _target
 *
 * (Modified) ConceptMap.group.element.target
 *
 * http://hl7.org/fhir/_target
 */
export const _target = 'http://hl7.org/fhir/_target' satisfies OwlObjectProperty;

/**
 * _implicated
 *
 * (Modified) DetectedIssue.implicated
 *
 * http://hl7.org/fhir/_implicated
 */
export const _implicated = 'http://hl7.org/fhir/_implicated' satisfies OwlObjectProperty;

/**
 * _administration
 *
 * (Modified) NutritionOrder.enteralFormula.administration
 *
 * http://hl7.org/fhir/_administration
 */
export const _administration = 'http://hl7.org/fhir/_administration' satisfies OwlObjectProperty;

/**
 * _flag
 *
 * (Modified) List.entry.flag
 *
 * http://hl7.org/fhir/_flag
 */
export const _flag = 'http://hl7.org/fhir/_flag' satisfies OwlObjectProperty;

/**
 * _party
 *
 * (Modified) Coverage.paymentBy.party
 *
 * http://hl7.org/fhir/_party
 */
export const _party = 'http://hl7.org/fhir/_party' satisfies OwlObjectProperty;

/**
 * _version
 *
 * (Modified) ValueSet.expansion.contains.version
 *
 * http://hl7.org/fhir/_version
 */
export const _version = 'http://hl7.org/fhir/_version' satisfies OwlObjectProperty;

/**
 * provision
 *
 * Consent.provision.provision.provision: Provisions which provide exceptions to the base provision or subprovisions.
 *
 * http://hl7.org/fhir/provision
 */
export const provision = 'http://hl7.org/fhir/provision' satisfies OwlObjectProperty;

/**
 * patientPaid
 *
 * Claim.item.patientPaid: The amount paid by the patient, in total at the claim claim level or specifically for the item and detail level, to the provider for goods and services.
 *
 * http://hl7.org/fhir/patientPaid
 */
export const patientPaid = 'http://hl7.org/fhir/patientPaid' satisfies OwlObjectProperty;

/**
 * referenceNumber
 *
 * PaymentReconciliation.referenceNumber: The check number, eft reference, car processor reference.
 *
 * http://hl7.org/fhir/referenceNumber
 */
export const referenceNumber = 'http://hl7.org/fhir/referenceNumber' satisfies OwlObjectProperty;

/**
 * manifest
 *
 * ImplementationGuide.manifest: Information about an assembled implementation guide, created by the publication tooling.
 *
 * http://hl7.org/fhir/manifest
 */
export const manifest = 'http://hl7.org/fhir/manifest' satisfies OwlObjectProperty;

/**
 * Account
 *
 * A financial tool for tracking value accrued for a particular purpose.  In the healthcare field, used to track charges for a patient, cost centers, etc.
 *
 * http://hl7.org/fhir/Account
 */
export const Account = 'http://hl7.org/fhir/Account' satisfies OwlClass;

/**
 * _goal
 *
 * (Modified) RequestOrchestration.action.action.goal
 *
 * http://hl7.org/fhir/_goal
 */
export const _goal = 'http://hl7.org/fhir/_goal' satisfies OwlObjectProperty;

/**
 * _basis
 *
 * (Modified) RiskAssessment.basis
 *
 * http://hl7.org/fhir/_basis
 */
export const _basis = 'http://hl7.org/fhir/_basis' satisfies OwlObjectProperty;

/**
 * MessageSource
 *
 * MessageHeader.MessageSource: The source application from which this message originated.
 *
 * http://hl7.org/fhir/MessageSource
 */
export const MessageSource = 'http://hl7.org/fhir/MessageSource' satisfies OwlClass;

/**
 * _formCode
 *
 * (Modified) PaymentReconciliation.formCode
 *
 * http://hl7.org/fhir/_formCode
 */
export const _formCode = 'http://hl7.org/fhir/_formCode' satisfies OwlObjectProperty;

/**
 * _disclaimer
 *
 * (Modified) Measure.disclaimer
 *
 * http://hl7.org/fhir/_disclaimer
 */
export const _disclaimer = 'http://hl7.org/fhir/_disclaimer' satisfies OwlObjectProperty;

/**
 * _definitionByCombination
 *
 * (Modified) EvidenceVariable.characteristic.definitionByCombination.characteristic.definitionByCombination
 *
 * http://hl7.org/fhir/_definitionByCombination
 */
export const _definitionByCombination = 'http://hl7.org/fhir/_definitionByCombination' satisfies OwlObjectProperty;

/**
 * step
 *
 * ExampleScenario.process.step.process.step.alternative.step.alternative.step: Indicates the operation, sub-process or scenario that happens if the alternative option is selected.
 *
 * http://hl7.org/fhir/step
 */
export const step = 'http://hl7.org/fhir/step' satisfies OwlObjectProperty;

/**
 * fractionDescription
 *
 * SubstanceSourceMaterial.fractionDescription: Many complex materials are fractions of parts of plants, animals, or minerals. Fraction elements are often necessary to define both Substances and Specified Group 1 Substances. For substances derived from Plants, fraction information will be captured at the Substance information level ( . Oils, Juices and Exudates). Additional information for Extracts, such as extraction solvent composition, will be captured at the Specified Substance Group 1 information level. For plasma-derived products fraction information will be captured at the Substance and the Specified Substance Group 1 levels.
 *
 * http://hl7.org/fhir/fractionDescription
 */
export const fractionDescription = 'http://hl7.org/fhir/fractionDescription' satisfies OwlObjectProperty;

/**
 * valueCategory
 *
 * Evidence.statistic.modelCharacteristic.variable.valueCategory: Description for grouping of ordinal or polychotomous variables.
 *
 * http://hl7.org/fhir/valueCategory
 */
export const valueCategory = 'http://hl7.org/fhir/valueCategory' satisfies OwlObjectProperty;

/**
 * requestMethod
 *
 * TestScript.test.action.assert.requestMethod: The request method or HTTP operation code to compare against that used by the client system under test.
 *
 * http://hl7.org/fhir/requestMethod
 */
export const requestMethod = 'http://hl7.org/fhir/requestMethod' satisfies OwlObjectProperty;

/**
 * BodySite
 *
 * Claim.Item.BodySite: Physical location where the service is performed or applies.
 *
 * http://hl7.org/fhir/BodySite
 */
export const BodySite = 'http://hl7.org/fhir/BodySite' satisfies OwlClass;

/**
 * etag
 *
 * Bundle.entry.response.etag: The Etag for the resource, if the operation for the entry produced a versioned resource (see [Resource Metadata and Versioning](http.html#versioning) and [Managing Resource Contention](http.html#concurrency)).
 *
 * http://hl7.org/fhir/etag
 */
export const etag = 'http://hl7.org/fhir/etag' satisfies OwlObjectProperty;

/**
 * specimenQuantity
 *
 * Specimen.container.specimenQuantity: The quantity of specimen in the container; may be volume, dimensions, or other appropriate measurements, depending on the specimen type.
 *
 * http://hl7.org/fhir/specimenQuantity
 */
export const specimenQuantity = 'http://hl7.org/fhir/specimenQuantity' satisfies OwlObjectProperty;

/**
 * comprisedOf
 *
 * MedicinalProductDefinition.comprisedOf: Types of medicinal manufactured items and/or devices that this product consists of, such as tablets, capsule, or syringes. Used as a direct link when the item's packaging is not being recorded (see also PackagedProductDefinition.package.containedItem.item).
 *
 * http://hl7.org/fhir/comprisedOf
 */
export const comprisedOf = 'http://hl7.org/fhir/comprisedOf' satisfies OwlObjectProperty;

/**
 * _pediatricUseIndicator
 *
 * (Modified) MedicinalProductDefinition.pediatricUseIndicator
 *
 * http://hl7.org/fhir/_pediatricUseIndicator
 */
export const _pediatricUseIndicator = 'http://hl7.org/fhir/_pediatricUseIndicator' satisfies OwlObjectProperty;

/**
 * _destination
 *
 * (Modified) TestScript.metadata.capability.destination
 *
 * http://hl7.org/fhir/_destination
 */
export const _destination = 'http://hl7.org/fhir/_destination' satisfies OwlObjectProperty;

/**
 * _evaluationMessage
 *
 * (Modified) GuidanceResponse.evaluationMessage
 *
 * http://hl7.org/fhir/_evaluationMessage
 */
export const _evaluationMessage = 'http://hl7.org/fhir/_evaluationMessage' satisfies OwlObjectProperty;

/**
 * ResearchStudyComparisonGroupComponent
 *
 * ResearchStudyComparisonGroupComponent: Describes an expected event or sequence of events for one of the subjects of a study. E.g. for a living subject: exposure to drug A, wash-out, exposure to drug B, wash-out, follow-up. E.g. for a stability study: {store sample from lot A at 25 degrees for 1 month}, {store sample from lot A at 40 degrees for 1 month}.
 *
 * http://hl7.org/fhir/ResearchStudyComparisonGroupComponent
 */
export const ResearchStudyComparisonGroupComponent = 'http://hl7.org/fhir/ResearchStudyComparisonGroupComponent' satisfies OwlClass;

/**
 * _DomainResource
 *
 * http://hl7.org/fhir/_DomainResource
 */
export const _DomainResource = 'http://hl7.org/fhir/_DomainResource' satisfies OwlClass;

/**
 * CitationCitedArtifactWebLocationComponent
 *
 * CitationCitedArtifactComponent.CitationCitedArtifactWebLocationComponent: Used for any URL for the article or artifact cited.
 *
 * http://hl7.org/fhir/CitationCitedArtifactWebLocationComponent
 */
export const CitationCitedArtifactWebLocationComponent = 'http://hl7.org/fhir/CitationCitedArtifactWebLocationComponent' satisfies OwlClass;

/**
 * beneficiary
 *
 * Coverage.beneficiary: The party who benefits from the insurance coverage; the patient when products and/or services are provided.
 *
 * http://hl7.org/fhir/beneficiary
 */
export const beneficiary = 'http://hl7.org/fhir/beneficiary' satisfies OwlObjectProperty;

/**
 * prefix
 *
 * Questionnaire.item.item.prefix: A short label for a particular group, question or set of display text within the questionnaire used for reference by the individual completing the questionnaire.
 *
 * http://hl7.org/fhir/prefix
 */
export const prefix = 'http://hl7.org/fhir/prefix' satisfies OwlObjectProperty;

/**
 * effectiveTime
 *
 * Contract.term.group.asset.valuedItem.effectiveTime: Indicates the time during which this Contract ValuedItem information is effective.
 *
 * http://hl7.org/fhir/effectiveTime
 */
export const effectiveTime = 'http://hl7.org/fhir/effectiveTime' satisfies OwlObjectProperty;

/**
 * RegulatedAuthorizationCaseComponent
 *
 * RegulatedAuthorizationCaseComponent: The case or regulatory procedure for granting or amending a regulated authorization. An authorization is granted in response to submissions/applications by those seeking authorization. A case is the administrative process that deals with the application(s) that relate to this and assesses them. Note: This area is subject to ongoing review and the workgroup is seeking implementer feedback on its use (see link at bottom of page).
 *
 * http://hl7.org/fhir/RegulatedAuthorizationCaseComponent
 */
export const RegulatedAuthorizationCaseComponent = 'http://hl7.org/fhir/RegulatedAuthorizationCaseComponent' satisfies OwlClass;

/**
 * AccountProcedureComponent
 *
 * AccountProcedureComponent: When using an account for billing a specific Encounter the set of procedures that are relevant for billing are stored here on the account where they are able to be sequenced appropriately prior to processing to produce claim(s).
 *
 * http://hl7.org/fhir/AccountProcedureComponent
 */
export const AccountProcedureComponent = 'http://hl7.org/fhir/AccountProcedureComponent' satisfies OwlClass;

/**
 * doseStatusReason
 *
 * ImmunizationEvaluation.doseStatusReason: Provides an explanation as to why the vaccine administration event is valid or not relative to the published recommendations.
 *
 * http://hl7.org/fhir/doseStatusReason
 */
export const doseStatusReason = 'http://hl7.org/fhir/doseStatusReason' satisfies OwlObjectProperty;

/**
 * ResearchStudyAssociatedPartyComponent
 *
 * ResearchStudyAssociatedPartyComponent: Sponsors, collaborators, and other parties.
 *
 * http://hl7.org/fhir/ResearchStudyAssociatedPartyComponent
 */
export const ResearchStudyAssociatedPartyComponent = 'http://hl7.org/fhir/ResearchStudyAssociatedPartyComponent' satisfies OwlClass;

/**
 * reason
 *
 * Procedure.reason: The coded reason or reference why the procedure was performed. This may be a coded entity of some type, be present as text, or be a reference to one of several resources that justify the procedure.
 *
 * http://hl7.org/fhir/reason
 */
export const reason = 'http://hl7.org/fhir/reason' satisfies OwlObjectProperty;

/**
 * _precondition
 *
 * (Modified) ConditionDefinition.precondition
 *
 * http://hl7.org/fhir/_precondition
 */
export const _precondition = 'http://hl7.org/fhir/_precondition' satisfies OwlObjectProperty;

/**
 * criteria
 *
 * Measure.supplementalData.criteria: The criteria for the supplemental data. This is typically the name of a valid expression defined within a referenced library, but it may also be a path to a specific data element. The criteria defines the data to be returned for this element.
 *
 * http://hl7.org/fhir/criteria
 */
export const criteria = 'http://hl7.org/fhir/criteria' satisfies OwlObjectProperty;

/**
 * MedicationAdministrationDosageComponent
 *
 * MedicationAdministrationDosageComponent: Describes the medication dosage information details e.g. dose, rate, site, route, etc.
 *
 * http://hl7.org/fhir/MedicationAdministrationDosageComponent
 */
export const MedicationAdministrationDosageComponent = 'http://hl7.org/fhir/MedicationAdministrationDosageComponent' satisfies OwlClass;

/**
 * latitude
 *
 * Location.position.latitude: Latitude. The value domain and the interpretation are the same as for the text of the latitude element in KML (see notes on Location main page).
 *
 * http://hl7.org/fhir/latitude
 */
export const latitude = 'http://hl7.org/fhir/latitude' satisfies OwlObjectProperty;

/**
 * IngredientSubstanceStrengthReferenceStrengthComponent
 *
 * IngredientSubstanceComponent.IngredientSubstanceStrengthComponent.IngredientSubstanceStrengthReferenceStrengthComponent: Strength expressed in terms of a reference substance. For when the ingredient strength is additionally expressed as equivalent to the strength of some other closely related substance (e.g. salt vs. base). Reference strength represents the strength (quantitative composition) of the active moiety of the active substance. There are situations when the active substance and active moiety are different, therefore both a strength and a reference strength are needed.
 *
 * http://hl7.org/fhir/IngredientSubstanceStrengthReferenceStrengthComponent
 */
export const IngredientSubstanceStrengthReferenceStrengthComponent = 'http://hl7.org/fhir/IngredientSubstanceStrengthReferenceStrengthComponent' satisfies OwlClass;

/**
 * _thursday
 *
 * (Modified) Appointment.recurrenceTemplate.weeklyTemplate.thursday
 *
 * http://hl7.org/fhir/_thursday
 */
export const _thursday = 'http://hl7.org/fhir/_thursday' satisfies OwlObjectProperty;

/**
 * securityContext
 *
 * Binary.securityContext: This element identifies another resource that can be used as a proxy of the security sensitivity to use when deciding and enforcing access control rules for the Binary resource. Given that the Binary resource contains very few elements that can be used to determine the sensitivity of the data and relationships to individuals, the referenced resource stands in as a proxy equivalent for this purpose. This referenced resource may be related to the Binary (e.g. DocumentReference), or may be some non-related Resource purely as a security proxy. E.g. to identify that the binary resource relates to a patient, and access should only be granted to applications that have access to the patient.
 *
 * http://hl7.org/fhir/securityContext
 */
export const securityContext = 'http://hl7.org/fhir/securityContext' satisfies OwlObjectProperty;

/**
 * _baseDefinition
 *
 * (Modified) StructureDefinition.baseDefinition
 *
 * http://hl7.org/fhir/_baseDefinition
 */
export const _baseDefinition = 'http://hl7.org/fhir/_baseDefinition' satisfies OwlObjectProperty;

/**
 * _publicationStatus
 *
 * (Modified) Contract.contentDefinition.publicationStatus
 *
 * http://hl7.org/fhir/_publicationStatus
 */
export const _publicationStatus = 'http://hl7.org/fhir/_publicationStatus' satisfies OwlObjectProperty;

/**
 * relatedArtifact
 *
 * Measure.relatedArtifact: Related artifacts such as additional documentation, justification, or bibliographic references.
 *
 * http://hl7.org/fhir/relatedArtifact
 */
export const relatedArtifact = 'http://hl7.org/fhir/relatedArtifact' satisfies OwlObjectProperty;

/**
 * safety
 *
 * DeviceDefinition.safety: Safety characteristics of the device.
 *
 * http://hl7.org/fhir/safety
 */
export const safety = 'http://hl7.org/fhir/safety' satisfies OwlObjectProperty;

/**
 * stereochemistry
 *
 * SubstanceDefinition.structure.stereochemistry: Stereochemistry type.
 *
 * http://hl7.org/fhir/stereochemistry
 */
export const stereochemistry = 'http://hl7.org/fhir/stereochemistry' satisfies OwlObjectProperty;

/**
 * _timeout
 *
 * (Modified) Subscription.timeout
 *
 * http://hl7.org/fhir/_timeout
 */
export const _timeout = 'http://hl7.org/fhir/_timeout' satisfies OwlObjectProperty;

/**
 * primarySource
 *
 * VerificationResult.primarySource: Information about the primary source(s) involved in validation.
 *
 * http://hl7.org/fhir/primarySource
 */
export const primarySource = 'http://hl7.org/fhir/primarySource' satisfies OwlObjectProperty;

/**
 * NutritionOrderOralDietNutrientComponent
 *
 * NutritionOrderOralDietComponent.NutritionOrderOralDietNutrientComponent: Class that defines the quantity and type of nutrient modifications (for example carbohydrate, fiber or sodium) required for the oral diet.
 *
 * http://hl7.org/fhir/NutritionOrderOralDietNutrientComponent
 */
export const NutritionOrderOralDietNutrientComponent = 'http://hl7.org/fhir/NutritionOrderOralDietNutrientComponent' satisfies OwlClass;

/**
 * responseCode
 *
 * TestScript.test.action.assert.responseCode: The value of the HTTP response code to be tested.
 *
 * http://hl7.org/fhir/responseCode
 */
export const responseCode = 'http://hl7.org/fhir/responseCode' satisfies OwlObjectProperty;

/**
 * eventHistory
 *
 * DeviceDispense.eventHistory: A summary of the events of interest that have occurred, such as when the dispense was verified.
 *
 * http://hl7.org/fhir/eventHistory
 */
export const eventHistory = 'http://hl7.org/fhir/eventHistory' satisfies OwlObjectProperty;

/**
 * _doseForm
 *
 * (Modified) MedicationKnowledge.definitional.doseForm
 *
 * http://hl7.org/fhir/_doseForm
 */
export const _doseForm = 'http://hl7.org/fhir/_doseForm' satisfies OwlObjectProperty;

/**
 * _allowedResponse
 *
 * (Modified) MessageDefinition.allowedResponse
 *
 * http://hl7.org/fhir/_allowedResponse
 */
export const _allowedResponse = 'http://hl7.org/fhir/_allowedResponse' satisfies OwlObjectProperty;

/**
 * _storageGuideline
 *
 * (Modified) MedicationKnowledge.storageGuideline
 *
 * http://hl7.org/fhir/_storageGuideline
 */
export const _storageGuideline = 'http://hl7.org/fhir/_storageGuideline' satisfies OwlObjectProperty;

/**
 * timezone
 *
 * Appointment.recurrenceTemplate.timezone: The timezone of the recurring appointment occurrences.
 *
 * http://hl7.org/fhir/timezone
 */
export const timezone = 'http://hl7.org/fhir/timezone' satisfies OwlObjectProperty;

/**
 * copolymerConnectivity
 *
 * SubstancePolymer.copolymerConnectivity: Descrtibes the copolymer sequence type (polymer connectivity).
 *
 * http://hl7.org/fhir/copolymerConnectivity
 */
export const copolymerConnectivity = 'http://hl7.org/fhir/copolymerConnectivity' satisfies OwlObjectProperty;

/**
 * GenomicStudyAnalysisOutputComponent
 *
 * GenomicStudyAnalysisComponent.GenomicStudyAnalysisOutputComponent: Outputs for the analysis event.
 *
 * http://hl7.org/fhir/GenomicStudyAnalysisOutputComponent
 */
export const GenomicStudyAnalysisOutputComponent = 'http://hl7.org/fhir/GenomicStudyAnalysisOutputComponent' satisfies OwlClass;

/**
 * _molecularWeight
 *
 * (Modified) SubstanceDefinition.structure.molecularWeight
 *
 * http://hl7.org/fhir/_molecularWeight
 */
export const _molecularWeight = 'http://hl7.org/fhir/_molecularWeight' satisfies OwlObjectProperty;

/**
 * ObservationDefinition
 *
 * Set of definitional characteristics for a kind of observation or measurement produced or consumed by an orderable health care service.
 *
 * http://hl7.org/fhir/ObservationDefinition
 */
export const ObservationDefinition = 'http://hl7.org/fhir/ObservationDefinition' satisfies OwlClass;

/**
 * ifNoneMatch
 *
 * Bundle.entry.request.ifNoneMatch: If the ETag values match, return a 304 Not Modified status. See the API documentation for ["Conditional Read"](http.html#cread).
 *
 * http://hl7.org/fhir/ifNoneMatch
 */
export const ifNoneMatch = 'http://hl7.org/fhir/ifNoneMatch' satisfies OwlObjectProperty;

/**
 * _notConsumed
 *
 * (Modified) NutritionIntake.consumedItem.notConsumed
 *
 * http://hl7.org/fhir/_notConsumed
 */
export const _notConsumed = 'http://hl7.org/fhir/_notConsumed' satisfies OwlObjectProperty;

/**
 * grade
 *
 * SubstanceDefinition.grade: The quality standard, established benchmark, to which substance complies (e.g. USP/NF, Ph. Eur, JP, BP, Company Standard).
 *
 * http://hl7.org/fhir/grade
 */
export const grade = 'http://hl7.org/fhir/grade' satisfies OwlObjectProperty;

/**
 * OralDietSchedule
 *
 * NutritionOrderOralDietComponent.OralDietSchedule: Schedule information for an oral diet.
 *
 * http://hl7.org/fhir/OralDietSchedule
 */
export const OralDietSchedule = 'http://hl7.org/fhir/OralDietSchedule' satisfies OwlClass;

/**
 * _diagnosis
 *
 * (Modified) Encounter.diagnosis
 *
 * http://hl7.org/fhir/_diagnosis
 */
export const _diagnosis = 'http://hl7.org/fhir/_diagnosis' satisfies OwlObjectProperty;

/**
 * _channelType
 *
 * (Modified) Subscription.channelType
 *
 * http://hl7.org/fhir/_channelType
 */
export const _channelType = 'http://hl7.org/fhir/_channelType' satisfies OwlObjectProperty;

/**
 * _encounter
 *
 * (Modified) ServiceRequest.encounter
 *
 * http://hl7.org/fhir/_encounter
 */
export const _encounter = 'http://hl7.org/fhir/_encounter' satisfies OwlObjectProperty;

/**
 * SubstancePolymerMonomerSetStartingMaterialComponent
 *
 * SubstancePolymerMonomerSetComponent.SubstancePolymerMonomerSetStartingMaterialComponent: The starting materials - monomer(s) used in the synthesis of the polymer.
 *
 * http://hl7.org/fhir/SubstancePolymerMonomerSetStartingMaterialComponent
 */
export const SubstancePolymerMonomerSetStartingMaterialComponent = 'http://hl7.org/fhir/SubstancePolymerMonomerSetStartingMaterialComponent' satisfies OwlClass;

/**
 * statisticType
 *
 * Evidence.statistic.statisticType: Type of statistic, e.g., relative risk.
 *
 * http://hl7.org/fhir/statisticType
 */
export const statisticType = 'http://hl7.org/fhir/statisticType' satisfies OwlObjectProperty;

/**
 * _webLocation
 *
 * (Modified) Citation.citedArtifact.webLocation
 *
 * http://hl7.org/fhir/_webLocation
 */
export const _webLocation = 'http://hl7.org/fhir/_webLocation' satisfies OwlObjectProperty;

/**
 * SubstanceSourceMaterialOrganismOrganismGeneralComponent
 *
 * SubstanceSourceMaterialOrganismComponent.SubstanceSourceMaterialOrganismOrganismGeneralComponent: 4.9.13.7.1 Kingdom (Conditional).
 *
 * http://hl7.org/fhir/SubstanceSourceMaterialOrganismOrganismGeneralComponent
 */
export const SubstanceSourceMaterialOrganismOrganismGeneralComponent = 'http://hl7.org/fhir/SubstanceSourceMaterialOrganismOrganismGeneralComponent' satisfies OwlClass;

/**
 * textConcentration
 *
 * Ingredient.substance.strength.textConcentration: A textual represention of either the whole of the concentration strength or a part of it - with the rest being in Strength.concentration as a ratio.
 *
 * http://hl7.org/fhir/textConcentration
 */
export const textConcentration = 'http://hl7.org/fhir/textConcentration' satisfies OwlObjectProperty;

/**
 * _multipleAnd
 *
 * (Modified) SearchParameter.multipleAnd
 *
 * http://hl7.org/fhir/_multipleAnd
 */
export const _multipleAnd = 'http://hl7.org/fhir/_multipleAnd' satisfies OwlObjectProperty;

/**
 * _freeToShare
 *
 * (Modified) ArtifactAssessment.content.component.freeToShare
 *
 * http://hl7.org/fhir/_freeToShare
 */
export const _freeToShare = 'http://hl7.org/fhir/_freeToShare' satisfies OwlObjectProperty;

/**
 * _contributionInstance
 *
 * (Modified) Citation.citedArtifact.contributorship.entry.contributionInstance
 *
 * http://hl7.org/fhir/_contributionInstance
 */
export const _contributionInstance = 'http://hl7.org/fhir/_contributionInstance' satisfies OwlObjectProperty;

/**
 * MedicationStatementAdherenceComponent
 *
 * MedicationStatementAdherenceComponent: Indicates whether the medication is or is not being consumed or administered.
 *
 * http://hl7.org/fhir/MedicationStatementAdherenceComponent
 */
export const MedicationStatementAdherenceComponent = 'http://hl7.org/fhir/MedicationStatementAdherenceComponent' satisfies OwlClass;

/**
 * _onAdmission
 *
 * (Modified) ExplanationOfBenefit.diagnosis.onAdmission
 *
 * http://hl7.org/fhir/_onAdmission
 */
export const _onAdmission = 'http://hl7.org/fhir/_onAdmission' satisfies OwlObjectProperty;

/**
 * output
 *
 * GenomicStudy.analysis.output: Outputs for the analysis event.
 *
 * http://hl7.org/fhir/output
 */
export const output = 'http://hl7.org/fhir/output' satisfies OwlObjectProperty;

/**
 * _indication
 *
 * (Modified) RegulatedAuthorization.indication
 *
 * http://hl7.org/fhir/_indication
 */
export const _indication = 'http://hl7.org/fhir/_indication' satisfies OwlObjectProperty;

/**
 * DeviceDefinitionChargeItemComponent
 *
 * DeviceDefinitionChargeItemComponent: Billing code or reference associated with the device.
 *
 * http://hl7.org/fhir/DeviceDefinitionChargeItemComponent
 */
export const DeviceDefinitionChargeItemComponent = 'http://hl7.org/fhir/DeviceDefinitionChargeItemComponent' satisfies OwlClass;

/**
 * location
 *
 * InventoryItem.instance.location: The location that the item is associated with.
 *
 * http://hl7.org/fhir/location
 */
export const location = 'http://hl7.org/fhir/location' satisfies OwlObjectProperty;

/**
 * generalCost
 *
 * InsurancePlan.plan.generalCost: Overall costs associated with the plan.
 *
 * http://hl7.org/fhir/generalCost
 */
export const generalCost = 'http://hl7.org/fhir/generalCost' satisfies OwlObjectProperty;

/**
 * _plannedActivityReference
 *
 * (Modified) CarePlan.activity.plannedActivityReference
 *
 * http://hl7.org/fhir/_plannedActivityReference
 */
export const _plannedActivityReference = 'http://hl7.org/fhir/_plannedActivityReference' satisfies OwlObjectProperty;

/**
 * rules
 *
 * ElementDefinition.slicing.rules: Whether additional slices are allowed or not. When the slices are ordered, profile authors can also say that additional slices are only allowed at the end.
 *
 * http://hl7.org/fhir/rules
 */
export const rules = 'http://hl7.org/fhir/rules' satisfies OwlObjectProperty;

/**
 * reported
 *
 * Procedure.reported
 *
 * http://hl7.org/fhir/reported
 */
export const reported = 'http://hl7.org/fhir/reported' satisfies OwlObjectProperty;

/**
 * maxDosePerDay
 *
 * AdministrableProductDefinition.routeOfAdministration.maxDosePerDay: The maximum dose per day (maximum dose quantity to be administered in any one 24-h period) that can be administered.
 *
 * http://hl7.org/fhir/maxDosePerDay
 */
export const maxDosePerDay = 'http://hl7.org/fhir/maxDosePerDay' satisfies OwlObjectProperty;

/**
 * NutritionOrderOralDietTextureComponent
 *
 * NutritionOrderOralDietComponent.NutritionOrderOralDietTextureComponent: Class that describes any texture modifications required for the patient to safely consume various types of solid foods.
 *
 * http://hl7.org/fhir/NutritionOrderOralDietTextureComponent
 */
export const NutritionOrderOralDietTextureComponent = 'http://hl7.org/fhir/NutritionOrderOralDietTextureComponent' satisfies OwlClass;

/**
 * _definitionByTypeAndValue
 *
 * (Modified) EvidenceVariable.characteristic.definitionByCombination.characteristic.definitionByTypeAndValue
 *
 * http://hl7.org/fhir/_definitionByTypeAndValue
 */
export const _definitionByTypeAndValue = 'http://hl7.org/fhir/_definitionByTypeAndValue' satisfies OwlObjectProperty;

/**
 * GroupMemberComponent
 *
 * GroupMemberComponent: Identifies the resource instances that are members of the group.
 *
 * http://hl7.org/fhir/GroupMemberComponent
 */
export const GroupMemberComponent = 'http://hl7.org/fhir/GroupMemberComponent' satisfies OwlClass;

/**
 * _verificationType
 *
 * (Modified) Consent.verification.verificationType
 *
 * http://hl7.org/fhir/_verificationType
 */
export const _verificationType = 'http://hl7.org/fhir/_verificationType' satisfies OwlObjectProperty;

/**
 * _supportingInformation
 *
 * (Modified) MedicationAdministration.supportingInformation
 *
 * http://hl7.org/fhir/_supportingInformation
 */
export const _supportingInformation = 'http://hl7.org/fhir/_supportingInformation' satisfies OwlObjectProperty;

/**
 * kingdom
 *
 * SubstanceSourceMaterial.organism.organismGeneral.kingdom: The kingdom of an organism shall be specified.
 *
 * http://hl7.org/fhir/kingdom
 */
export const kingdom = 'http://hl7.org/fhir/kingdom' satisfies OwlObjectProperty;

/**
 * sourceMaterialClass
 *
 * SubstanceSourceMaterial.sourceMaterialClass: General high level classification of the source material specific to the origin of the material.
 *
 * http://hl7.org/fhir/sourceMaterialClass
 */
export const sourceMaterialClass = 'http://hl7.org/fhir/sourceMaterialClass' satisfies OwlObjectProperty;

/**
 * _polymer
 *
 * (Modified) SubstanceDefinition.polymer
 *
 * http://hl7.org/fhir/_polymer
 */
export const _polymer = 'http://hl7.org/fhir/_polymer' satisfies OwlObjectProperty;

/**
 * insurance
 *
 * Transport.insurance: Insurance plans, coverage extensions, pre-authorizations and/or pre-determinations that may be relevant to the Transport.
 *
 * http://hl7.org/fhir/insurance
 */
export const insurance = 'http://hl7.org/fhir/insurance' satisfies OwlObjectProperty;

/**
 * _handling
 *
 * (Modified) SpecimenDefinition.typeTested.handling
 *
 * http://hl7.org/fhir/_handling
 */
export const _handling = 'http://hl7.org/fhir/_handling' satisfies OwlObjectProperty;

/**
 * supportingInfo
 *
 * AdverseEvent.supportingInfo: Supporting information relevant to the event.
 *
 * http://hl7.org/fhir/supportingInfo
 */
export const supportingInfo = 'http://hl7.org/fhir/supportingInfo' satisfies OwlObjectProperty;

/**
 * lifecycleStatus
 *
 * Goal.lifecycleStatus: The state of the goal throughout its lifecycle.
 *
 * http://hl7.org/fhir/lifecycleStatus
 */
export const lifecycleStatus = 'http://hl7.org/fhir/lifecycleStatus' satisfies OwlObjectProperty;

/**
 * _symptomConditionEffect
 *
 * (Modified) ClinicalUseDefinition.undesirableEffect.symptomConditionEffect
 *
 * http://hl7.org/fhir/_symptomConditionEffect
 */
export const _symptomConditionEffect = 'http://hl7.org/fhir/_symptomConditionEffect' satisfies OwlObjectProperty;

/**
 * _fraction
 *
 * (Modified) SubstanceSourceMaterial.fractionDescription.fraction
 *
 * http://hl7.org/fhir/_fraction
 */
export const _fraction = 'http://hl7.org/fhir/_fraction' satisfies OwlObjectProperty;

/**
 * language
 *
 * RelatedPerson.communication.language: The ISO-639-1 alpha 2 code in lower case for the language, optionally followed by a hyphen and the ISO-3166-1 alpha 2 code for the region in upper case; e.g. "en" for English, or "en-US" for American English versus "en-AU" for Australian English.
 *
 * http://hl7.org/fhir/language
 */
export const language = 'http://hl7.org/fhir/language' satisfies OwlObjectProperty;

/**
 * combining
 *
 * Permission.combining: Defines a procedure for arriving at an access decision given the set of rules.
 *
 * http://hl7.org/fhir/combining
 */
export const combining = 'http://hl7.org/fhir/combining' satisfies OwlObjectProperty;

/**
 * country
 *
 * Address.country: Country - a nation as commonly understood or generally accepted.
 *
 * http://hl7.org/fhir/country
 */
export const country = 'http://hl7.org/fhir/country' satisfies OwlObjectProperty;

/**
 * isExample
 *
 * ImplementationGuide.manifest.resource.isExample: If true, indicates the resource is an example instance.
 *
 * http://hl7.org/fhir/isExample
 */
export const isExample = 'http://hl7.org/fhir/isExample' satisfies OwlObjectProperty;

/**
 * _readHistory
 *
 * (Modified) CapabilityStatement.rest.resource.readHistory
 *
 * http://hl7.org/fhir/_readHistory
 */
export const _readHistory = 'http://hl7.org/fhir/_readHistory' satisfies OwlObjectProperty;

/**
 * BundleLinkComponent
 *
 * BundleLinkComponent: A series of links that provide context to this bundle.
 *
 * http://hl7.org/fhir/BundleLinkComponent
 */
export const BundleLinkComponent = 'http://hl7.org/fhir/BundleLinkComponent' satisfies OwlClass;

/**
 * currentLocation
 *
 * Transport.currentLocation: The current location for the entity to be transported.
 *
 * http://hl7.org/fhir/currentLocation
 */
export const currentLocation = 'http://hl7.org/fhir/currentLocation' satisfies OwlObjectProperty;

/**
 * official
 *
 * SubstanceDefinition.name.official: Details of the official nature of this name.
 *
 * http://hl7.org/fhir/official
 */
export const official = 'http://hl7.org/fhir/official' satisfies OwlObjectProperty;

/**
 * _EncounterHistory
 *
 * (Modified) EncounterHistory
 *
 * http://hl7.org/fhir/_EncounterHistory
 */
export const _EncounterHistory = 'http://hl7.org/fhir/_EncounterHistory' satisfies OwlClass;

/**
 * EvidenceVariableCategoryComponent
 *
 * EvidenceVariableCategoryComponent: A grouping for ordinal or polychotomous variables.
 *
 * http://hl7.org/fhir/EvidenceVariableCategoryComponent
 */
export const EvidenceVariableCategoryComponent = 'http://hl7.org/fhir/EvidenceVariableCategoryComponent' satisfies OwlClass;

/**
 * _administeredBy
 *
 * (Modified) InsurancePlan.administeredBy
 *
 * http://hl7.org/fhir/_administeredBy
 */
export const _administeredBy = 'http://hl7.org/fhir/_administeredBy' satisfies OwlObjectProperty;

/**
 * _ProductShelfLife
 *
 * (Modified) ProductShelfLife
 *
 * http://hl7.org/fhir/_ProductShelfLife
 */
export const _ProductShelfLife = 'http://hl7.org/fhir/_ProductShelfLife' satisfies OwlClass;

/**
 * SubstanceDefinitionMolecularWeightComponent
 *
 * SubstanceDefinitionMolecularWeightComponent: The average mass of a molecule of a compound compared to 1/12 the mass of carbon 12 and calculated as the sum of the atomic weights of the constituent atoms.
 *
 * http://hl7.org/fhir/SubstanceDefinitionMolecularWeightComponent
 */
export const SubstanceDefinitionMolecularWeightComponent = 'http://hl7.org/fhir/SubstanceDefinitionMolecularWeightComponent' satisfies OwlClass;

/**
 * affectsState
 *
 * OperationDefinition.affectsState: Whether the operation affects state. Side effects such as producing audit trail entries do not count as 'affecting  state'.
 *
 * http://hl7.org/fhir/affectsState
 */
export const affectsState = 'http://hl7.org/fhir/affectsState' satisfies OwlObjectProperty;

/**
 * notificationShape
 *
 * SubscriptionTopic.notificationShape: List of properties to describe the shape (e.g., resources) included in notifications from this Subscription Topic.
 *
 * http://hl7.org/fhir/notificationShape
 */
export const notificationShape = 'http://hl7.org/fhir/notificationShape' satisfies OwlObjectProperty;

/**
 * descriptionSummary
 *
 * ResearchStudy.descriptionSummary: A brief text for explaining the study.
 *
 * http://hl7.org/fhir/descriptionSummary
 */
export const descriptionSummary = 'http://hl7.org/fhir/descriptionSummary' satisfies OwlObjectProperty;

/**
 * _answerValueSet
 *
 * (Modified) Questionnaire.item.item.answerValueSet
 *
 * http://hl7.org/fhir/_answerValueSet
 */
export const _answerValueSet = 'http://hl7.org/fhir/_answerValueSet' satisfies OwlObjectProperty;

/**
 * PractitionerRole
 *
 * A specific set of Roles/Locations/specialties/services that a practitioner may perform, or has performed at an organization during a period of time.
 *
 * http://hl7.org/fhir/PractitionerRole
 */
export const PractitionerRole = 'http://hl7.org/fhir/PractitionerRole' satisfies OwlClass;

/**
 * _rationale
 *
 * (Modified) RiskAssessment.prediction.rationale
 *
 * http://hl7.org/fhir/_rationale
 */
export const _rationale = 'http://hl7.org/fhir/_rationale' satisfies OwlObjectProperty;

/**
 * _ChargeItem
 *
 * (Modified) ChargeItem
 *
 * http://hl7.org/fhir/_ChargeItem
 */
export const _ChargeItem = 'http://hl7.org/fhir/_ChargeItem' satisfies OwlClass;

/**
 * _offer
 *
 * (Modified) Contract.term.group.offer
 *
 * http://hl7.org/fhir/_offer
 */
export const _offer = 'http://hl7.org/fhir/_offer' satisfies OwlObjectProperty;

/**
 * OperationDefinitionParameterReferencedFromComponent
 *
 * OperationDefinitionParameterComponent.OperationDefinitionParameterReferencedFromComponent: Identifies other resource parameters within the operation invocation that are expected to resolve to this resource.
 *
 * http://hl7.org/fhir/OperationDefinitionParameterReferencedFromComponent
 */
export const OperationDefinitionParameterReferencedFromComponent = 'http://hl7.org/fhir/OperationDefinitionParameterReferencedFromComponent' satisfies OwlClass;

/**
 * singleUse
 *
 * SpecimenDefinition.typeTested.singleUse: Specimen can be used by only one test or panel if the value is "true".
 *
 * http://hl7.org/fhir/singleUse
 */
export const singleUse = 'http://hl7.org/fhir/singleUse' satisfies OwlObjectProperty;

/**
 * _exclude
 *
 * (Modified) ValueSet.compose.exclude
 *
 * http://hl7.org/fhir/_exclude
 */
export const _exclude = 'http://hl7.org/fhir/_exclude' satisfies OwlObjectProperty;

/**
 * fhirVersion
 *
 * ImplementationGuide.fhirVersion: The version(s) of the FHIR specification that this ImplementationGuide targets - e.g. describes how to use. The value of this element is the formal version of the specification, without the revision number, e.g. [publication].[major].[minor], which is 4.6.0. for this version.
 *
 * http://hl7.org/fhir/fhirVersion
 */
export const fhirVersion = 'http://hl7.org/fhir/fhirVersion' satisfies OwlObjectProperty;

/**
 * _nucleicAcid
 *
 * (Modified) SubstanceDefinition.nucleicAcid
 *
 * http://hl7.org/fhir/_nucleicAcid
 */
export const _nucleicAcid = 'http://hl7.org/fhir/_nucleicAcid' satisfies OwlObjectProperty;

/**
 * CodeableConcept
 *
 * A concept that may be defined by a formal reference to a terminology or ontology or may be provided by text.
 *
 * http://hl7.org/fhir/CodeableConcept
 */
export const CodeableConcept = 'http://hl7.org/fhir/CodeableConcept' satisfies OwlClass;

/**
 * _Claim
 *
 * (Modified) Claim
 *
 * http://hl7.org/fhir/_Claim
 */
export const _Claim = 'http://hl7.org/fhir/_Claim' satisfies OwlClass;

/**
 * _site
 *
 * (Modified) ExplanationOfBenefit.item.bodySite.site
 *
 * http://hl7.org/fhir/_site
 */
export const _site = 'http://hl7.org/fhir/_site' satisfies OwlObjectProperty;

/**
 * targetScope
 *
 * ConceptMap.targetScope
 *
 * http://hl7.org/fhir/targetScope
 */
export const targetScope = 'http://hl7.org/fhir/targetScope' satisfies OwlObjectProperty;

/**
 * _monthInterval
 *
 * (Modified) Appointment.recurrenceTemplate.monthlyTemplate.monthInterval
 *
 * http://hl7.org/fhir/_monthInterval
 */
export const _monthInterval = 'http://hl7.org/fhir/_monthInterval' satisfies OwlObjectProperty;

/**
 * _monitoringProgram
 *
 * (Modified) MedicationKnowledge.monitoringProgram
 *
 * http://hl7.org/fhir/_monitoringProgram
 */
export const _monitoringProgram = 'http://hl7.org/fhir/_monitoringProgram' satisfies OwlObjectProperty;

/**
 * mustHaveValue
 *
 * ElementDefinition.mustHaveValue: Specifies for a primitive data type that the value of the data type cannot be replaced by an extension.
 *
 * http://hl7.org/fhir/mustHaveValue
 */
export const mustHaveValue = 'http://hl7.org/fhir/mustHaveValue' satisfies OwlObjectProperty;

/**
 * _interpreter
 *
 * (Modified) GenomicStudy.interpreter
 *
 * http://hl7.org/fhir/_interpreter
 */
export const _interpreter = 'http://hl7.org/fhir/_interpreter' satisfies OwlObjectProperty;

/**
 * SubscriptionStatus
 *
 * The SubscriptionStatus resource describes the state of a Subscription during notifications. It is not persisted.
 *
 * http://hl7.org/fhir/SubscriptionStatus
 */
export const SubscriptionStatus = 'http://hl7.org/fhir/SubscriptionStatus' satisfies OwlClass;

/**
 * _productOrServiceEnd
 *
 * (Modified) ClaimResponse.addItem.detail.productOrServiceEnd
 *
 * http://hl7.org/fhir/_productOrServiceEnd
 */
export const _productOrServiceEnd = 'http://hl7.org/fhir/_productOrServiceEnd' satisfies OwlObjectProperty;

/**
 * doseQuantity
 *
 * Immunization.doseQuantity: The quantity of vaccine product that was administered.
 *
 * http://hl7.org/fhir/doseQuantity
 */
export const doseQuantity = 'http://hl7.org/fhir/doseQuantity' satisfies OwlObjectProperty;

/**
 * _prism
 *
 * (Modified) VisionPrescription.lensSpecification.prism
 *
 * http://hl7.org/fhir/_prism
 */
export const _prism = 'http://hl7.org/fhir/_prism' satisfies OwlObjectProperty;

/**
 * highNumerator
 *
 * RatioRange.highNumerator: The value of the high limit numerator.
 *
 * http://hl7.org/fhir/highNumerator
 */
export const highNumerator = 'http://hl7.org/fhir/highNumerator' satisfies OwlObjectProperty;

/**
 * contentDefinition
 *
 * Contract.contentDefinition: Precusory content developed with a focus and intent of supporting the formation a Contract instance, which may be associated with and transformable into a Contract.
 *
 * http://hl7.org/fhir/contentDefinition
 */
export const contentDefinition = 'http://hl7.org/fhir/contentDefinition' satisfies OwlObjectProperty;

/**
 * due
 *
 * PlanDefinition.goal.target.due: Indicates the timeframe after the start of the goal in which the goal should be met.
 *
 * http://hl7.org/fhir/due
 */
export const due = 'http://hl7.org/fhir/due' satisfies OwlObjectProperty;

/**
 * structureProfile
 *
 * ExampleScenario.instance.structureProfile
 *
 * http://hl7.org/fhir/structureProfile
 */
export const structureProfile = 'http://hl7.org/fhir/structureProfile' satisfies OwlObjectProperty;

/**
 * _acceptLanguage
 *
 * (Modified) CapabilityStatement.acceptLanguage
 *
 * http://hl7.org/fhir/_acceptLanguage
 */
export const _acceptLanguage = 'http://hl7.org/fhir/_acceptLanguage' satisfies OwlObjectProperty;

/**
 * _RegulatedAuthorization
 *
 * (Modified) RegulatedAuthorization
 *
 * http://hl7.org/fhir/_RegulatedAuthorization
 */
export const _RegulatedAuthorization = 'http://hl7.org/fhir/_RegulatedAuthorization' satisfies OwlClass;

/**
 * authorType
 *
 * SubstanceSourceMaterial.organism.author.authorType: The type of author of an organism species shall be specified. The parenthetical author of an organism species refers to the first author who published the plant/animal name (of any rank). The primary author of an organism species refers to the first author(s), who validly published the plant/animal name.
 *
 * http://hl7.org/fhir/authorType
 */
export const authorType = 'http://hl7.org/fhir/authorType' satisfies OwlObjectProperty;

/**
 * paymentIssuer
 *
 * PaymentReconciliation.paymentIssuer: The party who generated the payment.
 *
 * http://hl7.org/fhir/paymentIssuer
 */
export const paymentIssuer = 'http://hl7.org/fhir/paymentIssuer' satisfies OwlObjectProperty;

/**
 * clinicalTrial
 *
 * MedicinalProductDefinition.clinicalTrial: Clinical trials or studies that this product is involved in.
 *
 * http://hl7.org/fhir/clinicalTrial
 */
export const clinicalTrial = 'http://hl7.org/fhir/clinicalTrial' satisfies OwlObjectProperty;

/**
 * _parentSubstanceName
 *
 * (Modified) SubstanceSourceMaterial.parentSubstanceName
 *
 * http://hl7.org/fhir/_parentSubstanceName
 */
export const _parentSubstanceName = 'http://hl7.org/fhir/_parentSubstanceName' satisfies OwlObjectProperty;

/**
 * _high
 *
 * (Modified) SubstancePolymer.repeat.repeatUnit.degreeOfPolymerisation.high
 *
 * http://hl7.org/fhir/_high
 */
export const _high = 'http://hl7.org/fhir/_high' satisfies OwlObjectProperty;

/**
 * actorId
 *
 * PlanDefinition.action.action.participant.actorId: A reference to the id element of the actor who will participate in this action.
 *
 * http://hl7.org/fhir/actorId
 */
export const actorId = 'http://hl7.org/fhir/actorId' satisfies OwlObjectProperty;

/**
 * _document
 *
 * (Modified) SubstanceDefinition.structure.representation.document
 *
 * http://hl7.org/fhir/_document
 */
export const _document = 'http://hl7.org/fhir/_document' satisfies OwlObjectProperty;

/**
 * _marketPeriod
 *
 * (Modified) DeviceDefinition.packaging.packaging.udiDeviceIdentifier.marketDistribution.marketPeriod
 *
 * http://hl7.org/fhir/_marketPeriod
 */
export const _marketPeriod = 'http://hl7.org/fhir/_marketPeriod' satisfies OwlObjectProperty;

/**
 * _denominator
 *
 * (Modified) RatioRange.denominator
 *
 * http://hl7.org/fhir/_denominator
 */
export const _denominator = 'http://hl7.org/fhir/_denominator' satisfies OwlObjectProperty;

/**
 * accessionIdentifier
 *
 * Specimen.accessionIdentifier: The identifier assigned by the lab when accessioning specimen(s). This is not necessarily the same as the specimen identifier, depending on local lab procedures.
 *
 * http://hl7.org/fhir/accessionIdentifier
 */
export const accessionIdentifier = 'http://hl7.org/fhir/accessionIdentifier' satisfies OwlObjectProperty;

/**
 * VerificationResultPrimarySourceComponent
 *
 * VerificationResultPrimarySourceComponent: Information about the primary source(s) involved in validation.
 *
 * http://hl7.org/fhir/VerificationResultPrimarySourceComponent
 */
export const VerificationResultPrimarySourceComponent = 'http://hl7.org/fhir/VerificationResultPrimarySourceComponent' satisfies OwlClass;

/**
 * authored
 *
 * QuestionnaireResponse.authored: The date and/or time that this questionnaire response was last modified by the user - e.g. changing answers or revising status.
 *
 * http://hl7.org/fhir/authored
 */
export const authored = 'http://hl7.org/fhir/authored' satisfies OwlObjectProperty;

/**
 * serialNumber
 *
 * Device.serialNumber: The serial number assigned by the organization when the device was manufactured.
 *
 * http://hl7.org/fhir/serialNumber
 */
export const serialNumber = 'http://hl7.org/fhir/serialNumber' satisfies OwlObjectProperty;

/**
 * Consent
 *
 * A record of a healthcare consumer’s  choices  or choices made on their behalf by a third party, which permits or denies identified recipient(s) or recipient role(s) to perform one or more actions within a given policy context, for specific purposes and periods of time.
 *
 * http://hl7.org/fhir/Consent
 */
export const Consent = 'http://hl7.org/fhir/Consent' satisfies OwlClass;

/**
 * _resourceType
 *
 * (Modified) Subscription.filterBy.resourceType
 *
 * http://hl7.org/fhir/_resourceType
 */
export const _resourceType = 'http://hl7.org/fhir/_resourceType' satisfies OwlObjectProperty;

/**
 * outcomeMeasure
 *
 * ResearchStudy.outcomeMeasure: An "outcome measure", "endpoint", "effect measure" or "measure of effect" is a specific measurement or observation used to quantify the effect of experimental variables on the participants in a study, or for observational studies, to describe patterns of diseases or traits or associations with exposures, risk factors or treatment.
 *
 * http://hl7.org/fhir/outcomeMeasure
 */
export const outcomeMeasure = 'http://hl7.org/fhir/outcomeMeasure' satisfies OwlObjectProperty;

/**
 * purpose
 *
 * Requirements.purpose: Explanation of why this Requirements is needed and why it has been designed as it has.
 *
 * http://hl7.org/fhir/purpose
 */
export const purpose = 'http://hl7.org/fhir/purpose' satisfies OwlObjectProperty;

/**
 * DiagnosticReportSupportingInfoComponent
 *
 * DiagnosticReportSupportingInfoComponent: This backbone element contains supporting information that was used in the creation of the report not included in the results already included in the report.
 *
 * http://hl7.org/fhir/DiagnosticReportSupportingInfoComponent
 */
export const DiagnosticReportSupportingInfoComponent = 'http://hl7.org/fhir/DiagnosticReportSupportingInfoComponent' satisfies OwlClass;

/**
 * Citation
 *
 * The Citation Resource enables reference to any knowledge artifact for purposes of identification and attribution. The Citation Resource supports existing reference structures and developing publication practices such as versioning, expressing complex contributorship roles, and referencing computable resources.
 *
 * http://hl7.org/fhir/Citation
 */
export const Citation = 'http://hl7.org/fhir/Citation' satisfies OwlClass;

/**
 * _serviced
 *
 * (Modified) Invoice.lineItem.serviced
 *
 * http://hl7.org/fhir/_serviced
 */
export const _serviced = 'http://hl7.org/fhir/_serviced' satisfies OwlObjectProperty;

/**
 * performer
 *
 * Procedure.performer: Indicates who or what performed the procedure and how they were involved.
 *
 * http://hl7.org/fhir/performer
 */
export const performer = 'http://hl7.org/fhir/performer' satisfies OwlObjectProperty;

/**
 * _stratifier
 *
 * (Modified) MeasureReport.group.stratifier
 *
 * http://hl7.org/fhir/_stratifier
 */
export const _stratifier = 'http://hl7.org/fhir/_stratifier' satisfies OwlObjectProperty;

/**
 * InvoiceParticipantComponent
 *
 * InvoiceParticipantComponent: Indicates who or what performed or participated in the charged service.
 *
 * http://hl7.org/fhir/InvoiceParticipantComponent
 */
export const InvoiceParticipantComponent = 'http://hl7.org/fhir/InvoiceParticipantComponent' satisfies OwlClass;

/**
 * requiredBehavior
 *
 * PlanDefinition.action.requiredBehavior: Defines the required behavior for the action.
 *
 * http://hl7.org/fhir/requiredBehavior
 */
export const requiredBehavior = 'http://hl7.org/fhir/requiredBehavior' satisfies OwlObjectProperty;

/**
 * _oralDiet
 *
 * (Modified) NutritionOrder.oralDiet
 *
 * http://hl7.org/fhir/_oralDiet
 */
export const _oralDiet = 'http://hl7.org/fhir/_oralDiet' satisfies OwlObjectProperty;

/**
 * monday
 *
 * Appointment.recurrenceTemplate.weeklyTemplate.monday: Indicates that recurring appointments should occur on Mondays.
 *
 * http://hl7.org/fhir/monday
 */
export const monday = 'http://hl7.org/fhir/monday' satisfies OwlObjectProperty;

/**
 * MedicationRequestDispenseRequestComponent
 *
 * MedicationRequestDispenseRequestComponent: Indicates the specific details for the dispense or medication supply part of a medication request (also known as a Medication Prescription or Medication Order).  Note that this information is not always sent with the order.  There may be in some settings (e.g. hospitals) institutional or system support for completing the dispense details in the pharmacy department.
 *
 * http://hl7.org/fhir/MedicationRequestDispenseRequestComponent
 */
export const MedicationRequestDispenseRequestComponent = 'http://hl7.org/fhir/MedicationRequestDispenseRequestComponent' satisfies OwlClass;

/**
 * _subJurisdiction
 *
 * (Modified) DeviceDefinition.packaging.packaging.udiDeviceIdentifier.marketDistribution.subJurisdiction
 *
 * http://hl7.org/fhir/_subJurisdiction
 */
export const _subJurisdiction = 'http://hl7.org/fhir/_subJurisdiction' satisfies OwlObjectProperty;

/**
 * _interactant
 *
 * (Modified) ClinicalUseDefinition.interaction.interactant
 *
 * http://hl7.org/fhir/_interactant
 */
export const _interactant = 'http://hl7.org/fhir/_interactant' satisfies OwlObjectProperty;

/**
 * _admitSource
 *
 * (Modified) Encounter.admission.admitSource
 *
 * http://hl7.org/fhir/_admitSource
 */
export const _admitSource = 'http://hl7.org/fhir/_admitSource' satisfies OwlObjectProperty;

/**
 * TargetElement
 *
 * ConceptMapGroupComponent.SourceElement.TargetElement: A concept from the target value set that this concept maps to.
 *
 * http://hl7.org/fhir/TargetElement
 */
export const TargetElement = 'http://hl7.org/fhir/TargetElement' satisfies OwlClass;

/**
 * _given
 *
 * (Modified) HumanName.given
 *
 * http://hl7.org/fhir/_given
 */
export const _given = 'http://hl7.org/fhir/_given' satisfies OwlObjectProperty;

/**
 * _recorder
 *
 * (Modified) Procedure.recorder
 *
 * http://hl7.org/fhir/_recorder
 */
export const _recorder = 'http://hl7.org/fhir/_recorder' satisfies OwlObjectProperty;

/**
 * hasPart
 *
 * DeviceDefinition.hasPart: A device that is part (for example a component) of the present device.
 *
 * http://hl7.org/fhir/hasPart
 */
export const hasPart = 'http://hl7.org/fhir/hasPart' satisfies OwlObjectProperty;

/**
 * _cancellationDate
 *
 * (Modified) Appointment.cancellationDate
 *
 * http://hl7.org/fhir/_cancellationDate
 */
export const _cancellationDate = 'http://hl7.org/fhir/_cancellationDate' satisfies OwlObjectProperty;

/**
 * supplements
 *
 * CodeSystem.supplements: The canonical URL of the code system that this code system supplement is adding designations and properties to.
 *
 * http://hl7.org/fhir/supplements
 */
export const supplements = 'http://hl7.org/fhir/supplements' satisfies OwlObjectProperty;

/**
 * constraint
 *
 * SearchParameter.constraint: FHIRPath expression that defines/sets a complex constraint for when this SearchParameter is applicable.
 *
 * http://hl7.org/fhir/constraint
 */
export const constraint = 'http://hl7.org/fhir/constraint' satisfies OwlObjectProperty;

/**
 * total
 *
 * ValueSet.expansion.total: The total number of concepts in the expansion. If the number of concept nodes in this resource is less than the stated number, then the server can return more using the offset parameter.
 *
 * http://hl7.org/fhir/total
 */
export const total = 'http://hl7.org/fhir/total' satisfies OwlObjectProperty;

/**
 * outcome
 *
 * Goal.outcome: Identifies the change (or lack of change) at the point when the status of the goal is assessed.
 *
 * http://hl7.org/fhir/outcome
 */
export const outcome = 'http://hl7.org/fhir/outcome' satisfies OwlObjectProperty;

/**
 * sampleSize
 *
 * Evidence.statistic.sampleSize: Number of samples in the statistic.
 *
 * http://hl7.org/fhir/sampleSize
 */
export const sampleSize = 'http://hl7.org/fhir/sampleSize' satisfies OwlObjectProperty;

/**
 * ContributorshipSummary
 *
 * CitationCitedArtifactComponent.CitationCitedArtifactContributorshipComponent.ContributorshipSummary: Used to record a display of the author/contributor list without separate data element for each list member.
 *
 * http://hl7.org/fhir/ContributorshipSummary
 */
export const ContributorshipSummary = 'http://hl7.org/fhir/ContributorshipSummary' satisfies OwlClass;

/**
 * PrimitiveType
 *
 * The base type for all re-useable types defined that have a simple property.
 *
 * http://hl7.org/fhir/PrimitiveType
 */
export const PrimitiveType = 'http://hl7.org/fhir/PrimitiveType' satisfies OwlClass;

/**
 * caloricDensity
 *
 * NutritionOrder.enteralFormula.caloricDensity: The amount of energy (calories) that the formula should provide per specified volume, typically per mL or fluid oz.  For example, an infant may require a formula that provides 24 calories per fluid ounce or an adult may require an enteral formula that provides 1.5 calorie/mL.
 *
 * http://hl7.org/fhir/caloricDensity
 */
export const caloricDensity = 'http://hl7.org/fhir/caloricDensity' satisfies OwlObjectProperty;

/**
 * MedicationKnowledgeStorageGuidelineEnvironmentalSettingComponent
 *
 * MedicationKnowledgeStorageGuidelineComponent.MedicationKnowledgeStorageGuidelineEnvironmentalSettingComponent: Describes a setting/value on the environment for the adequate storage of the medication and other substances.  Environment settings may involve temperature, humidity, or exposure to light.
 *
 * http://hl7.org/fhir/MedicationKnowledgeStorageGuidelineEnvironmentalSettingComponent
 */
export const MedicationKnowledgeStorageGuidelineEnvironmentalSettingComponent = 'http://hl7.org/fhir/MedicationKnowledgeStorageGuidelineEnvironmentalSettingComponent' satisfies OwlClass;

/**
 * _clinicalUseIssue
 *
 * (Modified) MedicationKnowledge.clinicalUseIssue
 *
 * http://hl7.org/fhir/_clinicalUseIssue
 */
export const _clinicalUseIssue = 'http://hl7.org/fhir/_clinicalUseIssue' satisfies OwlObjectProperty;

/**
 * LinkageItemComponent
 *
 * LinkageItemComponent: Identifies which record considered as the reference to the same real-world occurrence as well as how the items should be evaluated within the collection of linked items.
 *
 * http://hl7.org/fhir/LinkageItemComponent
 */
export const LinkageItemComponent = 'http://hl7.org/fhir/LinkageItemComponent' satisfies OwlClass;

/**
 * AdministrableProductDefinitionRouteOfAdministrationComponent
 *
 * AdministrableProductDefinitionRouteOfAdministrationComponent: The path by which the product is taken into or makes contact with the body. In some regions this is referred to as the licenced or approved route. RouteOfAdministration cannot be used when the 'formOf' product already uses MedicinalProductDefinition.route (and vice versa).
 *
 * http://hl7.org/fhir/AdministrableProductDefinitionRouteOfAdministrationComponent
 */
export const AdministrableProductDefinitionRouteOfAdministrationComponent = 'http://hl7.org/fhir/AdministrableProductDefinitionRouteOfAdministrationComponent' satisfies OwlClass;

/**
 * _conditionalUpdate
 *
 * (Modified) CapabilityStatement.rest.resource.conditionalUpdate
 *
 * http://hl7.org/fhir/_conditionalUpdate
 */
export const _conditionalUpdate = 'http://hl7.org/fhir/_conditionalUpdate' satisfies OwlObjectProperty;

/**
 * _publisher
 *
 * (Modified) ImplementationGuide.publisher
 *
 * http://hl7.org/fhir/_publisher
 */
export const _publisher = 'http://hl7.org/fhir/_publisher' satisfies OwlObjectProperty;

/**
 * MolecularSequenceRelativeStartingSequenceComponent
 *
 * MolecularSequenceRelativeComponent.MolecularSequenceRelativeStartingSequenceComponent: A sequence that is used as a starting sequence to describe variants that are present in a sequence analyzed.
 *
 * http://hl7.org/fhir/MolecularSequenceRelativeStartingSequenceComponent
 */
export const MolecularSequenceRelativeStartingSequenceComponent = 'http://hl7.org/fhir/MolecularSequenceRelativeStartingSequenceComponent' satisfies OwlClass;

/**
 * _validator
 *
 * (Modified) VerificationResult.validator
 *
 * http://hl7.org/fhir/_validator
 */
export const _validator = 'http://hl7.org/fhir/_validator' satisfies OwlObjectProperty;

/**
 * _inactive
 *
 * (Modified) ValueSet.expansion.contains.contains.inactive
 *
 * http://hl7.org/fhir/_inactive
 */
export const _inactive = 'http://hl7.org/fhir/_inactive' satisfies OwlObjectProperty;

/**
 * AppointmentResponse
 *
 * A reply to an appointment request for a patient and/or practitioner(s), such as a confirmation or rejection.
 *
 * http://hl7.org/fhir/AppointmentResponse
 */
export const AppointmentResponse = 'http://hl7.org/fhir/AppointmentResponse' satisfies OwlClass;

/**
 * _molecularFormula
 *
 * (Modified) SubstanceDefinition.structure.molecularFormula
 *
 * http://hl7.org/fhir/_molecularFormula
 */
export const _molecularFormula = 'http://hl7.org/fhir/_molecularFormula' satisfies OwlObjectProperty;

/**
 * payload
 *
 * Endpoint.payload: The set of payloads that are provided/available at this endpoint.
 *
 * http://hl7.org/fhir/payload
 */
export const payload = 'http://hl7.org/fhir/payload' satisfies OwlObjectProperty;

/**
 * subSite
 *
 * ExplanationOfBenefit.addItem.bodySite.subSite: A region or surface of the bodySite, e.g. limb region or tooth surface(s).
 *
 * http://hl7.org/fhir/subSite
 */
export const subSite = 'http://hl7.org/fhir/subSite' satisfies OwlObjectProperty;

/**
 * _sort
 *
 * (Modified) DataRequirement.sort
 *
 * http://hl7.org/fhir/_sort
 */
export const _sort = 'http://hl7.org/fhir/_sort' satisfies OwlObjectProperty;

/**
 * TestScriptOriginComponent
 *
 * TestScriptOriginComponent: An abstract server used in operations within this test script in the origin element.
 *
 * http://hl7.org/fhir/TestScriptOriginComponent
 */
export const TestScriptOriginComponent = 'http://hl7.org/fhir/TestScriptOriginComponent' satisfies OwlClass;

/**
 * _allergyIntolerance
 *
 * (Modified) NutritionOrder.allergyIntolerance
 *
 * http://hl7.org/fhir/_allergyIntolerance
 */
export const _allergyIntolerance = 'http://hl7.org/fhir/_allergyIntolerance' satisfies OwlObjectProperty;

/**
 * _identityCertificate
 *
 * (Modified) VerificationResult.validator.identityCertificate
 *
 * http://hl7.org/fhir/_identityCertificate
 */
export const _identityCertificate = 'http://hl7.org/fhir/_identityCertificate' satisfies OwlObjectProperty;

/**
 * _additional
 *
 * (Modified) ElementDefinition.binding.additional
 *
 * http://hl7.org/fhir/_additional
 */
export const _additional = 'http://hl7.org/fhir/_additional' satisfies OwlObjectProperty;

/**
 * _assurance
 *
 * (Modified) Person.link.assurance
 *
 * http://hl7.org/fhir/_assurance
 */
export const _assurance = 'http://hl7.org/fhir/_assurance' satisfies OwlObjectProperty;

/**
 * _careManager
 *
 * (Modified) EpisodeOfCare.careManager
 *
 * http://hl7.org/fhir/_careManager
 */
export const _careManager = 'http://hl7.org/fhir/_careManager' satisfies OwlObjectProperty;

/**
 * ImageRegion2D
 *
 * ImagingSelectionInstanceComponent.ImageRegion2D: Each imaging selection instance or frame list might includes an image region, specified by a region type and a set of 2D coordinates.
 *        If the parent imagingSelection.instance contains a subset element of type frame, the image region applies to all frames in the subset list.
 *
 * http://hl7.org/fhir/ImageRegion2D
 */
export const ImageRegion2D = 'http://hl7.org/fhir/ImageRegion2D' satisfies OwlClass;

/**
 * forecastReason
 *
 * ImmunizationRecommendation.recommendation.forecastReason: The reason for the assigned forecast status.
 *
 * http://hl7.org/fhir/forecastReason
 */
export const forecastReason = 'http://hl7.org/fhir/forecastReason' satisfies OwlObjectProperty;

/**
 * supplement
 *
 * NutritionOrder.supplement: Oral nutritional products given in order to add further nutritional value to the patient's diet.
 *
 * http://hl7.org/fhir/supplement
 */
export const supplement = 'http://hl7.org/fhir/supplement' satisfies OwlObjectProperty;

/**
 * _nutrient
 *
 * (Modified) NutritionProduct.nutrient
 *
 * http://hl7.org/fhir/_nutrient
 */
export const _nutrient = 'http://hl7.org/fhir/_nutrient' satisfies OwlObjectProperty;

/**
 * _sugar
 *
 * (Modified) SubstanceNucleicAcid.subunit.sugar
 *
 * http://hl7.org/fhir/_sugar
 */
export const _sugar = 'http://hl7.org/fhir/_sugar' satisfies OwlObjectProperty;

/**
 * entryReference
 *
 * EvidenceReport.section.section.entryReference: A reference to the actual resource from which the narrative in the section is derived.
 *
 * http://hl7.org/fhir/entryReference
 */
export const entryReference = 'http://hl7.org/fhir/entryReference' satisfies OwlObjectProperty;

/**
 * _citedMedium
 *
 * (Modified) Citation.citedArtifact.publicationForm.citedMedium
 *
 * http://hl7.org/fhir/_citedMedium
 */
export const _citedMedium = 'http://hl7.org/fhir/_citedMedium' satisfies OwlObjectProperty;

/**
 * MeasureSupplementalDataComponent
 *
 * MeasureSupplementalDataComponent: The supplemental data criteria for the measure report, specified as either the name of a valid CQL expression within a referenced library, or a valid FHIR Resource Path.
 *
 * http://hl7.org/fhir/MeasureSupplementalDataComponent
 */
export const MeasureSupplementalDataComponent = 'http://hl7.org/fhir/MeasureSupplementalDataComponent' satisfies OwlClass;

/**
 * input
 *
 * StructureMap.group.input: A name assigned to an instance of data. The instance must be provided when the mapping is invoked.
 *
 * http://hl7.org/fhir/input
 */
export const input = 'http://hl7.org/fhir/input' satisfies OwlObjectProperty;

/**
 * ManufacturedItemDefinition
 *
 * The definition and characteristics of a medicinal manufactured item, such as a tablet or capsule, as contained in a packaged medicinal product.
 *
 * http://hl7.org/fhir/ManufacturedItemDefinition
 */
export const ManufacturedItemDefinition = 'http://hl7.org/fhir/ManufacturedItemDefinition' satisfies OwlClass;

/**
 * Prism
 *
 * VisionPrescriptionLensSpecificationComponent.Prism: Allows for adjustment on two axis.
 *
 * http://hl7.org/fhir/Prism
 */
export const Prism = 'http://hl7.org/fhir/Prism' satisfies OwlClass;

/**
 * GroupCharacteristicComponent
 *
 * GroupCharacteristicComponent: Identifies traits whose presence r absence is shared by members of the group.
 *
 * http://hl7.org/fhir/GroupCharacteristicComponent
 */
export const GroupCharacteristicComponent = 'http://hl7.org/fhir/GroupCharacteristicComponent' satisfies OwlClass;

/**
 * _qualifier
 *
 * (Modified) BodyStructure.excludedStructure.qualifier
 *
 * http://hl7.org/fhir/_qualifier
 */
export const _qualifier = 'http://hl7.org/fhir/_qualifier' satisfies OwlObjectProperty;

/**
 * GraphDefinition
 *
 * A formal computable definition of a graph of resources - that is, a coherent set of resources that form a graph by following references. The Graph Definition resource defines a set and makes rules about the set.
 *
 * http://hl7.org/fhir/GraphDefinition
 */
export const GraphDefinition = 'http://hl7.org/fhir/GraphDefinition' satisfies OwlClass;

/**
 * _BiologicallyDerivedProduct
 *
 * (Modified) BiologicallyDerivedProduct
 *
 * http://hl7.org/fhir/_BiologicallyDerivedProduct
 */
export const _BiologicallyDerivedProduct = 'http://hl7.org/fhir/_BiologicallyDerivedProduct' satisfies OwlClass;

/**
 * _Procedure
 *
 * (Modified) Procedure
 *
 * http://hl7.org/fhir/_Procedure
 */
export const _Procedure = 'http://hl7.org/fhir/_Procedure' satisfies OwlClass;

/**
 * _receivedTime
 *
 * (Modified) Specimen.receivedTime
 *
 * http://hl7.org/fhir/_receivedTime
 */
export const _receivedTime = 'http://hl7.org/fhir/_receivedTime' satisfies OwlObjectProperty;

/**
 * quantity
 *
 * ArtifactAssessment.content.component.quantity: A quantitative rating of the artifact.
 *
 * http://hl7.org/fhir/quantity
 */
export const quantity = 'http://hl7.org/fhir/quantity' satisfies OwlObjectProperty;

/**
 * _linkId
 *
 * (Modified) Contract.term.offer.linkId
 *
 * http://hl7.org/fhir/_linkId
 */
export const _linkId = 'http://hl7.org/fhir/_linkId' satisfies OwlObjectProperty;

/**
 * ManufacturedItemDefinitionComponentComponentComponentComponent
 *
 * A component that this component contains or is made from.
 *
 * http://hl7.org/fhir/ManufacturedItemDefinitionComponentComponentComponentComponent
 */
export const ManufacturedItemDefinitionComponentComponentComponentComponent = 'http://hl7.org/fhir/ManufacturedItemDefinitionComponentComponentComponentComponent' satisfies OwlClass;

/**
 * _prescriber
 *
 * (Modified) VisionPrescription.prescriber
 *
 * http://hl7.org/fhir/_prescriber
 */
export const _prescriber = 'http://hl7.org/fhir/_prescriber' satisfies OwlObjectProperty;

/**
 * EvidenceReportSubjectCharacteristicComponent
 *
 * EvidenceReportSubjectComponent.EvidenceReportSubjectCharacteristicComponent: Characteristic.
 *
 * http://hl7.org/fhir/EvidenceReportSubjectCharacteristicComponent
 */
export const EvidenceReportSubjectCharacteristicComponent = 'http://hl7.org/fhir/EvidenceReportSubjectCharacteristicComponent' satisfies OwlClass;

/**
 * hasSeverity
 *
 * ConditionDefinition.hasSeverity: Whether Severity is appropriate to collect for this condition.
 *
 * http://hl7.org/fhir/hasSeverity
 */
export const hasSeverity = 'http://hl7.org/fhir/hasSeverity' satisfies OwlObjectProperty;

/**
 * _estimate
 *
 * (Modified) Account.balance.estimate
 *
 * http://hl7.org/fhir/_estimate
 */
export const _estimate = 'http://hl7.org/fhir/_estimate' satisfies OwlObjectProperty;

/**
 * certainty
 *
 * Evidence.certainty: Assessment of certainty, confidence in the estimates, or quality of the evidence.
 *
 * http://hl7.org/fhir/certainty
 */
export const certainty = 'http://hl7.org/fhir/certainty' satisfies OwlObjectProperty;

/**
 * _billingStatus
 *
 * (Modified) Account.billingStatus
 *
 * http://hl7.org/fhir/_billingStatus
 */
export const _billingStatus = 'http://hl7.org/fhir/_billingStatus' satisfies OwlObjectProperty;

/**
 * ContactDetail
 *
 * Specifies contact information for a person or organization.
 *
 * http://hl7.org/fhir/ContactDetail
 */
export const ContactDetail = 'http://hl7.org/fhir/ContactDetail' satisfies OwlClass;

/**
 * sessionKey
 *
 * VirtualServiceDetail.sessionKey: Session Key required by the virtual service.
 *
 * http://hl7.org/fhir/sessionKey
 */
export const sessionKey = 'http://hl7.org/fhir/sessionKey' satisfies OwlObjectProperty;

/**
 * calibration
 *
 * DeviceMetric.calibration: Describes the calibrations that have been performed or that are required to be performed.
 *
 * http://hl7.org/fhir/calibration
 */
export const calibration = 'http://hl7.org/fhir/calibration' satisfies OwlObjectProperty;

/**
 * _literal
 *
 * (Modified) MolecularSequence.literal
 *
 * http://hl7.org/fhir/_literal
 */
export const _literal = 'http://hl7.org/fhir/_literal' satisfies OwlObjectProperty;

/**
 * ConditionDefinitionQuestionnaireComponent
 *
 * ConditionDefinitionQuestionnaireComponent: Questionnaire for this condition.
 *
 * http://hl7.org/fhir/ConditionDefinitionQuestionnaireComponent
 */
export const ConditionDefinitionQuestionnaireComponent = 'http://hl7.org/fhir/ConditionDefinitionQuestionnaireComponent' satisfies OwlClass;

/**
 * _dateTime
 *
 * (Modified) NutritionOrder.dateTime
 *
 * http://hl7.org/fhir/_dateTime
 */
export const _dateTime = 'http://hl7.org/fhir/_dateTime' satisfies OwlObjectProperty;

/**
 * CoverageEligibilityRequest
 *
 * The CoverageEligibilityRequest provides patient and insurance coverage information to an insurer for them to respond, in the form of an CoverageEligibilityResponse, with information regarding whether the stated coverage is valid and in-force and optionally to provide the insurance details of the policy.
 *
 * http://hl7.org/fhir/CoverageEligibilityRequest
 */
export const CoverageEligibilityRequest = 'http://hl7.org/fhir/CoverageEligibilityRequest' satisfies OwlClass;

/**
 * _repeatUnitAmountType
 *
 * (Modified) SubstancePolymer.repeat.repeatUnitAmountType
 *
 * http://hl7.org/fhir/_repeatUnitAmountType
 */
export const _repeatUnitAmountType = 'http://hl7.org/fhir/_repeatUnitAmountType' satisfies OwlObjectProperty;

/**
 * pediatricUseIndicator
 *
 * MedicinalProductDefinition.pediatricUseIndicator: If authorised for use in children, or infants, neonates etc.
 *
 * http://hl7.org/fhir/pediatricUseIndicator
 */
export const pediatricUseIndicator = 'http://hl7.org/fhir/pediatricUseIndicator' satisfies OwlObjectProperty;

/**
 * SampledData
 *
 * A series of measurements taken by a device, with upper and lower limits. There may be more than one dimension in the data.
 *
 * http://hl7.org/fhir/SampledData
 */
export const SampledData = 'http://hl7.org/fhir/SampledData' satisfies OwlClass;

/**
 * attester
 *
 * DocumentReference.attester: A participant who has authenticated the accuracy of the document.
 *
 * http://hl7.org/fhir/attester
 */
export const attester = 'http://hl7.org/fhir/attester' satisfies OwlObjectProperty;

/**
 * originatingAppointment
 *
 * Appointment.originatingAppointment: The originating appointment in a recurring set of related appointments.
 *
 * http://hl7.org/fhir/originatingAppointment
 */
export const originatingAppointment = 'http://hl7.org/fhir/originatingAppointment' satisfies OwlObjectProperty;

/**
 * progress
 *
 * ResearchSubject.progress: The current state (status) of the subject and resons for status change where appropriate.
 *
 * http://hl7.org/fhir/progress
 */
export const progress = 'http://hl7.org/fhir/progress' satisfies OwlObjectProperty;

/**
 * _frequencyMax
 *
 * (Modified) Timing.repeat.frequencyMax
 *
 * http://hl7.org/fhir/_frequencyMax
 */
export const _frequencyMax = 'http://hl7.org/fhir/_frequencyMax' satisfies OwlObjectProperty;

/**
 * measureScore
 *
 * MeasureReport.group.stratifier.stratum.measureScore
 *
 * http://hl7.org/fhir/measureScore
 */
export const measureScore = 'http://hl7.org/fhir/measureScore' satisfies OwlObjectProperty;

/**
 * InsurancePlanCoverageComponent
 *
 * InsurancePlanCoverageComponent: Details about the coverage offered by the insurance product.
 *
 * http://hl7.org/fhir/InsurancePlanCoverageComponent
 */
export const InsurancePlanCoverageComponent = 'http://hl7.org/fhir/InsurancePlanCoverageComponent' satisfies OwlClass;

/**
 * Evidence
 *
 * The Evidence Resource provides a machine-interpretable expression of an evidence concept including the evidence variables (e.g., population, exposures/interventions, comparators, outcomes, measured variables, confounding variables), the statistics, and the certainty of this evidence.
 *
 * http://hl7.org/fhir/Evidence
 */
export const Evidence = 'http://hl7.org/fhir/Evidence' satisfies OwlClass;

/**
 * _operationalStatus
 *
 * (Modified) Location.operationalStatus
 *
 * http://hl7.org/fhir/_operationalStatus
 */
export const _operationalStatus = 'http://hl7.org/fhir/_operationalStatus' satisfies OwlObjectProperty;

/**
 * ImagingSelectionPerformerComponent
 *
 * ImagingSelectionPerformerComponent: Selector of the instances – human or machine.
 *
 * http://hl7.org/fhir/ImagingSelectionPerformerComponent
 */
export const ImagingSelectionPerformerComponent = 'http://hl7.org/fhir/ImagingSelectionPerformerComponent' satisfies OwlClass;

/**
 * restriction
 *
 * Transport.restriction: If the Transport.focus is a request resource and the transport is seeking fulfillment (i.e. is asking for the request to be actioned), this element identifies any limitations on what parts of the referenced request should be actioned.
 *
 * http://hl7.org/fhir/restriction
 */
export const restriction = 'http://hl7.org/fhir/restriction' satisfies OwlObjectProperty;

/**
 * _issues
 *
 * (Modified) Bundle.issues
 *
 * http://hl7.org/fhir/_issues
 */
export const _issues = 'http://hl7.org/fhir/_issues' satisfies OwlObjectProperty;

/**
 * dose
 *
 * MedicationAdministration.dosage.dose: The amount of the medication given at one administration event.   Use this value when the administration is essentially an instantaneous event such as a swallowing a tablet or giving an injection.
 *
 * http://hl7.org/fhir/dose
 */
export const dose = 'http://hl7.org/fhir/dose' satisfies OwlObjectProperty;

/**
 * _updateCreate
 *
 * (Modified) CapabilityStatement.rest.resource.updateCreate
 *
 * http://hl7.org/fhir/_updateCreate
 */
export const _updateCreate = 'http://hl7.org/fhir/_updateCreate' satisfies OwlObjectProperty;

/**
 * _supportingInfo
 *
 * (Modified) Procedure.supportingInfo
 *
 * http://hl7.org/fhir/_supportingInfo
 */
export const _supportingInfo = 'http://hl7.org/fhir/_supportingInfo' satisfies OwlObjectProperty;

/**
 * warningOnly
 *
 * TestScript.test.action.assert.warningOnly: Whether or not the test execution will produce a warning only on error for this assert.
 *
 * http://hl7.org/fhir/warningOnly
 */
export const warningOnly = 'http://hl7.org/fhir/warningOnly' satisfies OwlObjectProperty;

/**
 * _coverage
 *
 * (Modified) Account.coverage.coverage
 *
 * http://hl7.org/fhir/_coverage
 */
export const _coverage = 'http://hl7.org/fhir/_coverage' satisfies OwlObjectProperty;

/**
 * informationSequence
 *
 * ExplanationOfBenefit.item.informationSequence: Exceptions, special conditions and supporting information applicable for this service or product.
 *
 * http://hl7.org/fhir/informationSequence
 */
export const informationSequence = 'http://hl7.org/fhir/informationSequence' satisfies OwlObjectProperty;

/**
 * netContent
 *
 * InventoryItem.netContent: Net content or amount present in the item.
 *
 * http://hl7.org/fhir/netContent
 */
export const netContent = 'http://hl7.org/fhir/netContent' satisfies OwlObjectProperty;

/**
 * representation
 *
 * SubstanceDefinition.structure.representation: A depiction of the structure of the substance.
 *
 * http://hl7.org/fhir/representation
 */
export const representation = 'http://hl7.org/fhir/representation' satisfies OwlObjectProperty;

/**
 * _typeMode
 *
 * (Modified) StructureMap.group.typeMode
 *
 * http://hl7.org/fhir/_typeMode
 */
export const _typeMode = 'http://hl7.org/fhir/_typeMode' satisfies OwlObjectProperty;

/**
 * subProperty
 *
 * ValueSet.expansion.contains.contains.property.subProperty: A subproperty value for this concept.
 *
 * http://hl7.org/fhir/subProperty
 */
export const subProperty = 'http://hl7.org/fhir/subProperty' satisfies OwlObjectProperty;

/**
 * _subscription
 *
 * (Modified) SubscriptionStatus.subscription
 *
 * http://hl7.org/fhir/_subscription
 */
export const _subscription = 'http://hl7.org/fhir/_subscription' satisfies OwlObjectProperty;

/**
 * Library
 *
 * The Library resource is a general-purpose container for knowledge asset definitions. It can be used to describe and expose existing knowledge assets such as logic libraries and information model descriptions, as well as to describe a collection of knowledge assets.
 *
 * http://hl7.org/fhir/Library
 */
export const Library = 'http://hl7.org/fhir/Library' satisfies OwlClass;

/**
 * DeviceMetricCalibrationComponent
 *
 * DeviceMetricCalibrationComponent: Describes the calibrations that have been performed or that are required to be performed.
 *
 * http://hl7.org/fhir/DeviceMetricCalibrationComponent
 */
export const DeviceMetricCalibrationComponent = 'http://hl7.org/fhir/DeviceMetricCalibrationComponent' satisfies OwlClass;

/**
 * implicated
 *
 * DetectedIssue.implicated: Indicates the resource representing the current activity or proposed activity that is potentially problematic.
 *
 * http://hl7.org/fhir/implicated
 */
export const implicated = 'http://hl7.org/fhir/implicated' satisfies OwlObjectProperty;

/**
 * _actualGroup
 *
 * (Modified) ResearchStudy.recruitment.actualGroup
 *
 * http://hl7.org/fhir/_actualGroup
 */
export const _actualGroup = 'http://hl7.org/fhir/_actualGroup' satisfies OwlObjectProperty;

/**
 * _SubstanceProtein
 *
 * (Modified) SubstanceProtein
 *
 * http://hl7.org/fhir/_SubstanceProtein
 */
export const _SubstanceProtein = 'http://hl7.org/fhir/_SubstanceProtein' satisfies OwlClass;

/**
 * _capabilities
 *
 * (Modified) TestScript.metadata.capability.capabilities
 *
 * http://hl7.org/fhir/_capabilities
 */
export const _capabilities = 'http://hl7.org/fhir/_capabilities' satisfies OwlObjectProperty;

/**
 * _associatedParty
 *
 * (Modified) ResearchStudy.associatedParty
 *
 * http://hl7.org/fhir/_associatedParty
 */
export const _associatedParty = 'http://hl7.org/fhir/_associatedParty' satisfies OwlObjectProperty;

/**
 * _supplementalData
 *
 * (Modified) MeasureReport.supplementalData
 *
 * http://hl7.org/fhir/_supplementalData
 */
export const _supplementalData = 'http://hl7.org/fhir/_supplementalData' satisfies OwlObjectProperty;

/**
 * _program
 *
 * (Modified) Immunization.programEligibility.program
 *
 * http://hl7.org/fhir/_program
 */
export const _program = 'http://hl7.org/fhir/_program' satisfies OwlObjectProperty;

/**
 * offeredIn
 *
 * HealthcareService.offeredIn: When the HealthcareService is representing a specific, schedulable service, the availableIn property can refer to a generic service.
 *
 * http://hl7.org/fhir/offeredIn
 */
export const offeredIn = 'http://hl7.org/fhir/offeredIn' satisfies OwlObjectProperty;

/**
 * TerminologyCapabilitiesCodeSystemComponent
 *
 * TerminologyCapabilitiesCodeSystemComponent: Identifies a code system that is supported by the server. If there is a no code system URL, then this declares the general assumptions a client can make about support for any CodeSystem resource.
 *
 * http://hl7.org/fhir/TerminologyCapabilitiesCodeSystemComponent
 */
export const TerminologyCapabilitiesCodeSystemComponent = 'http://hl7.org/fhir/TerminologyCapabilitiesCodeSystemComponent' satisfies OwlClass;

/**
 * multipleBirth
 *
 * Patient.multipleBirth
 *
 * http://hl7.org/fhir/multipleBirth
 */
export const multipleBirth = 'http://hl7.org/fhir/multipleBirth' satisfies OwlObjectProperty;

/**
 * _replacedSequence
 *
 * (Modified) MolecularSequence.relative.edit.replacedSequence
 *
 * http://hl7.org/fhir/_replacedSequence
 */
export const _replacedSequence = 'http://hl7.org/fhir/_replacedSequence' satisfies OwlObjectProperty;

/**
 * disclaimer
 *
 * Measure.disclaimer: Notices and disclaimers regarding the use of the measure or related to intellectual property (such as code systems) referenced by the measure.
 *
 * http://hl7.org/fhir/disclaimer
 */
export const disclaimer = 'http://hl7.org/fhir/disclaimer' satisfies OwlObjectProperty;

/**
 * InsurancePlan
 *
 * Details of a Health Insurance product/plan provided by an organization.
 *
 * http://hl7.org/fhir/InsurancePlan
 */
export const InsurancePlan = 'http://hl7.org/fhir/InsurancePlan' satisfies OwlClass;

/**
 * _installDate
 *
 * (Modified) Device.version.installDate
 *
 * http://hl7.org/fhir/_installDate
 */
export const _installDate = 'http://hl7.org/fhir/_installDate' satisfies OwlObjectProperty;

/**
 * _extends
 *
 * (Modified) StructureMap.group.extends
 *
 * http://hl7.org/fhir/_extends
 */
export const _extends = 'http://hl7.org/fhir/_extends' satisfies OwlObjectProperty;

/**
 * fundsReserve
 *
 * ExplanationOfBenefit.fundsReserve: A code, used only on a response to a preauthorization, to indicate whether the benefits payable have been reserved and for whom.
 *
 * http://hl7.org/fhir/fundsReserve
 */
export const fundsReserve = 'http://hl7.org/fhir/fundsReserve' satisfies OwlObjectProperty;

/**
 * assigner
 *
 * Identifier.assigner: Organization that issued/manages the identifier.
 *
 * http://hl7.org/fhir/assigner
 */
export const assigner = 'http://hl7.org/fhir/assigner' satisfies OwlObjectProperty;

/**
 * SpecimenProcessingComponent
 *
 * SpecimenProcessingComponent: Details concerning processing and processing steps for the specimen.
 *
 * http://hl7.org/fhir/SpecimenProcessingComponent
 */
export const SpecimenProcessingComponent = 'http://hl7.org/fhir/SpecimenProcessingComponent' satisfies OwlClass;

/**
 * occurred
 *
 * Provenance.occurred
 *
 * http://hl7.org/fhir/occurred
 */
export const occurred = 'http://hl7.org/fhir/occurred' satisfies OwlObjectProperty;

/**
 * _lockedDate
 *
 * (Modified) ValueSet.compose.lockedDate
 *
 * http://hl7.org/fhir/_lockedDate
 */
export const _lockedDate = 'http://hl7.org/fhir/_lockedDate' satisfies OwlObjectProperty;

/**
 * GenomicStudyAnalysisPerformerComponent
 *
 * GenomicStudyAnalysisComponent.GenomicStudyAnalysisPerformerComponent: Performer for the analysis event.
 *
 * http://hl7.org/fhir/GenomicStudyAnalysisPerformerComponent
 */
export const GenomicStudyAnalysisPerformerComponent = 'http://hl7.org/fhir/GenomicStudyAnalysisPerformerComponent' satisfies OwlClass;

/**
 * _lowNumerator
 *
 * (Modified) RatioRange.lowNumerator
 *
 * http://hl7.org/fhir/_lowNumerator
 */
export const _lowNumerator = 'http://hl7.org/fhir/_lowNumerator' satisfies OwlObjectProperty;

/**
 * _classifier
 *
 * (Modified) ResearchStudy.classifier
 *
 * http://hl7.org/fhir/_classifier
 */
export const _classifier = 'http://hl7.org/fhir/_classifier' satisfies OwlObjectProperty;

/**
 * resultsInterpreter
 *
 * DiagnosticReport.resultsInterpreter: The practitioner or organization that is responsible for the report's conclusions and interpretations.
 *
 * http://hl7.org/fhir/resultsInterpreter
 */
export const resultsInterpreter = 'http://hl7.org/fhir/resultsInterpreter' satisfies OwlObjectProperty;

/**
 * _limit
 *
 * (Modified) Permission.rule.limit
 *
 * http://hl7.org/fhir/_limit
 */
export const _limit = 'http://hl7.org/fhir/_limit' satisfies OwlObjectProperty;

/**
 * _serviceProvider
 *
 * (Modified) Encounter.serviceProvider
 *
 * http://hl7.org/fhir/_serviceProvider
 */
export const _serviceProvider = 'http://hl7.org/fhir/_serviceProvider' satisfies OwlObjectProperty;

/**
 * patientInstruction
 *
 * ServiceRequest.patientInstruction: Instructions in terms that are understood by the patient or consumer.
 *
 * http://hl7.org/fhir/patientInstruction
 */
export const patientInstruction = 'http://hl7.org/fhir/patientInstruction' satisfies OwlObjectProperty;

/**
 * binding
 *
 * OperationDefinition.parameter.part.binding: Binds to a value set if this parameter is coded (code, Coding, CodeableConcept).
 *
 * http://hl7.org/fhir/binding
 */
export const binding = 'http://hl7.org/fhir/binding' satisfies OwlObjectProperty;

/**
 * recurrenceType
 *
 * Appointment.recurrenceTemplate.recurrenceType: How often the appointment series should recur.
 *
 * http://hl7.org/fhir/recurrenceType
 */
export const recurrenceType = 'http://hl7.org/fhir/recurrenceType' satisfies OwlObjectProperty;

/**
 * during
 *
 * Availability.notAvailableTime.during: Service not available during this period.
 *
 * http://hl7.org/fhir/during
 */
export const during = 'http://hl7.org/fhir/during' satisfies OwlObjectProperty;

/**
 * capability
 *
 * TestScript.metadata.capability: Capabilities that must exist and are assumed to function correctly on the FHIR server being tested.
 *
 * http://hl7.org/fhir/capability
 */
export const capability = 'http://hl7.org/fhir/capability' satisfies OwlObjectProperty;

/**
 * Substance
 *
 * A homogeneous material with a definite composition.
 *
 * http://hl7.org/fhir/Substance
 */
export const Substance = 'http://hl7.org/fhir/Substance' satisfies OwlClass;

/**
 * suspectEntity
 *
 * AdverseEvent.suspectEntity: Describes the entity that is suspected to have caused the adverse event.
 *
 * http://hl7.org/fhir/suspectEntity
 */
export const suspectEntity = 'http://hl7.org/fhir/suspectEntity' satisfies OwlObjectProperty;

/**
 * QuestionnaireItemInitialComponent
 *
 * QuestionnaireItemComponentItem.QuestionnaireItemInitialComponent: One or more values that should be pre-populated in the answer when initially rendering the questionnaire for user input.
 *
 * http://hl7.org/fhir/QuestionnaireItemInitialComponent
 */
export const QuestionnaireItemInitialComponent = 'http://hl7.org/fhir/QuestionnaireItemInitialComponent' satisfies OwlClass;

/**
 * occurrenceDate
 *
 * AppointmentResponse.occurrenceDate: The original date within a recurring request. This could be used in place of the recurrenceId to be more direct (or where the template is provided through the simple list of dates in `Appointment.occurrenceDate`).
 *
 * http://hl7.org/fhir/occurrenceDate
 */
export const occurrenceDate = 'http://hl7.org/fhir/occurrenceDate' satisfies OwlObjectProperty;

/**
 * monthlyTemplate
 *
 * Appointment.recurrenceTemplate.monthlyTemplate: Information about monthly recurring appointments.
 *
 * http://hl7.org/fhir/monthlyTemplate
 */
export const monthlyTemplate = 'http://hl7.org/fhir/monthlyTemplate' satisfies OwlObjectProperty;

/**
 * supportingInformation
 *
 * DeviceDispense.supportingInformation: Additional information that supports the device being dispensed.
 *
 * http://hl7.org/fhir/supportingInformation
 */
export const supportingInformation = 'http://hl7.org/fhir/supportingInformation' satisfies OwlObjectProperty;

/**
 * authorizationRequired
 *
 * CoverageEligibilityResponse.insurance.item.authorizationRequired: A boolean flag indicating whether a preauthorization is required prior to actual service delivery.
 *
 * http://hl7.org/fhir/authorizationRequired
 */
export const authorizationRequired = 'http://hl7.org/fhir/authorizationRequired' satisfies OwlObjectProperty;

/**
 * _versionReference
 *
 * (Modified) ExampleScenario.process.step.process.step.operation.request.versionReference
 *
 * http://hl7.org/fhir/_versionReference
 */
export const _versionReference = 'http://hl7.org/fhir/_versionReference' satisfies OwlObjectProperty;

/**
 * ImmunizationRecommendationRecommendationComponent
 *
 * ImmunizationRecommendationRecommendationComponent: Vaccine administration recommendations.
 *
 * http://hl7.org/fhir/ImmunizationRecommendationRecommendationComponent
 */
export const ImmunizationRecommendationRecommendationComponent = 'http://hl7.org/fhir/ImmunizationRecommendationRecommendationComponent' satisfies OwlClass;

/**
 * _measurementPoint
 *
 * (Modified) Ingredient.substance.strength.referenceStrength.measurementPoint
 *
 * http://hl7.org/fhir/_measurementPoint
 */
export const _measurementPoint = 'http://hl7.org/fhir/_measurementPoint' satisfies OwlObjectProperty;

/**
 * batch
 *
 * Medication.batch: Information that only applies to packages (not products).
 *
 * http://hl7.org/fhir/batch
 */
export const batch = 'http://hl7.org/fhir/batch' satisfies OwlObjectProperty;

/**
 * _include
 *
 * (Modified) ValueSet.compose.include
 *
 * http://hl7.org/fhir/_include
 */
export const _include = 'http://hl7.org/fhir/_include' satisfies OwlObjectProperty;

/**
 * ValueSetComposeIncludeFilterComponent
 *
 * ValueSetComposeComponentInclude.ValueSetComposeIncludeFilterComponent: Select concepts by specifying a matching criterion based on the properties (including relationships) defined by the system, or on filters defined by the system. If multiple filters are specified within the include, they SHALL all be true.
 *
 * http://hl7.org/fhir/ValueSetComposeIncludeFilterComponent
 */
export const ValueSetComposeIncludeFilterComponent = 'http://hl7.org/fhir/ValueSetComposeIncludeFilterComponent' satisfies OwlClass;

/**
 * subcomponent
 *
 * Evidence.certainty.subcomponent: A domain or subdomain of certainty.
 *
 * http://hl7.org/fhir/subcomponent
 */
export const subcomponent = 'http://hl7.org/fhir/subcomponent' satisfies OwlObjectProperty;

/**
 * _DetectedIssue
 *
 * (Modified) DetectedIssue
 *
 * http://hl7.org/fhir/_DetectedIssue
 */
export const _DetectedIssue = 'http://hl7.org/fhir/_DetectedIssue' satisfies OwlClass;

/**
 * _GuidanceResponse
 *
 * (Modified) GuidanceResponse
 *
 * http://hl7.org/fhir/_GuidanceResponse
 */
export const _GuidanceResponse = 'http://hl7.org/fhir/_GuidanceResponse' satisfies OwlClass;

/**
 * _participantType
 *
 * (Modified) AppointmentResponse.participantType
 *
 * http://hl7.org/fhir/_participantType
 */
export const _participantType = 'http://hl7.org/fhir/_participantType' satisfies OwlObjectProperty;

/**
 * _division
 *
 * (Modified) BiologicallyDerivedProduct.division
 *
 * http://hl7.org/fhir/_division
 */
export const _division = 'http://hl7.org/fhir/_division' satisfies OwlObjectProperty;

/**
 * _section
 *
 * (Modified) EvidenceReport.section.section
 *
 * http://hl7.org/fhir/_section
 */
export const _section = 'http://hl7.org/fhir/_section' satisfies OwlObjectProperty;

/**
 * _MedicationAdministration
 *
 * (Modified) MedicationAdministration
 *
 * http://hl7.org/fhir/_MedicationAdministration
 */
export const _MedicationAdministration = 'http://hl7.org/fhir/_MedicationAdministration' satisfies OwlClass;

/**
 * _outcomeMeasure
 *
 * (Modified) ResearchStudy.outcomeMeasure
 *
 * http://hl7.org/fhir/_outcomeMeasure
 */
export const _outcomeMeasure = 'http://hl7.org/fhir/_outcomeMeasure' satisfies OwlObjectProperty;

/**
 * PackagingDistributor
 *
 * DeviceDefinitionPackagingComponentPackaging.PackagingDistributor: An organization that distributes the packaged device.
 *
 * http://hl7.org/fhir/PackagingDistributor
 */
export const PackagingDistributor = 'http://hl7.org/fhir/PackagingDistributor' satisfies OwlClass;

/**
 * _serviceType
 *
 * (Modified) Slot.serviceType
 *
 * http://hl7.org/fhir/_serviceType
 */
export const _serviceType = 'http://hl7.org/fhir/_serviceType' satisfies OwlObjectProperty;

/**
 * _subjectReport
 *
 * (Modified) MeasureReport.group.stratifier.stratum.population.subjectReport
 *
 * http://hl7.org/fhir/_subjectReport
 */
export const _subjectReport = 'http://hl7.org/fhir/_subjectReport' satisfies OwlObjectProperty;

/**
 * _initialFill
 *
 * (Modified) MedicationRequest.dispenseRequest.initialFill
 *
 * http://hl7.org/fhir/_initialFill
 */
export const _initialFill = 'http://hl7.org/fhir/_initialFill' satisfies OwlObjectProperty;

/**
 * _administrableDoseForm
 *
 * (Modified) AdministrableProductDefinition.administrableDoseForm
 *
 * http://hl7.org/fhir/_administrableDoseForm
 */
export const _administrableDoseForm = 'http://hl7.org/fhir/_administrableDoseForm' satisfies OwlObjectProperty;

/**
 * areaOfHybridisation
 *
 * SubstanceNucleicAcid.areaOfHybridisation: The area of hybridisation shall be described if applicable for double stranded RNA or DNA. The number associated with the subunit followed by the number associated to the residue shall be specified in increasing order. The underscore “” shall be used as separator as follows: “Subunitnumber Residue”.
 *
 * http://hl7.org/fhir/areaOfHybridisation
 */
export const areaOfHybridisation = 'http://hl7.org/fhir/areaOfHybridisation' satisfies OwlObjectProperty;

/**
 * subjectType
 *
 * Questionnaire.subjectType: The types of subjects that can be the subject of responses created for the questionnaire.
 *
 * http://hl7.org/fhir/subjectType
 */
export const subjectType = 'http://hl7.org/fhir/subjectType' satisfies OwlObjectProperty;

/**
 * device
 *
 * Specimen.container.device: The device resource for the the container holding the specimen. If the container is in a holder then the referenced device will point to a parent device.
 *
 * http://hl7.org/fhir/device
 */
export const device = 'http://hl7.org/fhir/device' satisfies OwlObjectProperty;

/**
 * AddedItem
 *
 * ExplanationOfBenefit.AddedItem: The first-tier service adjudications for payor added product or service lines.
 *
 * http://hl7.org/fhir/AddedItem
 */
export const AddedItem = 'http://hl7.org/fhir/AddedItem' satisfies OwlClass;

/**
 * _region
 *
 * (Modified) ResearchStudy.region
 *
 * http://hl7.org/fhir/_region
 */
export const _region = 'http://hl7.org/fhir/_region' satisfies OwlObjectProperty;

/**
 * MedicationKnowledgeRegulatorySubstitutionComponent
 *
 * MedicationKnowledgeRegulatoryComponent.MedicationKnowledgeRegulatorySubstitutionComponent: Specifies if changes are allowed when dispensing a medication from a regulatory perspective.
 *
 * http://hl7.org/fhir/MedicationKnowledgeRegulatorySubstitutionComponent
 */
export const MedicationKnowledgeRegulatorySubstitutionComponent = 'http://hl7.org/fhir/MedicationKnowledgeRegulatorySubstitutionComponent' satisfies OwlClass;

/**
 * MeasureReportGroupComponent
 *
 * MeasureReportGroupComponent: The results of the calculation, one for each population group in the measure.
 *
 * http://hl7.org/fhir/MeasureReportGroupComponent
 */
export const MeasureReportGroupComponent = 'http://hl7.org/fhir/MeasureReportGroupComponent' satisfies OwlClass;

/**
 * _accident
 *
 * (Modified) ExplanationOfBenefit.accident
 *
 * http://hl7.org/fhir/_accident
 */
export const _accident = 'http://hl7.org/fhir/_accident' satisfies OwlObjectProperty;

/**
 * endRelationship
 *
 * RequestOrchestration.action.relatedAction.endRelationship: The relationship of the end of this action to the related action.
 *
 * http://hl7.org/fhir/endRelationship
 */
export const endRelationship = 'http://hl7.org/fhir/endRelationship' satisfies OwlObjectProperty;

/**
 * structure
 *
 * SubstanceDefinition.structure: Structural information.
 *
 * http://hl7.org/fhir/structure
 */
export const structure = 'http://hl7.org/fhir/structure' satisfies OwlObjectProperty;

/**
 * _library
 *
 * (Modified) PlanDefinition.library
 *
 * http://hl7.org/fhir/_library
 */
export const _library = 'http://hl7.org/fhir/_library' satisfies OwlObjectProperty;

/**
 * _descriptionSummary
 *
 * (Modified) ResearchStudy.descriptionSummary
 *
 * http://hl7.org/fhir/_descriptionSummary
 */
export const _descriptionSummary = 'http://hl7.org/fhir/_descriptionSummary' satisfies OwlObjectProperty;

/**
 * baseCitation
 *
 * Citation.citedArtifact.part.baseCitation: The citation for the full article or artifact.
 *
 * http://hl7.org/fhir/baseCitation
 */
export const baseCitation = 'http://hl7.org/fhir/baseCitation' satisfies OwlObjectProperty;

/**
 * definitionId
 *
 * EvidenceVariable.characteristic.definitionByCombination.characteristic.definitionId: Defines the characteristic using id.
 *
 * http://hl7.org/fhir/definitionId
 */
export const definitionId = 'http://hl7.org/fhir/definitionId' satisfies OwlObjectProperty;

/**
 * _coordinateSystem
 *
 * (Modified) MolecularSequence.relative.coordinateSystem
 *
 * http://hl7.org/fhir/_coordinateSystem
 */
export const _coordinateSystem = 'http://hl7.org/fhir/_coordinateSystem' satisfies OwlObjectProperty;

/**
 * characteristicType
 *
 * InventoryItem.characteristic.characteristicType: The type of characteristic that is being defined.
 *
 * http://hl7.org/fhir/characteristicType
 */
export const characteristicType = 'http://hl7.org/fhir/characteristicType' satisfies OwlObjectProperty;

/**
 * _entry
 *
 * (Modified) List.entry
 *
 * http://hl7.org/fhir/_entry
 */
export const _entry = 'http://hl7.org/fhir/_entry' satisfies OwlObjectProperty;

/**
 * imageRegion2D
 *
 * ImagingSelection.instance.imageRegion2D: Each imaging selection instance or frame list might includes an image region, specified by a region type and a set of 2D coordinates.
 *        If the parent imagingSelection.instance contains a subset element of type frame, the image region applies to all frames in the subset list.
 *
 * http://hl7.org/fhir/imageRegion2D
 */
export const imageRegion2D = 'http://hl7.org/fhir/imageRegion2D' satisfies OwlObjectProperty;

/**
 * _DeviceDefinition
 *
 * (Modified) DeviceDefinition
 *
 * http://hl7.org/fhir/_DeviceDefinition
 */
export const _DeviceDefinition = 'http://hl7.org/fhir/_DeviceDefinition' satisfies OwlClass;

/**
 * conclusionCode
 *
 * DiagnosticReport.conclusionCode: One or more codes that represent the summary conclusion (interpretation/impression) of the diagnostic report.
 *
 * http://hl7.org/fhir/conclusionCode
 */
export const conclusionCode = 'http://hl7.org/fhir/conclusionCode' satisfies OwlObjectProperty;

/**
 * BiologicallyDerivedProductDispensePerformerComponent
 *
 * BiologicallyDerivedProductDispensePerformerComponent: Indicates who or what performed an action.
 *
 * http://hl7.org/fhir/BiologicallyDerivedProductDispensePerformerComponent
 */
export const BiologicallyDerivedProductDispensePerformerComponent = 'http://hl7.org/fhir/BiologicallyDerivedProductDispensePerformerComponent' satisfies OwlClass;

/**
 * _caloricDensity
 *
 * (Modified) NutritionOrder.enteralFormula.caloricDensity
 *
 * http://hl7.org/fhir/_caloricDensity
 */
export const _caloricDensity = 'http://hl7.org/fhir/_caloricDensity' satisfies OwlObjectProperty;

/**
 * ManufacturedItemDefinitionComponentComponent
 *
 * ManufacturedItemDefinitionComponentComponent: Physical parts of the manufactured item, that it is intrisically made from. This is distinct from the ingredients that are part of its chemical makeup.
 *
 * http://hl7.org/fhir/ManufacturedItemDefinitionComponentComponent
 */
export const ManufacturedItemDefinitionComponentComponent = 'http://hl7.org/fhir/ManufacturedItemDefinitionComponentComponent' satisfies OwlClass;

/**
 * _focal
 *
 * (Modified) ExplanationOfBenefit.insurance.focal
 *
 * http://hl7.org/fhir/_focal
 */
export const _focal = 'http://hl7.org/fhir/_focal' satisfies OwlObjectProperty;

/**
 * indication
 *
 * MedicinalProductDefinition.indication: Description of indication(s) for this product, used when structured indications are not required. In cases where structured indications are required, they are captured using the ClinicalUseDefinition resource. An indication is a medical situation for which using the product is appropriate.
 *
 * http://hl7.org/fhir/indication
 */
export const indication = 'http://hl7.org/fhir/indication' satisfies OwlObjectProperty;

/**
 * _AllergyIntolerance
 *
 * (Modified) AllergyIntolerance
 *
 * http://hl7.org/fhir/_AllergyIntolerance
 */
export const _AllergyIntolerance = 'http://hl7.org/fhir/_AllergyIntolerance' satisfies OwlClass;

/**
 * _publishedIn
 *
 * (Modified) Citation.citedArtifact.publicationForm.publishedIn
 *
 * http://hl7.org/fhir/_publishedIn
 */
export const _publishedIn = 'http://hl7.org/fhir/_publishedIn' satisfies OwlObjectProperty;

/**
 * partOf
 *
 * BiologicallyDerivedProductDispense.partOf: A larger event of which this particular event is a component.
 *
 * http://hl7.org/fhir/partOf
 */
export const partOf = 'http://hl7.org/fhir/partOf' satisfies OwlObjectProperty;

/**
 * _initialSelected
 *
 * (Modified) Questionnaire.item.item.answerOption.initialSelected
 *
 * http://hl7.org/fhir/_initialSelected
 */
export const _initialSelected = 'http://hl7.org/fhir/_initialSelected' satisfies OwlObjectProperty;

/**
 * _key
 *
 * (Modified) Requirements.statement.key
 *
 * http://hl7.org/fhir/_key
 */
export const _key = 'http://hl7.org/fhir/_key' satisfies OwlObjectProperty;

/**
 * backCurve
 *
 * VisionPrescription.lensSpecification.backCurve: Back curvature measured in millimetres.
 *
 * http://hl7.org/fhir/backCurve
 */
export const backCurve = 'http://hl7.org/fhir/backCurve' satisfies OwlObjectProperty;

/**
 * _path
 *
 * (Modified) RequestOrchestration.action.dynamicValue.path
 *
 * http://hl7.org/fhir/_path
 */
export const _path = 'http://hl7.org/fhir/_path' satisfies OwlObjectProperty;

/**
 * definitionUri
 *
 * ChargeItem.definitionUri: References the (external) source of pricing information, rules of application for the code this ChargeItem uses.
 *
 * http://hl7.org/fhir/definitionUri
 */
export const definitionUri = 'http://hl7.org/fhir/definitionUri' satisfies OwlObjectProperty;

/**
 * ExplanationOfBenefitItemReviewOutcomeComponent
 *
 * ExplanationOfBenefit.Item.ExplanationOfBenefitItemReviewOutcomeComponent: The high-level results of the adjudication if adjudication has been performed.
 *
 * http://hl7.org/fhir/ExplanationOfBenefitItemReviewOutcomeComponent
 */
export const ExplanationOfBenefitItemReviewOutcomeComponent = 'http://hl7.org/fhir/ExplanationOfBenefitItemReviewOutcomeComponent' satisfies OwlClass;

/**
 * DetectedIssueMitigationComponent
 *
 * DetectedIssueMitigationComponent: Indicates an action that has been taken or is committed to reduce or eliminate the likelihood of the risk identified by the detected issue from manifesting.  Can also reflect an observation of known mitigating factors that may reduce/eliminate the need for any action.
 *
 * http://hl7.org/fhir/DetectedIssueMitigationComponent
 */
export const DetectedIssueMitigationComponent = 'http://hl7.org/fhir/DetectedIssueMitigationComponent' satisfies OwlClass;

/**
 * _lastOccurrenceDate
 *
 * (Modified) Appointment.recurrenceTemplate.lastOccurrenceDate
 *
 * http://hl7.org/fhir/_lastOccurrenceDate
 */
export const _lastOccurrenceDate = 'http://hl7.org/fhir/_lastOccurrenceDate' satisfies OwlObjectProperty;

/**
 * _enableWhen
 *
 * (Modified) Questionnaire.item.item.enableWhen
 *
 * http://hl7.org/fhir/_enableWhen
 */
export const _enableWhen = 'http://hl7.org/fhir/_enableWhen' satisfies OwlObjectProperty;

/**
 * time
 *
 * DocumentReference.attester.time: When the document was attested by the party.
 *
 * http://hl7.org/fhir/time
 */
export const time = 'http://hl7.org/fhir/time' satisfies OwlObjectProperty;

/**
 * MedicinalProductDefinitionNameUsageComponent
 *
 * MedicinalProductDefinitionNameComponent.MedicinalProductDefinitionNameUsageComponent: Country and jurisdiction where the name applies, and associated language.
 *
 * http://hl7.org/fhir/MedicinalProductDefinitionNameUsageComponent
 */
export const MedicinalProductDefinitionNameUsageComponent = 'http://hl7.org/fhir/MedicinalProductDefinitionNameUsageComponent' satisfies OwlClass;

/**
 * ChargeItemDefinitionApplicabilityComponent
 *
 * ChargeItemDefinitionApplicabilityComponent: Expressions that describe applicability criteria for the billing code.
 *
 * http://hl7.org/fhir/ChargeItemDefinitionApplicabilityComponent
 */
export const ChargeItemDefinitionApplicabilityComponent = 'http://hl7.org/fhir/ChargeItemDefinitionApplicabilityComponent' satisfies OwlClass;

/**
 * InventoryItemCharacteristicComponent
 *
 * InventoryItemCharacteristicComponent: The descriptive or identifying characteristics of the item.
 *
 * http://hl7.org/fhir/InventoryItemCharacteristicComponent
 */
export const InventoryItemCharacteristicComponent = 'http://hl7.org/fhir/InventoryItemCharacteristicComponent' satisfies OwlClass;

/**
 * _dischargeDisposition
 *
 * (Modified) Encounter.admission.dischargeDisposition
 *
 * http://hl7.org/fhir/_dischargeDisposition
 */
export const _dischargeDisposition = 'http://hl7.org/fhir/_dischargeDisposition' satisfies OwlObjectProperty;

/**
 * isModifierReason
 *
 * ElementDefinition.isModifierReason: Explains how that element affects the interpretation of the resource or element that contains it.
 *
 * http://hl7.org/fhir/isModifierReason
 */
export const isModifierReason = 'http://hl7.org/fhir/isModifierReason' satisfies OwlObjectProperty;

/**
 * StructureDefinitionContextComponent
 *
 * StructureDefinitionContextComponent: Identifies the types of resource or data type elements to which the extension can be applied. For more guidance on using the 'context' element, see the [defining extensions page](defining-extensions.html#context).
 *
 * http://hl7.org/fhir/StructureDefinitionContextComponent
 */
export const StructureDefinitionContextComponent = 'http://hl7.org/fhir/StructureDefinitionContextComponent' satisfies OwlClass;

/**
 * _forecastReason
 *
 * (Modified) ImmunizationRecommendation.recommendation.forecastReason
 *
 * http://hl7.org/fhir/_forecastReason
 */
export const _forecastReason = 'http://hl7.org/fhir/_forecastReason' satisfies OwlObjectProperty;

/**
 * SubstanceDefinitionMoietyComponent
 *
 * SubstanceDefinitionMoietyComponent: Moiety, for structural modifications.
 *
 * http://hl7.org/fhir/SubstanceDefinitionMoietyComponent
 */
export const SubstanceDefinitionMoietyComponent = 'http://hl7.org/fhir/SubstanceDefinitionMoietyComponent' satisfies OwlClass;

/**
 * _step
 *
 * (Modified) ExampleScenario.process.step.alternative.step
 *
 * http://hl7.org/fhir/_step
 */
export const _step = 'http://hl7.org/fhir/_step' satisfies OwlObjectProperty;

/**
 * rest
 *
 * CapabilityStatement.rest: A definition of the restful capabilities of the solution, if any.
 *
 * http://hl7.org/fhir/rest
 */
export const rest = 'http://hl7.org/fhir/rest' satisfies OwlObjectProperty;

/**
 * issuer
 *
 * DeviceDefinition.packaging.packaging.udiDeviceIdentifier.issuer: The organization that assigns the identifier algorithm.
 *
 * http://hl7.org/fhir/issuer
 */
export const issuer = 'http://hl7.org/fhir/issuer' satisfies OwlObjectProperty;

/**
 * _nutritionProduct
 *
 * (Modified) NutritionIntake.consumedItem.nutritionProduct
 *
 * http://hl7.org/fhir/_nutritionProduct
 */
export const _nutritionProduct = 'http://hl7.org/fhir/_nutritionProduct' satisfies OwlObjectProperty;

/**
 * SubstancePolymer
 *
 * Properties of a substance specific to it being a polymer.
 *
 * http://hl7.org/fhir/SubstancePolymer
 */
export const SubstancePolymer = 'http://hl7.org/fhir/SubstancePolymer' satisfies OwlClass;

/**
 * ValueSetComposeComponent
 *
 * ValueSetComposeComponent: A set of criteria that define the contents of the value set by including or excluding codes selected from the specified code system(s) that the value set draws from. This is also known as the Content Logical Definition (CLD).
 *
 * http://hl7.org/fhir/ValueSetComposeComponent
 */
export const ValueSetComposeComponent = 'http://hl7.org/fhir/ValueSetComposeComponent' satisfies OwlClass;

/**
 * _doseNumber
 *
 * (Modified) ImmunizationRecommendation.recommendation.doseNumber
 *
 * http://hl7.org/fhir/_doseNumber
 */
export const _doseNumber = 'http://hl7.org/fhir/_doseNumber' satisfies OwlObjectProperty;

/**
 * SubstanceDefinitionNameComponent
 *
 * SubstanceDefinitionNameComponent: Names applicable to this substance.
 *
 * http://hl7.org/fhir/SubstanceDefinitionNameComponent
 */
export const SubstanceDefinitionNameComponent = 'http://hl7.org/fhir/SubstanceDefinitionNameComponent' satisfies OwlClass;

/**
 * derivedFromUri
 *
 * SpecimenDefinition.derivedFromUri: The URL pointing to an externally-defined type of specimen, guideline or other definition that is adhered to in whole or in part by this definition.
 *
 * http://hl7.org/fhir/derivedFromUri
 */
export const derivedFromUri = 'http://hl7.org/fhir/derivedFromUri' satisfies OwlObjectProperty;

/**
 * _startParam
 *
 * (Modified) CompartmentDefinition.resource.startParam
 *
 * http://hl7.org/fhir/_startParam
 */
export const _startParam = 'http://hl7.org/fhir/_startParam' satisfies OwlObjectProperty;

/**
 * _attribute
 *
 * (Modified) ConceptMap.group.element.target.product.attribute
 *
 * http://hl7.org/fhir/_attribute
 */
export const _attribute = 'http://hl7.org/fhir/_attribute' satisfies OwlObjectProperty;

/**
 * _extraDetails
 *
 * (Modified) HealthcareService.extraDetails
 *
 * http://hl7.org/fhir/_extraDetails
 */
export const _extraDetails = 'http://hl7.org/fhir/_extraDetails' satisfies OwlObjectProperty;

/**
 * _accessionIdentifier
 *
 * (Modified) Specimen.accessionIdentifier
 *
 * http://hl7.org/fhir/_accessionIdentifier
 */
export const _accessionIdentifier = 'http://hl7.org/fhir/_accessionIdentifier' satisfies OwlObjectProperty;

/**
 * _entryReference
 *
 * (Modified) EvidenceReport.section.section.entryReference
 *
 * http://hl7.org/fhir/_entryReference
 */
export const _entryReference = 'http://hl7.org/fhir/_entryReference' satisfies OwlObjectProperty;

/**
 * Parameters
 *
 * This resource is used to pass information into and back from an operation (whether invoked directly from REST or within a messaging environment).  It is not persisted or allowed to be referenced by other resources except as described in the definition of the Parameters resource.
 *
 * http://hl7.org/fhir/Parameters
 */
export const Parameters = 'http://hl7.org/fhir/Parameters' satisfies OwlClass;

/**
 * ChargeItem
 *
 * The resource ChargeItem describes the provision of healthcare provider products for a certain patient, therefore referring not only to the product, but containing in addition details of the provision, like date, time, amounts and participating organizations and persons. Main Usage of the ChargeItem is to enable the billing process and internal cost allocation.
 *
 * http://hl7.org/fhir/ChargeItem
 */
export const ChargeItem = 'http://hl7.org/fhir/ChargeItem' satisfies OwlClass;

/**
 * _uid
 *
 * (Modified) ImagingStudy.series.instance.uid
 *
 * http://hl7.org/fhir/_uid
 */
export const _uid = 'http://hl7.org/fhir/_uid' satisfies OwlObjectProperty;

/**
 * chain
 *
 * SearchParameter.chain: Contains the names of any search parameters which may be chained to the containing search parameter. Chained parameters may be added to search parameters of type reference and specify that resources will only be returned if they contain a reference to a resource which matches the chained parameter value. Values for this field should be drawn from SearchParameter.code for a parameter on the target resource type.
 *
 * http://hl7.org/fhir/chain
 */
export const chain = 'http://hl7.org/fhir/chain' satisfies OwlObjectProperty;

/**
 * _bodySite
 *
 * (Modified) Claim.item.bodySite
 *
 * http://hl7.org/fhir/_bodySite
 */
export const _bodySite = 'http://hl7.org/fhir/_bodySite' satisfies OwlObjectProperty;

/**
 * qualification
 *
 * Practitioner.qualification: The official qualifications, certifications, accreditations, training, licenses (and other types of educations/skills/capabilities) that authorize or otherwise pertain to the provision of care by the practitioner.

For example, a medical license issued by a medical board of licensure authorizing the practitioner to practice medicine within a certain locality.
 *
 * http://hl7.org/fhir/qualification
 */
export const qualification = 'http://hl7.org/fhir/qualification' satisfies OwlObjectProperty;

/**
 * yearInterval
 *
 * Appointment.recurrenceTemplate.yearlyTemplate.yearInterval: Appointment recurs every nth year.
 *
 * http://hl7.org/fhir/yearInterval
 */
export const yearInterval = 'http://hl7.org/fhir/yearInterval' satisfies OwlObjectProperty;

/**
 * _developmentStage
 *
 * (Modified) SubstanceSourceMaterial.developmentStage
 *
 * http://hl7.org/fhir/_developmentStage
 */
export const _developmentStage = 'http://hl7.org/fhir/_developmentStage' satisfies OwlObjectProperty;

/**
 * riskAdjustment
 *
 * Measure.riskAdjustment: A description of the risk adjustment factors that may impact the resulting score for the measure and how they may be accounted for when computing and reporting measure results.
 *
 * http://hl7.org/fhir/riskAdjustment
 */
export const riskAdjustment = 'http://hl7.org/fhir/riskAdjustment' satisfies OwlObjectProperty;

/**
 * _estimatedAge
 *
 * (Modified) FamilyMemberHistory.estimatedAge
 *
 * http://hl7.org/fhir/_estimatedAge
 */
export const _estimatedAge = 'http://hl7.org/fhir/_estimatedAge' satisfies OwlObjectProperty;

/**
 * RequirementsStatementComponent
 *
 * RequirementsStatementComponent: The actual statement of requirement, in markdown format.
 *
 * http://hl7.org/fhir/RequirementsStatementComponent
 */
export const RequirementsStatementComponent = 'http://hl7.org/fhir/RequirementsStatementComponent' satisfies OwlClass;

/**
 * _intendedRoute
 *
 * (Modified) MedicationKnowledge.definitional.intendedRoute
 *
 * http://hl7.org/fhir/_intendedRoute
 */
export const _intendedRoute = 'http://hl7.org/fhir/_intendedRoute' satisfies OwlObjectProperty;

/**
 * score
 *
 * TestReport.score: The final score (percentage of tests passed) resulting from the execution of the TestScript.
 *
 * http://hl7.org/fhir/score
 */
export const score = 'http://hl7.org/fhir/score' satisfies OwlObjectProperty;

/**
 * DeviceRequestParameterComponent
 *
 * DeviceRequestParameterComponent: Specific parameters for the ordered item.  For example, the prism value for lenses.
 *
 * http://hl7.org/fhir/DeviceRequestParameterComponent
 */
export const DeviceRequestParameterComponent = 'http://hl7.org/fhir/DeviceRequestParameterComponent' satisfies OwlClass;

/**
 * _diseaseSymptomProcedure
 *
 * (Modified) ClinicalUseDefinition.indication.diseaseSymptomProcedure
 *
 * http://hl7.org/fhir/_diseaseSymptomProcedure
 */
export const _diseaseSymptomProcedure = 'http://hl7.org/fhir/_diseaseSymptomProcedure' satisfies OwlObjectProperty;

/**
 * _validationProcess
 *
 * (Modified) VerificationResult.validationProcess
 *
 * http://hl7.org/fhir/_validationProcess
 */
export const _validationProcess = 'http://hl7.org/fhir/_validationProcess' satisfies OwlObjectProperty;

/**
 * ExampleScenarioProcessComponent
 *
 * ExampleScenarioProcessComponent: A group of operations that represents a significant step within a scenario.
 *
 * http://hl7.org/fhir/ExampleScenarioProcessComponent
 */
export const ExampleScenarioProcessComponent = 'http://hl7.org/fhir/ExampleScenarioProcessComponent' satisfies OwlClass;

/**
 * _timestamp
 *
 * (Modified) ValueSet.expansion.timestamp
 *
 * http://hl7.org/fhir/_timestamp
 */
export const _timestamp = 'http://hl7.org/fhir/_timestamp' satisfies OwlObjectProperty;

/**
 * supportedProfile
 *
 * CapabilityStatement.rest.resource.supportedProfile: A list of profiles representing different use cases the system hosts/produces. A supported profile is a statement about the functionality of the data and services provided by the server (or the client) for supported use cases. For example, a system can define and declare multiple Observation profiles for laboratory observations, vital sign observations, etc. By declaring supported profiles, systems provide a way to determine whether individual resources are conformant. See further discussion in [Using Profiles](profiling.html#profile-uses).
 *
 * http://hl7.org/fhir/supportedProfile
 */
export const supportedProfile = 'http://hl7.org/fhir/supportedProfile' satisfies OwlObjectProperty;

/**
 * TestReportSetupActionAssertComponent
 *
 * TestReportSetupComponent.SetupAction.TestReportSetupActionAssertComponent: The results of the assertion performed on the previous operations.
 *
 * http://hl7.org/fhir/TestReportSetupActionAssertComponent
 */
export const TestReportSetupActionAssertComponent = 'http://hl7.org/fhir/TestReportSetupActionAssertComponent' satisfies OwlClass;

/**
 * _label
 *
 * (Modified) Citation.citedArtifact.relatesTo.label
 *
 * http://hl7.org/fhir/_label
 */
export const _label = 'http://hl7.org/fhir/_label' satisfies OwlObjectProperty;

/**
 * _preparationInstruction
 *
 * (Modified) MedicationKnowledge.preparationInstruction
 *
 * http://hl7.org/fhir/_preparationInstruction
 */
export const _preparationInstruction = 'http://hl7.org/fhir/_preparationInstruction' satisfies OwlObjectProperty;

/**
 * InventoryItemResponsibleOrganizationComponent
 *
 * InventoryItemResponsibleOrganizationComponent: Organization(s) responsible for the product.
 *
 * http://hl7.org/fhir/InventoryItemResponsibleOrganizationComponent
 */
export const InventoryItemResponsibleOrganizationComponent = 'http://hl7.org/fhir/InventoryItemResponsibleOrganizationComponent' satisfies OwlClass;

/**
 * informationType
 *
 * ArtifactAssessment.content.component.informationType: The type of information this component of the content represents.
 *
 * http://hl7.org/fhir/informationType
 */
export const informationType = 'http://hl7.org/fhir/informationType' satisfies OwlObjectProperty;

/**
 * BodyStructureIncludedStructure
 *
 * The anatomical location(s) or region(s) not occupied or represented by the specimen, lesion, or body structure.
 *
 * http://hl7.org/fhir/BodyStructureIncludedStructure
 */
export const BodyStructureIncludedStructure = 'http://hl7.org/fhir/BodyStructureIncludedStructure' satisfies OwlClass;

/**
 * _requesterLinkId
 *
 * (Modified) Contract.term.group.action.requesterLinkId
 *
 * http://hl7.org/fhir/_requesterLinkId
 */
export const _requesterLinkId = 'http://hl7.org/fhir/_requesterLinkId' satisfies OwlObjectProperty;

/**
 * PlanDefinition
 *
 * This resource allows for the definition of various types of plans as a sharable, consumable, and executable artifact. The resource is general enough to support the description of a broad range of clinical and non-clinical artifacts such as clinical decision support rules, order sets, protocols, and drug quality specifications.
 *
 * http://hl7.org/fhir/PlanDefinition
 */
export const PlanDefinition = 'http://hl7.org/fhir/PlanDefinition' satisfies OwlClass;

/**
 * postConditions
 *
 * ExampleScenario.process.step.alternative.step.process.postConditions: Description of the final state of the actors, environment and data after the process has been successfully completed.
 *
 * http://hl7.org/fhir/postConditions
 */
export const postConditions = 'http://hl7.org/fhir/postConditions' satisfies OwlObjectProperty;

/**
 * EvidenceVariableDefinitionComponent
 *
 * EvidenceVariableDefinitionComponent: Evidence variable such as population, exposure, or outcome.
 *
 * http://hl7.org/fhir/EvidenceVariableDefinitionComponent
 */
export const EvidenceVariableDefinitionComponent = 'http://hl7.org/fhir/EvidenceVariableDefinitionComponent' satisfies OwlClass;

/**
 * _meaningWhenMissing
 *
 * (Modified) ElementDefinition.meaningWhenMissing
 *
 * http://hl7.org/fhir/_meaningWhenMissing
 */
export const _meaningWhenMissing = 'http://hl7.org/fhir/_meaningWhenMissing' satisfies OwlObjectProperty;

/**
 * DeviceDispense
 *
 * Indicates that a device is to be or has been dispensed for a named person/patient.  This includes a description of the product (supply) provided and the instructions for using the device.
 *
 * http://hl7.org/fhir/DeviceDispense
 */
export const DeviceDispense = 'http://hl7.org/fhir/DeviceDispense' satisfies OwlClass;

/**
 * _modelCharacteristic
 *
 * (Modified) Evidence.statistic.modelCharacteristic
 *
 * http://hl7.org/fhir/_modelCharacteristic
 */
export const _modelCharacteristic = 'http://hl7.org/fhir/_modelCharacteristic' satisfies OwlObjectProperty;

/**
 * SetupAction
 *
 * TestScriptSetupComponent.SetupAction: Action would contain either an operation or an assertion.
 *
 * http://hl7.org/fhir/SetupAction
 */
export const SetupAction = 'http://hl7.org/fhir/SetupAction' satisfies OwlClass;

/**
 * _studyDesign
 *
 * (Modified) ResearchStudy.studyDesign
 *
 * http://hl7.org/fhir/_studyDesign
 */
export const _studyDesign = 'http://hl7.org/fhir/_studyDesign' satisfies OwlObjectProperty;

/**
 * _analysis
 *
 * (Modified) GenomicStudy.analysis
 *
 * http://hl7.org/fhir/_analysis
 */
export const _analysis = 'http://hl7.org/fhir/_analysis' satisfies OwlObjectProperty;

/**
 * insurancePlan
 *
 * Coverage.insurancePlan: The insurance plan details, benefits and costs, which constitute this insurance coverage.
 *
 * http://hl7.org/fhir/insurancePlan
 */
export const insurancePlan = 'http://hl7.org/fhir/insurancePlan' satisfies OwlObjectProperty;

/**
 * communicationRequest
 *
 * ClaimResponse.communicationRequest: Request for additional supporting or authorizing information.
 *
 * http://hl7.org/fhir/communicationRequest
 */
export const communicationRequest = 'http://hl7.org/fhir/communicationRequest' satisfies OwlObjectProperty;

/**
 * specialty
 *
 * Appointment.specialty: The specialty of a practitioner that would be required to perform the service requested in this appointment.
 *
 * http://hl7.org/fhir/specialty
 */
export const specialty = 'http://hl7.org/fhir/specialty' satisfies OwlObjectProperty;

/**
 * _artifact
 *
 * (Modified) TestScript.scope.artifact
 *
 * http://hl7.org/fhir/_artifact
 */
export const _artifact = 'http://hl7.org/fhir/_artifact' satisfies OwlObjectProperty;

/**
 * chargeItemCode
 *
 * DeviceDefinition.chargeItem.chargeItemCode: The code or reference for the charge item.
 *
 * http://hl7.org/fhir/chargeItemCode
 */
export const chargeItemCode = 'http://hl7.org/fhir/chargeItemCode' satisfies OwlObjectProperty;

/**
 * actuality
 *
 * AdverseEvent.actuality: Whether the event actually happened or was a near miss. Note that this is independent of whether anyone was affected or harmed or how severely.
 *
 * http://hl7.org/fhir/actuality
 */
export const actuality = 'http://hl7.org/fhir/actuality' satisfies OwlObjectProperty;

/**
 * _maxParticipants
 *
 * (Modified) VirtualServiceDetail.maxParticipants
 *
 * http://hl7.org/fhir/_maxParticipants
 */
export const _maxParticipants = 'http://hl7.org/fhir/_maxParticipants' satisfies OwlObjectProperty;

/**
 * _Basic
 *
 * (Modified) Basic
 *
 * http://hl7.org/fhir/_Basic
 */
export const _Basic = 'http://hl7.org/fhir/_Basic' satisfies OwlClass;

/**
 * _example
 *
 * (Modified) ElementDefinition.example
 *
 * http://hl7.org/fhir/_example
 */
export const _example = 'http://hl7.org/fhir/_example' satisfies OwlObjectProperty;

/**
 * _representation
 *
 * (Modified) SubstancePolymer.repeat.repeatUnit.structuralRepresentation.representation
 *
 * http://hl7.org/fhir/_representation
 */
export const _representation = 'http://hl7.org/fhir/_representation' satisfies OwlObjectProperty;

/**
 * telecom
 *
 * ContactDetail.telecom: The contact details for the individual (if a name was provided) or the organization.
 *
 * http://hl7.org/fhir/telecom
 */
export const telecom = 'http://hl7.org/fhir/telecom' satisfies OwlObjectProperty;

/**
 * EvidenceCertaintyComponentCertaintyCertainty
 *
 * A domain or subdomain of certainty.
 *
 * http://hl7.org/fhir/EvidenceCertaintyComponentCertaintyCertainty
 */
export const EvidenceCertaintyComponentCertaintyCertainty = 'http://hl7.org/fhir/EvidenceCertaintyComponentCertaintyCertainty' satisfies OwlClass;

/**
 * _lastPerformed
 *
 * (Modified) VerificationResult.lastPerformed
 *
 * http://hl7.org/fhir/_lastPerformed
 */
export const _lastPerformed = 'http://hl7.org/fhir/_lastPerformed' satisfies OwlObjectProperty;

/**
 * _legalState
 *
 * (Modified) Contract.legalState
 *
 * http://hl7.org/fhir/_legalState
 */
export const _legalState = 'http://hl7.org/fhir/_legalState' satisfies OwlObjectProperty;

/**
 * _preAuthPeriod
 *
 * (Modified) ExplanationOfBenefit.item.detail.reviewOutcome.preAuthPeriod
 *
 * http://hl7.org/fhir/_preAuthPeriod
 */
export const _preAuthPeriod = 'http://hl7.org/fhir/_preAuthPeriod' satisfies OwlObjectProperty;

/**
 * GraphDefinitionLinkComponent
 *
 * GraphDefinitionLinkComponent: Links this graph makes rules about.
 *
 * http://hl7.org/fhir/GraphDefinitionLinkComponent
 */
export const GraphDefinitionLinkComponent = 'http://hl7.org/fhir/GraphDefinitionLinkComponent' satisfies OwlClass;

/**
 * workflow
 *
 * ExampleScenario.process.step.alternative.step.process.step.workflow: Indicates that the step is defined by a seaparate scenario instance.
 *
 * http://hl7.org/fhir/workflow
 */
export const workflow = 'http://hl7.org/fhir/workflow' satisfies OwlObjectProperty;

/**
 * _incomplete
 *
 * (Modified) TerminologyCapabilities.expansion.incomplete
 *
 * http://hl7.org/fhir/_incomplete
 */
export const _incomplete = 'http://hl7.org/fhir/_incomplete' satisfies OwlObjectProperty;

/**
 * _sphere
 *
 * (Modified) VisionPrescription.lensSpecification.sphere
 *
 * http://hl7.org/fhir/_sphere
 */
export const _sphere = 'http://hl7.org/fhir/_sphere' satisfies OwlObjectProperty;

/**
 * _substanceDefinition
 *
 * (Modified) SubstanceDefinition.relationship.substanceDefinition
 *
 * http://hl7.org/fhir/_substanceDefinition
 */
export const _substanceDefinition = 'http://hl7.org/fhir/_substanceDefinition' satisfies OwlObjectProperty;

/**
 * informationSource
 *
 * Immunization.informationSource: Typically the source of the data when the report of the immunization event is not based on information from the person who administered the vaccine.
 *
 * http://hl7.org/fhir/informationSource
 */
export const informationSource = 'http://hl7.org/fhir/informationSource' satisfies OwlObjectProperty;

/**
 * _periodUnit
 *
 * (Modified) Timing.repeat.periodUnit
 *
 * http://hl7.org/fhir/_periodUnit
 */
export const _periodUnit = 'http://hl7.org/fhir/_periodUnit' satisfies OwlObjectProperty;

/**
 * paymentIdentifier
 *
 * PaymentReconciliation.paymentIdentifier: Issuer's unique identifier for the payment instrument.
 *
 * http://hl7.org/fhir/paymentIdentifier
 */
export const paymentIdentifier = 'http://hl7.org/fhir/paymentIdentifier' satisfies OwlObjectProperty;

/**
 * stratifier
 *
 * MeasureReport.group.stratifier: When a measure includes multiple stratifiers, there will be a stratifier group for each stratifier defined by the measure.
 *
 * http://hl7.org/fhir/stratifier
 */
export const stratifier = 'http://hl7.org/fhir/stratifier' satisfies OwlObjectProperty;

/**
 * pause
 *
 * ExampleScenario.process.step.process.step.alternative.step.pause: If true, indicates that, following this step, there is a pause in the flow and the subsequent step will occur at some later time (triggered by some event).
 *
 * http://hl7.org/fhir/pause
 */
export const pause = 'http://hl7.org/fhir/pause' satisfies OwlObjectProperty;

/**
 * _isActive
 *
 * (Modified) Medication.ingredient.isActive
 *
 * http://hl7.org/fhir/_isActive
 */
export const _isActive = 'http://hl7.org/fhir/_isActive' satisfies OwlObjectProperty;

/**
 * _synonym
 *
 * (Modified) SubstanceDefinition.name.translation.synonym
 *
 * http://hl7.org/fhir/_synonym
 */
export const _synonym = 'http://hl7.org/fhir/_synonym' satisfies OwlObjectProperty;

/**
 * _manifestation
 *
 * (Modified) Immunization.reaction.manifestation
 *
 * http://hl7.org/fhir/_manifestation
 */
export const _manifestation = 'http://hl7.org/fhir/_manifestation' satisfies OwlObjectProperty;

/**
 * _control
 *
 * (Modified) Contract.term.group.securityLabel.control
 *
 * http://hl7.org/fhir/_control
 */
export const _control = 'http://hl7.org/fhir/_control' satisfies OwlObjectProperty;

/**
 * RegulatedAuthorizationCaseComponentCase
 *
 * A regulatory submission from an organization to a regulator, as part of an assessing case. Multiple applications may occur over time, with more or different information to support or modify the submission or the authorization. The applications can be considered as steps within the longer running case or procedure for this authorization process.
 *
 * http://hl7.org/fhir/RegulatedAuthorizationCaseComponentCase
 */
export const RegulatedAuthorizationCaseComponentCase = 'http://hl7.org/fhir/RegulatedAuthorizationCaseComponentCase' satisfies OwlClass;

/**
 * dosageInstruction
 *
 * MedicationRequest.dosageInstruction: Specific instructions for how the medication is to be used by the patient.
 *
 * http://hl7.org/fhir/dosageInstruction
 */
export const dosageInstruction = 'http://hl7.org/fhir/dosageInstruction' satisfies OwlObjectProperty;

/**
 * _implicitRules
 *
 * (Modified) Resource.implicitRules
 *
 * http://hl7.org/fhir/_implicitRules
 */
export const _implicitRules = 'http://hl7.org/fhir/_implicitRules' satisfies OwlObjectProperty;

/**
 * AvailabilityAvailableTimeComponent
 *
 * AvailabilityAvailableTimeComponent: Times the {item} is available.
 *
 * http://hl7.org/fhir/AvailabilityAvailableTimeComponent
 */
export const AvailabilityAvailableTimeComponent = 'http://hl7.org/fhir/AvailabilityAvailableTimeComponent' satisfies OwlClass;

/**
 * SpecimenCollectionComponent
 *
 * SpecimenCollectionComponent: Details concerning the specimen collection.
 *
 * http://hl7.org/fhir/SpecimenCollectionComponent
 */
export const SpecimenCollectionComponent = 'http://hl7.org/fhir/SpecimenCollectionComponent' satisfies OwlClass;

/**
 * regulatoryAuthority
 *
 * MedicationKnowledge.regulatory.regulatoryAuthority: The authority that is specifying the regulations.
 *
 * http://hl7.org/fhir/regulatoryAuthority
 */
export const regulatoryAuthority = 'http://hl7.org/fhir/regulatoryAuthority' satisfies OwlObjectProperty;

/**
 * _EnrollmentRequest
 *
 * (Modified) EnrollmentRequest
 *
 * http://hl7.org/fhir/_EnrollmentRequest
 */
export const _EnrollmentRequest = 'http://hl7.org/fhir/_EnrollmentRequest' satisfies OwlClass;

/**
 * hash
 *
 * Attachment.hash: The calculated hash of the data using SHA-1. Represented using base64.
 *
 * http://hl7.org/fhir/hash
 */
export const hash = 'http://hl7.org/fhir/hash' satisfies OwlObjectProperty;

/**
 * marketDistribution
 *
 * DeviceDefinition.packaging.packaging.udiDeviceIdentifier.marketDistribution: Indicates where and when the device is available on the market.
 *
 * http://hl7.org/fhir/marketDistribution
 */
export const marketDistribution = 'http://hl7.org/fhir/marketDistribution' satisfies OwlObjectProperty;

/**
 * countType
 *
 * InventoryReport.countType: Whether the report is about the current inventory count (snapshot) or a differential change in inventory (change).
 *
 * http://hl7.org/fhir/countType
 */
export const countType = 'http://hl7.org/fhir/countType' satisfies OwlObjectProperty;

/**
 * _documentation
 *
 * (Modified) ParameterDefinition.documentation
 *
 * http://hl7.org/fhir/_documentation
 */
export const _documentation = 'http://hl7.org/fhir/_documentation' satisfies OwlObjectProperty;

/**
 * association
 *
 * InventoryItem.association: Association with other items or products.
 *
 * http://hl7.org/fhir/association
 */
export const association = 'http://hl7.org/fhir/association' satisfies OwlObjectProperty;

/**
 * _intendedJurisdiction
 *
 * (Modified) MedicationKnowledge.intendedJurisdiction
 *
 * http://hl7.org/fhir/_intendedJurisdiction
 */
export const _intendedJurisdiction = 'http://hl7.org/fhir/_intendedJurisdiction' satisfies OwlObjectProperty;

/**
 * _recurrenceType
 *
 * (Modified) Appointment.recurrenceTemplate.recurrenceType
 *
 * http://hl7.org/fhir/_recurrenceType
 */
export const _recurrenceType = 'http://hl7.org/fhir/_recurrenceType' satisfies OwlObjectProperty;

/**
 * when
 *
 * RiskAssessment.prediction.when
 *
 * http://hl7.org/fhir/when
 */
export const when = 'http://hl7.org/fhir/when' satisfies OwlObjectProperty;

/**
 * form
 *
 * ClaimResponse.form: The actual form, by reference or inclusion, for printing the content or an EOB.
 *
 * http://hl7.org/fhir/form
 */
export const form = 'http://hl7.org/fhir/form' satisfies OwlObjectProperty;

/**
 * _complete
 *
 * (Modified) Citation.citedArtifact.contributorship.complete
 *
 * http://hl7.org/fhir/_complete
 */
export const _complete = 'http://hl7.org/fhir/_complete' satisfies OwlObjectProperty;

/**
 * _shortDoco
 *
 * (Modified) ElementDefinition.binding.additional.shortDoco
 *
 * http://hl7.org/fhir/_shortDoco
 */
export const _shortDoco = 'http://hl7.org/fhir/_shortDoco' satisfies OwlObjectProperty;

/**
 * differential
 *
 * StructureDefinition.differential: A differential view is expressed relative to the base StructureDefinition - a statement of differences that it applies.
 *
 * http://hl7.org/fhir/differential
 */
export const differential = 'http://hl7.org/fhir/differential' satisfies OwlObjectProperty;

/**
 * _occurrenceDate
 *
 * (Modified) AppointmentResponse.occurrenceDate
 *
 * http://hl7.org/fhir/_occurrenceDate
 */
export const _occurrenceDate = 'http://hl7.org/fhir/_occurrenceDate' satisfies OwlObjectProperty;

/**
 * additional
 *
 * ElementDefinition.binding.additional: Additional bindings that help applications implementing this element. Additional bindings do not replace the main binding but provide more information and/or context.
 *
 * http://hl7.org/fhir/additional
 */
export const additional = 'http://hl7.org/fhir/additional' satisfies OwlObjectProperty;

/**
 * canonical
 *
 * A URI that is a reference to a canonical URL on a FHIR resource
 *
 * http://hl7.org/fhir/canonical
 */
export const canonical = 'http://hl7.org/fhir/canonical' satisfies OwlClass;

/**
 * _actualComparisonGroup
 *
 * (Modified) ResearchSubject.actualComparisonGroup
 *
 * http://hl7.org/fhir/_actualComparisonGroup
 */
export const _actualComparisonGroup = 'http://hl7.org/fhir/_actualComparisonGroup' satisfies OwlObjectProperty;

/**
 * _requestor
 *
 * (Modified) PaymentReconciliation.requestor
 *
 * http://hl7.org/fhir/_requestor
 */
export const _requestor = 'http://hl7.org/fhir/_requestor' satisfies OwlObjectProperty;

/**
 * CommunicationPayloadComponent
 *
 * CommunicationPayloadComponent: Text, attachment(s), or resource(s) that was communicated to the recipient.
 *
 * http://hl7.org/fhir/CommunicationPayloadComponent
 */
export const CommunicationPayloadComponent = 'http://hl7.org/fhir/CommunicationPayloadComponent' satisfies OwlClass;

/**
 * AccountDiagnosisComponent
 *
 * AccountDiagnosisComponent: When using an account for billing a specific Encounter the set of diagnoses that are relevant for billing are stored here on the account where they are able to be sequenced appropriately prior to processing to produce claim(s).
 *
 * http://hl7.org/fhir/AccountDiagnosisComponent
 */
export const AccountDiagnosisComponent = 'http://hl7.org/fhir/AccountDiagnosisComponent' satisfies OwlClass;

/**
 * _doseStatus
 *
 * (Modified) ImmunizationEvaluation.doseStatus
 *
 * http://hl7.org/fhir/_doseStatus
 */
export const _doseStatus = 'http://hl7.org/fhir/_doseStatus' satisfies OwlObjectProperty;

/**
 * TestScriptTestComponent
 *
 * TestScriptTestComponent: A test in this script.
 *
 * http://hl7.org/fhir/TestScriptTestComponent
 */
export const TestScriptTestComponent = 'http://hl7.org/fhir/TestScriptTestComponent' satisfies OwlClass;

/**
 * TaskOutputComponent
 *
 * TaskOutputComponent: Outputs produced by the Task.
 *
 * http://hl7.org/fhir/TaskOutputComponent
 */
export const TaskOutputComponent = 'http://hl7.org/fhir/TaskOutputComponent' satisfies OwlClass;

/**
 * MeasureReport
 *
 * The MeasureReport resource contains the results of the calculation of a measure; and optionally a reference to the resources involved in that calculation.
 *
 * http://hl7.org/fhir/MeasureReport
 */
export const MeasureReport = 'http://hl7.org/fhir/MeasureReport' satisfies OwlClass;

/**
 * producedFrom
 *
 * AdministrableProductDefinition.producedFrom: Indicates the specific manufactured items that are part of the 'formOf' product that are used in the preparation of this specific administrable form.  In some cases, an administrable form might use all of the items from the overall product (or there might only be one item), while in other cases, an administrable form might use only a subset of the items available in the overall product.  For example, an administrable form might involve combining a liquid and a powder available as part of an overall product, but not involve applying the also supplied cream.
 *
 * http://hl7.org/fhir/producedFrom
 */
export const producedFrom = 'http://hl7.org/fhir/producedFrom' satisfies OwlObjectProperty;

/**
 * tuesday
 *
 * Appointment.recurrenceTemplate.weeklyTemplate.tuesday: Indicates that recurring appointments should occur on Tuesdays.
 *
 * http://hl7.org/fhir/tuesday
 */
export const tuesday = 'http://hl7.org/fhir/tuesday' satisfies OwlObjectProperty;

/**
 * _sourceReference
 *
 * (Modified) Consent.sourceReference
 *
 * http://hl7.org/fhir/_sourceReference
 */
export const _sourceReference = 'http://hl7.org/fhir/_sourceReference' satisfies OwlObjectProperty;

/**
 * crossReference
 *
 * MedicinalProductDefinition.crossReference: Reference to another product, e.g. for linking authorised to investigational product, or a virtual product.
 *
 * http://hl7.org/fhir/crossReference
 */
export const crossReference = 'http://hl7.org/fhir/crossReference' satisfies OwlObjectProperty;

/**
 * _Composition
 *
 * (Modified) Composition
 *
 * http://hl7.org/fhir/_Composition
 */
export const _Composition = 'http://hl7.org/fhir/_Composition' satisfies OwlClass;

/**
 * subdetailSequence
 *
 * ClaimResponse.addItem.subdetailSequence: The sequence number of the sub-details within the details within the claim item which this line is intended to replace.
 *
 * http://hl7.org/fhir/subdetailSequence
 */
export const subdetailSequence = 'http://hl7.org/fhir/subdetailSequence' satisfies OwlObjectProperty;

/**
 * _definitionReference
 *
 * (Modified) EvidenceVariable.characteristic.definitionByCombination.characteristic.definitionReference
 *
 * http://hl7.org/fhir/_definitionReference
 */
export const _definitionReference = 'http://hl7.org/fhir/_definitionReference' satisfies OwlObjectProperty;

/**
 * supplier
 *
 * SubstanceDefinition.supplier: An entity that is the source for the substance. It may be different from the manufacturer. Supplier is synonymous to a distributor.
 *
 * http://hl7.org/fhir/supplier
 */
export const supplier = 'http://hl7.org/fhir/supplier' satisfies OwlObjectProperty;

/**
 * inputPopulationId
 *
 * Measure.group.population.inputPopulationId: The id of a population element in this measure that provides the input for this population criteria. In most cases, the scoring structure of the measure implies specific relationships (e.g. the Numerator uses the Denominator as the source in a proportion scoring). In some cases, however, multiple possible choices exist and must be resolved explicitly. For example in a ratio measure with multiple initial populations, the denominator must specify which population should be used as the starting point.
 *
 * http://hl7.org/fhir/inputPopulationId
 */
export const inputPopulationId = 'http://hl7.org/fhir/inputPopulationId' satisfies OwlObjectProperty;

/**
 * CarePlan
 *
 * Describes the intention of how one or more practitioners intend to deliver care for a particular patient, group or community for a period of time, possibly limited to care for a specific condition or set of conditions.
 *
 * http://hl7.org/fhir/CarePlan
 */
export const CarePlan = 'http://hl7.org/fhir/CarePlan' satisfies OwlClass;

/**
 * clinicalStatus
 *
 * Condition.clinicalStatus: The clinical status of the condition.
 *
 * http://hl7.org/fhir/clinicalStatus
 */
export const clinicalStatus = 'http://hl7.org/fhir/clinicalStatus' satisfies OwlObjectProperty;

/**
 * measurementType
 *
 * SubstanceDefinition.moiety.measurementType: The measurement type of the quantitative value. In capturing the actual relative amounts of substances or molecular fragments it may be necessary to indicate whether the amount refers to, for example, a mole ratio or weight ratio.
 *
 * http://hl7.org/fhir/measurementType
 */
export const measurementType = 'http://hl7.org/fhir/measurementType' satisfies OwlObjectProperty;

/**
 * ImplementationGuideDefinitionGroupingComponent
 *
 * ImplementationGuideDefinitionComponent.ImplementationGuideDefinitionGroupingComponent: A logical group of resources. Logical groups can be used when building pages.
 *
 * http://hl7.org/fhir/ImplementationGuideDefinitionGroupingComponent
 */
export const ImplementationGuideDefinitionGroupingComponent = 'http://hl7.org/fhir/ImplementationGuideDefinitionGroupingComponent' satisfies OwlClass;

/**
 * _fundingSource
 *
 * (Modified) Immunization.fundingSource
 *
 * http://hl7.org/fhir/_fundingSource
 */
export const _fundingSource = 'http://hl7.org/fhir/_fundingSource' satisfies OwlObjectProperty;

/**
 * _immunizationEvent
 *
 * (Modified) ImmunizationEvaluation.immunizationEvent
 *
 * http://hl7.org/fhir/_immunizationEvent
 */
export const _immunizationEvent = 'http://hl7.org/fhir/_immunizationEvent' satisfies OwlObjectProperty;

/**
 * ClaimResponseEventComponent
 *
 * ClaimResponseEventComponent: Information code for an event with a corresponding date or period.
 *
 * http://hl7.org/fhir/ClaimResponseEventComponent
 */
export const ClaimResponseEventComponent = 'http://hl7.org/fhir/ClaimResponseEventComponent' satisfies OwlClass;

/**
 * statement
 *
 * Requirements.statement: The actual statement of requirement, in markdown format.
 *
 * http://hl7.org/fhir/statement
 */
export const statement = 'http://hl7.org/fhir/statement' satisfies OwlObjectProperty;

/**
 * ImageRegion3D
 *
 * ImagingSelectionInstanceComponent.ImageRegion3D: Each imaging selection might includes a 3D image region, specified by a region type and a set of 3D coordinates.
 *
 * http://hl7.org/fhir/ImageRegion3D
 */
export const ImageRegion3D = 'http://hl7.org/fhir/ImageRegion3D' satisfies OwlClass;

/**
 * _item
 *
 * (Modified) Linkage.item
 *
 * http://hl7.org/fhir/_item
 */
export const _item = 'http://hl7.org/fhir/_item' satisfies OwlObjectProperty;

/**
 * _repeatUnit
 *
 * (Modified) SubstancePolymer.repeat.repeatUnit
 *
 * http://hl7.org/fhir/_repeatUnit
 */
export const _repeatUnit = 'http://hl7.org/fhir/_repeatUnit' satisfies OwlObjectProperty;

/**
 * startingMaterial
 *
 * SubstancePolymer.monomerSet.startingMaterial: The starting materials - monomer(s) used in the synthesis of the polymer.
 *
 * http://hl7.org/fhir/startingMaterial
 */
export const startingMaterial = 'http://hl7.org/fhir/startingMaterial' satisfies OwlObjectProperty;

/**
 * _temperatureQualifier
 *
 * (Modified) SpecimenDefinition.typeTested.handling.temperatureQualifier
 *
 * http://hl7.org/fhir/_temperatureQualifier
 */
export const _temperatureQualifier = 'http://hl7.org/fhir/_temperatureQualifier' satisfies OwlObjectProperty;

/**
 * dosingGuideline
 *
 * MedicationKnowledge.indicationGuideline.dosingGuideline: The guidelines for the dosage of the medication for the indication.
 *
 * http://hl7.org/fhir/dosingGuideline
 */
export const dosingGuideline = 'http://hl7.org/fhir/dosingGuideline' satisfies OwlObjectProperty;

/**
 * _serviceCategory
 *
 * (Modified) Slot.serviceCategory
 *
 * http://hl7.org/fhir/_serviceCategory
 */
export const _serviceCategory = 'http://hl7.org/fhir/_serviceCategory' satisfies OwlObjectProperty;

/**
 * _rate
 *
 * (Modified) NutritionOrder.enteralFormula.administration.rate
 *
 * http://hl7.org/fhir/_rate
 */
export const _rate = 'http://hl7.org/fhir/_rate' satisfies OwlObjectProperty;

/**
 * _filterDefinition
 *
 * (Modified) SubscriptionTopic.canFilterBy.filterDefinition
 *
 * http://hl7.org/fhir/_filterDefinition
 */
export const _filterDefinition = 'http://hl7.org/fhir/_filterDefinition' satisfies OwlObjectProperty;

/**
 * prescriber
 *
 * VisionPrescription.prescriber: The healthcare professional responsible for authorizing the prescription.
 *
 * http://hl7.org/fhir/prescriber
 */
export const prescriber = 'http://hl7.org/fhir/prescriber' satisfies OwlObjectProperty;

/**
 * oid
 *
 * An OID represented as a URI
 *
 * http://hl7.org/fhir/oid
 */
export const oid = 'http://hl7.org/fhir/oid' satisfies OwlClass;

/**
 * _attachment
 *
 * (Modified) SubstancePolymer.repeat.repeatUnit.structuralRepresentation.attachment
 *
 * http://hl7.org/fhir/_attachment
 */
export const _attachment = 'http://hl7.org/fhir/_attachment' satisfies OwlObjectProperty;

/**
 * _sourceAttachment
 *
 * (Modified) Consent.sourceAttachment
 *
 * http://hl7.org/fhir/_sourceAttachment
 */
export const _sourceAttachment = 'http://hl7.org/fhir/_sourceAttachment' satisfies OwlObjectProperty;

/**
 * _materialType
 *
 * (Modified) SubstanceSourceMaterial.fractionDescription.materialType
 *
 * http://hl7.org/fhir/_materialType
 */
export const _materialType = 'http://hl7.org/fhir/_materialType' satisfies OwlObjectProperty;

/**
 * target
 *
 * VerificationResult.target: A resource that was validated.
 *
 * http://hl7.org/fhir/target
 */
export const target = 'http://hl7.org/fhir/target' satisfies OwlObjectProperty;

/**
 * _valueCategory
 *
 * (Modified) Evidence.statistic.modelCharacteristic.variable.valueCategory
 *
 * http://hl7.org/fhir/_valueCategory
 */
export const _valueCategory = 'http://hl7.org/fhir/_valueCategory' satisfies OwlObjectProperty;

/**
 * _requestMethod
 *
 * (Modified) TestScript.test.action.assert.requestMethod
 *
 * http://hl7.org/fhir/_requestMethod
 */
export const _requestMethod = 'http://hl7.org/fhir/_requestMethod' satisfies OwlObjectProperty;

/**
 * linkage
 *
 * SubstanceNucleicAcid.subunit.linkage: The linkages between sugar residues will also be captured.
 *
 * http://hl7.org/fhir/linkage
 */
export const linkage = 'http://hl7.org/fhir/linkage' satisfies OwlObjectProperty;

/**
 * DeviceUdiCarrierComponent
 *
 * DeviceUdiCarrierComponent: Unique device identifier (UDI) assigned to device label or package.  Note that the Device may include multiple udiCarriers as it either may include just the udiCarrier for the jurisdiction it is sold, or for multiple jurisdictions it could have been sold.
 *
 * http://hl7.org/fhir/DeviceUdiCarrierComponent
 */
export const DeviceUdiCarrierComponent = 'http://hl7.org/fhir/DeviceUdiCarrierComponent' satisfies OwlClass;

/**
 * TerminologyCapabilitiesClosureComponent
 *
 * TerminologyCapabilitiesClosureComponent: Whether the $closure operation is supported.
 *
 * http://hl7.org/fhir/TerminologyCapabilitiesClosureComponent
 */
export const TerminologyCapabilitiesClosureComponent = 'http://hl7.org/fhir/TerminologyCapabilitiesClosureComponent' satisfies OwlClass;

/**
 * _conclusionCode
 *
 * (Modified) DiagnosticReport.conclusionCode
 *
 * http://hl7.org/fhir/_conclusionCode
 */
export const _conclusionCode = 'http://hl7.org/fhir/_conclusionCode' satisfies OwlObjectProperty;

/**
 * _div
 *
 * (Modified) Narrative.div
 *
 * http://hl7.org/fhir/_div
 */
export const _div = 'http://hl7.org/fhir/_div' satisfies OwlObjectProperty;

/**
 * processingMode
 *
 * SearchParameter.processingMode: How the search parameter relates to the set of elements returned by evaluating the expression query.
 *
 * http://hl7.org/fhir/processingMode
 */
export const processingMode = 'http://hl7.org/fhir/processingMode' satisfies OwlObjectProperty;

/**
 * _rule
 *
 * (Modified) StructureMap.group.rule.rule
 *
 * http://hl7.org/fhir/_rule
 */
export const _rule = 'http://hl7.org/fhir/_rule' satisfies OwlObjectProperty;

/**
 * StructureMap
 *
 * A Map of relationships between 2 structures that can be used to transform data.
 *
 * http://hl7.org/fhir/StructureMap
 */
export const StructureMap = 'http://hl7.org/fhir/StructureMap' satisfies OwlClass;

/**
 * _molecularFormulaByMoiety
 *
 * (Modified) SubstanceDefinition.structure.molecularFormulaByMoiety
 *
 * http://hl7.org/fhir/_molecularFormulaByMoiety
 */
export const _molecularFormulaByMoiety = 'http://hl7.org/fhir/_molecularFormulaByMoiety' satisfies OwlObjectProperty;

/**
 * firstDose
 *
 * AdministrableProductDefinition.routeOfAdministration.firstDose: The first dose (dose quantity) administered can be specified for the product, using a numerical value and its unit of measurement.
 *
 * http://hl7.org/fhir/firstDose
 */
export const firstDose = 'http://hl7.org/fhir/firstDose' satisfies OwlObjectProperty;

/**
 * BundleEntryResponseComponent
 *
 * BundleEntryComponent.BundleEntryResponseComponent: Indicates the results of processing the corresponding 'request' entry in the batch or transaction being responded to or what the results of an operation where when returning history.
 *
 * http://hl7.org/fhir/BundleEntryResponseComponent
 */
export const BundleEntryResponseComponent = 'http://hl7.org/fhir/BundleEntryResponseComponent' satisfies OwlClass;

/**
 * structureVersion
 *
 * ExampleScenario.instance.structureVersion: Conveys the version of the data structure instantiated.  I.e. what release of FHIR, X12, OpenEHR, etc. is instance compliant with.
 *
 * http://hl7.org/fhir/structureVersion
 */
export const structureVersion = 'http://hl7.org/fhir/structureVersion' satisfies OwlObjectProperty;

/**
 * alias
 *
 * InsurancePlan.alias: A list of alternate names that the product is known as, or was known as in the past.
 *
 * http://hl7.org/fhir/alias
 */
export const alias = 'http://hl7.org/fhir/alias' satisfies OwlObjectProperty;

/**
 * _programCode
 *
 * (Modified) ExplanationOfBenefit.item.detail.subDetail.programCode
 *
 * http://hl7.org/fhir/_programCode
 */
export const _programCode = 'http://hl7.org/fhir/_programCode' satisfies OwlObjectProperty;

/**
 * _resultForDelete
 *
 * (Modified) SubscriptionTopic.resourceTrigger.queryCriteria.resultForDelete
 *
 * http://hl7.org/fhir/_resultForDelete
 */
export const _resultForDelete = 'http://hl7.org/fhir/_resultForDelete' satisfies OwlObjectProperty;

/**
 * grantee
 *
 * Consent.grantee: The entity responsible for complying with the Consent Directive, including any obligations or limitations on authorizations and enforcement of prohibitions.
 *
 * http://hl7.org/fhir/grantee
 */
export const grantee = 'http://hl7.org/fhir/grantee' satisfies OwlObjectProperty;

/**
 * _effectiveTime
 *
 * (Modified) Contract.term.group.asset.valuedItem.effectiveTime
 *
 * http://hl7.org/fhir/_effectiveTime
 */
export const _effectiveTime = 'http://hl7.org/fhir/_effectiveTime' satisfies OwlObjectProperty;

/**
 * definitionCodeableConcept
 *
 * EvidenceVariable.characteristic.definitionByCombination.characteristic.definitionCodeableConcept: Defines the characteristic using CodeableConcept.
 *
 * http://hl7.org/fhir/definitionCodeableConcept
 */
export const definitionCodeableConcept = 'http://hl7.org/fhir/definitionCodeableConcept' satisfies OwlObjectProperty;

/**
 * Property
 *
 * ConceptMap.Property: A property defines a slot through which additional information can be provided about a map from source -> target.
 *
 * http://hl7.org/fhir/Property
 */
export const Property = 'http://hl7.org/fhir/Property' satisfies OwlClass;

/**
 * entryClassifier
 *
 * EvidenceReport.section.section.entryClassifier: Specifies any type of classification of the evidence report.
 *
 * http://hl7.org/fhir/entryClassifier
 */
export const entryClassifier = 'http://hl7.org/fhir/entryClassifier' satisfies OwlObjectProperty;

/**
 * _combining
 *
 * (Modified) Permission.combining
 *
 * http://hl7.org/fhir/_combining
 */
export const _combining = 'http://hl7.org/fhir/_combining' satisfies OwlObjectProperty;

/**
 * paternalOrganismName
 *
 * SubstanceSourceMaterial.organism.hybrid.paternalOrganismName: The name of the paternal species constituting the hybrid organism shall be specified.
 *
 * http://hl7.org/fhir/paternalOrganismName
 */
export const paternalOrganismName = 'http://hl7.org/fhir/paternalOrganismName' satisfies OwlObjectProperty;

/**
 * _asset
 *
 * (Modified) Contract.term.group.asset
 *
 * http://hl7.org/fhir/_asset
 */
export const _asset = 'http://hl7.org/fhir/_asset' satisfies OwlObjectProperty;

/**
 * PaymentReconciliationAllocationComponent
 *
 * PaymentReconciliationAllocationComponent: Distribution of the payment amount for a previously acknowledged payable.
 *
 * http://hl7.org/fhir/PaymentReconciliationAllocationComponent
 */
export const PaymentReconciliationAllocationComponent = 'http://hl7.org/fhir/PaymentReconciliationAllocationComponent' satisfies OwlClass;

/**
 * _part
 *
 * (Modified) OperationDefinition.parameter.part
 *
 * http://hl7.org/fhir/_part
 */
export const _part = 'http://hl7.org/fhir/_part' satisfies OwlObjectProperty;

/**
 * actor
 *
 * Schedule.actor: Slots that reference this schedule resource provide the availability details to these referenced resource(s).
 *
 * http://hl7.org/fhir/actor
 */
export const actor = 'http://hl7.org/fhir/actor' satisfies OwlObjectProperty;

/**
 * _isExample
 *
 * (Modified) ImplementationGuide.manifest.resource.isExample
 *
 * http://hl7.org/fhir/_isExample
 */
export const _isExample = 'http://hl7.org/fhir/_isExample' satisfies OwlObjectProperty;

/**
 * navigationLinks
 *
 * TestScript.test.action.assert.navigationLinks: Whether or not the test execution performs validation on the bundle navigation links.
 *
 * http://hl7.org/fhir/navigationLinks
 */
export const navigationLinks = 'http://hl7.org/fhir/navigationLinks' satisfies OwlObjectProperty;

/**
 * availability
 *
 * PractitionerRole.availability: A collection of times the practitioner is available or performing this role at the location and/or healthcareservice.
 *
 * http://hl7.org/fhir/availability
 */
export const availability = 'http://hl7.org/fhir/availability' satisfies OwlObjectProperty;

/**
 * _specimen
 *
 * (Modified) ServiceRequest.specimen
 *
 * http://hl7.org/fhir/_specimen
 */
export const _specimen = 'http://hl7.org/fhir/_specimen' satisfies OwlObjectProperty;

/**
 * term
 *
 * Contract.term: One or more Contract Provisions, which may be related and conveyed as a group, and may contain nested groups.
 *
 * http://hl7.org/fhir/term
 */
export const term = 'http://hl7.org/fhir/term' satisfies OwlObjectProperty;

/**
 * notAvailableTime
 *
 * Availability.notAvailableTime: Not available during this time due to provided reason.
 *
 * http://hl7.org/fhir/notAvailableTime
 */
export const notAvailableTime = 'http://hl7.org/fhir/notAvailableTime' satisfies OwlObjectProperty;

/**
 * specimenRequirement
 *
 * ActivityDefinition.specimenRequirement: Defines specimen requirements for the action to be performed, such as required specimens for a lab test.
 *
 * http://hl7.org/fhir/specimenRequirement
 */
export const specimenRequirement = 'http://hl7.org/fhir/specimenRequirement' satisfies OwlObjectProperty;

/**
 * answer
 *
 * Contract.term.offer.answer: Response to offer text.
 *
 * http://hl7.org/fhir/answer
 */
export const answer = 'http://hl7.org/fhir/answer' satisfies OwlObjectProperty;

/**
 * _citation
 *
 * (Modified) Citation.citedArtifact.relatesTo.citation
 *
 * http://hl7.org/fhir/_citation
 */
export const _citation = 'http://hl7.org/fhir/_citation' satisfies OwlObjectProperty;

/**
 * patient
 *
 * CoverageEligibilityRequest.patient: The party who is the beneficiary of the supplied coverage and for whom eligibility is sought.
 *
 * http://hl7.org/fhir/patient
 */
export const patient = 'http://hl7.org/fhir/patient' satisfies OwlObjectProperty;

/**
 * suppress
 *
 * ElementDefinition.constraint.suppress: If true, indicates that the warning or best practice guideline should be suppressed.
 *
 * http://hl7.org/fhir/suppress
 */
export const suppress = 'http://hl7.org/fhir/suppress' satisfies OwlObjectProperty;

/**
 * additionalUse
 *
 * CodeSystem.concept.concept.designation.additionalUse: Additional codes that detail how this designation would be used, if there is more than one use.
 *
 * http://hl7.org/fhir/additionalUse
 */
export const additionalUse = 'http://hl7.org/fhir/additionalUse' satisfies OwlObjectProperty;

/**
 * _maxDosePerLifetime
 *
 * (Modified) Dosage.maxDosePerLifetime
 *
 * http://hl7.org/fhir/_maxDosePerLifetime
 */
export const _maxDosePerLifetime = 'http://hl7.org/fhir/_maxDosePerLifetime' satisfies OwlObjectProperty;

/**
 * Distance
 *
 * A length - a value with a unit that is a physical distance.
 *
 * http://hl7.org/fhir/Distance
 */
export const Distance = 'http://hl7.org/fhir/Distance' satisfies OwlClass;

/**
 * _primarySource
 *
 * (Modified) VerificationResult.primarySource
 *
 * http://hl7.org/fhir/_primarySource
 */
export const _primarySource = 'http://hl7.org/fhir/_primarySource' satisfies OwlObjectProperty;

/**
 * _opticalActivity
 *
 * (Modified) SubstanceDefinition.structure.opticalActivity
 *
 * http://hl7.org/fhir/_opticalActivity
 */
export const _opticalActivity = 'http://hl7.org/fhir/_opticalActivity' satisfies OwlObjectProperty;

/**
 * _multipleOr
 *
 * (Modified) SearchParameter.multipleOr
 *
 * http://hl7.org/fhir/_multipleOr
 */
export const _multipleOr = 'http://hl7.org/fhir/_multipleOr' satisfies OwlObjectProperty;

/**
 * _specialMeasures
 *
 * (Modified) MedicinalProductDefinition.specialMeasures
 *
 * http://hl7.org/fhir/_specialMeasures
 */
export const _specialMeasures = 'http://hl7.org/fhir/_specialMeasures' satisfies OwlObjectProperty;

/**
 * usageReason
 *
 * DeviceUsage.usageReason: The reason for asserting the usage status - for example forgot, lost, stolen, broken.
 *
 * http://hl7.org/fhir/usageReason
 */
export const usageReason = 'http://hl7.org/fhir/usageReason' satisfies OwlObjectProperty;

/**
 * GoalTargetComponent
 *
 * GoalTargetComponent: Indicates what should be done by when.
 *
 * http://hl7.org/fhir/GoalTargetComponent
 */
export const GoalTargetComponent = 'http://hl7.org/fhir/GoalTargetComponent' satisfies OwlClass;

/**
 * measure
 *
 * MeasureReport.measure: A reference to the Measure that was calculated to produce this report.
 *
 * http://hl7.org/fhir/measure
 */
export const measure = 'http://hl7.org/fhir/measure' satisfies OwlObjectProperty;

/**
 * contributionType
 *
 * Citation.citedArtifact.contributorship.entry.contributionType: This element identifies the specific nature of an individual’s contribution with respect to the cited work.
 *
 * http://hl7.org/fhir/contributionType
 */
export const contributionType = 'http://hl7.org/fhir/contributionType' satisfies OwlObjectProperty;

/**
 * modelNumber
 *
 * DeviceDefinition.modelNumber: The model number for the device for example as defined by the manufacturer or labeler, or other agency.
 *
 * http://hl7.org/fhir/modelNumber
 */
export const modelNumber = 'http://hl7.org/fhir/modelNumber' satisfies OwlObjectProperty;

/**
 * _derivedFromUri
 *
 * (Modified) SpecimenDefinition.derivedFromUri
 *
 * http://hl7.org/fhir/_derivedFromUri
 */
export const _derivedFromUri = 'http://hl7.org/fhir/_derivedFromUri' satisfies OwlObjectProperty;

/**
 * _method
 *
 * (Modified) MedicationAdministration.dosage.method
 *
 * http://hl7.org/fhir/_method
 */
export const _method = 'http://hl7.org/fhir/_method' satisfies OwlObjectProperty;

/**
 * effectiveDate
 *
 * MedicinalProductDefinition.operation.effectiveDate: Date range of applicability.
 *
 * http://hl7.org/fhir/effectiveDate
 */
export const effectiveDate = 'http://hl7.org/fhir/effectiveDate' satisfies OwlObjectProperty;

/**
 * _servicePeriod
 *
 * (Modified) Account.servicePeriod
 *
 * http://hl7.org/fhir/_servicePeriod
 */
export const _servicePeriod = 'http://hl7.org/fhir/_servicePeriod' satisfies OwlObjectProperty;

/**
 * asNeededFor
 *
 * DeviceRequest.asNeededFor: The reason for using the device.
 *
 * http://hl7.org/fhir/asNeededFor
 */
export const asNeededFor = 'http://hl7.org/fhir/asNeededFor' satisfies OwlObjectProperty;

/**
 * ExplanationOfBenefit
 *
 * This resource provides: the claim details; adjudication details from the processing of a Claim; and optionally account balance information, for informing the subscriber of the benefits provided.
 *
 * http://hl7.org/fhir/ExplanationOfBenefit
 */
export const ExplanationOfBenefit = 'http://hl7.org/fhir/ExplanationOfBenefit' satisfies OwlClass;

/**
 * _add
 *
 * (Modified) VisionPrescription.lensSpecification.add
 *
 * http://hl7.org/fhir/_add
 */
export const _add = 'http://hl7.org/fhir/_add' satisfies OwlObjectProperty;

/**
 * _cancelledReason
 *
 * (Modified) Invoice.cancelledReason
 *
 * http://hl7.org/fhir/_cancelledReason
 */
export const _cancelledReason = 'http://hl7.org/fhir/_cancelledReason' satisfies OwlObjectProperty;

/**
 * orderMeaning
 *
 * ElementDefinition.orderMeaning: If present, indicates that the order of the repeating element has meaning and describes what that meaning is.  If absent, it means that the order of the element has no meaning.
 *
 * http://hl7.org/fhir/orderMeaning
 */
export const orderMeaning = 'http://hl7.org/fhir/orderMeaning' satisfies OwlObjectProperty;

/**
 * testCase
 *
 * TestPlan.testCase: The individual test cases that are part of this plan, when they they are made explicit.
 *
 * http://hl7.org/fhir/testCase
 */
export const testCase = 'http://hl7.org/fhir/testCase' satisfies OwlObjectProperty;

/**
 * net
 *
 * ExplanationOfBenefit.addItem.detail.net: The total amount claimed for the group (if a grouper) or the addItem.detail. Net = unit price * quantity * factor.
 *
 * http://hl7.org/fhir/net
 */
export const net = 'http://hl7.org/fhir/net' satisfies OwlObjectProperty;

/**
 * VerificationResultAttestationComponent
 *
 * VerificationResultAttestationComponent: Information about the entity attesting to information.
 *
 * http://hl7.org/fhir/VerificationResultAttestationComponent
 */
export const VerificationResultAttestationComponent = 'http://hl7.org/fhir/VerificationResultAttestationComponent' satisfies OwlClass;

/**
 * _class
 *
 * (Modified) SubstanceSourceMaterial.organism.organismGeneral.class
 *
 * http://hl7.org/fhir/_class
 */
export const _class = 'http://hl7.org/fhir/_class' satisfies OwlObjectProperty;

/**
 * claim
 *
 * ExplanationOfBenefit.related.claim: Reference to a related claim.
 *
 * http://hl7.org/fhir/claim
 */
export const claim = 'http://hl7.org/fhir/claim' satisfies OwlObjectProperty;

/**
 * Flag
 *
 * Prospective warnings of potential issues when providing care to the patient.
 *
 * http://hl7.org/fhir/Flag
 */
export const Flag = 'http://hl7.org/fhir/Flag' satisfies OwlClass;

/**
 * _riskAdjustment
 *
 * (Modified) Measure.riskAdjustment
 *
 * http://hl7.org/fhir/_riskAdjustment
 */
export const _riskAdjustment = 'http://hl7.org/fhir/_riskAdjustment' satisfies OwlObjectProperty;

/**
 * _compareToSourceExpression
 *
 * (Modified) TestScript.test.action.assert.compareToSourceExpression
 *
 * http://hl7.org/fhir/_compareToSourceExpression
 */
export const _compareToSourceExpression = 'http://hl7.org/fhir/_compareToSourceExpression' satisfies OwlObjectProperty;

/**
 * _notificationEvent
 *
 * (Modified) SubscriptionStatus.notificationEvent
 *
 * http://hl7.org/fhir/_notificationEvent
 */
export const _notificationEvent = 'http://hl7.org/fhir/_notificationEvent' satisfies OwlObjectProperty;

/**
 * guideline
 *
 * DeviceDefinition.guideline: Information aimed at providing directions for the usage of this model of device.
 *
 * http://hl7.org/fhir/guideline
 */
export const guideline = 'http://hl7.org/fhir/guideline' satisfies OwlObjectProperty;

/**
 * amount
 *
 * ExplanationOfBenefit.total.amount: Monetary total amount associated with the category.
 *
 * http://hl7.org/fhir/amount
 */
export const amount = 'http://hl7.org/fhir/amount' satisfies OwlObjectProperty;

/**
 * _dateFilter
 *
 * (Modified) DataRequirement.dateFilter
 *
 * http://hl7.org/fhir/_dateFilter
 */
export const _dateFilter = 'http://hl7.org/fhir/_dateFilter' satisfies OwlObjectProperty;

/**
 * _statisticType
 *
 * (Modified) Evidence.statistic.statisticType
 *
 * http://hl7.org/fhir/_statisticType
 */
export const _statisticType = 'http://hl7.org/fhir/_statisticType' satisfies OwlObjectProperty;

/**
 * genus
 *
 * SubstanceSourceMaterial.organism.genus: The genus of an organism shall be specified; refers to the Latin epithet of the genus element of the plant/animal scientific name; it is present in names for genera, species and infraspecies.
 *
 * http://hl7.org/fhir/genus
 */
export const genus = 'http://hl7.org/fhir/genus' satisfies OwlObjectProperty;

/**
 * _MessageHeader
 *
 * (Modified) MessageHeader
 *
 * http://hl7.org/fhir/_MessageHeader
 */
export const _MessageHeader = 'http://hl7.org/fhir/_MessageHeader' satisfies OwlClass;

/**
 * _administrationTreatment
 *
 * (Modified) MedicationKnowledge.indicationGuideline.dosingGuideline.administrationTreatment
 *
 * http://hl7.org/fhir/_administrationTreatment
 */
export const _administrationTreatment = 'http://hl7.org/fhir/_administrationTreatment' satisfies OwlObjectProperty;

/**
 * _country
 *
 * (Modified) MedicinalProductDefinition.name.usage.country
 *
 * http://hl7.org/fhir/_country
 */
export const _country = 'http://hl7.org/fhir/_country' satisfies OwlObjectProperty;

/**
 * insurer
 *
 * Claim.insurer: The Insurer who is target of the request.
 *
 * http://hl7.org/fhir/insurer
 */
export const insurer = 'http://hl7.org/fhir/insurer' satisfies OwlObjectProperty;

/**
 * DeviceDefinitionLinkComponent
 *
 * DeviceDefinitionLinkComponent: An associated device, attached to, used with, communicating with or linking a previous or new device model to the focal device.
 *
 * http://hl7.org/fhir/DeviceDefinitionLinkComponent
 */
export const DeviceDefinitionLinkComponent = 'http://hl7.org/fhir/DeviceDefinitionLinkComponent' satisfies OwlClass;

/**
 * container
 *
 * SpecimenDefinition.typeTested.container: The specimen's container.
 *
 * http://hl7.org/fhir/container
 */
export const container = 'http://hl7.org/fhir/container' satisfies OwlObjectProperty;

/**
 * _params
 *
 * (Modified) TestScript.teardown.action.operation.params
 *
 * http://hl7.org/fhir/_params
 */
export const _params = 'http://hl7.org/fhir/_params' satisfies OwlObjectProperty;

/**
 * Goal
 *
 * Describes the intended objective(s) for a patient, group or organization care, for example, weight loss, restoring an activity of daily living, obtaining herd immunity via immunization, meeting a process improvement objective, etc.
 *
 * http://hl7.org/fhir/Goal
 */
export const Goal = 'http://hl7.org/fhir/Goal' satisfies OwlClass;

/**
 * lockedDate
 *
 * ValueSet.compose.lockedDate: The Locked Date is  the effective date that is used to determine the version of all referenced Code Systems and Value Set Definitions included in the compose that are not already tied to a specific version.
 *
 * http://hl7.org/fhir/lockedDate
 */
export const lockedDate = 'http://hl7.org/fhir/lockedDate' satisfies OwlObjectProperty;

/**
 * symptomConditionEffect
 *
 * ClinicalUseDefinition.undesirableEffect.symptomConditionEffect: The situation in which the undesirable effect may manifest.
 *
 * http://hl7.org/fhir/symptomConditionEffect
 */
export const symptomConditionEffect = 'http://hl7.org/fhir/symptomConditionEffect' satisfies OwlObjectProperty;

/**
 * referenceStrength
 *
 * Ingredient.substance.strength.referenceStrength: Strength expressed in terms of a reference substance. For when the ingredient strength is additionally expressed as equivalent to the strength of some other closely related substance (e.g. salt vs. base). Reference strength represents the strength (quantitative composition) of the active moiety of the active substance. There are situations when the active substance and active moiety are different, therefore both a strength and a reference strength are needed.
 *
 * http://hl7.org/fhir/referenceStrength
 */
export const referenceStrength = 'http://hl7.org/fhir/referenceStrength' satisfies OwlObjectProperty;

/**
 * interval
 *
 * SampledData.interval: Amount of intervalUnits between samples, e.g. milliseconds for time-based sampling.
 *
 * http://hl7.org/fhir/interval
 */
export const interval = 'http://hl7.org/fhir/interval' satisfies OwlObjectProperty;

/**
 * _compartment
 *
 * (Modified) GraphDefinition.link.compartment
 *
 * http://hl7.org/fhir/_compartment
 */
export const _compartment = 'http://hl7.org/fhir/_compartment' satisfies OwlObjectProperty;

/**
 * classifier
 *
 * Citation.classification.classifier: The specific classification value.
 *
 * http://hl7.org/fhir/classifier
 */
export const classifier = 'http://hl7.org/fhir/classifier' satisfies OwlObjectProperty;

/**
 * PackagedProductDefinitionPackagingPropertyComponent
 *
 * PackagedProductDefinitionPackagingComponent.PackagedProductDefinitionPackagingPropertyComponent: General characteristics of this item.
 *
 * http://hl7.org/fhir/PackagedProductDefinitionPackagingPropertyComponent
 */
export const PackagedProductDefinitionPackagingPropertyComponent = 'http://hl7.org/fhir/PackagedProductDefinitionPackagingPropertyComponent' satisfies OwlClass;

/**
 * setup
 *
 * TestScript.setup: A series of required setup operations before tests are executed.
 *
 * http://hl7.org/fhir/setup
 */
export const setup = 'http://hl7.org/fhir/setup' satisfies OwlObjectProperty;

/**
 * _areaOfHybridisation
 *
 * (Modified) SubstanceNucleicAcid.areaOfHybridisation
 *
 * http://hl7.org/fhir/_areaOfHybridisation
 */
export const _areaOfHybridisation = 'http://hl7.org/fhir/_areaOfHybridisation' satisfies OwlObjectProperty;

/**
 * maxLength
 *
 * Questionnaire.item.item.maxLength: The maximum number of characters that are permitted in the answer to be considered a "valid" QuestionnaireResponse.
 *
 * http://hl7.org/fhir/maxLength
 */
export const maxLength = 'http://hl7.org/fhir/maxLength' satisfies OwlObjectProperty;

/**
 * publisherLocation
 *
 * Citation.citedArtifact.publicationForm.publishedIn.publisherLocation: Geographic location of the publisher.
 *
 * http://hl7.org/fhir/publisherLocation
 */
export const publisherLocation = 'http://hl7.org/fhir/publisherLocation' satisfies OwlObjectProperty;

/**
 * RelatedPerson
 *
 * Information about a person that is involved in a patient's health or the care for a patient, but who is not the target of healthcare, nor has a formal responsibility in the care process.
 *
 * http://hl7.org/fhir/RelatedPerson
 */
export const RelatedPerson = 'http://hl7.org/fhir/RelatedPerson' satisfies OwlClass;

/**
 * _storageTempRequirements
 *
 * (Modified) BiologicallyDerivedProduct.storageTempRequirements
 *
 * http://hl7.org/fhir/_storageTempRequirements
 */
export const _storageTempRequirements = 'http://hl7.org/fhir/_storageTempRequirements' satisfies OwlObjectProperty;

/**
 * _Organization
 *
 * (Modified) Organization
 *
 * http://hl7.org/fhir/_Organization
 */
export const _Organization = 'http://hl7.org/fhir/_Organization' satisfies OwlClass;

/**
 * _postConditions
 *
 * (Modified) ExampleScenario.process.step.alternative.step.process.postConditions
 *
 * http://hl7.org/fhir/_postConditions
 */
export const _postConditions = 'http://hl7.org/fhir/_postConditions' satisfies OwlObjectProperty;

/**
 * _DeviceDispense
 *
 * (Modified) DeviceDispense
 *
 * http://hl7.org/fhir/_DeviceDispense
 */
export const _DeviceDispense = 'http://hl7.org/fhir/_DeviceDispense' satisfies OwlClass;

/**
 * state
 *
 * ResearchStudy.progressStatus.state: Label for status or state (e.g. recruitment status).
 *
 * http://hl7.org/fhir/state
 */
export const state = 'http://hl7.org/fhir/state' satisfies OwlObjectProperty;

/**
 * SubstanceDefinitionSourceMaterialComponent
 *
 * SubstanceDefinitionSourceMaterialComponent: Material or taxonomic/anatomical source for the substance.
 *
 * http://hl7.org/fhir/SubstanceDefinitionSourceMaterialComponent
 */
export const SubstanceDefinitionSourceMaterialComponent = 'http://hl7.org/fhir/SubstanceDefinitionSourceMaterialComponent' satisfies OwlClass;

/**
 * _aggregate
 *
 * (Modified) Account.balance.aggregate
 *
 * http://hl7.org/fhir/_aggregate
 */
export const _aggregate = 'http://hl7.org/fhir/_aggregate' satisfies OwlObjectProperty;

/**
 * fluidConsistencyType
 *
 * NutritionOrder.oralDiet.fluidConsistencyType: The required consistency (e.g. honey-thick, nectar-thick, thin, thickened.) of liquids or fluids served to the patient.
 *
 * http://hl7.org/fhir/fluidConsistencyType
 */
export const fluidConsistencyType = 'http://hl7.org/fhir/fluidConsistencyType' satisfies OwlObjectProperty;

/**
 * MoneyQuantity
 *
 * There SHALL be a code if there is a value and it SHALL be an expression of currency.  If system is present, it SHALL be ISO 4217 (system = "urn:iso:std:iso:4217" - currency).
 *
 * http://hl7.org/fhir/MoneyQuantity
 */
export const MoneyQuantity = 'http://hl7.org/fhir/MoneyQuantity' satisfies OwlClass;

/**
 * _specificCost
 *
 * (Modified) InsurancePlan.plan.specificCost
 *
 * http://hl7.org/fhir/_specificCost
 */
export const _specificCost = 'http://hl7.org/fhir/_specificCost' satisfies OwlObjectProperty;

/**
 * _organismId
 *
 * (Modified) SubstanceSourceMaterial.organismId
 *
 * http://hl7.org/fhir/_organismId
 */
export const _organismId = 'http://hl7.org/fhir/_organismId' satisfies OwlObjectProperty;

/**
 * StructureMapGroupInputComponent
 *
 * StructureMapGroupComponent.StructureMapGroupInputComponent: A name assigned to an instance of data. The instance must be provided when the mapping is invoked.
 *
 * http://hl7.org/fhir/StructureMapGroupInputComponent
 */
export const StructureMapGroupInputComponent = 'http://hl7.org/fhir/StructureMapGroupInputComponent' satisfies OwlClass;

/**
 * _check
 *
 * (Modified) StructureMap.group.rule.rule.source.check
 *
 * http://hl7.org/fhir/_check
 */
export const _check = 'http://hl7.org/fhir/_check' satisfies OwlObjectProperty;

/**
 * _chargeItemCode
 *
 * (Modified) DeviceDefinition.chargeItem.chargeItemCode
 *
 * http://hl7.org/fhir/_chargeItemCode
 */
export const _chargeItemCode = 'http://hl7.org/fhir/_chargeItemCode' satisfies OwlObjectProperty;

/**
 * ownedBy
 *
 * InsurancePlan.ownedBy: The entity that is providing  the health insurance product and underwriting the risk.  This is typically an insurance carriers, other third-party payers, or health plan sponsors comonly referred to as 'payers'.
 *
 * http://hl7.org/fhir/ownedBy
 */
export const ownedBy = 'http://hl7.org/fhir/ownedBy' satisfies OwlObjectProperty;

/**
 * _participantStatus
 *
 * (Modified) AppointmentResponse.participantStatus
 *
 * http://hl7.org/fhir/_participantStatus
 */
export const _participantStatus = 'http://hl7.org/fhir/_participantStatus' satisfies OwlObjectProperty;

/**
 * _baseFormulaType
 *
 * (Modified) NutritionOrder.enteralFormula.baseFormulaType
 *
 * http://hl7.org/fhir/_baseFormulaType
 */
export const _baseFormulaType = 'http://hl7.org/fhir/_baseFormulaType' satisfies OwlObjectProperty;

/**
 * shelfLifeStorage
 *
 * PackagedProductDefinition.packaging.packaging.shelfLifeStorage: Shelf Life and storage information.
 *
 * http://hl7.org/fhir/shelfLifeStorage
 */
export const shelfLifeStorage = 'http://hl7.org/fhir/shelfLifeStorage' satisfies OwlObjectProperty;

/**
 * authorizingPrescription
 *
 * MedicationDispense.authorizingPrescription: Indicates the medication order that is being dispensed against.
 *
 * http://hl7.org/fhir/authorizingPrescription
 */
export const authorizingPrescription = 'http://hl7.org/fhir/authorizingPrescription' satisfies OwlObjectProperty;

/**
 * protein
 *
 * SubstanceDefinition.protein: Data items specific to proteins.
 *
 * http://hl7.org/fhir/protein
 */
export const protein = 'http://hl7.org/fhir/protein' satisfies OwlObjectProperty;

/**
 * connectivity
 *
 * SubstanceNucleicAcid.subunit.linkage.connectivity: The entity that links the sugar residues together should also be captured for nearly all naturally occurring nucleic acid the linkage is a phosphate group. For many synthetic oligonucleotides phosphorothioate linkages are often seen. Linkage connectivity is assumed to be 3’-5’. If the linkage is either 3’-3’ or 5’-5’ this should be specified.
 *
 * http://hl7.org/fhir/connectivity
 */
export const connectivity = 'http://hl7.org/fhir/connectivity' satisfies OwlObjectProperty;

/**
 * information
 *
 * CoverageEligibilityRequest.supportingInfo.information: Additional data or information such as resources, documents, images etc. including references to the data or the actual inclusion of the data.
 *
 * http://hl7.org/fhir/information
 */
export const information = 'http://hl7.org/fhir/information' satisfies OwlObjectProperty;

/**
 * DeviceDefinitionVersionComponent
 *
 * DeviceDefinitionVersionComponent: The version of the device or software.
 *
 * http://hl7.org/fhir/DeviceDefinitionVersionComponent
 */
export const DeviceDefinitionVersionComponent = 'http://hl7.org/fhir/DeviceDefinitionVersionComponent' satisfies OwlClass;

/**
 * AdverseEvent
 *
 * An event (i.e. any change to current patient status) that may be related to unintended effects on a patient or research participant. The unintended effects may require additional monitoring, treatment, hospitalization, or may result in death. The AdverseEvent resource also extends to potential or avoided events that could have had such effects. There are two major domains where the AdverseEvent resource is expected to be used. One is in clinical care reported adverse events and the other is in reporting adverse events in clinical  research trial management.  Adverse events can be reported by healthcare providers, patients, caregivers or by medical products manufacturers.  Given the differences between these two concepts, we recommend consulting the domain specific implementation guides when implementing the AdverseEvent Resource. The implementation guides include specific extensions, value sets and constraints.
 *
 * http://hl7.org/fhir/AdverseEvent
 */
export const AdverseEvent = 'http://hl7.org/fhir/AdverseEvent' satisfies OwlClass;

/**
 * _originRelationshipType
 *
 * (Modified) BiologicallyDerivedProductDispense.originRelationshipType
 *
 * http://hl7.org/fhir/_originRelationshipType
 */
export const _originRelationshipType = 'http://hl7.org/fhir/_originRelationshipType' satisfies OwlObjectProperty;

/**
 * definitionExpression
 *
 * EvidenceVariable.characteristic.definitionByCombination.characteristic.definitionExpression: Defines the characteristic using Expression.
 *
 * http://hl7.org/fhir/definitionExpression
 */
export const definitionExpression = 'http://hl7.org/fhir/definitionExpression' satisfies OwlObjectProperty;

/**
 * ServiceRequestOrderDetailParameterComponent
 *
 * ServiceRequestOrderDetailComponent.ServiceRequestOrderDetailParameterComponent: The parameter details for the service being requested.
 *
 * http://hl7.org/fhir/ServiceRequestOrderDetailParameterComponent
 */
export const ServiceRequestOrderDetailParameterComponent = 'http://hl7.org/fhir/ServiceRequestOrderDetailParameterComponent' satisfies OwlClass;

/**
 * TestPlan
 *
 * A plan for executing testing on an artifact or specifications
 *
 * http://hl7.org/fhir/TestPlan
 */
export const TestPlan = 'http://hl7.org/fhir/TestPlan' satisfies OwlClass;

/**
 * requestProvider
 *
 * EnrollmentResponse.requestProvider: The practitioner who is responsible for the services rendered to the patient.
 *
 * http://hl7.org/fhir/requestProvider
 */
export const requestProvider = 'http://hl7.org/fhir/requestProvider' satisfies OwlObjectProperty;

/**
 * _formatted
 *
 * (Modified) MolecularSequence.formatted
 *
 * http://hl7.org/fhir/_formatted
 */
export const _formatted = 'http://hl7.org/fhir/_formatted' satisfies OwlObjectProperty;

/**
 * NutritionProduct
 *
 * A food or supplement that is consumed by patients.
 *
 * http://hl7.org/fhir/NutritionProduct
 */
export const NutritionProduct = 'http://hl7.org/fhir/NutritionProduct' satisfies OwlClass;

/**
 * ActorDefinition
 *
 * The ActorDefinition resource is used to describe an actor - a human or an application that plays a role in data exchange, and that may have obligations associated with the role the actor plays.
 *
 * http://hl7.org/fhir/ActorDefinition
 */
export const ActorDefinition = 'http://hl7.org/fhir/ActorDefinition' satisfies OwlClass;

/**
 * RegulatedAuthorization
 *
 * Regulatory approval, clearance or licencing related to a regulated product, treatment, facility or activity that is cited in a guidance, regulation, rule or legislative act. An example is Market Authorization relating to a Medicinal Product.
 *
 * http://hl7.org/fhir/RegulatedAuthorization
 */
export const RegulatedAuthorization = 'http://hl7.org/fhir/RegulatedAuthorization' satisfies OwlClass;

/**
 * _facility
 *
 * (Modified) ExplanationOfBenefit.facility
 *
 * http://hl7.org/fhir/_facility
 */
export const _facility = 'http://hl7.org/fhir/_facility' satisfies OwlObjectProperty;

/**
 * sourceDocument
 *
 * SubstanceDefinition.structure.sourceDocument: The source of information about the structure.
 *
 * http://hl7.org/fhir/sourceDocument
 */
export const sourceDocument = 'http://hl7.org/fhir/sourceDocument' satisfies OwlObjectProperty;

/**
 * _morphology
 *
 * (Modified) BodyStructure.morphology
 *
 * http://hl7.org/fhir/_morphology
 */
export const _morphology = 'http://hl7.org/fhir/_morphology' satisfies OwlObjectProperty;

/**
 * _kind
 *
 * (Modified) Coverage.kind
 *
 * http://hl7.org/fhir/_kind
 */
export const _kind = 'http://hl7.org/fhir/_kind' satisfies OwlObjectProperty;

/**
 * color
 *
 * VisionPrescription.lensSpecification.color: Special color or pattern.
 *
 * http://hl7.org/fhir/color
 */
export const color = 'http://hl7.org/fhir/color' satisfies OwlObjectProperty;

/**
 * _bounds
 *
 * (Modified) Timing.repeat.bounds
 *
 * http://hl7.org/fhir/_bounds
 */
export const _bounds = 'http://hl7.org/fhir/_bounds' satisfies OwlObjectProperty;

/**
 * snapshot
 *
 * StructureDefinition.snapshot: A snapshot view is expressed in a standalone form that can be used and interpreted without considering the base StructureDefinition.
 *
 * http://hl7.org/fhir/snapshot
 */
export const snapshot = 'http://hl7.org/fhir/snapshot' satisfies OwlObjectProperty;

/**
 * SpecimenContainerComponent
 *
 * SpecimenContainerComponent: The container holding the specimen.  The recursive nature of containers; i.e. blood in tube in tray in rack is not addressed here.
 *
 * http://hl7.org/fhir/SpecimenContainerComponent
 */
export const SpecimenContainerComponent = 'http://hl7.org/fhir/SpecimenContainerComponent' satisfies OwlClass;

/**
 * unsignedInt
 *
 * An integer with a value that is not negative (e.g. >= 0)
 *
 * http://hl7.org/fhir/unsignedInt
 */
export const unsignedInt = 'http://hl7.org/fhir/unsignedInt' satisfies OwlClass;

/**
 * MedicationKnowledgeMedicineClassificationComponent
 *
 * MedicationKnowledgeMedicineClassificationComponent: Categorization of the medication within a formulary or classification system.
 *
 * http://hl7.org/fhir/MedicationKnowledgeMedicineClassificationComponent
 */
export const MedicationKnowledgeMedicineClassificationComponent = 'http://hl7.org/fhir/MedicationKnowledgeMedicineClassificationComponent' satisfies OwlClass;

/**
 * ImmunizationProgramEligibilityComponent
 *
 * ImmunizationProgramEligibilityComponent: Indicates a patient's eligibility for a funding program.
 *
 * http://hl7.org/fhir/ImmunizationProgramEligibilityComponent
 */
export const ImmunizationProgramEligibilityComponent = 'http://hl7.org/fhir/ImmunizationProgramEligibilityComponent' satisfies OwlClass;

/**
 * _dose
 *
 * (Modified) MedicationAdministration.dosage.dose
 *
 * http://hl7.org/fhir/_dose
 */
export const _dose = 'http://hl7.org/fhir/_dose' satisfies OwlObjectProperty;

/**
 * useBy
 *
 * NutritionProduct.instance.useBy: The time after which the product is no longer expected to be in proper condition, or its use is not advised or not allowed.
 *
 * http://hl7.org/fhir/useBy
 */
export const useBy = 'http://hl7.org/fhir/useBy' satisfies OwlObjectProperty;

/**
 * _start
 *
 * (Modified) Period.start
 *
 * http://hl7.org/fhir/_start
 */
export const _start = 'http://hl7.org/fhir/_start' satisfies OwlObjectProperty;

/**
 * _import
 *
 * (Modified) StructureMap.import
 *
 * http://hl7.org/fhir/_import
 */
export const _import = 'http://hl7.org/fhir/_import' satisfies OwlObjectProperty;

/**
 * TaskPerformerComponent
 *
 * TaskPerformerComponent: The entity who performed the requested task.
 *
 * http://hl7.org/fhir/TaskPerformerComponent
 */
export const TaskPerformerComponent = 'http://hl7.org/fhir/TaskPerformerComponent' satisfies OwlClass;

/**
 * grantor
 *
 * Consent.grantor: The entity responsible for granting the rights listed in a Consent Directive.
 *
 * http://hl7.org/fhir/grantor
 */
export const grantor = 'http://hl7.org/fhir/grantor' satisfies OwlObjectProperty;

/**
 * _purpose
 *
 * (Modified) CanonicalResource.purpose
 *
 * http://hl7.org/fhir/_purpose
 */
export const _purpose = 'http://hl7.org/fhir/_purpose' satisfies OwlObjectProperty;

/**
 * benefit
 *
 * InsurancePlan.plan.specificCost.benefit: List of the specific benefits under this category of benefit.
 *
 * http://hl7.org/fhir/benefit
 */
export const benefit = 'http://hl7.org/fhir/benefit' satisfies OwlObjectProperty;

/**
 * contributorship
 *
 * Citation.citedArtifact.contributorship: This element is used to list authors and other contributors, their contact information, specific contributions, and summary statements.
 *
 * http://hl7.org/fhir/contributorship
 */
export const contributorship = 'http://hl7.org/fhir/contributorship' satisfies OwlObjectProperty;

/**
 * PlanDefinitionActionDynamicValueComponent
 *
 * PlanDefinitionActionComponent.PlanDefinitionActionDynamicValueComponent: Customizations that should be applied to the statically defined resource. For example, if the dosage of a medication must be computed based on the patient's weight, a customization would be used to specify an expression that calculated the weight, and the path on the resource that would contain the result.
 *
 * http://hl7.org/fhir/PlanDefinitionActionDynamicValueComponent
 */
export const PlanDefinitionActionDynamicValueComponent = 'http://hl7.org/fhir/PlanDefinitionActionDynamicValueComponent' satisfies OwlClass;

/**
 * ImagingStudySeriesComponent
 *
 * ImagingStudySeriesComponent: Each study has one or more series of images or other content.
 *
 * http://hl7.org/fhir/ImagingStudySeriesComponent
 */
export const ImagingStudySeriesComponent = 'http://hl7.org/fhir/ImagingStudySeriesComponent' satisfies OwlClass;

/**
 * programStatus
 *
 * Immunization.programEligibility.programStatus: Indicates the patient's eligility status for for a specific payment program.
 *
 * http://hl7.org/fhir/programStatus
 */
export const programStatus = 'http://hl7.org/fhir/programStatus' satisfies OwlObjectProperty;

/**
 * _evidence
 *
 * (Modified) Permission.justification.evidence
 *
 * http://hl7.org/fhir/_evidence
 */
export const _evidence = 'http://hl7.org/fhir/_evidence' satisfies OwlObjectProperty;

/**
 * ClinicalUseDefinitionInteractionInteractantComponent
 *
 * ClinicalUseDefinitionInteractionComponent.ClinicalUseDefinitionInteractionInteractantComponent: The specific medication, product, food, substance etc. or laboratory test that interacts.
 *
 * http://hl7.org/fhir/ClinicalUseDefinitionInteractionInteractantComponent
 */
export const ClinicalUseDefinitionInteractionInteractantComponent = 'http://hl7.org/fhir/ClinicalUseDefinitionInteractionInteractantComponent' satisfies OwlClass;

/**
 * _highNumerator
 *
 * (Modified) RatioRange.highNumerator
 *
 * http://hl7.org/fhir/_highNumerator
 */
export const _highNumerator = 'http://hl7.org/fhir/_highNumerator' satisfies OwlObjectProperty;

/**
 * ChargeItemDefinitionPropertyGroupComponent
 *
 * ChargeItemDefinitionPropertyGroupComponent: Group of properties which are applicable under the same conditions. If no applicability rules are established for the group, then all properties always apply.
 *
 * http://hl7.org/fhir/ChargeItemDefinitionPropertyGroupComponent
 */
export const ChargeItemDefinitionPropertyGroupComponent = 'http://hl7.org/fhir/ChargeItemDefinitionPropertyGroupComponent' satisfies OwlClass;

/**
 * boolean
 *
 * Value of "true" or "false"
 *
 * http://hl7.org/fhir/boolean
 */
export const boolean = 'http://hl7.org/fhir/boolean' satisfies OwlClass;

/**
 * PackagedProductDefinitionProperty
 *
 * Allows the key features to be recorded, such as "hospital pack", "nurse prescribable", "calendar pack".
 *
 * http://hl7.org/fhir/PackagedProductDefinitionProperty
 */
export const PackagedProductDefinitionProperty = 'http://hl7.org/fhir/PackagedProductDefinitionProperty' satisfies OwlClass;

/**
 * _Group
 *
 * (Modified) Group
 *
 * http://hl7.org/fhir/_Group
 */
export const _Group = 'http://hl7.org/fhir/_Group' satisfies OwlClass;

/**
 * _media
 *
 * (Modified) DiagnosticReport.media
 *
 * http://hl7.org/fhir/_media
 */
export const _media = 'http://hl7.org/fhir/_media' satisfies OwlObjectProperty;

/**
 * hasStage
 *
 * ConditionDefinition.hasStage: Whether stage is appropriate to collect for this condition.
 *
 * http://hl7.org/fhir/hasStage
 */
export const hasStage = 'http://hl7.org/fhir/hasStage' satisfies OwlObjectProperty;

/**
 * TestReportSetupActionAssertRequirementComponent
 *
 * TestReportTestComponent.TestActionAssert.TestReportSetupActionAssertRequirementComponent: Links or references providing traceability to the testing requirements for this assert.
 *
 * http://hl7.org/fhir/TestReportSetupActionAssertRequirementComponent
 */
export const TestReportSetupActionAssertRequirementComponent = 'http://hl7.org/fhir/TestReportSetupActionAssertRequirementComponent' satisfies OwlClass;

/**
 * _onBehalfOf
 *
 * (Modified) VerificationResult.attestation.onBehalfOf
 *
 * http://hl7.org/fhir/_onBehalfOf
 */
export const _onBehalfOf = 'http://hl7.org/fhir/_onBehalfOf' satisfies OwlObjectProperty;

/**
 * SubstanceReferenceInformationGeneElementComponent
 *
 * SubstanceReferenceInformationGeneElementComponent: Todo.
 *
 * http://hl7.org/fhir/SubstanceReferenceInformationGeneElementComponent
 */
export const SubstanceReferenceInformationGeneElementComponent = 'http://hl7.org/fhir/SubstanceReferenceInformationGeneElementComponent' satisfies OwlClass;

/**
 * maxCount
 *
 * Subscription.maxCount: If present, the maximum number of events that will be included in a notification bundle. Note that this is not a strict limit on the number of entries in a bundle, as dependent resources can be included.
 *
 * http://hl7.org/fhir/maxCount
 */
export const maxCount = 'http://hl7.org/fhir/maxCount' satisfies OwlObjectProperty;

/**
 * enableWhen
 *
 * Questionnaire.item.item.enableWhen: A constraint indicating that this item should only be enabled (displayed/allow answers to be captured) when the specified condition is true.
 *
 * http://hl7.org/fhir/enableWhen
 */
export const enableWhen = 'http://hl7.org/fhir/enableWhen' satisfies OwlObjectProperty;

/**
 * regulator
 *
 * RegulatedAuthorization.regulator: The regulatory authority or authorizing body granting the authorization. For example, European Medicines Agency (EMA), Food and Drug Administration (FDA), Health Canada (HC), etc.
 *
 * http://hl7.org/fhir/regulator
 */
export const regulator = 'http://hl7.org/fhir/regulator' satisfies OwlObjectProperty;

/**
 * _medicineClassification
 *
 * (Modified) MedicationKnowledge.medicineClassification
 *
 * http://hl7.org/fhir/_medicineClassification
 */
export const _medicineClassification = 'http://hl7.org/fhir/_medicineClassification' satisfies OwlObjectProperty;

/**
 * imageRegion3D
 *
 * ImagingSelection.instance.imageRegion3D: Each imaging selection might includes a 3D image region, specified by a region type and a set of 3D coordinates.
 *
 * http://hl7.org/fhir/imageRegion3D
 */
export const imageRegion3D = 'http://hl7.org/fhir/imageRegion3D' satisfies OwlObjectProperty;

/**
 * _source
 *
 * (Modified) SubstanceDefinition.name.translation.source
 *
 * http://hl7.org/fhir/_source
 */
export const _source = 'http://hl7.org/fhir/_source' satisfies OwlObjectProperty;

/**
 * _hoursOfOperation
 *
 * (Modified) Location.hoursOfOperation
 *
 * http://hl7.org/fhir/_hoursOfOperation
 */
export const _hoursOfOperation = 'http://hl7.org/fhir/_hoursOfOperation' satisfies OwlObjectProperty;

/**
 * admission
 *
 * Encounter.admission: Details about the stay during which a healthcare service is provided.

This does not describe the event of admitting the patient, but rather any information that is relevant from the time of admittance until the time of discharge.
 *
 * http://hl7.org/fhir/admission
 */
export const admission = 'http://hl7.org/fhir/admission' satisfies OwlObjectProperty;

/**
 * extension
 *
 * DomainResource.extension: May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and managable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.
 *
 * http://hl7.org/fhir/extension
 */
export const extension = 'http://hl7.org/fhir/extension' satisfies OwlObjectProperty;

/**
 * _reAdmission
 *
 * (Modified) Encounter.admission.reAdmission
 *
 * http://hl7.org/fhir/_reAdmission
 */
export const _reAdmission = 'http://hl7.org/fhir/_reAdmission' satisfies OwlObjectProperty;

/**
 * integer64
 *
 * A very large whole number
 *
 * http://hl7.org/fhir/integer64
 */
export const integer64 = 'http://hl7.org/fhir/integer64' satisfies OwlClass;

/**
 * _Task
 *
 * (Modified) Task
 *
 * http://hl7.org/fhir/_Task
 */
export const _Task = 'http://hl7.org/fhir/_Task' satisfies OwlClass;

/**
 * HealthcareService
 *
 * The details of a healthcare service available at a location or in a catalog.  In the case where there is a hierarchy of services (for example, Lab -> Pathology -> Wound Cultures), this can be represented using a set of linked HealthcareServices.
 *
 * http://hl7.org/fhir/HealthcareService
 */
export const HealthcareService = 'http://hl7.org/fhir/HealthcareService' satisfies OwlClass;

/**
 * _Appointment
 *
 * (Modified) Appointment
 *
 * http://hl7.org/fhir/_Appointment
 */
export const _Appointment = 'http://hl7.org/fhir/_Appointment' satisfies OwlClass;

/**
 * _crossReference
 *
 * (Modified) MedicinalProductDefinition.crossReference
 *
 * http://hl7.org/fhir/_crossReference
 */
export const _crossReference = 'http://hl7.org/fhir/_crossReference' satisfies OwlObjectProperty;

/**
 * _hasPart
 *
 * (Modified) DeviceDefinition.hasPart
 *
 * http://hl7.org/fhir/_hasPart
 */
export const _hasPart = 'http://hl7.org/fhir/_hasPart' satisfies OwlObjectProperty;

/**
 * _executionPeriod
 *
 * (Modified) Task.executionPeriod
 *
 * http://hl7.org/fhir/_executionPeriod
 */
export const _executionPeriod = 'http://hl7.org/fhir/_executionPeriod' satisfies OwlObjectProperty;

/**
 * Expression
 *
 * A expression that is evaluated in a specified context and returns a value. The context of use of the expression must specify the context in which the expression is evaluated, and how the result of the expression is used.
 *
 * http://hl7.org/fhir/Expression
 */
export const Expression = 'http://hl7.org/fhir/Expression' satisfies OwlClass;

/**
 * Class
 *
 * Coverage.Class: A suite of underwriter specific classifiers.
 *
 * http://hl7.org/fhir/Class
 */
export const Class = 'http://hl7.org/fhir/Class' satisfies OwlClass;

/**
 * _operation
 *
 * (Modified) TestScript.test.action.operation
 *
 * http://hl7.org/fhir/_operation
 */
export const _operation = 'http://hl7.org/fhir/_operation' satisfies OwlObjectProperty;

/**
 * _adjustmentReason
 *
 * (Modified) ExplanationOfBenefit.payment.adjustmentReason
 *
 * http://hl7.org/fhir/_adjustmentReason
 */
export const _adjustmentReason = 'http://hl7.org/fhir/_adjustmentReason' satisfies OwlObjectProperty;

/**
 * notConsumed
 *
 * NutritionIntake.consumedItem.notConsumed: Indicator when a patient is in a setting where it is helpful to know if food was not consumed, such as it was refused, held (as in tube feedings), or otherwise not provided. If a consumption is being recorded from an app, such as MyFitnessPal, this indicator will likely not be used.
 *
 * http://hl7.org/fhir/notConsumed
 */
export const notConsumed = 'http://hl7.org/fhir/notConsumed' satisfies OwlObjectProperty;

/**
 * relativePath
 *
 * ImplementationGuide.manifest.resource.relativePath: The relative path for primary page for this resource within the IG.
 *
 * http://hl7.org/fhir/relativePath
 */
export const relativePath = 'http://hl7.org/fhir/relativePath' satisfies OwlObjectProperty;

/**
 * ImplementationGuideDefinitionComponent
 *
 * ImplementationGuideDefinitionComponent: The information needed by an IG publisher tool to publish the whole implementation guide.
 *
 * http://hl7.org/fhir/ImplementationGuideDefinitionComponent
 */
export const ImplementationGuideDefinitionComponent = 'http://hl7.org/fhir/ImplementationGuideDefinitionComponent' satisfies OwlClass;

/**
 * geneSequenceOrigin
 *
 * SubstanceReferenceInformation.gene.geneSequenceOrigin: Todo.
 *
 * http://hl7.org/fhir/geneSequenceOrigin
 */
export const geneSequenceOrigin = 'http://hl7.org/fhir/geneSequenceOrigin' satisfies OwlObjectProperty;

/**
 * level
 *
 * Evidence.statistic.modelCharacteristic.attributeEstimate.level: Use 95 for a 95% confidence interval.
 *
 * http://hl7.org/fhir/level
 */
export const level = 'http://hl7.org/fhir/level' satisfies OwlObjectProperty;

/**
 * TestReportTestComponent
 *
 * TestReportTestComponent: A test executed from the test script.
 *
 * http://hl7.org/fhir/TestReportTestComponent
 */
export const TestReportTestComponent = 'http://hl7.org/fhir/TestReportTestComponent' satisfies OwlClass;

/**
 * doseNumber
 *
 * ImmunizationRecommendation.recommendation.doseNumber: Nominal position of the recommended dose in a series as determined by the evaluation and forecasting process (e.g. dose 2 is the next recommended dose).
 *
 * http://hl7.org/fhir/doseNumber
 */
export const doseNumber = 'http://hl7.org/fhir/doseNumber' satisfies OwlObjectProperty;

/**
 * ParametersParameterComponentParameterParameter
 *
 * A named part of a multi-part parameter.
 *
 * http://hl7.org/fhir/ParametersParameterComponentParameterParameter
 */
export const ParametersParameterComponentParameterParameter = 'http://hl7.org/fhir/ParametersParameterComponentParameterParameter' satisfies OwlClass;

/**
 * age
 *
 * FamilyMemberHistory.age
 *
 * http://hl7.org/fhir/age
 */
export const age = 'http://hl7.org/fhir/age' satisfies OwlObjectProperty;

/**
 * _payload
 *
 * (Modified) Endpoint.payload
 *
 * http://hl7.org/fhir/_payload
 */
export const _payload = 'http://hl7.org/fhir/_payload' satisfies OwlObjectProperty;

/**
 * entityRelatedness
 *
 * AdverseEvent.suspectEntity.causality.entityRelatedness: The result of the assessment regarding the relatedness of the suspected entity to the event.
 *
 * http://hl7.org/fhir/entityRelatedness
 */
export const entityRelatedness = 'http://hl7.org/fhir/entityRelatedness' satisfies OwlObjectProperty;

/**
 * startParam
 *
 * CompartmentDefinition.resource.startParam: Search Parameter for mapping requests made with $everything.start (e.g. on [Patient.$everything](patient-operation-everything.html)).
 *
 * http://hl7.org/fhir/startParam
 */
export const startParam = 'http://hl7.org/fhir/startParam' satisfies OwlObjectProperty;

/**
 * _intraspecificDescription
 *
 * (Modified) SubstanceSourceMaterial.organism.intraspecificDescription
 *
 * http://hl7.org/fhir/_intraspecificDescription
 */
export const _intraspecificDescription = 'http://hl7.org/fhir/_intraspecificDescription' satisfies OwlObjectProperty;

/**
 * _clinicalStatus
 *
 * (Modified) Condition.clinicalStatus
 *
 * http://hl7.org/fhir/_clinicalStatus
 */
export const _clinicalStatus = 'http://hl7.org/fhir/_clinicalStatus' satisfies OwlObjectProperty;

/**
 * _compositeScoring
 *
 * (Modified) Measure.compositeScoring
 *
 * http://hl7.org/fhir/_compositeScoring
 */
export const _compositeScoring = 'http://hl7.org/fhir/_compositeScoring' satisfies OwlObjectProperty;

/**
 * jurisdiction
 *
 * SubstanceDefinition.name.synonym.jurisdiction: The jurisdiction where this name applies.
 *
 * http://hl7.org/fhir/jurisdiction
 */
export const jurisdiction = 'http://hl7.org/fhir/jurisdiction' satisfies OwlObjectProperty;

/**
 * Exemption
 *
 * Coverage.CostToBeneficiary.Exemption: A suite of codes indicating exceptions or reductions to patient costs and their effective periods.
 *
 * http://hl7.org/fhir/Exemption
 */
export const Exemption = 'http://hl7.org/fhir/Exemption' satisfies OwlClass;

/**
 * _requestHeader
 *
 * (Modified) TestScript.teardown.action.operation.requestHeader
 *
 * http://hl7.org/fhir/_requestHeader
 */
export const _requestHeader = 'http://hl7.org/fhir/_requestHeader' satisfies OwlObjectProperty;

/**
 * _certainty
 *
 * (Modified) Evidence.certainty
 *
 * http://hl7.org/fhir/_certainty
 */
export const _certainty = 'http://hl7.org/fhir/_certainty' satisfies OwlObjectProperty;

/**
 * connectionType
 *
 * Endpoint.connectionType: A coded value that represents the technical details of the usage of this endpoint, such as what WSDLs should be used in what way. (e.g. XDS.b/DICOM/cds-hook).
 *
 * http://hl7.org/fhir/connectionType
 */
export const connectionType = 'http://hl7.org/fhir/connectionType' satisfies OwlObjectProperty;

/**
 * _groupingBehavior
 *
 * (Modified) RequestOrchestration.action.action.groupingBehavior
 *
 * http://hl7.org/fhir/_groupingBehavior
 */
export const _groupingBehavior = 'http://hl7.org/fhir/_groupingBehavior' satisfies OwlObjectProperty;

/**
 * _translations
 *
 * (Modified) TerminologyCapabilities.validateCode.translations
 *
 * http://hl7.org/fhir/_translations
 */
export const _translations = 'http://hl7.org/fhir/_translations' satisfies OwlObjectProperty;

/**
 * photo
 *
 * Person.photo: An image that can be displayed as a thumbnail of the person to enhance the identification of the individual.
 *
 * http://hl7.org/fhir/photo
 */
export const photo = 'http://hl7.org/fhir/photo' satisfies OwlObjectProperty;

/**
 * multipleAnd
 *
 * SearchParameter.multipleAnd: Whether multiple parameters are allowed - e.g. more than one parameter with the same name. The search matches if all the parameters match.
 *
 * http://hl7.org/fhir/multipleAnd
 */
export const multipleAnd = 'http://hl7.org/fhir/multipleAnd' satisfies OwlObjectProperty;

/**
 * _gender
 *
 * (Modified) RelatedPerson.gender
 *
 * http://hl7.org/fhir/_gender
 */
export const _gender = 'http://hl7.org/fhir/_gender' satisfies OwlObjectProperty;

/**
 * _coding
 *
 * (Modified) CodeableConcept.coding
 *
 * http://hl7.org/fhir/_coding
 */
export const _coding = 'http://hl7.org/fhir/_coding' satisfies OwlObjectProperty;

/**
 * _system
 *
 * (Modified) Coding.system
 *
 * http://hl7.org/fhir/_system
 */
export const _system = 'http://hl7.org/fhir/_system' satisfies OwlObjectProperty;

/**
 * _Slot
 *
 * (Modified) Slot
 *
 * http://hl7.org/fhir/_Slot
 */
export const _Slot = 'http://hl7.org/fhir/_Slot' satisfies OwlClass;

/**
 * freeToShare
 *
 * ArtifactAssessment.content.component.freeToShare: Acceptable to publicly share the comment, classifier or rating.
 *
 * http://hl7.org/fhir/freeToShare
 */
export const freeToShare = 'http://hl7.org/fhir/freeToShare' satisfies OwlObjectProperty;

/**
 * ElementDefinitionMappingComponent
 *
 * ElementDefinitionMappingComponent: Identifies a concept from an external specification that roughly corresponds to this element.
 *
 * http://hl7.org/fhir/ElementDefinitionMappingComponent
 */
export const ElementDefinitionMappingComponent = 'http://hl7.org/fhir/ElementDefinitionMappingComponent' satisfies OwlClass;

/**
 * copackagedIndicator
 *
 * PackagedProductDefinition.copackagedIndicator: Identifies if the package contains different items, such as when a drug product is supplied with another item e.g. a diluent or adjuvant.
 *
 * http://hl7.org/fhir/copackagedIndicator
 */
export const copackagedIndicator = 'http://hl7.org/fhir/copackagedIndicator' satisfies OwlObjectProperty;

/**
 * precheckBehavior
 *
 * RequestOrchestration.action.action.precheckBehavior: Defines whether the action should usually be preselected.
 *
 * http://hl7.org/fhir/precheckBehavior
 */
export const precheckBehavior = 'http://hl7.org/fhir/precheckBehavior' satisfies OwlObjectProperty;

/**
 * map
 *
 * ElementDefinition.mapping.map: Expresses what part of the target specification corresponds to this element.
 *
 * http://hl7.org/fhir/map
 */
export const map = 'http://hl7.org/fhir/map' satisfies OwlObjectProperty;

/**
 * additionalInfo
 *
 * VirtualServiceDetail.additionalInfo: Address to see alternative connection details.
 *
 * http://hl7.org/fhir/additionalInfo
 */
export const additionalInfo = 'http://hl7.org/fhir/additionalInfo' satisfies OwlObjectProperty;

/**
 * preConditions
 *
 * ExampleScenario.process.step.alternative.step.process.preConditions: Description of the initial state of the actors, environment and data before the process starts.
 *
 * http://hl7.org/fhir/preConditions
 */
export const preConditions = 'http://hl7.org/fhir/preConditions' satisfies OwlObjectProperty;

/**
 * numberOfSubunits
 *
 * SubstanceProtein.numberOfSubunits: Number of linear sequences of amino acids linked through peptide bonds. The number of subunits constituting the SubstanceProtein shall be described. It is possible that the number of subunits can be variable.
 *
 * http://hl7.org/fhir/numberOfSubunits
 */
export const numberOfSubunits = 'http://hl7.org/fhir/numberOfSubunits' satisfies OwlObjectProperty;

/**
 * numberOfEvents
 *
 * Evidence.statistic.numberOfEvents: The number of events associated with the statistic, where the unit of analysis is different from numberAffected, sampleSize.knownDataCount and sampleSize.numberOfParticipants.
 *
 * http://hl7.org/fhir/numberOfEvents
 */
export const numberOfEvents = 'http://hl7.org/fhir/numberOfEvents' satisfies OwlObjectProperty;

/**
 * _sender
 *
 * (Modified) MessageHeader.sender
 *
 * http://hl7.org/fhir/_sender
 */
export const _sender = 'http://hl7.org/fhir/_sender' satisfies OwlObjectProperty;

/**
 * _validCodedValueSet
 *
 * (Modified) ObservationDefinition.component.qualifiedValue.validCodedValueSet
 *
 * http://hl7.org/fhir/_validCodedValueSet
 */
export const _validCodedValueSet = 'http://hl7.org/fhir/_validCodedValueSet' satisfies OwlObjectProperty;

/**
 * _referenceInformation
 *
 * (Modified) SubstanceDefinition.referenceInformation
 *
 * http://hl7.org/fhir/_referenceInformation
 */
export const _referenceInformation = 'http://hl7.org/fhir/_referenceInformation' satisfies OwlObjectProperty;

/**
 * longitude
 *
 * Location.position.longitude: Longitude. The value domain and the interpretation are the same as for the text of the longitude element in KML (see notes on Location main page).
 *
 * http://hl7.org/fhir/longitude
 */
export const longitude = 'http://hl7.org/fhir/longitude' satisfies OwlObjectProperty;

/**
 * _contentDerivative
 *
 * (Modified) Contract.contentDerivative
 *
 * http://hl7.org/fhir/_contentDerivative
 */
export const _contentDerivative = 'http://hl7.org/fhir/_contentDerivative' satisfies OwlObjectProperty;

/**
 * _reportedDateTime
 *
 * (Modified) InventoryReport.reportedDateTime
 *
 * http://hl7.org/fhir/_reportedDateTime
 */
export const _reportedDateTime = 'http://hl7.org/fhir/_reportedDateTime' satisfies OwlObjectProperty;

/**
 * Primitive
 *
 * Types with only a value and no additional elements as children
 *
 * http://hl7.org/fhir/Primitive
 */
export const Primitive = 'http://hl7.org/fhir/Primitive' satisfies OwlClass;

/**
 * _processingMode
 *
 * (Modified) SearchParameter.processingMode
 *
 * http://hl7.org/fhir/_processingMode
 */
export const _processingMode = 'http://hl7.org/fhir/_processingMode' satisfies OwlObjectProperty;

/**
 * _composition
 *
 * (Modified) DiagnosticReport.composition
 *
 * http://hl7.org/fhir/_composition
 */
export const _composition = 'http://hl7.org/fhir/_composition' satisfies OwlObjectProperty;

/**
 * _width
 *
 * (Modified) Attachment.width
 *
 * http://hl7.org/fhir/_width
 */
export const _width = 'http://hl7.org/fhir/_width' satisfies OwlObjectProperty;

/**
 * _valueAlternatives
 *
 * (Modified) ElementDefinition.valueAlternatives
 *
 * http://hl7.org/fhir/_valueAlternatives
 */
export const _valueAlternatives = 'http://hl7.org/fhir/_valueAlternatives' satisfies OwlObjectProperty;

/**
 * hint
 *
 * TestScript.variable.hint: Displayable text string with hint help information to the user when entering a default value.
 *
 * http://hl7.org/fhir/hint
 */
export const hint = 'http://hl7.org/fhir/hint' satisfies OwlObjectProperty;

/**
 * license
 *
 * ImplementationGuide.license: The license that applies to this Implementation Guide, using an SPDX license code, or 'not-open-source'.
 *
 * http://hl7.org/fhir/license
 */
export const license = 'http://hl7.org/fhir/license' satisfies OwlObjectProperty;

/**
 * created
 *
 * ExplanationOfBenefit.created: The date this resource was created.
 *
 * http://hl7.org/fhir/created
 */
export const created = 'http://hl7.org/fhir/created' satisfies OwlObjectProperty;

/**
 * expectedInResearchStudy
 *
 * AdverseEvent.expectedInResearchStudy: Considered likely or probable or anticipated in the research study.  Whether the reported event matches any of the outcomes for the patient that are considered by the study as known or likely.
 *
 * http://hl7.org/fhir/expectedInResearchStudy
 */
export const expectedInResearchStudy = 'http://hl7.org/fhir/expectedInResearchStudy' satisfies OwlObjectProperty;

/**
 * originalPrescription
 *
 * ExplanationOfBenefit.originalPrescription: Original prescription which has been superseded by this prescription to support the dispensing of pharmacy services, medications or products.
 *
 * http://hl7.org/fhir/originalPrescription
 */
export const originalPrescription = 'http://hl7.org/fhir/originalPrescription' satisfies OwlObjectProperty;

/**
 * scoring
 *
 * MeasureReport.scoring: Indicates how the calculation is performed for the measure, including proportion, ratio, continuous-variable, and cohort. The value set is extensible, allowing additional measure scoring types to be represented. It is expected to be the same as the scoring element on the referenced Measure.
 *
 * http://hl7.org/fhir/scoring
 */
export const scoring = 'http://hl7.org/fhir/scoring' satisfies OwlObjectProperty;

/**
 * ClinicalUseDefinitionInteractionComponent
 *
 * ClinicalUseDefinitionInteractionComponent: Specifics for when this is an interaction.
 *
 * http://hl7.org/fhir/ClinicalUseDefinitionInteractionComponent
 */
export const ClinicalUseDefinitionInteractionComponent = 'http://hl7.org/fhir/ClinicalUseDefinitionInteractionComponent' satisfies OwlClass;

/**
 * PlanDefinitionActorComponent
 *
 * PlanDefinitionActorComponent: Actors represent the individuals or groups involved in the execution of the defined set of activities.
 *
 * http://hl7.org/fhir/PlanDefinitionActorComponent
 */
export const PlanDefinitionActorComponent = 'http://hl7.org/fhir/PlanDefinitionActorComponent' satisfies OwlClass;

/**
 * subjectStatus
 *
 * EncounterHistory.subjectStatus: The subjectStatus value can be used to track the patient's status within the encounter. It details whether the patient has arrived or departed, has been triaged or is currently in a waiting status.
 *
 * http://hl7.org/fhir/subjectStatus
 */
export const subjectStatus = 'http://hl7.org/fhir/subjectStatus' satisfies OwlObjectProperty;

/**
 * _qualitativeRisk
 *
 * (Modified) RiskAssessment.prediction.qualitativeRisk
 *
 * http://hl7.org/fhir/_qualitativeRisk
 */
export const _qualitativeRisk = 'http://hl7.org/fhir/_qualitativeRisk' satisfies OwlObjectProperty;

/**
 * _header
 *
 * (Modified) Endpoint.header
 *
 * http://hl7.org/fhir/_header
 */
export const _header = 'http://hl7.org/fhir/_header' satisfies OwlObjectProperty;

/**
 * recurrenceId
 *
 * AppointmentResponse.recurrenceId: The recurrence ID (sequence number) of the specific appointment when responding to a recurring request.
 *
 * http://hl7.org/fhir/recurrenceId
 */
export const recurrenceId = 'http://hl7.org/fhir/recurrenceId' satisfies OwlObjectProperty;

/**
 * _author
 *
 * (Modified) EvidenceReport.section.section.author
 *
 * http://hl7.org/fhir/_author
 */
export const _author = 'http://hl7.org/fhir/_author' satisfies OwlObjectProperty;

/**
 * responsibleOrganization
 *
 * InventoryItem.responsibleOrganization: Organization(s) responsible for the product.
 *
 * http://hl7.org/fhir/responsibleOrganization
 */
export const responsibleOrganization = 'http://hl7.org/fhir/responsibleOrganization' satisfies OwlObjectProperty;

/**
 * TriggerDefinition
 *
 * A description of a triggering event. Triggering events can be named events, data events, or periodic, as determined by the type element.
 *
 * http://hl7.org/fhir/TriggerDefinition
 */
export const TriggerDefinition = 'http://hl7.org/fhir/TriggerDefinition' satisfies OwlClass;

/**
 * _BackboneElement
 *
 * http://hl7.org/fhir/_BackboneElement
 */
export const _BackboneElement = 'http://hl7.org/fhir/_BackboneElement' satisfies OwlClass;

/**
 * _offeredIn
 *
 * (Modified) HealthcareService.offeredIn
 *
 * http://hl7.org/fhir/_offeredIn
 */
export const _offeredIn = 'http://hl7.org/fhir/_offeredIn' satisfies OwlObjectProperty;

/**
 * _accessionNumber
 *
 * (Modified) Citation.citedArtifact.publicationForm.accessionNumber
 *
 * http://hl7.org/fhir/_accessionNumber
 */
export const _accessionNumber = 'http://hl7.org/fhir/_accessionNumber' satisfies OwlObjectProperty;

/**
 * legalState
 *
 * Contract.legalState: Legal states of the formation of a legal instrument, which is a formally executed written document that can be formally attributed to its author, records and formally expresses a legally enforceable act, process, or contractual duty, obligation, or right, and therefore evidences that act, process, or agreement.
 *
 * http://hl7.org/fhir/legalState
 */
export const legalState = 'http://hl7.org/fhir/legalState' satisfies OwlObjectProperty;

/**
 * incomplete
 *
 * TerminologyCapabilities.expansion.incomplete: True if requests for incomplete expansions are allowed.
 *
 * http://hl7.org/fhir/incomplete
 */
export const incomplete = 'http://hl7.org/fhir/incomplete' satisfies OwlObjectProperty;

/**
 * CodeableReference
 *
 * A reference to a resource (by instance), or instead, a reference to a concept defined in a terminology or ontology (by class).
 *
 * http://hl7.org/fhir/CodeableReference
 */
export const CodeableReference = 'http://hl7.org/fhir/CodeableReference' satisfies OwlClass;

/**
 * activity
 *
 * Citation.citedArtifact.statusDate.activity: A definition of the status associated with a date or period.
 *
 * http://hl7.org/fhir/activity
 */
export const activity = 'http://hl7.org/fhir/activity' satisfies OwlObjectProperty;

/**
 * availableEndTime
 *
 * Availability.availableTime.availableEndTime: Closing time of day (ignored if allDay = true).
 *
 * http://hl7.org/fhir/availableEndTime
 */
export const availableEndTime = 'http://hl7.org/fhir/availableEndTime' satisfies OwlObjectProperty;

/**
 * mimeType
 *
 * Endpoint.payload.mimeType: The mime type to send the payload in - e.g. application/fhir+xml, application/fhir+json. If the mime type is not specified, then the sender could send any content (including no content depending on the connectionType).
 *
 * http://hl7.org/fhir/mimeType
 */
export const mimeType = 'http://hl7.org/fhir/mimeType' satisfies OwlObjectProperty;

/**
 * NutritionOrderEnteralFormulaAdministrationComponent
 *
 * NutritionOrderEnteralFormulaComponent.NutritionOrderEnteralFormulaAdministrationComponent: Formula administration instructions as structured data.  This repeating structure allows for changing the administration rate or volume over time for both bolus and continuous feeding.  An example of this would be an instruction to increase the rate of continuous feeding every 2 hours.
 *
 * http://hl7.org/fhir/NutritionOrderEnteralFormulaAdministrationComponent
 */
export const NutritionOrderEnteralFormulaAdministrationComponent = 'http://hl7.org/fhir/NutritionOrderEnteralFormulaAdministrationComponent' satisfies OwlClass;

/**
 * periodUnit
 *
 * Timing.repeat.periodUnit: The units of time for the period in UCUM units
 * Normal practice is to use the 'mo' code as a calendar month when calculating the next occurrence.
 *
 * http://hl7.org/fhir/periodUnit
 */
export const periodUnit = 'http://hl7.org/fhir/periodUnit' satisfies OwlObjectProperty;

/**
 * EvidenceReportRelatesToComponent
 *
 * EvidenceReportRelatesToComponent: Relationships that this composition has with other compositions or documents that already exist.
 *
 * http://hl7.org/fhir/EvidenceReportRelatesToComponent
 */
export const EvidenceReportRelatesToComponent = 'http://hl7.org/fhir/EvidenceReportRelatesToComponent' satisfies OwlClass;

/**
 * SubstanceDefinition
 *
 * The detailed description of a substance, typically at a level beyond what is used for prescribing.
 *
 * http://hl7.org/fhir/SubstanceDefinition
 */
export const SubstanceDefinition = 'http://hl7.org/fhir/SubstanceDefinition' satisfies OwlClass;

/**
 * _useContext
 *
 * (Modified) Library.useContext
 *
 * http://hl7.org/fhir/_useContext
 */
export const _useContext = 'http://hl7.org/fhir/_useContext' satisfies OwlObjectProperty;

/**
 * _instantiatesUri
 *
 * (Modified) Transport.instantiatesUri
 *
 * http://hl7.org/fhir/_instantiatesUri
 */
export const _instantiatesUri = 'http://hl7.org/fhir/_instantiatesUri' satisfies OwlObjectProperty;

/**
 * authorizationUrl
 *
 * CoverageEligibilityResponse.insurance.item.authorizationUrl: A web location for obtaining requirements or descriptive information regarding the preauthorization.
 *
 * http://hl7.org/fhir/authorizationUrl
 */
export const authorizationUrl = 'http://hl7.org/fhir/authorizationUrl' satisfies OwlObjectProperty;

/**
 * contributedToDeath
 *
 * FamilyMemberHistory.procedure.contributedToDeath: This procedure contributed to the cause of death of the related person. If contributedToDeath is not populated, then it is unknown.
 *
 * http://hl7.org/fhir/contributedToDeath
 */
export const contributedToDeath = 'http://hl7.org/fhir/contributedToDeath' satisfies OwlObjectProperty;

/**
 * confidentialityIndicator
 *
 * MedicinalProductDefinition.operation.confidentialityIndicator: Specifies whether this particular business or manufacturing process is considered proprietary or confidential.
 *
 * http://hl7.org/fhir/confidentialityIndicator
 */
export const confidentialityIndicator = 'http://hl7.org/fhir/confidentialityIndicator' satisfies OwlObjectProperty;

/**
 * _diagnosisSequence
 *
 * (Modified) ExplanationOfBenefit.item.diagnosisSequence
 *
 * http://hl7.org/fhir/_diagnosisSequence
 */
export const _diagnosisSequence = 'http://hl7.org/fhir/_diagnosisSequence' satisfies OwlObjectProperty;

/**
 * selectionBehavior
 *
 * PlanDefinition.action.action.selectionBehavior: Defines the selection behavior for the action and its children.
 *
 * http://hl7.org/fhir/selectionBehavior
 */
export const selectionBehavior = 'http://hl7.org/fhir/selectionBehavior' satisfies OwlObjectProperty;

/**
 * _time
 *
 * (Modified) Specimen.processing.time
 *
 * http://hl7.org/fhir/_time
 */
export const _time = 'http://hl7.org/fhir/_time' satisfies OwlObjectProperty;

/**
 * addresses
 *
 * Goal.addresses: The identified conditions and other health record elements that are intended to be addressed by the goal.
 *
 * http://hl7.org/fhir/addresses
 */
export const addresses = 'http://hl7.org/fhir/addresses' satisfies OwlObjectProperty;

/**
 * _dataRequirement
 *
 * (Modified) Library.dataRequirement
 *
 * http://hl7.org/fhir/_dataRequirement
 */
export const _dataRequirement = 'http://hl7.org/fhir/_dataRequirement' satisfies OwlObjectProperty;

/**
 * CapabilityStatementRestResourceComponent
 *
 * CapabilityStatementRestComponent.CapabilityStatementRestResourceComponent: A specification of the restful capabilities of the solution for a specific resource type.
 *
 * http://hl7.org/fhir/CapabilityStatementRestResourceComponent
 */
export const CapabilityStatementRestResourceComponent = 'http://hl7.org/fhir/CapabilityStatementRestResourceComponent' satisfies OwlClass;

/**
 * _lineItem
 *
 * (Modified) Invoice.lineItem
 *
 * http://hl7.org/fhir/_lineItem
 */
export const _lineItem = 'http://hl7.org/fhir/_lineItem' satisfies OwlObjectProperty;

/**
 * _InventoryReport
 *
 * (Modified) InventoryReport
 *
 * http://hl7.org/fhir/_InventoryReport
 */
export const _InventoryReport = 'http://hl7.org/fhir/_InventoryReport' satisfies OwlClass;

/**
 * _copyright
 *
 * (Modified) ArtifactAssessment.copyright
 *
 * http://hl7.org/fhir/_copyright
 */
export const _copyright = 'http://hl7.org/fhir/_copyright' satisfies OwlObjectProperty;

/**
 * _Substance
 *
 * (Modified) Substance
 *
 * http://hl7.org/fhir/_Substance
 */
export const _Substance = 'http://hl7.org/fhir/_Substance' satisfies OwlClass;

/**
 * _timing
 *
 * (Modified) PlanDefinition.action.timing
 *
 * http://hl7.org/fhir/_timing
 */
export const _timing = 'http://hl7.org/fhir/_timing' satisfies OwlObjectProperty;

/**
 * wasSubstituted
 *
 * MedicationDispense.substitution.wasSubstituted: True if the dispenser dispensed a different drug or product from what was prescribed.
 *
 * http://hl7.org/fhir/wasSubstituted
 */
export const wasSubstituted = 'http://hl7.org/fhir/wasSubstituted' satisfies OwlObjectProperty;

/**
 * aggregation
 *
 * ElementDefinition.type.aggregation: If the type is a reference to another resource, how the resource is or can be aggregated - is it a contained resource, or a reference, and if the context is a bundle, is it included in the bundle.
 *
 * http://hl7.org/fhir/aggregation
 */
export const aggregation = 'http://hl7.org/fhir/aggregation' satisfies OwlObjectProperty;

/**
 * _authorDescription
 *
 * (Modified) SubstanceSourceMaterial.organism.author.authorDescription
 *
 * http://hl7.org/fhir/_authorDescription
 */
export const _authorDescription = 'http://hl7.org/fhir/_authorDescription' satisfies OwlObjectProperty;

/**
 * _filter
 *
 * (Modified) ValueSet.compose.exclude.filter
 *
 * http://hl7.org/fhir/_filter
 */
export const _filter = 'http://hl7.org/fhir/_filter' satisfies OwlObjectProperty;

/**
 * MedicinalProductDefinitionOperationComponent
 *
 * MedicinalProductDefinitionOperationComponent: A manufacturing or administrative process or step associated with (or performed on) the medicinal product.
 *
 * http://hl7.org/fhir/MedicinalProductDefinitionOperationComponent
 */
export const MedicinalProductDefinitionOperationComponent = 'http://hl7.org/fhir/MedicinalProductDefinitionOperationComponent' satisfies OwlClass;

/**
 * _defaultValue
 *
 * (Modified) TestScript.variable.defaultValue
 *
 * http://hl7.org/fhir/_defaultValue
 */
export const _defaultValue = 'http://hl7.org/fhir/_defaultValue' satisfies OwlObjectProperty;

/**
 * StructureMapStructureComponent
 *
 * StructureMapStructureComponent: A structure definition used by this map. The structure definition may describe instances that are converted, or the instances that are produced.
 *
 * http://hl7.org/fhir/StructureMapStructureComponent
 */
export const StructureMapStructureComponent = 'http://hl7.org/fhir/StructureMapStructureComponent' satisfies OwlClass;

/**
 * recipient
 *
 * Task.restriction.recipient: For requests that are targeted to more than one potential recipient/target, to identify who is fulfillment is sought for.
 *
 * http://hl7.org/fhir/recipient
 */
export const recipient = 'http://hl7.org/fhir/recipient' satisfies OwlObjectProperty;

/**
 * _lotNumber
 *
 * (Modified) NutritionProduct.instance.lotNumber
 *
 * http://hl7.org/fhir/_lotNumber
 */
export const _lotNumber = 'http://hl7.org/fhir/_lotNumber' satisfies OwlObjectProperty;

/**
 * QuestionnaireItemAnswerOptionComponent
 *
 * QuestionnaireItemComponentItem.QuestionnaireItemAnswerOptionComponent: One of the permitted answers for the question.
 *
 * http://hl7.org/fhir/QuestionnaireItemAnswerOptionComponent
 */
export const QuestionnaireItemAnswerOptionComponent = 'http://hl7.org/fhir/QuestionnaireItemAnswerOptionComponent' satisfies OwlClass;

/**
 * applies
 *
 * Contract.applies: Relevant time or time-period when this Contract is applicable.
 *
 * http://hl7.org/fhir/applies
 */
export const applies = 'http://hl7.org/fhir/applies' satisfies OwlObjectProperty;

/**
 * caseSensitive
 *
 * CodeSystem.caseSensitive: If code comparison is case sensitive when codes within this system are compared to each other.
 *
 * http://hl7.org/fhir/caseSensitive
 */
export const caseSensitive = 'http://hl7.org/fhir/caseSensitive' satisfies OwlObjectProperty;

/**
 * subtype
 *
 * Contract.term.group.asset.subtype: May be a subtype or part of an offered asset.
 *
 * http://hl7.org/fhir/subtype
 */
export const subtype = 'http://hl7.org/fhir/subtype' satisfies OwlObjectProperty;

/**
 * _field
 *
 * (Modified) TestScript.teardown.action.operation.requestHeader.field
 *
 * http://hl7.org/fhir/_field
 */
export const _field = 'http://hl7.org/fhir/_field' satisfies OwlObjectProperty;

/**
 * _hasIngredient
 *
 * (Modified) ManufacturedItemDefinition.component.component.constituent.hasIngredient
 *
 * http://hl7.org/fhir/_hasIngredient
 */
export const _hasIngredient = 'http://hl7.org/fhir/_hasIngredient' satisfies OwlObjectProperty;

/**
 * strength
 *
 * OperationDefinition.parameter.part.binding.strength: Indicates the degree of conformance expectations associated with this binding - that is, the degree to which the provided value set must be adhered to in the instances.
 *
 * http://hl7.org/fhir/strength
 */
export const strength = 'http://hl7.org/fhir/strength' satisfies OwlObjectProperty;

/**
 * linkId
 *
 * ResearchStudy.comparisonGroup.linkId: Allows the comparisonGroup for the study and the comparisonGroup for the subject to be linked easily.
 *
 * http://hl7.org/fhir/linkId
 */
export const linkId = 'http://hl7.org/fhir/linkId' satisfies OwlObjectProperty;

/**
 * StructureMapGroupRuleTargetComponent
 *
 * StructureMapGroupComponent.StructureMapGroupRuleComponentRule.StructureMapGroupRuleTargetComponent: Content to create because of this mapping rule.
 *
 * http://hl7.org/fhir/StructureMapGroupRuleTargetComponent
 */
export const StructureMapGroupRuleTargetComponent = 'http://hl7.org/fhir/StructureMapGroupRuleTargetComponent' satisfies OwlClass;

/**
 * _resultingEffect
 *
 * (Modified) AdverseEvent.resultingEffect
 *
 * http://hl7.org/fhir/_resultingEffect
 */
export const _resultingEffect = 'http://hl7.org/fhir/_resultingEffect' satisfies OwlObjectProperty;

/**
 * altitude
 *
 * Location.position.altitude: Altitude. The value domain and the interpretation are the same as for the text of the altitude element in KML (see notes on Location main page).
 *
 * http://hl7.org/fhir/altitude
 */
export const altitude = 'http://hl7.org/fhir/altitude' satisfies OwlObjectProperty;

/**
 * phase
 *
 * TestScript.scope.phase: The phase of testing for this artifact: unit - development / implementation phase, integration - internal system to system phase, production - live system to system phase (Note, this may involve pii/phi data).
 *
 * http://hl7.org/fhir/phase
 */
export const phase = 'http://hl7.org/fhir/phase' satisfies OwlObjectProperty;

/**
 * _numberOfRepeatsAllowed
 *
 * (Modified) MedicationRequest.dispenseRequest.numberOfRepeatsAllowed
 *
 * http://hl7.org/fhir/_numberOfRepeatsAllowed
 */
export const _numberOfRepeatsAllowed = 'http://hl7.org/fhir/_numberOfRepeatsAllowed' satisfies OwlObjectProperty;

/**
 * groupSize
 *
 * InsurancePlan.plan.generalCost.groupSize: Number of participants enrolled in the plan.
 *
 * http://hl7.org/fhir/groupSize
 */
export const groupSize = 'http://hl7.org/fhir/groupSize' satisfies OwlObjectProperty;

/**
 * _oligoNucleotideType
 *
 * (Modified) SubstanceNucleicAcid.oligoNucleotideType
 *
 * http://hl7.org/fhir/_oligoNucleotideType
 */
export const _oligoNucleotideType = 'http://hl7.org/fhir/_oligoNucleotideType' satisfies OwlObjectProperty;

/**
 * doseStatus
 *
 * ImmunizationEvaluation.doseStatus: Indicates if the dose is valid or not valid with respect to the published recommendations.
 *
 * http://hl7.org/fhir/doseStatus
 */
export const doseStatus = 'http://hl7.org/fhir/doseStatus' satisfies OwlObjectProperty;

/**
 * directnessMatch
 *
 * Evidence.variableDefinition.directnessMatch: Indication of quality of match between intended variable to actual variable.
 *
 * http://hl7.org/fhir/directnessMatch
 */
export const directnessMatch = 'http://hl7.org/fhir/directnessMatch' satisfies OwlObjectProperty;

/**
 * AppointmentParticipantComponent
 *
 * AppointmentParticipantComponent: List of participants involved in the appointment.
 *
 * http://hl7.org/fhir/AppointmentParticipantComponent
 */
export const AppointmentParticipantComponent = 'http://hl7.org/fhir/AppointmentParticipantComponent' satisfies OwlClass;

/**
 * _continuous
 *
 * (Modified) Goal.continuous
 *
 * http://hl7.org/fhir/_continuous
 */
export const _continuous = 'http://hl7.org/fhir/_continuous' satisfies OwlObjectProperty;

/**
 * _dispenseInterval
 *
 * (Modified) MedicationRequest.dispenseRequest.dispenseInterval
 *
 * http://hl7.org/fhir/_dispenseInterval
 */
export const _dispenseInterval = 'http://hl7.org/fhir/_dispenseInterval' satisfies OwlObjectProperty;

/**
 * stage
 *
 * ConditionDefinition.stage: Clinical stage or grade of a condition. May include formal severity assessments.
 *
 * http://hl7.org/fhir/stage
 */
export const stage = 'http://hl7.org/fhir/stage' satisfies OwlObjectProperty;

/**
 * associatedMedication
 *
 * MedicationKnowledge.associatedMedication: Links to associated medications that could be prescribed, dispensed or administered.
 *
 * http://hl7.org/fhir/associatedMedication
 */
export const associatedMedication = 'http://hl7.org/fhir/associatedMedication' satisfies OwlObjectProperty;

/**
 * dateOfDiagnosis
 *
 * Account.diagnosis.dateOfDiagnosis: Ranking of the diagnosis (for each type).
 *
 * http://hl7.org/fhir/dateOfDiagnosis
 */
export const dateOfDiagnosis = 'http://hl7.org/fhir/dateOfDiagnosis' satisfies OwlObjectProperty;

/**
 * _actualPeriod
 *
 * (Modified) EncounterHistory.actualPeriod
 *
 * http://hl7.org/fhir/_actualPeriod
 */
export const _actualPeriod = 'http://hl7.org/fhir/_actualPeriod' satisfies OwlObjectProperty;

/**
 * ValueSet
 *
 * A ValueSet resource instance specifies a set of codes drawn from one or more code systems, intended for use in a particular context. Value sets link between [[[CodeSystem]]] definitions and their use in [coded elements](terminologies.html).
 *
 * http://hl7.org/fhir/ValueSet
 */
export const ValueSet = 'http://hl7.org/fhir/ValueSet' satisfies OwlClass;

/**
 * lastOccurrence
 *
 * AllergyIntolerance.lastOccurrence: Represents the date and/or time of the last known occurrence of a reaction event.
 *
 * http://hl7.org/fhir/lastOccurrence
 */
export const lastOccurrence = 'http://hl7.org/fhir/lastOccurrence' satisfies OwlObjectProperty;

/**
 * disulfideLinkage
 *
 * SubstanceProtein.disulfideLinkage: The disulphide bond between two cysteine residues either on the same subunit or on two different subunits shall be described. The position of the disulfide bonds in the SubstanceProtein shall be listed in increasing order of subunit number and position within subunit followed by the abbreviation of the amino acids involved. The disulfide linkage positions shall actually contain the amino acid Cysteine at the respective positions.
 *
 * http://hl7.org/fhir/disulfideLinkage
 */
export const disulfideLinkage = 'http://hl7.org/fhir/disulfideLinkage' satisfies OwlObjectProperty;

/**
 * participatingOrganization
 *
 * OrganizationAffiliation.participatingOrganization: The Participating Organization provides/performs the role(s) defined by the code to the Primary Organization (e.g. providing services or is a member of).
 *
 * http://hl7.org/fhir/participatingOrganization
 */
export const participatingOrganization = 'http://hl7.org/fhir/participatingOrganization' satisfies OwlObjectProperty;

/**
 * ResearchSubject
 *
 * A ResearchSubject is a participant or object which is the recipient of investigative activities in a research study.
 *
 * http://hl7.org/fhir/ResearchSubject
 */
export const ResearchSubject = 'http://hl7.org/fhir/ResearchSubject' satisfies OwlClass;

/**
 * heartbeatPeriod
 *
 * Subscription.heartbeatPeriod: If present, a 'heartbeat' notification (keep-alive) is sent via this channel with an interval period equal to this elements integer value in seconds.  If not present, a heartbeat notification is not sent.
 *
 * http://hl7.org/fhir/heartbeatPeriod
 */
export const heartbeatPeriod = 'http://hl7.org/fhir/heartbeatPeriod' satisfies OwlObjectProperty;

/**
 * OrganizationAffiliation
 *
 * Defines an affiliation/assotiation/relationship between 2 distinct organizations, that is not a part-of relationship/sub-division relationship.
 *
 * http://hl7.org/fhir/OrganizationAffiliation
 */
export const OrganizationAffiliation = 'http://hl7.org/fhir/OrganizationAffiliation' satisfies OwlClass;

/**
 * _binding
 *
 * (Modified) OperationDefinition.parameter.part.binding
 *
 * http://hl7.org/fhir/_binding
 */
export const _binding = 'http://hl7.org/fhir/_binding' satisfies OwlObjectProperty;

/**
 * SubstanceNucleicAcidSubunitLinkageComponent
 *
 * SubstanceNucleicAcidSubunitComponent.SubstanceNucleicAcidSubunitLinkageComponent: The linkages between sugar residues will also be captured.
 *
 * http://hl7.org/fhir/SubstanceNucleicAcidSubunitLinkageComponent
 */
export const SubstanceNucleicAcidSubunitLinkageComponent = 'http://hl7.org/fhir/SubstanceNucleicAcidSubunitLinkageComponent' satisfies OwlClass;

/**
 * ImplementationGuideDefinitionPageComponent
 *
 * ImplementationGuideDefinitionComponent.ImplementationGuideDefinitionPageComponent: A page / section in the implementation guide. The root page is the implementation guide home page.
 *
 * http://hl7.org/fhir/ImplementationGuideDefinitionPageComponent
 */
export const ImplementationGuideDefinitionPageComponent = 'http://hl7.org/fhir/ImplementationGuideDefinitionPageComponent' satisfies OwlClass;

/**
 * FamilyMemberHistoryProcedureComponent
 *
 * FamilyMemberHistoryProcedureComponent: The significant Procedures (or procedure) that the family member had. This is a repeating section to allow a system to represent more than one procedure per resource, though there is nothing stopping multiple resources - one per procedure.
 *
 * http://hl7.org/fhir/FamilyMemberHistoryProcedureComponent
 */
export const FamilyMemberHistoryProcedureComponent = 'http://hl7.org/fhir/FamilyMemberHistoryProcedureComponent' satisfies OwlClass;

/**
 * subscriptionTopic
 *
 * TriggerDefinition.subscriptionTopic: A reference to a SubscriptionTopic resource that defines the event. If this element is provided, no other information about the trigger definition may be supplied.
 *
 * http://hl7.org/fhir/subscriptionTopic
 */
export const subscriptionTopic = 'http://hl7.org/fhir/subscriptionTopic' satisfies OwlObjectProperty;

/**
 * _resource
 *
 * (Modified) RelatedArtifact.resource
 *
 * http://hl7.org/fhir/_resource
 */
export const _resource = 'http://hl7.org/fhir/_resource' satisfies OwlObjectProperty;

/**
 * correspondingContact
 *
 * Citation.citedArtifact.contributorship.entry.correspondingContact: Whether the contributor is the corresponding contributor for the role.
 *
 * http://hl7.org/fhir/correspondingContact
 */
export const correspondingContact = 'http://hl7.org/fhir/correspondingContact' satisfies OwlObjectProperty;

/**
 * graph
 *
 * MessageDefinition.graph: Graph is Canonical reference to a GraphDefinition. If a URL is provided, it is the canonical reference to a GraphDefinition that it controls what additional resources are to be added to the Bundle when building the message. The GraphDefinition can also specify profiles that apply to the various resources.
 *
 * http://hl7.org/fhir/graph
 */
export const graph = 'http://hl7.org/fhir/graph' satisfies OwlObjectProperty;

/**
 * _QuestionnaireResponse
 *
 * (Modified) QuestionnaireResponse
 *
 * http://hl7.org/fhir/_QuestionnaireResponse
 */
export const _QuestionnaireResponse = 'http://hl7.org/fhir/_QuestionnaireResponse' satisfies OwlClass;

/**
 * RequestOrchestrationActionComponentAction
 *
 * Sub actions.
 *
 * http://hl7.org/fhir/RequestOrchestrationActionComponentAction
 */
export const RequestOrchestrationActionComponentAction = 'http://hl7.org/fhir/RequestOrchestrationActionComponentAction' satisfies OwlClass;

/**
 * issues
 *
 * Bundle.issues: Captures issues and warnings that relate to the construction of the Bundle and the content within it.
 *
 * http://hl7.org/fhir/issues
 */
export const issues = 'http://hl7.org/fhir/issues' satisfies OwlObjectProperty;

/**
 * instances
 *
 * EvidenceVariable.characteristic.instances
 *
 * http://hl7.org/fhir/instances
 */
export const instances = 'http://hl7.org/fhir/instances' satisfies OwlObjectProperty;

/**
 * _isDefining
 *
 * (Modified) SubstancePolymer.monomerSet.startingMaterial.isDefining
 *
 * http://hl7.org/fhir/_isDefining
 */
export const _isDefining = 'http://hl7.org/fhir/_isDefining' satisfies OwlObjectProperty;

/**
 * primaryPurposeType
 *
 * ResearchStudy.primaryPurposeType: The type of study based upon the intent of the study activities. A classification of the intent of the study.
 *
 * http://hl7.org/fhir/primaryPurposeType
 */
export const primaryPurposeType = 'http://hl7.org/fhir/primaryPurposeType' satisfies OwlObjectProperty;

/**
 * _specimenRequirement
 *
 * (Modified) ActivityDefinition.specimenRequirement
 *
 * http://hl7.org/fhir/_specimenRequirement
 */
export const _specimenRequirement = 'http://hl7.org/fhir/_specimenRequirement' satisfies OwlObjectProperty;

/**
 * _sourceDocument
 *
 * (Modified) SubstanceDefinition.structure.sourceDocument
 *
 * http://hl7.org/fhir/_sourceDocument
 */
export const _sourceDocument = 'http://hl7.org/fhir/_sourceDocument' satisfies OwlObjectProperty;

/**
 * SubstanceReferenceInformation
 *
 * Todo.
 *
 * http://hl7.org/fhir/SubstanceReferenceInformation
 */
export const SubstanceReferenceInformation = 'http://hl7.org/fhir/SubstanceReferenceInformation' satisfies OwlClass;

/**
 * _multipleBirth
 *
 * (Modified) Patient.multipleBirth
 *
 * http://hl7.org/fhir/_multipleBirth
 */
export const _multipleBirth = 'http://hl7.org/fhir/_multipleBirth' satisfies OwlObjectProperty;

/**
 * _InsurancePlan
 *
 * (Modified) InsurancePlan
 *
 * http://hl7.org/fhir/_InsurancePlan
 */
export const _InsurancePlan = 'http://hl7.org/fhir/_InsurancePlan' satisfies OwlClass;

/**
 * repeatUnit
 *
 * SubstancePolymer.repeat.repeatUnit: An SRU - Structural Repeat Unit.
 *
 * http://hl7.org/fhir/repeatUnit
 */
export const repeatUnit = 'http://hl7.org/fhir/repeatUnit' satisfies OwlObjectProperty;

/**
 * StructureDefinition
 *
 * A definition of a FHIR structure. This resource is used to describe the underlying resources, data types defined in FHIR, and also for describing extensions and constraints on resources and data types.
 *
 * http://hl7.org/fhir/StructureDefinition
 */
export const StructureDefinition = 'http://hl7.org/fhir/StructureDefinition' satisfies OwlClass;

/**
 * _node
 *
 * (Modified) GraphDefinition.node
 *
 * http://hl7.org/fhir/_node
 */
export const _node = 'http://hl7.org/fhir/_node' satisfies OwlObjectProperty;

/**
 * TestPlanTestCaseAssertionComponent
 *
 * TestPlanTestCaseComponent.TestPlanTestCaseAssertionComponent: The test assertions - the expectations of test results from the execution of the test case.
 *
 * http://hl7.org/fhir/TestPlanTestCaseAssertionComponent
 */
export const TestPlanTestCaseAssertionComponent = 'http://hl7.org/fhir/TestPlanTestCaseAssertionComponent' satisfies OwlClass;

/**
 * relatedData
 *
 * PlanDefinition.action.input.relatedData: Points to an existing input or output element that provides data to this input.
 *
 * http://hl7.org/fhir/relatedData
 */
export const relatedData = 'http://hl7.org/fhir/relatedData' satisfies OwlObjectProperty;

/**
 * _content
 *
 * (Modified) CommunicationRequest.payload.content
 *
 * http://hl7.org/fhir/_content
 */
export const _content = 'http://hl7.org/fhir/_content' satisfies OwlObjectProperty;

/**
 * _associationType
 *
 * (Modified) InventoryItem.association.associationType
 *
 * http://hl7.org/fhir/_associationType
 */
export const _associationType = 'http://hl7.org/fhir/_associationType' satisfies OwlObjectProperty;

/**
 * _regulatoryBasis
 *
 * (Modified) Consent.regulatoryBasis
 *
 * http://hl7.org/fhir/_regulatoryBasis
 */
export const _regulatoryBasis = 'http://hl7.org/fhir/_regulatoryBasis' satisfies OwlObjectProperty;

/**
 * attachment
 *
 * SubstancePolymer.repeat.repeatUnit.structuralRepresentation.attachment: An attached file with the structural representation.
 *
 * http://hl7.org/fhir/attachment
 */
export const attachment = 'http://hl7.org/fhir/attachment' satisfies OwlObjectProperty;

/**
 * ActionSubject
 *
 * Contract.Term.Action.ActionSubject: Entity of the action.
 *
 * http://hl7.org/fhir/ActionSubject
 */
export const ActionSubject = 'http://hl7.org/fhir/ActionSubject' satisfies OwlClass;

/**
 * _packagedMedicinalProduct
 *
 * (Modified) MedicinalProductDefinition.packagedMedicinalProduct
 *
 * http://hl7.org/fhir/_packagedMedicinalProduct
 */
export const _packagedMedicinalProduct = 'http://hl7.org/fhir/_packagedMedicinalProduct' satisfies OwlObjectProperty;

/**
 * _packagedProduct
 *
 * (Modified) MedicationKnowledge.packaging.packagedProduct
 *
 * http://hl7.org/fhir/_packagedProduct
 */
export const _packagedProduct = 'http://hl7.org/fhir/_packagedProduct' satisfies OwlObjectProperty;

/**
 * _onset
 *
 * (Modified) FamilyMemberHistory.condition.onset
 *
 * http://hl7.org/fhir/_onset
 */
export const _onset = 'http://hl7.org/fhir/_onset' satisfies OwlObjectProperty;

/**
 * _basedOn
 *
 * (Modified) DeviceUsage.basedOn
 *
 * http://hl7.org/fhir/_basedOn
 */
export const _basedOn = 'http://hl7.org/fhir/_basedOn' satisfies OwlObjectProperty;

/**
 * CitationCitedArtifactRelatesToComponent
 *
 * CitationCitedArtifactComponent.CitationCitedArtifactRelatesToComponent: The artifact related to the cited artifact.
 *
 * http://hl7.org/fhir/CitationCitedArtifactRelatesToComponent
 */
export const CitationCitedArtifactRelatesToComponent = 'http://hl7.org/fhir/CitationCitedArtifactRelatesToComponent' satisfies OwlClass;

/**
 * _backCurve
 *
 * (Modified) VisionPrescription.lensSpecification.backCurve
 *
 * http://hl7.org/fhir/_backCurve
 */
export const _backCurve = 'http://hl7.org/fhir/_backCurve' satisfies OwlObjectProperty;

/**
 * AuditEventOutcomeComponent
 *
 * AuditEventOutcomeComponent: Indicates whether the event succeeded or failed. A free text descripiton can be given in outcome.text.
 *
 * http://hl7.org/fhir/AuditEventOutcomeComponent
 */
export const AuditEventOutcomeComponent = 'http://hl7.org/fhir/AuditEventOutcomeComponent' satisfies OwlClass;

/**
 * payee
 *
 * PaymentNotice.payee: The party who will receive or has received payment that is the subject of this notification.
 *
 * http://hl7.org/fhir/payee
 */
export const payee = 'http://hl7.org/fhir/payee' satisfies OwlObjectProperty;

/**
 * _reporter
 *
 * (Modified) PaymentNotice.reporter
 *
 * http://hl7.org/fhir/_reporter
 */
export const _reporter = 'http://hl7.org/fhir/_reporter' satisfies OwlObjectProperty;

/**
 * SubstanceDefinitionStructureComponentMolecularWeight
 *
 * The molecular weight or weight range (for proteins, polymers or nucleic acids).
 *
 * http://hl7.org/fhir/SubstanceDefinitionStructureComponentMolecularWeight
 */
export const SubstanceDefinitionStructureComponentMolecularWeight = 'http://hl7.org/fhir/SubstanceDefinitionStructureComponentMolecularWeight' satisfies OwlClass;

/**
 * biologicalSourceEvent
 *
 * BiologicallyDerivedProduct.biologicalSourceEvent: An identifier that supports traceability to the event during which material in this product from one or more biological entities was obtained or pooled.
 *
 * http://hl7.org/fhir/biologicalSourceEvent
 */
export const biologicalSourceEvent = 'http://hl7.org/fhir/biologicalSourceEvent' satisfies OwlObjectProperty;

/**
 * RequestOrchestrationActionComponent
 *
 * RequestOrchestrationActionComponent: The actions, if any, produced by the evaluation of the artifact.
 *
 * http://hl7.org/fhir/RequestOrchestrationActionComponent
 */
export const RequestOrchestrationActionComponent = 'http://hl7.org/fhir/RequestOrchestrationActionComponent' satisfies OwlClass;

/**
 * period
 *
 * RelatedPerson.period: The period of time during which this relationship is or was active. If there are no dates defined, then the interval is unknown.
 *
 * http://hl7.org/fhir/period
 */
export const period = 'http://hl7.org/fhir/period' satisfies OwlObjectProperty;

/**
 * SearchParameterComponentComponent
 *
 * SearchParameterComponentComponent: Used to define the parts of a composite search parameter.
 *
 * http://hl7.org/fhir/SearchParameterComponentComponent
 */
export const SearchParameterComponentComponent = 'http://hl7.org/fhir/SearchParameterComponentComponent' satisfies OwlClass;

/**
 * protocolPerformed
 *
 * GenomicStudy.analysis.protocolPerformed: The protocol that was performed for the analysis event.
 *
 * http://hl7.org/fhir/protocolPerformed
 */
export const protocolPerformed = 'http://hl7.org/fhir/protocolPerformed' satisfies OwlObjectProperty;

/**
 * ResearchStudyLabelComponent
 *
 * ResearchStudyLabelComponent: Additional names for the study.
 *
 * http://hl7.org/fhir/ResearchStudyLabelComponent
 */
export const ResearchStudyLabelComponent = 'http://hl7.org/fhir/ResearchStudyLabelComponent' satisfies OwlClass;

/**
 * _careTeamSequence
 *
 * (Modified) ExplanationOfBenefit.item.careTeamSequence
 *
 * http://hl7.org/fhir/_careTeamSequence
 */
export const _careTeamSequence = 'http://hl7.org/fhir/_careTeamSequence' satisfies OwlObjectProperty;

/**
 * instantiates
 *
 * Observation.instantiates
 *
 * http://hl7.org/fhir/instantiates
 */
export const instantiates = 'http://hl7.org/fhir/instantiates' satisfies OwlObjectProperty;

/**
 * _patientCharacteristic
 *
 * (Modified) MedicationKnowledge.indicationGuideline.dosingGuideline.patientCharacteristic
 *
 * http://hl7.org/fhir/_patientCharacteristic
 */
export const _patientCharacteristic = 'http://hl7.org/fhir/_patientCharacteristic' satisfies OwlObjectProperty;

/**
 * _allowedType
 *
 * (Modified) OperationDefinition.parameter.part.allowedType
 *
 * http://hl7.org/fhir/_allowedType
 */
export const _allowedType = 'http://hl7.org/fhir/_allowedType' satisfies OwlObjectProperty;

/**
 * Element
 *
 * Base definition for all elements in a resource.
 *
 * http://hl7.org/fhir/Element
 */
export const Element = 'http://hl7.org/fhir/Element' satisfies OwlClass;

/**
 * DeviceMetric
 *
 * Describes a measurement, calculation or setting capability of a device.  The DeviceMetric resource is derived from the ISO/IEEE 11073-10201 Domain Information Model standard, but is more widely applicable. 
 *
 * http://hl7.org/fhir/DeviceMetric
 */
export const DeviceMetric = 'http://hl7.org/fhir/DeviceMetric' satisfies OwlClass;

/**
 * _maxTreatmentPeriod
 *
 * (Modified) AdministrableProductDefinition.routeOfAdministration.maxTreatmentPeriod
 *
 * http://hl7.org/fhir/_maxTreatmentPeriod
 */
export const _maxTreatmentPeriod = 'http://hl7.org/fhir/_maxTreatmentPeriod' satisfies OwlObjectProperty;

/**
 * _InventoryItem
 *
 * (Modified) InventoryItem
 *
 * http://hl7.org/fhir/_InventoryItem
 */
export const _InventoryItem = 'http://hl7.org/fhir/_InventoryItem' satisfies OwlClass;

/**
 * AppointmentRecurrenceTemplateComponent
 *
 * AppointmentRecurrenceTemplateComponent: The details of the recurrence pattern or template that is used to generate recurring appointments.
 *
 * http://hl7.org/fhir/AppointmentRecurrenceTemplateComponent
 */
export const AppointmentRecurrenceTemplateComponent = 'http://hl7.org/fhir/AppointmentRecurrenceTemplateComponent' satisfies OwlClass;

/**
 * targetDisease
 *
 * ImmunizationRecommendation.recommendation.targetDisease: The targeted disease for the recommendation.
 *
 * http://hl7.org/fhir/targetDisease
 */
export const targetDisease = 'http://hl7.org/fhir/targetDisease' satisfies OwlObjectProperty;

/**
 * PlanDefinitionActionComponentAction
 *
 * Sub actions that are contained within the action. The behavior of this action determines the functionality of the sub-actions. For example, a selection behavior of at-most-one indicates that of the sub-actions, at most one may be chosen as part of realizing the action definition.
 *
 * http://hl7.org/fhir/PlanDefinitionActionComponentAction
 */
export const PlanDefinitionActionComponentAction = 'http://hl7.org/fhir/PlanDefinitionActionComponentAction' satisfies OwlClass;

/**
 * file
 *
 * SubstanceDefinition.characterization.file: The data produced by the analytical instrument or a pictorial representation of that data. Examples: a JCAMP, JDX, or ADX file, or a chromatogram or spectrum analysis.
 *
 * http://hl7.org/fhir/file
 */
export const file = 'http://hl7.org/fhir/file' satisfies OwlObjectProperty;

/**
 * const
 *
 * StructureMap.const: Definition of a constant value used in the map rules.
 * Note that `const` is a reserved Javascript keyword, and is therefore suffixed by `__workaround`.
 * For a list of reserved keywords, see https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Lexical_grammar#Keywords.
 *
 * http://hl7.org/fhir/const
 */
export const const__workaround = 'http://hl7.org/fhir/const' satisfies OwlObjectProperty;

/**
 * citedMedium
 *
 * Citation.citedArtifact.publicationForm.citedMedium: Describes the form of the medium cited. Common codes are "Internet" or "Print". The CitedMedium value set has 6 codes. The codes internet, print, and offline-digital-storage are the common codes for a typical publication form, though internet and print are more common for study citations. Three additional codes (each appending one of the primary codes with "-without-issue" are used for situations when a study is published both within an issue (of a periodical release as commonly done for journals) AND is published separately from the issue (as commonly done with early online publication), to represent specific identification of the publication form not associated with the issue.
 *
 * http://hl7.org/fhir/citedMedium
 */
export const citedMedium = 'http://hl7.org/fhir/citedMedium' satisfies OwlObjectProperty;

/**
 * _frames
 *
 * (Modified) Attachment.frames
 *
 * http://hl7.org/fhir/_frames
 */
export const _frames = 'http://hl7.org/fhir/_frames' satisfies OwlObjectProperty;

/**
 * multipleOr
 *
 * SearchParameter.multipleOr: Whether multiple values are allowed for each time the parameter exists. Values are separated by commas, and the parameter matches if any of the values match.
 *
 * http://hl7.org/fhir/multipleOr
 */
export const multipleOr = 'http://hl7.org/fhir/multipleOr' satisfies OwlObjectProperty;

/**
 * inputParameters
 *
 * MeasureReport.inputParameters: A reference to a Parameters resource (typically represented using a contained resource) that represents any input parameters that were provided to the operation that generated the report.
 *
 * http://hl7.org/fhir/inputParameters
 */
export const inputParameters = 'http://hl7.org/fhir/inputParameters' satisfies OwlObjectProperty;

/**
 * causality
 *
 * AdverseEvent.suspectEntity.causality: Information on the possible cause of the event.
 *
 * http://hl7.org/fhir/causality
 */
export const causality = 'http://hl7.org/fhir/causality' satisfies OwlObjectProperty;

/**
 * SupplyDelivery
 *
 * Record of delivery of what is supplied.
 *
 * http://hl7.org/fhir/SupplyDelivery
 */
export const SupplyDelivery = 'http://hl7.org/fhir/SupplyDelivery' satisfies OwlClass;

/**
 * minimumId
 *
 * TestScript.test.action.assert.minimumId: The ID of a fixture. Asserts that the response contains at a minimum the fixture specified by minimumId.
 *
 * http://hl7.org/fhir/minimumId
 */
export const minimumId = 'http://hl7.org/fhir/minimumId' satisfies OwlObjectProperty;

/**
 * _processNote
 *
 * (Modified) PaymentReconciliation.processNote
 *
 * http://hl7.org/fhir/_processNote
 */
export const _processNote = 'http://hl7.org/fhir/_processNote' satisfies OwlObjectProperty;

/**
 * Money
 *
 * An amount of economic utility in some recognized currency.
 *
 * http://hl7.org/fhir/Money
 */
export const Money = 'http://hl7.org/fhir/Money' satisfies OwlClass;

/**
 * _BackboneType
 *
 * http://hl7.org/fhir/_BackboneType
 */
export const _BackboneType = 'http://hl7.org/fhir/_BackboneType' satisfies OwlClass;

/**
 * _Endpoint
 *
 * (Modified) Endpoint
 *
 * http://hl7.org/fhir/_Endpoint
 */
export const _Endpoint = 'http://hl7.org/fhir/_Endpoint' satisfies OwlClass;

/**
 * udiDeviceIdentifier
 *
 * DeviceDefinition.packaging.packaging.udiDeviceIdentifier: Unique Device Identifier (UDI) Barcode string on the packaging.
 *
 * http://hl7.org/fhir/udiDeviceIdentifier
 */
export const udiDeviceIdentifier = 'http://hl7.org/fhir/udiDeviceIdentifier' satisfies OwlObjectProperty;

/**
 * EnteralFormulaSchedule
 *
 * NutritionOrderEnteralFormulaComponent.NutritionOrderEnteralFormulaAdministrationComponent.EnteralFormulaSchedule: Schedule information for an enteral formula.
 *
 * http://hl7.org/fhir/EnteralFormulaSchedule
 */
export const EnteralFormulaSchedule = 'http://hl7.org/fhir/EnteralFormulaSchedule' satisfies OwlClass;

/**
 * diseaseStatus
 *
 * ClinicalUseDefinition.indication.diseaseStatus: The status of the disease or symptom for the indication, for example "chronic" or "metastatic".
 *
 * http://hl7.org/fhir/diseaseStatus
 */
export const diseaseStatus = 'http://hl7.org/fhir/diseaseStatus' satisfies OwlObjectProperty;

/**
 * _expectedSupplyDuration
 *
 * (Modified) MedicationRequest.dispenseRequest.expectedSupplyDuration
 *
 * http://hl7.org/fhir/_expectedSupplyDuration
 */
export const _expectedSupplyDuration = 'http://hl7.org/fhir/_expectedSupplyDuration' satisfies OwlObjectProperty;

/**
 * ifModifiedSince
 *
 * Bundle.entry.request.ifModifiedSince: Only perform the operation if the last updated date matches. See the API documentation for ["Conditional Read"](http.html#cread).
 *
 * http://hl7.org/fhir/ifModifiedSince
 */
export const ifModifiedSince = 'http://hl7.org/fhir/ifModifiedSince' satisfies OwlObjectProperty;

/**
 * formCode
 *
 * PaymentReconciliation.formCode: A code for the form to be used for printing the content.
 *
 * http://hl7.org/fhir/formCode
 */
export const formCode = 'http://hl7.org/fhir/formCode' satisfies OwlObjectProperty;

/**
 * _connectionType
 *
 * (Modified) Endpoint.connectionType
 *
 * http://hl7.org/fhir/_connectionType
 */
export const _connectionType = 'http://hl7.org/fhir/_connectionType' satisfies OwlObjectProperty;

/**
 * ImplementationGuideDefinitionResourceComponent
 *
 * ImplementationGuideDefinitionComponent.ImplementationGuideDefinitionResourceComponent: A resource that is part of the implementation guide. Conformance resources (value set, structure definition, capability statements etc.) are obvious candidates for inclusion, but any kind of resource can be included as an example resource.
 *
 * http://hl7.org/fhir/ImplementationGuideDefinitionResourceComponent
 */
export const ImplementationGuideDefinitionResourceComponent = 'http://hl7.org/fhir/ImplementationGuideDefinitionResourceComponent' satisfies OwlClass;

/**
 * _fundsReserveRequested
 *
 * (Modified) ExplanationOfBenefit.fundsReserveRequested
 *
 * http://hl7.org/fhir/_fundsReserveRequested
 */
export const _fundsReserveRequested = 'http://hl7.org/fhir/_fundsReserveRequested' satisfies OwlObjectProperty;

/**
 * dateFilter
 *
 * DataRequirement.dateFilter: Date filters specify additional constraints on the data in terms of the applicable date range for specific elements. Each date filter specifies an additional constraint on the data, i.e. date filters are AND'ed, not OR'ed.
 *
 * http://hl7.org/fhir/dateFilter
 */
export const dateFilter = 'http://hl7.org/fhir/dateFilter' satisfies OwlObjectProperty;

/**
 * matchStatus
 *
 * BiologicallyDerivedProductDispense.matchStatus: Indicates the type of matching associated with the dispense.
 *
 * http://hl7.org/fhir/matchStatus
 */
export const matchStatus = 'http://hl7.org/fhir/matchStatus' satisfies OwlObjectProperty;

/**
 * usePeriod
 *
 * Contract.term.group.asset.usePeriod: Time period of asset use.
 *
 * http://hl7.org/fhir/usePeriod
 */
export const usePeriod = 'http://hl7.org/fhir/usePeriod' satisfies OwlObjectProperty;

/**
 * _participant
 *
 * (Modified) PlanDefinition.action.participant
 *
 * http://hl7.org/fhir/_participant
 */
export const _participant = 'http://hl7.org/fhir/_participant' satisfies OwlObjectProperty;

/**
 * MessageDestination
 *
 * MessageHeader.MessageDestination: The destination application which the message is intended for.
 *
 * http://hl7.org/fhir/MessageDestination
 */
export const MessageDestination = 'http://hl7.org/fhir/MessageDestination' satisfies OwlClass;

/**
 * _additionalInfo
 *
 * (Modified) VirtualServiceDetail.additionalInfo
 *
 * http://hl7.org/fhir/_additionalInfo
 */
export const _additionalInfo = 'http://hl7.org/fhir/_additionalInfo' satisfies OwlObjectProperty;

/**
 * _numberOfEvents
 *
 * (Modified) Evidence.statistic.numberOfEvents
 *
 * http://hl7.org/fhir/_numberOfEvents
 */
export const _numberOfEvents = 'http://hl7.org/fhir/_numberOfEvents' satisfies OwlObjectProperty;

/**
 * _includedStructure
 *
 * (Modified) BodyStructure.includedStructure
 *
 * http://hl7.org/fhir/_includedStructure
 */
export const _includedStructure = 'http://hl7.org/fhir/_includedStructure' satisfies OwlObjectProperty;

/**
 * _imageRegion2D
 *
 * (Modified) ImagingSelection.instance.imageRegion2D
 *
 * http://hl7.org/fhir/_imageRegion2D
 */
export const _imageRegion2D = 'http://hl7.org/fhir/_imageRegion2D' satisfies OwlObjectProperty;

/**
 * _tax
 *
 * (Modified) ExplanationOfBenefit.item.detail.subDetail.tax
 *
 * http://hl7.org/fhir/_tax
 */
export const _tax = 'http://hl7.org/fhir/_tax' satisfies OwlObjectProperty;

/**
 * _appointment
 *
 * (Modified) Encounter.appointment
 *
 * http://hl7.org/fhir/_appointment
 */
export const _appointment = 'http://hl7.org/fhir/_appointment' satisfies OwlObjectProperty;

/**
 * treatmentIntent
 *
 * MedicationKnowledge.indicationGuideline.dosingGuideline.treatmentIntent: The overall intention of the treatment, for example, prophylactic, supporative, curative, etc.
 *
 * http://hl7.org/fhir/treatmentIntent
 */
export const treatmentIntent = 'http://hl7.org/fhir/treatmentIntent' satisfies OwlObjectProperty;

/**
 * SubstanceDefinitionCodeComponent
 *
 * SubstanceDefinitionCodeComponent: Codes associated with the substance.
 *
 * http://hl7.org/fhir/SubstanceDefinitionCodeComponent
 */
export const SubstanceDefinitionCodeComponent = 'http://hl7.org/fhir/SubstanceDefinitionCodeComponent' satisfies OwlClass;

/**
 * _study
 *
 * (Modified) ResearchSubject.study
 *
 * http://hl7.org/fhir/_study
 */
export const _study = 'http://hl7.org/fhir/_study' satisfies OwlObjectProperty;

/**
 * _ratioType
 *
 * (Modified) SubstancePolymer.monomerSet.ratioType
 *
 * http://hl7.org/fhir/_ratioType
 */
export const _ratioType = 'http://hl7.org/fhir/_ratioType' satisfies OwlObjectProperty;

/**
 * policyHolder
 *
 * Coverage.policyHolder: The party who 'owns' the insurance policy.
 *
 * http://hl7.org/fhir/policyHolder
 */
export const policyHolder = 'http://hl7.org/fhir/policyHolder' satisfies OwlObjectProperty;

/**
 * region
 *
 * ResearchStudy.region: A country, state or other area where the study is taking place rather than its precise geographic location or address.
 *
 * http://hl7.org/fhir/region
 */
export const region = 'http://hl7.org/fhir/region' satisfies OwlObjectProperty;

/**
 * operationType
 *
 * InventoryReport.operationType: What type of operation is being performed - addition or subtraction.
 *
 * http://hl7.org/fhir/operationType
 */
export const operationType = 'http://hl7.org/fhir/operationType' satisfies OwlObjectProperty;

/**
 * _actuality
 *
 * (Modified) AdverseEvent.actuality
 *
 * http://hl7.org/fhir/_actuality
 */
export const _actuality = 'http://hl7.org/fhir/_actuality' satisfies OwlObjectProperty;

/**
 * _definitionUri
 *
 * (Modified) ChargeItem.definitionUri
 *
 * http://hl7.org/fhir/_definitionUri
 */
export const _definitionUri = 'http://hl7.org/fhir/_definitionUri' satisfies OwlObjectProperty;

/**
 * organismId
 *
 * SubstanceSourceMaterial.organismId: The unique identifier associated with the source material parent organism shall be specified.
 *
 * http://hl7.org/fhir/organismId
 */
export const organismId = 'http://hl7.org/fhir/organismId' satisfies OwlObjectProperty;

/**
 * ManufacturedItemDefinitionComponentComponentComponentProperty
 *
 * General characteristics of this component.
 *
 * http://hl7.org/fhir/ManufacturedItemDefinitionComponentComponentComponentProperty
 */
export const ManufacturedItemDefinitionComponentComponentComponentProperty = 'http://hl7.org/fhir/ManufacturedItemDefinitionComponentComponentComponentProperty' satisfies OwlClass;

/**
 * _consumedItem
 *
 * (Modified) NutritionIntake.consumedItem
 *
 * http://hl7.org/fhir/_consumedItem
 */
export const _consumedItem = 'http://hl7.org/fhir/_consumedItem' satisfies OwlObjectProperty;

/**
 * thursday
 *
 * Appointment.recurrenceTemplate.weeklyTemplate.thursday: Indicates that recurring appointments should occur on Thursdays.
 *
 * http://hl7.org/fhir/thursday
 */
export const thursday = 'http://hl7.org/fhir/thursday' satisfies OwlObjectProperty;

/**
 * _rules
 *
 * (Modified) ElementDefinition.slicing.rules
 *
 * http://hl7.org/fhir/_rules
 */
export const _rules = 'http://hl7.org/fhir/_rules' satisfies OwlObjectProperty;

/**
 * dependent
 *
 * StructureMap.group.rule.dependent: Which other rules to apply in the context of this rule.
 *
 * http://hl7.org/fhir/dependent
 */
export const dependent = 'http://hl7.org/fhir/dependent' satisfies OwlObjectProperty;

/**
 * deliverFrom
 *
 * SupplyRequest.deliverFrom: Where the supply is expected to come from.
 *
 * http://hl7.org/fhir/deliverFrom
 */
export const deliverFrom = 'http://hl7.org/fhir/deliverFrom' satisfies OwlObjectProperty;

/**
 * ImmunizationProtocolAppliedComponent
 *
 * ImmunizationProtocolAppliedComponent: The protocol (set of recommendations) being followed by the provider who administered the dose.
 *
 * http://hl7.org/fhir/ImmunizationProtocolAppliedComponent
 */
export const ImmunizationProtocolAppliedComponent = 'http://hl7.org/fhir/ImmunizationProtocolAppliedComponent' satisfies OwlClass;

/**
 * actualGroup
 *
 * ResearchStudy.recruitment.actualGroup: Group of participants who were enrolled in study.
 *
 * http://hl7.org/fhir/actualGroup
 */
export const actualGroup = 'http://hl7.org/fhir/actualGroup' satisfies OwlObjectProperty;

/**
 * Age
 *
 * A duration of time during which an organism (or a process) has existed.
 *
 * http://hl7.org/fhir/Age
 */
export const Age = 'http://hl7.org/fhir/Age' satisfies OwlClass;

/**
 * subsumption
 *
 * TerminologyCapabilities.codeSystem.subsumption: True if subsumption is supported for this version of the code system.
 *
 * http://hl7.org/fhir/subsumption
 */
export const subsumption = 'http://hl7.org/fhir/subsumption' satisfies OwlObjectProperty;

/**
 * ElementDefinitionConstraintComponent
 *
 * ElementDefinitionConstraintComponent: Formal constraints such as co-occurrence and other constraints that can be computationally evaluated within the context of the instance.
 *
 * http://hl7.org/fhir/ElementDefinitionConstraintComponent
 */
export const ElementDefinitionConstraintComponent = 'http://hl7.org/fhir/ElementDefinitionConstraintComponent' satisfies OwlClass;

/**
 * subjectResults
 *
 * MeasureReport.group.stratifier.stratum.population.subjectResults: This element refers to a List of individual level MeasureReport resources, one for each subject in this population in this stratum.
 *
 * http://hl7.org/fhir/subjectResults
 */
export const subjectResults = 'http://hl7.org/fhir/subjectResults' satisfies OwlObjectProperty;

/**
 * OperationDefinitionOverloadComponent
 *
 * OperationDefinitionOverloadComponent: Defines an appropriate combination of parameters to use when invoking this operation, to help code generators when generating overloaded parameter sets for this operation.
 *
 * http://hl7.org/fhir/OperationDefinitionOverloadComponent
 */
export const OperationDefinitionOverloadComponent = 'http://hl7.org/fhir/OperationDefinitionOverloadComponent' satisfies OwlClass;

/**
 * recurrenceTemplate
 *
 * Appointment.recurrenceTemplate: The details of the recurrence pattern or template that is used to generate recurring appointments.
 *
 * http://hl7.org/fhir/recurrenceTemplate
 */
export const recurrenceTemplate = 'http://hl7.org/fhir/recurrenceTemplate' satisfies OwlObjectProperty;

/**
 * doseForm
 *
 * MedicationKnowledge.definitional.doseForm: Describes the form of the item.  Powder; tablets; capsule.
 *
 * http://hl7.org/fhir/doseForm
 */
export const doseForm = 'http://hl7.org/fhir/doseForm' satisfies OwlObjectProperty;

/**
 * adherence
 *
 * MedicationStatement.adherence: Indicates whether the medication is or is not being consumed or administered.
 *
 * http://hl7.org/fhir/adherence
 */
export const adherence = 'http://hl7.org/fhir/adherence' satisfies OwlObjectProperty;

/**
 * ServiceRequest
 *
 * A record of a request for service such as diagnostic investigations, treatments, or operations to be performed.
 *
 * http://hl7.org/fhir/ServiceRequest
 */
export const ServiceRequest = 'http://hl7.org/fhir/ServiceRequest' satisfies OwlClass;

/**
 * deviceIdentifier
 *
 * Device.udiCarrier.deviceIdentifier: The device identifier (DI) is a mandatory, fixed portion of a UDI that identifies the labeler and the specific version or model of a device.
 *
 * http://hl7.org/fhir/deviceIdentifier
 */
export const deviceIdentifier = 'http://hl7.org/fhir/deviceIdentifier' satisfies OwlObjectProperty;

/**
 * _reasonLinkId
 *
 * (Modified) Contract.term.group.action.reasonLinkId
 *
 * http://hl7.org/fhir/_reasonLinkId
 */
export const _reasonLinkId = 'http://hl7.org/fhir/_reasonLinkId' satisfies OwlObjectProperty;

/**
 * versionId
 *
 * Meta.versionId: The version specific identifier, as it appears in the version portion of the URL. This value changes when the resource is created, updated, or deleted.
 *
 * http://hl7.org/fhir/versionId
 */
export const versionId = 'http://hl7.org/fhir/versionId' satisfies OwlObjectProperty;

/**
 * componentPart
 *
 * PackagedProductDefinition.packaging.packaging.componentPart: Is this a part of the packaging (e.g. a cap or bottle stopper), rather than the packaging itself (e.g. a bottle or vial). The latter type are designed be a container, but the former are not.
 *
 * http://hl7.org/fhir/componentPart
 */
export const componentPart = 'http://hl7.org/fhir/componentPart' satisfies OwlObjectProperty;

/**
 * _value
 *
 * (Modified) ResearchStudy.label.value
 *
 * http://hl7.org/fhir/_value
 */
export const _value = 'http://hl7.org/fhir/_value' satisfies OwlObjectProperty;

/**
 * TestReportParticipantComponent
 *
 * TestReportParticipantComponent: A participant in the test execution, either the execution engine, a client, or a server.
 *
 * http://hl7.org/fhir/TestReportParticipantComponent
 */
export const TestReportParticipantComponent = 'http://hl7.org/fhir/TestReportParticipantComponent' satisfies OwlClass;

/**
 * morphology
 *
 * BodyStructure.morphology: The kind of structure being represented by the body structure at `BodyStructure.location`.  This can define both normal and abnormal morphologies.
 *
 * http://hl7.org/fhir/morphology
 */
export const morphology = 'http://hl7.org/fhir/morphology' satisfies OwlObjectProperty;

/**
 * date
 *
 * ResearchStudy.date: The date (and optionally time) when the ResearchStudy Resource was last significantly changed. The date must change when the business version changes and it must change if the status code changes. In addition, it should change when the substantive content of the ResearchStudy Resource changes.
 *
 * http://hl7.org/fhir/date
 */
export const date = 'http://hl7.org/fhir/date' satisfies OwlObjectProperty;

/**
 * _isModifier
 *
 * (Modified) ElementDefinition.isModifier
 *
 * http://hl7.org/fhir/_isModifier
 */
export const _isModifier = 'http://hl7.org/fhir/_isModifier' satisfies OwlObjectProperty;

/**
 * _allDay
 *
 * (Modified) Availability.availableTime.allDay
 *
 * http://hl7.org/fhir/_allDay
 */
export const _allDay = 'http://hl7.org/fhir/_allDay' satisfies OwlObjectProperty;

/**
 * contentReference
 *
 * ElementDefinition.contentReference: Identifies an element defined elsewhere in the definition whose content rules should be applied to the current element. ContentReferences bring across all the rules that are in the ElementDefinition for the element, including definitions, cardinality constraints, bindings, invariants etc.
 *
 * http://hl7.org/fhir/contentReference
 */
export const contentReference = 'http://hl7.org/fhir/contentReference' satisfies OwlObjectProperty;

/**
 * _sunday
 *
 * (Modified) Appointment.recurrenceTemplate.weeklyTemplate.sunday
 *
 * http://hl7.org/fhir/_sunday
 */
export const _sunday = 'http://hl7.org/fhir/_sunday' satisfies OwlObjectProperty;

/**
 * DeviceUsageAdherenceComponent
 *
 * DeviceUsageAdherenceComponent: This indicates how or if the device is being used.
 *
 * http://hl7.org/fhir/DeviceUsageAdherenceComponent
 */
export const DeviceUsageAdherenceComponent = 'http://hl7.org/fhir/DeviceUsageAdherenceComponent' satisfies OwlClass;

/**
 * maxSingleDose
 *
 * AdministrableProductDefinition.routeOfAdministration.maxSingleDose: The maximum single dose that can be administered, specified using a numerical value and its unit of measurement.
 *
 * http://hl7.org/fhir/maxSingleDose
 */
export const maxSingleDose = 'http://hl7.org/fhir/maxSingleDose' satisfies OwlObjectProperty;

/**
 * referenceRange
 *
 * Observation.component.referenceRange: Guidance on how to interpret the value by comparison to a normal or recommended range.
 *
 * http://hl7.org/fhir/referenceRange
 */
export const referenceRange = 'http://hl7.org/fhir/referenceRange' satisfies OwlObjectProperty;

/**
 * _pages
 *
 * (Modified) Attachment.pages
 *
 * http://hl7.org/fhir/_pages
 */
export const _pages = 'http://hl7.org/fhir/_pages' satisfies OwlObjectProperty;

/**
 * DeviceDefinitionGuidelineComponent
 *
 * DeviceDefinitionGuidelineComponent: Information aimed at providing directions for the usage of this model of device.
 *
 * http://hl7.org/fhir/DeviceDefinitionGuidelineComponent
 */
export const DeviceDefinitionGuidelineComponent = 'http://hl7.org/fhir/DeviceDefinitionGuidelineComponent' satisfies OwlClass;

/**
 * _temperatureRange
 *
 * (Modified) SpecimenDefinition.typeTested.handling.temperatureRange
 *
 * http://hl7.org/fhir/_temperatureRange
 */
export const _temperatureRange = 'http://hl7.org/fhir/_temperatureRange' satisfies OwlObjectProperty;

/**
 * _sequenceType
 *
 * (Modified) SubstanceProtein.sequenceType
 *
 * http://hl7.org/fhir/_sequenceType
 */
export const _sequenceType = 'http://hl7.org/fhir/_sequenceType' satisfies OwlObjectProperty;

/**
 * _partNumber
 *
 * (Modified) DeviceDefinition.partNumber
 *
 * http://hl7.org/fhir/_partNumber
 */
export const _partNumber = 'http://hl7.org/fhir/_partNumber' satisfies OwlObjectProperty;

/**
 * _term
 *
 * (Modified) Measure.term
 *
 * http://hl7.org/fhir/_term
 */
export const _term = 'http://hl7.org/fhir/_term' satisfies OwlObjectProperty;

/**
 * StructureDefinitionDifferentialComponent
 *
 * StructureDefinitionDifferentialComponent: A differential view is expressed relative to the base StructureDefinition - a statement of differences that it applies.
 *
 * http://hl7.org/fhir/StructureDefinitionDifferentialComponent
 */
export const StructureDefinitionDifferentialComponent = 'http://hl7.org/fhir/StructureDefinitionDifferentialComponent' satisfies OwlClass;

/**
 * _udi
 *
 * (Modified) Claim.item.udi
 *
 * http://hl7.org/fhir/_udi
 */
export const _udi = 'http://hl7.org/fhir/_udi' satisfies OwlObjectProperty;

/**
 * _telecom
 *
 * (Modified) Patient.telecom
 *
 * http://hl7.org/fhir/_telecom
 */
export const _telecom = 'http://hl7.org/fhir/_telecom' satisfies OwlObjectProperty;

/**
 * CitationCitedArtifactPublicationFormPublishedInComponent
 *
 * CitationCitedArtifactComponent.CitationCitedArtifactPublicationFormComponent.CitationCitedArtifactPublicationFormPublishedInComponent: The collection the cited article or artifact is published in.
 *
 * http://hl7.org/fhir/CitationCitedArtifactPublicationFormPublishedInComponent
 */
export const CitationCitedArtifactPublicationFormPublishedInComponent = 'http://hl7.org/fhir/CitationCitedArtifactPublicationFormPublishedInComponent' satisfies OwlClass;

/**
 * _wasSubstituted
 *
 * (Modified) MedicationDispense.substitution.wasSubstituted
 *
 * http://hl7.org/fhir/_wasSubstituted
 */
export const _wasSubstituted = 'http://hl7.org/fhir/_wasSubstituted' satisfies OwlObjectProperty;

/**
 * initial
 *
 * Questionnaire.item.item.initial: One or more values that should be pre-populated in the answer when initially rendering the questionnaire for user input.
 *
 * http://hl7.org/fhir/initial
 */
export const initial = 'http://hl7.org/fhir/initial' satisfies OwlObjectProperty;

/**
 * doNotPerform
 *
 * Contract.term.action.doNotPerform: True if the term prohibits the  action.
 *
 * http://hl7.org/fhir/doNotPerform
 */
export const doNotPerform = 'http://hl7.org/fhir/doNotPerform' satisfies OwlObjectProperty;

/**
 * diameter
 *
 * VisionPrescription.lensSpecification.diameter: Contact lens diameter measured in millimetres.
 *
 * http://hl7.org/fhir/diameter
 */
export const diameter = 'http://hl7.org/fhir/diameter' satisfies OwlObjectProperty;

/**
 * _property
 *
 * (Modified) ValueSet.compose.include.filter.property
 *
 * http://hl7.org/fhir/_property
 */
export const _property = 'http://hl7.org/fhir/_property' satisfies OwlObjectProperty;

/**
 * MessageHeaderResponseComponent
 *
 * MessageHeaderResponseComponent: Information about the message that this message is a response to.  Only present if this message is a response.
 *
 * http://hl7.org/fhir/MessageHeaderResponseComponent
 */
export const MessageHeaderResponseComponent = 'http://hl7.org/fhir/MessageHeaderResponseComponent' satisfies OwlClass;

/**
 * Linkage
 *
 * Identifies two or more records (resource instances) that refer to the same real-world "occurrence".
 *
 * http://hl7.org/fhir/Linkage
 */
export const Linkage = 'http://hl7.org/fhir/Linkage' satisfies OwlClass;

/**
 * permittedUnit
 *
 * ObservationDefinition.component.permittedUnit: Units allowed for the valueQuantity element in the instance observations conforming to this ObservationDefinition.
 *
 * http://hl7.org/fhir/permittedUnit
 */
export const permittedUnit = 'http://hl7.org/fhir/permittedUnit' satisfies OwlObjectProperty;

/**
 * _sex
 *
 * (Modified) FamilyMemberHistory.sex
 *
 * http://hl7.org/fhir/_sex
 */
export const _sex = 'http://hl7.org/fhir/_sex' satisfies OwlObjectProperty;

/**
 * genomeBuild
 *
 * GenomicStudy.analysis.genomeBuild: The reference genome build that is used in this analysis.
 *
 * http://hl7.org/fhir/genomeBuild
 */
export const genomeBuild = 'http://hl7.org/fhir/genomeBuild' satisfies OwlObjectProperty;

/**
 * changePattern
 *
 * ClinicalImpression.changePattern: Change in the status/pattern of a subject's condition since previously assessed, such as worsening, improving, or no change.  It is a subjective assessment of the direction of the change.
 *
 * http://hl7.org/fhir/changePattern
 */
export const changePattern = 'http://hl7.org/fhir/changePattern' satisfies OwlObjectProperty;

/**
 * MedicationRequestSubstitutionComponent
 *
 * MedicationRequestSubstitutionComponent: Indicates whether or not substitution can or should be part of the dispense. In some cases, substitution must happen, in other cases substitution must not happen. This block explains the prescriber's intent. If nothing is specified substitution may be done.
 *
 * http://hl7.org/fhir/MedicationRequestSubstitutionComponent
 */
export const MedicationRequestSubstitutionComponent = 'http://hl7.org/fhir/MedicationRequestSubstitutionComponent' satisfies OwlClass;

/**
 * _authority
 *
 * (Modified) SubstanceDefinition.name.official.authority
 *
 * http://hl7.org/fhir/_authority
 */
export const _authority = 'http://hl7.org/fhir/_authority' satisfies OwlObjectProperty;

/**
 * onBehalfOf
 *
 * Provenance.entity.agent.onBehalfOf: The agent that delegated authority to perform the activity performed by the agent.who element.
 *
 * http://hl7.org/fhir/onBehalfOf
 */
export const onBehalfOf = 'http://hl7.org/fhir/onBehalfOf' satisfies OwlObjectProperty;

/**
 * _rateAggregation
 *
 * (Modified) Measure.group.rateAggregation
 *
 * http://hl7.org/fhir/_rateAggregation
 */
export const _rateAggregation = 'http://hl7.org/fhir/_rateAggregation' satisfies OwlObjectProperty;

/**
 * managingOrganization
 *
 * Patient.managingOrganization: Organization that is the custodian of the patient record.
 *
 * http://hl7.org/fhir/managingOrganization
 */
export const managingOrganization = 'http://hl7.org/fhir/managingOrganization' satisfies OwlObjectProperty;

/**
 * handling
 *
 * SpecimenDefinition.typeTested.handling: Set of instructions for preservation/transport of the specimen at a defined temperature interval, prior the testing process.
 *
 * http://hl7.org/fhir/handling
 */
export const handling = 'http://hl7.org/fhir/handling' satisfies OwlObjectProperty;

/**
 * notConsumedReason
 *
 * NutritionIntake.consumedItem.notConsumedReason: Document the reason the food or fluid was not consumed, such as refused, held, etc.
 *
 * http://hl7.org/fhir/notConsumedReason
 */
export const notConsumedReason = 'http://hl7.org/fhir/notConsumedReason' satisfies OwlObjectProperty;

/**
 * axis
 *
 * VisionPrescription.lensSpecification.axis: Adjustment for astigmatism measured in integer degrees.
 *
 * http://hl7.org/fhir/axis
 */
export const axis = 'http://hl7.org/fhir/axis' satisfies OwlObjectProperty;

/**
 * _udiCarrier
 *
 * (Modified) Device.udiCarrier
 *
 * http://hl7.org/fhir/_udiCarrier
 */
export const _udiCarrier = 'http://hl7.org/fhir/_udiCarrier' satisfies OwlObjectProperty;

/**
 * paymentBy
 *
 * Coverage.paymentBy: Link to the paying party and optionally what specifically they will be responsible to pay.
 *
 * http://hl7.org/fhir/paymentBy
 */
export const paymentBy = 'http://hl7.org/fhir/paymentBy' satisfies OwlObjectProperty;

/**
 * _insurancePlan
 *
 * (Modified) Coverage.insurancePlan
 *
 * http://hl7.org/fhir/_insurancePlan
 */
export const _insurancePlan = 'http://hl7.org/fhir/_insurancePlan' satisfies OwlObjectProperty;

/**
 * subDetailSequence
 *
 * ExplanationOfBenefit.addItem.subDetailSequence: The sequence number of the sub-details woithin the details within the claim item which this line is intended to replace.
 *
 * http://hl7.org/fhir/subDetailSequence
 */
export const subDetailSequence = 'http://hl7.org/fhir/subDetailSequence' satisfies OwlObjectProperty;

/**
 * DataRequirementValueFilterComponent
 *
 * DataRequirementValueFilterComponent: Value filters specify additional constraints on the data for elements other than code-valued or date-valued. Each value filter specifies an additional constraint on the data (i.e. valueFilters are AND'ed, not OR'ed).
 *
 * http://hl7.org/fhir/DataRequirementValueFilterComponent
 */
export const DataRequirementValueFilterComponent = 'http://hl7.org/fhir/DataRequirementValueFilterComponent' satisfies OwlClass;

/**
 * problem
 *
 * ClinicalImpression.problem: A list of the relevant problems/conditions for a patient.
 *
 * http://hl7.org/fhir/problem
 */
export const problem = 'http://hl7.org/fhir/problem' satisfies OwlObjectProperty;

/**
 * initialFill
 *
 * MedicationRequest.dispenseRequest.initialFill: Indicates the quantity or duration for the first dispense of the medication.
 *
 * http://hl7.org/fhir/initialFill
 */
export const initialFill = 'http://hl7.org/fhir/initialFill' satisfies OwlObjectProperty;

/**
 * _ManufacturedItemDefinition
 *
 * (Modified) ManufacturedItemDefinition
 *
 * http://hl7.org/fhir/_ManufacturedItemDefinition
 */
export const _ManufacturedItemDefinition = 'http://hl7.org/fhir/_ManufacturedItemDefinition' satisfies OwlClass;

/**
 * _improvementNotation
 *
 * (Modified) MeasureReport.improvementNotation
 *
 * http://hl7.org/fhir/_improvementNotation
 */
export const _improvementNotation = 'http://hl7.org/fhir/_improvementNotation' satisfies OwlObjectProperty;

/**
 * ClinicalUseDefinitionIndicationComponentOtherTherapy
 *
 * Information about the use of the medicinal product in relation to other therapies described as part of the indication.
 *
 * http://hl7.org/fhir/ClinicalUseDefinitionIndicationComponentOtherTherapy
 */
export const ClinicalUseDefinitionIndicationComponentOtherTherapy = 'http://hl7.org/fhir/ClinicalUseDefinitionIndicationComponentOtherTherapy' satisfies OwlClass;

/**
 * fraction
 *
 * SubstanceSourceMaterial.fractionDescription.fraction: This element is capturing information about the fraction of a plant part, or human plasma for fractionation.
 *
 * http://hl7.org/fhir/fraction
 */
export const fraction = 'http://hl7.org/fhir/fraction' satisfies OwlObjectProperty;

/**
 * _lastOccurrence
 *
 * (Modified) AllergyIntolerance.lastOccurrence
 *
 * http://hl7.org/fhir/_lastOccurrence
 */
export const _lastOccurrence = 'http://hl7.org/fhir/_lastOccurrence' satisfies OwlObjectProperty;

/**
 * _assessment
 *
 * (Modified) Condition.stage.assessment
 *
 * http://hl7.org/fhir/_assessment
 */
export const _assessment = 'http://hl7.org/fhir/_assessment' satisfies OwlObjectProperty;

/**
 * Patient
 *
 * Demographics and other administrative information about an individual or animal receiving care or other health-related services.
 *
 * http://hl7.org/fhir/Patient
 */
export const Patient = 'http://hl7.org/fhir/Patient' satisfies OwlClass;

/**
 * _identified
 *
 * (Modified) DetectedIssue.identified
 *
 * http://hl7.org/fhir/_identified
 */
export const _identified = 'http://hl7.org/fhir/_identified' satisfies OwlObjectProperty;

/**
 * ExplanationOfBenefitAdjudication
 *
 * The adjudication results which are presented at the header level rather than at the line-item or add-item levels.
 *
 * http://hl7.org/fhir/ExplanationOfBenefitAdjudication
 */
export const ExplanationOfBenefitAdjudication = 'http://hl7.org/fhir/ExplanationOfBenefitAdjudication' satisfies OwlClass;

/**
 * _Subscription
 *
 * (Modified) Subscription
 *
 * http://hl7.org/fhir/_Subscription
 */
export const _Subscription = 'http://hl7.org/fhir/_Subscription' satisfies OwlClass;

/**
 * tag
 *
 * Meta.tag: Tags applied to this resource. Tags are intended to be used to identify and relate resources to process and workflow, and applications are not required to consider the tags when interpreting the meaning of a resource.
 *
 * http://hl7.org/fhir/tag
 */
export const tag = 'http://hl7.org/fhir/tag' satisfies OwlObjectProperty;

/**
 * _performed
 *
 * (Modified) FamilyMemberHistory.procedure.performed
 *
 * http://hl7.org/fhir/_performed
 */
export const _performed = 'http://hl7.org/fhir/_performed' satisfies OwlObjectProperty;

/**
 * _formOf
 *
 * (Modified) AdministrableProductDefinition.formOf
 *
 * http://hl7.org/fhir/_formOf
 */
export const _formOf = 'http://hl7.org/fhir/_formOf' satisfies OwlObjectProperty;

/**
 * DeviceDefinitionPackagingComponentPackagingPackaging
 *
 * Allows packages within packages.
 *
 * http://hl7.org/fhir/DeviceDefinitionPackagingComponentPackagingPackaging
 */
export const DeviceDefinitionPackagingComponentPackagingPackaging = 'http://hl7.org/fhir/DeviceDefinitionPackagingComponentPackagingPackaging' satisfies OwlClass;

/**
 * _subrogation
 *
 * (Modified) Coverage.subrogation
 *
 * http://hl7.org/fhir/_subrogation
 */
export const _subrogation = 'http://hl7.org/fhir/_subrogation' satisfies OwlObjectProperty;

/**
 * _deceased
 *
 * (Modified) Practitioner.deceased
 *
 * http://hl7.org/fhir/_deceased
 */
export const _deceased = 'http://hl7.org/fhir/_deceased' satisfies OwlObjectProperty;

/**
 * relatedAccount
 *
 * Account.relatedAccount: Other associated accounts related to this account.
 *
 * http://hl7.org/fhir/relatedAccount
 */
export const relatedAccount = 'http://hl7.org/fhir/relatedAccount' satisfies OwlObjectProperty;

/**
 * Transport
 *
 * Record of transport.
 *
 * http://hl7.org/fhir/Transport
 */
export const Transport = 'http://hl7.org/fhir/Transport' satisfies OwlClass;

/**
 * Measure
 *
 * The Measure resource provides the definition of a quality measure.
 *
 * http://hl7.org/fhir/Measure
 */
export const Measure = 'http://hl7.org/fhir/Measure' satisfies OwlClass;

/**
 * RiskAssessment
 *
 * An assessment of the likely outcome(s) for a patient or other subject as well as the likelihood of each outcome.
 *
 * http://hl7.org/fhir/RiskAssessment
 */
export const RiskAssessment = 'http://hl7.org/fhir/RiskAssessment' satisfies OwlClass;

/**
 * _teardown
 *
 * (Modified) TestScript.teardown
 *
 * http://hl7.org/fhir/_teardown
 */
export const _teardown = 'http://hl7.org/fhir/_teardown' satisfies OwlObjectProperty;

/**
 * degreeOfPolymerisation
 *
 * SubstancePolymer.repeat.repeatUnit.degreeOfPolymerisation: Applies to homopolymer and block co-polymers where the degree of polymerisation within a block can be described.
 *
 * http://hl7.org/fhir/degreeOfPolymerisation
 */
export const degreeOfPolymerisation = 'http://hl7.org/fhir/degreeOfPolymerisation' satisfies OwlObjectProperty;

/**
 * _CoverageEligibilityRequest
 *
 * (Modified) CoverageEligibilityRequest
 *
 * http://hl7.org/fhir/_CoverageEligibilityRequest
 */
export const _CoverageEligibilityRequest = 'http://hl7.org/fhir/_CoverageEligibilityRequest' satisfies OwlClass;

/**
 * _Medication
 *
 * (Modified) Medication
 *
 * http://hl7.org/fhir/_Medication
 */
export const _Medication = 'http://hl7.org/fhir/_Medication' satisfies OwlClass;

/**
 * manufacturedDoseForm
 *
 * ManufacturedItemDefinition.manufacturedDoseForm: Dose form as manufactured and before any transformation into the pharmaceutical product.
 *
 * http://hl7.org/fhir/manufacturedDoseForm
 */
export const manufacturedDoseForm = 'http://hl7.org/fhir/manufacturedDoseForm' satisfies OwlObjectProperty;

/**
 * sliceName
 *
 * GraphDefinition.link.sliceName: Which slice (if profiled).
 *
 * http://hl7.org/fhir/sliceName
 */
export const sliceName = 'http://hl7.org/fhir/sliceName' satisfies OwlObjectProperty;

/**
 * dateAsserted
 *
 * MedicationStatement.dateAsserted: The date when the Medication Statement was asserted by the information source.
 *
 * http://hl7.org/fhir/dateAsserted
 */
export const dateAsserted = 'http://hl7.org/fhir/dateAsserted' satisfies OwlObjectProperty;

/**
 * ContractParty
 *
 * Contract.TermTerm.ContractOffer.ContractParty: Offer Recipient.
 *
 * http://hl7.org/fhir/ContractParty
 */
export const ContractParty = 'http://hl7.org/fhir/ContractParty' satisfies OwlClass;

/**
 * validationStatus
 *
 * VerificationResult.primarySource.validationStatus: Status of the validation of the target against the primary source (successful; failed; unknown).
 *
 * http://hl7.org/fhir/validationStatus
 */
export const validationStatus = 'http://hl7.org/fhir/validationStatus' satisfies OwlObjectProperty;

/**
 * TestScriptMetadataComponent
 *
 * TestScriptMetadataComponent: The required capability must exist and are assumed to function correctly on the FHIR server being tested.
 *
 * http://hl7.org/fhir/TestScriptMetadataComponent
 */
export const TestScriptMetadataComponent = 'http://hl7.org/fhir/TestScriptMetadataComponent' satisfies OwlClass;

/**
 * _headerField
 *
 * (Modified) TestScript.test.action.assert.headerField
 *
 * http://hl7.org/fhir/_headerField
 */
export const _headerField = 'http://hl7.org/fhir/_headerField' satisfies OwlObjectProperty;

/**
 * geographicalLocation
 *
 * SubstanceSourceMaterial.geographicalLocation: The place/region where the plant is harvested or the places/regions where the animal source material has its habitat.
 *
 * http://hl7.org/fhir/geographicalLocation
 */
export const geographicalLocation = 'http://hl7.org/fhir/geographicalLocation' satisfies OwlObjectProperty;

/**
 * versionNeeded
 *
 * CodeSystem.versionNeeded: This flag is used to signify that the code system does not commit to concept permanence across versions. If true, a version must be specified when referencing this code system.
 *
 * http://hl7.org/fhir/versionNeeded
 */
export const versionNeeded = 'http://hl7.org/fhir/versionNeeded' satisfies OwlObjectProperty;

/**
 * ConceptDefinition
 *
 * CodeSystem.ConceptDefinition: Concepts that are in the code system. The concept definitions are inherently hierarchical, but the definitions must be consulted to determine what the meanings of the hierarchical relationships are.
 *
 * http://hl7.org/fhir/ConceptDefinition
 */
export const ConceptDefinition = 'http://hl7.org/fhir/ConceptDefinition' satisfies OwlClass;

/**
 * _sigFormat
 *
 * (Modified) Signature.sigFormat
 *
 * http://hl7.org/fhir/_sigFormat
 */
export const _sigFormat = 'http://hl7.org/fhir/_sigFormat' satisfies OwlObjectProperty;

/**
 * publishedIn
 *
 * Citation.citedArtifact.publicationForm.publishedIn: The collection the cited article or artifact is published in.
 *
 * http://hl7.org/fhir/publishedIn
 */
export const publishedIn = 'http://hl7.org/fhir/publishedIn' satisfies OwlObjectProperty;

/**
 * sphere
 *
 * VisionPrescription.lensSpecification.sphere: Lens power measured in dioptres (0.25 units).
 *
 * http://hl7.org/fhir/sphere
 */
export const sphere = 'http://hl7.org/fhir/sphere' satisfies OwlObjectProperty;

/**
 * _SubstanceDefinition
 *
 * (Modified) SubstanceDefinition
 *
 * http://hl7.org/fhir/_SubstanceDefinition
 */
export const _SubstanceDefinition = 'http://hl7.org/fhir/_SubstanceDefinition' satisfies OwlClass;

/**
 * SubstanceDefinitionNameOfficialComponent
 *
 * SubstanceDefinitionNameComponentName.SubstanceDefinitionNameOfficialComponent: Details of the official nature of this name.
 *
 * http://hl7.org/fhir/SubstanceDefinitionNameOfficialComponent
 */
export const SubstanceDefinitionNameOfficialComponent = 'http://hl7.org/fhir/SubstanceDefinitionNameOfficialComponent' satisfies OwlClass;

/**
 * _listRuleId
 *
 * (Modified) StructureMap.group.rule.rule.target.listRuleId
 *
 * http://hl7.org/fhir/_listRuleId
 */
export const _listRuleId = 'http://hl7.org/fhir/_listRuleId' satisfies OwlObjectProperty;

/**
 * started
 *
 * ImagingStudy.series.started: The date and time the series was started.
 *
 * http://hl7.org/fhir/started
 */
export const started = 'http://hl7.org/fhir/started' satisfies OwlObjectProperty;

/**
 * EvidenceVariable
 *
 * The EvidenceVariable resource describes an element that knowledge (Evidence) is about.
 *
 * http://hl7.org/fhir/EvidenceVariable
 */
export const EvidenceVariable = 'http://hl7.org/fhir/EvidenceVariable' satisfies OwlClass;

/**
 * ResearchStudyOutcomeMeasureComponent
 *
 * ResearchStudyOutcomeMeasureComponent: An "outcome measure", "endpoint", "effect measure" or "measure of effect" is a specific measurement or observation used to quantify the effect of experimental variables on the participants in a study, or for observational studies, to describe patterns of diseases or traits or associations with exposures, risk factors or treatment.
 *
 * http://hl7.org/fhir/ResearchStudyOutcomeMeasureComponent
 */
export const ResearchStudyOutcomeMeasureComponent = 'http://hl7.org/fhir/ResearchStudyOutcomeMeasureComponent' satisfies OwlClass;

/**
 * allowedResponse
 *
 * MessageDefinition.allowedResponse: Indicates what types of messages may be sent as an application-level response to this message.
 *
 * http://hl7.org/fhir/allowedResponse
 */
export const allowedResponse = 'http://hl7.org/fhir/allowedResponse' satisfies OwlObjectProperty;

/**
 * _ElementDefinition
 *
 * (Modified) ElementDefinition
 *
 * http://hl7.org/fhir/_ElementDefinition
 */
export const _ElementDefinition = 'http://hl7.org/fhir/_ElementDefinition' satisfies OwlClass;

/**
 * CitationCitedArtifactContributorshipComponent
 *
 * CitationCitedArtifactComponent.CitationCitedArtifactContributorshipComponent: This element is used to list authors and other contributors, their contact information, specific contributions, and summary statements.
 *
 * http://hl7.org/fhir/CitationCitedArtifactContributorshipComponent
 */
export const CitationCitedArtifactContributorshipComponent = 'http://hl7.org/fhir/CitationCitedArtifactContributorshipComponent' satisfies OwlClass;

/**
 * _contentType
 *
 * (Modified) TestScript.test.action.assert.contentType
 *
 * http://hl7.org/fhir/_contentType
 */
export const _contentType = 'http://hl7.org/fhir/_contentType' satisfies OwlObjectProperty;

/**
 * _DeviceUsage
 *
 * (Modified) DeviceUsage
 *
 * http://hl7.org/fhir/_DeviceUsage
 */
export const _DeviceUsage = 'http://hl7.org/fhir/_DeviceUsage' satisfies OwlClass;

/**
 * DeviceDefinitionUdiDeviceIdentifierComponent
 *
 * DeviceDefinitionUdiDeviceIdentifierComponent: Unique device identifier (UDI) assigned to device label or package.  Note that the Device may include multiple udiCarriers as it either may include just the udiCarrier for the jurisdiction it is sold, or for multiple jurisdictions it could have been sold.
 *
 * http://hl7.org/fhir/DeviceDefinitionUdiDeviceIdentifierComponent
 */
export const DeviceDefinitionUdiDeviceIdentifierComponent = 'http://hl7.org/fhir/DeviceDefinitionUdiDeviceIdentifierComponent' satisfies OwlClass;

/**
 * document
 *
 * CapabilityStatement.document: A document definition.
 *
 * http://hl7.org/fhir/document
 */
export const document = 'http://hl7.org/fhir/document' satisfies OwlObjectProperty;

/**
 * event
 *
 * Composition.event: The clinical service, such as a colonoscopy or an appendectomy, being documented.
 *
 * http://hl7.org/fhir/event
 */
export const event = 'http://hl7.org/fhir/event' satisfies OwlObjectProperty;

/**
 * Guarantor
 *
 * Account.Guarantor: The parties responsible for balancing the account if other payment options fall short.
 *
 * http://hl7.org/fhir/Guarantor
 */
export const Guarantor = 'http://hl7.org/fhir/Guarantor' satisfies OwlClass;

/**
 * molecularWeight
 *
 * SubstanceDefinition.structure.molecularWeight: The molecular weight or weight range (for proteins, polymers or nucleic acids).
 *
 * http://hl7.org/fhir/molecularWeight
 */
export const molecularWeight = 'http://hl7.org/fhir/molecularWeight' satisfies OwlObjectProperty;

/**
 * substitution
 *
 * MedicationRequest.substitution: Indicates whether or not substitution can or should be part of the dispense. In some cases, substitution must happen, in other cases substitution must not happen. This block explains the prescriber's intent. If nothing is specified substitution may be done.
 *
 * http://hl7.org/fhir/substitution
 */
export const substitution = 'http://hl7.org/fhir/substitution' satisfies OwlObjectProperty;

/**
 * NutritionOrderSupplementComponent
 *
 * NutritionOrderSupplementComponent: Oral nutritional products given in order to add further nutritional value to the patient's diet.
 *
 * http://hl7.org/fhir/NutritionOrderSupplementComponent
 */
export const NutritionOrderSupplementComponent = 'http://hl7.org/fhir/NutritionOrderSupplementComponent' satisfies OwlClass;

/**
 * _relativeRisk
 *
 * (Modified) RiskAssessment.prediction.relativeRisk
 *
 * http://hl7.org/fhir/_relativeRisk
 */
export const _relativeRisk = 'http://hl7.org/fhir/_relativeRisk' satisfies OwlObjectProperty;

/**
 * _volume
 *
 * (Modified) Citation.citedArtifact.publicationForm.volume
 *
 * http://hl7.org/fhir/_volume
 */
export const _volume = 'http://hl7.org/fhir/_volume' satisfies OwlObjectProperty;

/**
 * _manager
 *
 * (Modified) Consent.manager
 *
 * http://hl7.org/fhir/_manager
 */
export const _manager = 'http://hl7.org/fhir/_manager' satisfies OwlObjectProperty;

/**
 * _presentation
 *
 * (Modified) Ingredient.substance.strength.presentation
 *
 * http://hl7.org/fhir/_presentation
 */
export const _presentation = 'http://hl7.org/fhir/_presentation' satisfies OwlObjectProperty;

/**
 * _linkage
 *
 * (Modified) SubstanceNucleicAcid.subunit.linkage
 *
 * http://hl7.org/fhir/_linkage
 */
export const _linkage = 'http://hl7.org/fhir/_linkage' satisfies OwlObjectProperty;

/**
 * isDefault
 *
 * TerminologyCapabilities.codeSystem.version.isDefault: If this is the default version for this code system.
 *
 * http://hl7.org/fhir/isDefault
 */
export const isDefault = 'http://hl7.org/fhir/isDefault' satisfies OwlObjectProperty;

/**
 * BodyStructure
 *
 * Record details about an anatomical structure.  This resource may be used when a coded concept does not provide the necessary detail needed for the use case.
 *
 * http://hl7.org/fhir/BodyStructure
 */
export const BodyStructure = 'http://hl7.org/fhir/BodyStructure' satisfies OwlClass;

/**
 * _relationship
 *
 * (Modified) Contract.term.group.asset.relationship
 *
 * http://hl7.org/fhir/_relationship
 */
export const _relationship = 'http://hl7.org/fhir/_relationship' satisfies OwlObjectProperty;

/**
 * _maxDispense
 *
 * (Modified) MedicationKnowledge.regulatory.maxDispense
 *
 * http://hl7.org/fhir/_maxDispense
 */
export const _maxDispense = 'http://hl7.org/fhir/_maxDispense' satisfies OwlObjectProperty;

/**
 * ChargeItemDefinition
 *
 * The ChargeItemDefinition resource provides the properties that apply to the (billing) codes necessary to calculate costs and prices. The properties may differ largely depending on type and realm, therefore this resource gives only a rough structure and requires profiling for each type of billing code system.
 *
 * http://hl7.org/fhir/ChargeItemDefinition
 */
export const ChargeItemDefinition = 'http://hl7.org/fhir/ChargeItemDefinition' satisfies OwlClass;

/**
 * _SupplyDelivery
 *
 * (Modified) SupplyDelivery
 *
 * http://hl7.org/fhir/_SupplyDelivery
 */
export const _SupplyDelivery = 'http://hl7.org/fhir/_SupplyDelivery' satisfies OwlClass;

/**
 * _specialArrangement
 *
 * (Modified) Encounter.specialArrangement
 *
 * http://hl7.org/fhir/_specialArrangement
 */
export const _specialArrangement = 'http://hl7.org/fhir/_specialArrangement' satisfies OwlObjectProperty;

/**
 * DosageDoseAndRateComponent
 *
 * DosageDoseAndRateComponent: Depending on the resource,this is the amount of medication administered, to  be administered or typical amount to be administered.
 *
 * http://hl7.org/fhir/DosageDoseAndRateComponent
 */
export const DosageDoseAndRateComponent = 'http://hl7.org/fhir/DosageDoseAndRateComponent' satisfies OwlClass;

/**
 * _guideline
 *
 * (Modified) DeviceDefinition.guideline
 *
 * http://hl7.org/fhir/_guideline
 */
export const _guideline = 'http://hl7.org/fhir/_guideline' satisfies OwlObjectProperty;

/**
 * _grantee
 *
 * (Modified) Consent.grantee
 *
 * http://hl7.org/fhir/_grantee
 */
export const _grantee = 'http://hl7.org/fhir/_grantee' satisfies OwlObjectProperty;

/**
 * serviced
 *
 * ExplanationOfBenefit.addItem.serviced
 *
 * http://hl7.org/fhir/serviced
 */
export const serviced = 'http://hl7.org/fhir/serviced' satisfies OwlObjectProperty;

/**
 * _active
 *
 * (Modified) Patient.active
 *
 * http://hl7.org/fhir/_active
 */
export const _active = 'http://hl7.org/fhir/_active' satisfies OwlObjectProperty;

/**
 * _preference
 *
 * (Modified) SpecimenDefinition.typeTested.preference
 *
 * http://hl7.org/fhir/_preference
 */
export const _preference = 'http://hl7.org/fhir/_preference' satisfies OwlObjectProperty;

/**
 * useContext
 *
 * ExampleScenario.useContext: The content was developed with a focus and intent of supporting the contexts that are listed. These contexts may be general categories (gender, age, ...) or may be references to specific programs (insurance plans, studies, ...) and may be used to assist with indexing and searching for appropriate example scenario instances.
 *
 * http://hl7.org/fhir/useContext
 */
export const useContext = 'http://hl7.org/fhir/useContext' satisfies OwlObjectProperty;

/**
 * _container
 *
 * (Modified) SpecimenDefinition.typeTested.container
 *
 * http://hl7.org/fhir/_container
 */
export const _container = 'http://hl7.org/fhir/_container' satisfies OwlObjectProperty;

/**
 * justification
 *
 * Permission.justification: The asserted justification for using the data.
 *
 * http://hl7.org/fhir/justification
 */
export const justification = 'http://hl7.org/fhir/justification' satisfies OwlObjectProperty;

/**
 * oralDiet
 *
 * NutritionOrder.oralDiet: Diet given orally in contrast to enteral (tube) feeding.
 *
 * http://hl7.org/fhir/oralDiet
 */
export const oralDiet = 'http://hl7.org/fhir/oralDiet' satisfies OwlObjectProperty;

/**
 * _testingDestination
 *
 * (Modified) SpecimenDefinition.typeTested.testingDestination
 *
 * http://hl7.org/fhir/_testingDestination
 */
export const _testingDestination = 'http://hl7.org/fhir/_testingDestination' satisfies OwlObjectProperty;

/**
 * lastRevisionDate
 *
 * Citation.citedArtifact.publicationForm.lastRevisionDate: The date the article was last revised or updated in the database.
 *
 * http://hl7.org/fhir/lastRevisionDate
 */
export const lastRevisionDate = 'http://hl7.org/fhir/lastRevisionDate' satisfies OwlObjectProperty;

/**
 * NutritionIntakeIngredientLabelComponent
 *
 * NutritionIntakeIngredientLabelComponent: Total nutrient amounts for the whole meal, product, serving, etc.
 *
 * http://hl7.org/fhir/NutritionIntakeIngredientLabelComponent
 */
export const NutritionIntakeIngredientLabelComponent = 'http://hl7.org/fhir/NutritionIntakeIngredientLabelComponent' satisfies OwlClass;

/**
 * QuestionnaireResponseItemComponentItem
 *
 * Sub-questions, sub-groups or display items nested beneath a group.
 *
 * http://hl7.org/fhir/QuestionnaireResponseItemComponentItem
 */
export const QuestionnaireResponseItemComponentItem = 'http://hl7.org/fhir/QuestionnaireResponseItemComponentItem' satisfies OwlClass;

/**
 * PermissionJustificationComponent
 *
 * PermissionJustificationComponent: The asserted justification for using the data.
 *
 * http://hl7.org/fhir/PermissionJustificationComponent
 */
export const PermissionJustificationComponent = 'http://hl7.org/fhir/PermissionJustificationComponent' satisfies OwlClass;

/**
 * recorder
 *
 * Procedure.recorder: Individual who recorded the record and takes responsibility for its content.
 *
 * http://hl7.org/fhir/recorder
 */
export const recorder = 'http://hl7.org/fhir/recorder' satisfies OwlObjectProperty;

/**
 * ImmunizationRecommendationRecommendationDateCriterionComponent
 *
 * ImmunizationRecommendationRecommendationComponent.ImmunizationRecommendationRecommendationDateCriterionComponent: Vaccine date recommendations.  For example, earliest date to administer, latest date to administer, etc.
 *
 * http://hl7.org/fhir/ImmunizationRecommendationRecommendationDateCriterionComponent
 */
export const ImmunizationRecommendationRecommendationDateCriterionComponent = 'http://hl7.org/fhir/ImmunizationRecommendationRecommendationDateCriterionComponent' satisfies OwlClass;

/**
 * _focus
 *
 * (Modified) ServiceRequest.focus
 *
 * http://hl7.org/fhir/_focus
 */
export const _focus = 'http://hl7.org/fhir/_focus' satisfies OwlObjectProperty;

/**
 * countingDateTime
 *
 * InventoryReport.inventoryListing.countingDateTime: The date and time when the items were counted.
 *
 * http://hl7.org/fhir/countingDateTime
 */
export const countingDateTime = 'http://hl7.org/fhir/countingDateTime' satisfies OwlObjectProperty;

/**
 * MedicationKnowledge
 *
 * Information about a medication that is used to support knowledge.
 *
 * http://hl7.org/fhir/MedicationKnowledge
 */
export const MedicationKnowledge = 'http://hl7.org/fhir/MedicationKnowledge' satisfies OwlClass;

/**
 * ConditionDefinition
 *
 * A definition of a condition and information relevant to managing it.
 *
 * http://hl7.org/fhir/ConditionDefinition
 */
export const ConditionDefinition = 'http://hl7.org/fhir/ConditionDefinition' satisfies OwlClass;

/**
 * noMap
 *
 * ConceptMap.group.element.noMap: If noMap = true this indicates that no mapping to a target concept exists for this source concept.
 *
 * http://hl7.org/fhir/noMap
 */
export const noMap = 'http://hl7.org/fhir/noMap' satisfies OwlObjectProperty;

/**
 * _userSelected
 *
 * (Modified) Coding.userSelected
 *
 * http://hl7.org/fhir/_userSelected
 */
export const _userSelected = 'http://hl7.org/fhir/_userSelected' satisfies OwlObjectProperty;

/**
 * appointmentRequired
 *
 * HealthcareService.appointmentRequired: Indicates whether or not a prospective consumer will require an appointment for a particular service at a site to be provided by the Organization. Indicates if an appointment is required for access to this service.
 *
 * http://hl7.org/fhir/appointmentRequired
 */
export const appointmentRequired = 'http://hl7.org/fhir/appointmentRequired' satisfies OwlObjectProperty;

/**
 * _numberOfStudies
 *
 * (Modified) Evidence.statistic.sampleSize.numberOfStudies
 *
 * http://hl7.org/fhir/_numberOfStudies
 */
export const _numberOfStudies = 'http://hl7.org/fhir/_numberOfStudies' satisfies OwlObjectProperty;

/**
 * capabilities
 *
 * TestScript.metadata.capability.capabilities: Minimum capabilities required of server for test script to execute successfully.   If server does not meet at a minimum the referenced capability statement, then all tests in this script are skipped.
 *
 * http://hl7.org/fhir/capabilities
 */
export const capabilities = 'http://hl7.org/fhir/capabilities' satisfies OwlObjectProperty;

/**
 * Benefit
 *
 * CoverageEligibilityResponse.Insurance.Items.Benefit: Benefits used to date.
 *
 * http://hl7.org/fhir/Benefit
 */
export const Benefit = 'http://hl7.org/fhir/Benefit' satisfies OwlClass;

/**
 * _uri
 *
 * (Modified) ImplementationGuide.dependsOn.uri
 *
 * http://hl7.org/fhir/_uri
 */
export const _uri = 'http://hl7.org/fhir/_uri' satisfies OwlObjectProperty;

/**
 * _max
 *
 * (Modified) StructureMap.group.rule.rule.source.max
 *
 * http://hl7.org/fhir/_max
 */
export const _max = 'http://hl7.org/fhir/_max' satisfies OwlObjectProperty;

/**
 * inactive
 *
 * ValueSet.expansion.contains.contains.inactive: If the concept is inactive in the code system that defines it. Inactive codes are those that are no longer to be used, but are maintained by the code system for understanding legacy data. It might not be known or specified whether a concept is inactive (and it may depend on the context of use).
 *
 * http://hl7.org/fhir/inactive
 */
export const inactive = 'http://hl7.org/fhir/inactive' satisfies OwlObjectProperty;

/**
 * other
 *
 * Patient.link.other: Link to a Patient or RelatedPerson resource that concerns the same actual individual.
 *
 * http://hl7.org/fhir/other
 */
export const other = 'http://hl7.org/fhir/other' satisfies OwlObjectProperty;

/**
 * dependsOn
 *
 * ImplementationGuide.dependsOn: Another implementation guide that this implementation depends on. Typically, an implementation guide uses value sets, profiles etc.defined in other implementation guides.
 *
 * http://hl7.org/fhir/dependsOn
 */
export const dependsOn = 'http://hl7.org/fhir/dependsOn' satisfies OwlObjectProperty;

/**
 * citedArtifact
 *
 * Citation.citedArtifact: The article or artifact being described.
 *
 * http://hl7.org/fhir/citedArtifact
 */
export const citedArtifact = 'http://hl7.org/fhir/citedArtifact' satisfies OwlObjectProperty;

/**
 * fixture
 *
 * TestScript.fixture: Fixture in the test script - by reference (uri). All fixtures are required for the test script to execute.
 *
 * http://hl7.org/fhir/fixture
 */
export const fixture = 'http://hl7.org/fhir/fixture' satisfies OwlObjectProperty;

/**
 * _insurer
 *
 * (Modified) ExplanationOfBenefit.insurer
 *
 * http://hl7.org/fhir/_insurer
 */
export const _insurer = 'http://hl7.org/fhir/_insurer' satisfies OwlObjectProperty;

/**
 * _endParam
 *
 * (Modified) CompartmentDefinition.resource.endParam
 *
 * http://hl7.org/fhir/_endParam
 */
export const _endParam = 'http://hl7.org/fhir/_endParam' satisfies OwlObjectProperty;

/**
 * continuous
 *
 * Goal.continuous: After meeting the goal, ongoing activity is needed to sustain the goal objective.
 *
 * http://hl7.org/fhir/continuous
 */
export const continuous = 'http://hl7.org/fhir/continuous' satisfies OwlObjectProperty;

/**
 * SubstancePolymerRepeatRepeatUnitStructuralRepresentationComponent
 *
 * SubstancePolymerRepeatComponent.SubstancePolymerRepeatRepeatUnitComponent.SubstancePolymerRepeatRepeatUnitStructuralRepresentationComponent: A graphical structure for this SRU.
 *
 * http://hl7.org/fhir/SubstancePolymerRepeatRepeatUnitStructuralRepresentationComponent
 */
export const SubstancePolymerRepeatRepeatUnitStructuralRepresentationComponent = 'http://hl7.org/fhir/SubstancePolymerRepeatRepeatUnitStructuralRepresentationComponent' satisfies OwlClass;

/**
 * _responsibleOrganization
 *
 * (Modified) InventoryItem.responsibleOrganization
 *
 * http://hl7.org/fhir/_responsibleOrganization
 */
export const _responsibleOrganization = 'http://hl7.org/fhir/_responsibleOrganization' satisfies OwlObjectProperty;

/**
 * url
 *
 * ChargeItemDefinition.url: An absolute URI that is used to identify this charge item definition when it is referenced in a specification, model, design or an instance; also called its canonical identifier. This SHOULD be globally unique and SHOULD be a literal address at which an authoritative instance of this charge item definition is (or will be) published. This URL can be the target of a canonical reference. It SHALL remain the same when the charge item definition is stored on different servers.
 *
 * http://hl7.org/fhir/url
 */
export const url = 'http://hl7.org/fhir/url' satisfies OwlClass;

/**
 * compareToSourceExpression
 *
 * TestScript.test.action.assert.compareToSourceExpression: The FHIRPath expression for a specific value to evaluate against the source fixture. When compareToSourceId is defined, either compareToSourceExpression or compareToSourcePath must be defined, but not both.
 *
 * http://hl7.org/fhir/compareToSourceExpression
 */
export const compareToSourceExpression = 'http://hl7.org/fhir/compareToSourceExpression' satisfies OwlObjectProperty;

/**
 * nutrient
 *
 * NutritionProduct.nutrient: The product's nutritional information expressed by the nutrients.
 *
 * http://hl7.org/fhir/nutrient
 */
export const nutrient = 'http://hl7.org/fhir/nutrient' satisfies OwlObjectProperty;

/**
 * _subjectResults
 *
 * (Modified) MeasureReport.group.stratifier.stratum.population.subjectResults
 *
 * http://hl7.org/fhir/_subjectResults
 */
export const _subjectResults = 'http://hl7.org/fhir/_subjectResults' satisfies OwlObjectProperty;

/**
 * DocumentReferenceRelatesToComponent
 *
 * DocumentReferenceRelatesToComponent: Relationships that this document has with other document references that already exist.
 *
 * http://hl7.org/fhir/DocumentReferenceRelatesToComponent
 */
export const DocumentReferenceRelatesToComponent = 'http://hl7.org/fhir/DocumentReferenceRelatesToComponent' satisfies OwlClass;

/**
 * ImagingStudy
 *
 * Representation of the content produced in a DICOM imaging study. A study comprises a set of series, each of which includes a set of Service-Object Pair Instances (SOP Instances - images or other data) acquired or produced in a common context.  A series is of only one modality (e.g. X-ray, CT, MR, ultrasound), but a study may have multiple series of different modalities.
 *
 * http://hl7.org/fhir/ImagingStudy
 */
export const ImagingStudy = 'http://hl7.org/fhir/ImagingStudy' satisfies OwlClass;

/**
 * AppointmentRecurrenceTemplateYearlyTemplateComponent
 *
 * AppointmentRecurrenceTemplateComponent.AppointmentRecurrenceTemplateYearlyTemplateComponent: Information about yearly recurring appointments.
 *
 * http://hl7.org/fhir/AppointmentRecurrenceTemplateYearlyTemplateComponent
 */
export const AppointmentRecurrenceTemplateYearlyTemplateComponent = 'http://hl7.org/fhir/AppointmentRecurrenceTemplateYearlyTemplateComponent' satisfies OwlClass;

/**
 * SpecimenFeatureComponent
 *
 * SpecimenFeatureComponent: A physical feature or landmark on a specimen, highlighted for context by the collector of the specimen (e.g. surgeon), that identifies the type of feature as well as its meaning (e.g. the red ink indicating the resection margin of the right lobe of the excised prostate tissue or wire loop at radiologically suspected tumor location).
 *
 * http://hl7.org/fhir/SpecimenFeatureComponent
 */
export const SpecimenFeatureComponent = 'http://hl7.org/fhir/SpecimenFeatureComponent' satisfies OwlClass;

/**
 * _ServiceRequest
 *
 * (Modified) ServiceRequest
 *
 * http://hl7.org/fhir/_ServiceRequest
 */
export const _ServiceRequest = 'http://hl7.org/fhir/_ServiceRequest' satisfies OwlClass;

/**
 * tester
 *
 * TestReport.tester: Name of the tester producing this report (Organization or individual).
 *
 * http://hl7.org/fhir/tester
 */
export const tester = 'http://hl7.org/fhir/tester' satisfies OwlObjectProperty;

/**
 * seriousness
 *
 * AdverseEvent.seriousness: Assessment whether this event, or averted event, was of clinical importance.
 *
 * http://hl7.org/fhir/seriousness
 */
export const seriousness = 'http://hl7.org/fhir/seriousness' satisfies OwlObjectProperty;

/**
 * isDefining
 *
 * SubstancePolymer.monomerSet.startingMaterial.isDefining: Used to specify whether the attribute described is a defining element for the unique identification of the polymer.
 *
 * http://hl7.org/fhir/isDefining
 */
export const isDefining = 'http://hl7.org/fhir/isDefining' satisfies OwlObjectProperty;

/**
 * contributingFactor
 *
 * AdverseEvent.contributingFactor: The contributing factors suspected to have increased the probability or severity of the adverse event.
 *
 * http://hl7.org/fhir/contributingFactor
 */
export const contributingFactor = 'http://hl7.org/fhir/contributingFactor' satisfies OwlObjectProperty;

/**
 * CapabilityStatement
 *
 * A Capability Statement documents a set of capabilities (behaviors) of a FHIR Server or Client for a particular version of FHIR that may be used as a statement of actual server functionality or a statement of required or desired server implementation.
 *
 * http://hl7.org/fhir/CapabilityStatement
 */
export const CapabilityStatement = 'http://hl7.org/fhir/CapabilityStatement' satisfies OwlClass;

/**
 * _ImagingSelection
 *
 * (Modified) ImagingSelection
 *
 * http://hl7.org/fhir/_ImagingSelection
 */
export const _ImagingSelection = 'http://hl7.org/fhir/_ImagingSelection' satisfies OwlClass;

/**
 * _unmapped
 *
 * (Modified) ConceptMap.group.unmapped
 *
 * http://hl7.org/fhir/_unmapped
 */
export const _unmapped = 'http://hl7.org/fhir/_unmapped' satisfies OwlObjectProperty;

/**
 * compositional
 *
 * TerminologyCapabilities.codeSystem.version.compositional: If the compositional grammar defined by the code system is supported.
 *
 * http://hl7.org/fhir/compositional
 */
export const compositional = 'http://hl7.org/fhir/compositional' satisfies OwlObjectProperty;

/**
 * fundsReserveRequested
 *
 * ExplanationOfBenefit.fundsReserveRequested: A code to indicate whether and for whom funds are to be reserved for future claims.
 *
 * http://hl7.org/fhir/fundsReserveRequested
 */
export const fundsReserveRequested = 'http://hl7.org/fhir/fundsReserveRequested' satisfies OwlObjectProperty;

/**
 * Total
 *
 * ExplanationOfBenefit.Total: Categorized monetary totals for the adjudication.
 *
 * http://hl7.org/fhir/Total
 */
export const Total = 'http://hl7.org/fhir/Total' satisfies OwlClass;

/**
 * _citeAs
 *
 * (Modified) EvidenceReport.citeAs
 *
 * http://hl7.org/fhir/_citeAs
 */
export const _citeAs = 'http://hl7.org/fhir/_citeAs' satisfies OwlObjectProperty;

/**
 * _protein
 *
 * (Modified) SubstanceDefinition.protein
 *
 * http://hl7.org/fhir/_protein
 */
export const _protein = 'http://hl7.org/fhir/_protein' satisfies OwlObjectProperty;

/**
 * _referenceRange
 *
 * (Modified) Observation.component.referenceRange
 *
 * http://hl7.org/fhir/_referenceRange
 */
export const _referenceRange = 'http://hl7.org/fhir/_referenceRange' satisfies OwlObjectProperty;

/**
 * complication
 *
 * Procedure.complication: Any complications that occurred during the procedure, or in the immediate post-performance period. These are generally tracked separately from the notes, which will typically describe the procedure itself rather than any 'post procedure' issues.
 *
 * http://hl7.org/fhir/complication
 */
export const complication = 'http://hl7.org/fhir/complication' satisfies OwlObjectProperty;

/**
 * SubscriptionTopicResourceTriggerComponent
 *
 * SubscriptionTopicResourceTriggerComponent: A definition of a resource-based event that triggers a notification based on the SubscriptionTopic. The criteria may be just a human readable description and/or a full FHIR search string or FHIRPath expression. Multiple triggers are considered OR joined (e.g., a resource update matching ANY of the definitions will trigger a notification).
 *
 * http://hl7.org/fhir/SubscriptionTopicResourceTriggerComponent
 */
export const SubscriptionTopicResourceTriggerComponent = 'http://hl7.org/fhir/SubscriptionTopicResourceTriggerComponent' satisfies OwlClass;

/**
 * estimate
 *
 * Account.balance.estimate: The amount is only an estimated value - this is likely common for `current` term balances, but not with known terms (that were generated by a backend process).
 *
 * http://hl7.org/fhir/estimate
 */
export const estimate = 'http://hl7.org/fhir/estimate' satisfies OwlObjectProperty;

/**
 * _material
 *
 * (Modified) SpecimenDefinition.typeTested.container.material
 *
 * http://hl7.org/fhir/_material
 */
export const _material = 'http://hl7.org/fhir/_material' satisfies OwlObjectProperty;

/**
 * Item
 *
 * ClaimResponse.Item: A claim line. Either a simple (a product or service) or a 'group' of details which can also be a simple items or groups of sub-details.
 *
 * http://hl7.org/fhir/Item
 */
export const Item = 'http://hl7.org/fhir/Item' satisfies OwlClass;

/**
 * encodeRequestUrl
 *
 * TestScript.teardown.action.operation.encodeRequestUrl: Whether or not to implicitly send the request url in encoded format. The default is true to match the standard RESTful client behavior. Set to false when communicating with a server that does not support encoded url paths.
 *
 * http://hl7.org/fhir/encodeRequestUrl
 */
export const encodeRequestUrl = 'http://hl7.org/fhir/encodeRequestUrl' satisfies OwlObjectProperty;

/**
 * _currentLocation
 *
 * (Modified) Transport.currentLocation
 *
 * http://hl7.org/fhir/_currentLocation
 */
export const _currentLocation = 'http://hl7.org/fhir/_currentLocation' satisfies OwlObjectProperty;

/**
 * style
 *
 * Citation.citedArtifact.contributorship.summary.style: The format for the display string, such as author last name with first letter capitalized followed by forename initials.
 *
 * http://hl7.org/fhir/style
 */
export const style = 'http://hl7.org/fhir/style' satisfies OwlObjectProperty;

/**
 * method
 *
 * TestScript.test.action.operation.method: The HTTP method the test engine MUST use for this operation regardless of any other operation details.
 *
 * http://hl7.org/fhir/method
 */
export const method = 'http://hl7.org/fhir/method' satisfies OwlObjectProperty;

/**
 * _MarketingStatus
 *
 * (Modified) MarketingStatus
 *
 * http://hl7.org/fhir/_MarketingStatus
 */
export const _MarketingStatus = 'http://hl7.org/fhir/_MarketingStatus' satisfies OwlClass;

/**
 * group
 *
 * StructureMap.group: Organizes the mapping into managable chunks for human review/ease of maintenance.
 *
 * http://hl7.org/fhir/group
 */
export const group = 'http://hl7.org/fhir/group' satisfies OwlObjectProperty;

/**
 * achievementStatus
 *
 * Goal.achievementStatus: Describes the progression, or lack thereof, towards the goal against the target.
 *
 * http://hl7.org/fhir/achievementStatus
 */
export const achievementStatus = 'http://hl7.org/fhir/achievementStatus' satisfies OwlObjectProperty;

/**
 * evaluatedResource
 *
 * MeasureReport.evaluatedResource: Evaluated resources are used to capture what data was involved in the calculation of a measure. This usage is only allowed for individual reports to ensure that the size of the MeasureReport resource is bounded.
 *
 * http://hl7.org/fhir/evaluatedResource
 */
export const evaluatedResource = 'http://hl7.org/fhir/evaluatedResource' satisfies OwlObjectProperty;

/**
 * _udiDeviceIdentifier
 *
 * (Modified) DeviceDefinition.packaging.packaging.udiDeviceIdentifier
 *
 * http://hl7.org/fhir/_udiDeviceIdentifier
 */
export const _udiDeviceIdentifier = 'http://hl7.org/fhir/_udiDeviceIdentifier' satisfies OwlObjectProperty;

/**
 * _RelatedPerson
 *
 * (Modified) RelatedPerson
 *
 * http://hl7.org/fhir/_RelatedPerson
 */
export const _RelatedPerson = 'http://hl7.org/fhir/_RelatedPerson' satisfies OwlClass;

/**
 * dateTime
 *
 * A date, date-time or partial date (e.g. just year or year + month).  If hours and minutes are specified, a UTC offset SHALL be populated. The format is a union of the schema types gYear, gYearMonth, date and dateTime. Seconds must be provided due to schema type constraints but may be zero-filled and may be ignored.                 Dates SHALL be valid dates.
 *
 * http://hl7.org/fhir/dateTime
 */
export const dateTime = 'http://hl7.org/fhir/dateTime' satisfies OwlClass;

/**
 * _intervalUnit
 *
 * (Modified) SampledData.intervalUnit
 *
 * http://hl7.org/fhir/_intervalUnit
 */
export const _intervalUnit = 'http://hl7.org/fhir/_intervalUnit' satisfies OwlObjectProperty;

/**
 * text
 *
 * Annotation.text: The text of the annotation in markdown format.
 *
 * http://hl7.org/fhir/text
 */
export const text = 'http://hl7.org/fhir/text' satisfies OwlObjectProperty;

/**
 * _contact
 *
 * (Modified) DeviceDefinition.contact
 *
 * http://hl7.org/fhir/_contact
 */
export const _contact = 'http://hl7.org/fhir/_contact' satisfies OwlObjectProperty;

/**
 * searchInclude
 *
 * CapabilityStatement.rest.resource.searchInclude: A list of _include values supported by the server.
 *
 * http://hl7.org/fhir/searchInclude
 */
export const searchInclude = 'http://hl7.org/fhir/searchInclude' satisfies OwlObjectProperty;

/**
 * _fivePrime
 *
 * (Modified) SubstanceNucleicAcid.subunit.fivePrime
 *
 * http://hl7.org/fhir/_fivePrime
 */
export const _fivePrime = 'http://hl7.org/fhir/_fivePrime' satisfies OwlObjectProperty;

/**
 * timeOfDay
 *
 * Timing.repeat.timeOfDay: Specified time of day for action to take place.
 *
 * http://hl7.org/fhir/timeOfDay
 */
export const timeOfDay = 'http://hl7.org/fhir/timeOfDay' satisfies OwlObjectProperty;

/**
 * originRelationshipType
 *
 * BiologicallyDerivedProductDispense.originRelationshipType: Indicates the relationship between the donor of the biologically derived product and the intended recipient.
 *
 * http://hl7.org/fhir/originRelationshipType
 */
export const originRelationshipType = 'http://hl7.org/fhir/originRelationshipType' satisfies OwlObjectProperty;

/**
 * CitationClassificationComponent
 *
 * CitationClassificationComponent: The assignment to an organizing scheme.
 *
 * http://hl7.org/fhir/CitationClassificationComponent
 */
export const CitationClassificationComponent = 'http://hl7.org/fhir/CitationClassificationComponent' satisfies OwlClass;

/**
 * _plannedStartDate
 *
 * (Modified) EncounterHistory.plannedStartDate
 *
 * http://hl7.org/fhir/_plannedStartDate
 */
export const _plannedStartDate = 'http://hl7.org/fhir/_plannedStartDate' satisfies OwlObjectProperty;

/**
 * documentType
 *
 * Consent.provision.provision.documentType: The documentType(s) covered by this provision. The type can be a CDA document, or some other type that indicates what sort of information the consent relates to.
 *
 * http://hl7.org/fhir/documentType
 */
export const documentType = 'http://hl7.org/fhir/documentType' satisfies OwlObjectProperty;

/**
 * CoverageEligibilityRequestEventComponent
 *
 * CoverageEligibilityRequestEventComponent: Information code for an event with a corresponding date or period.
 *
 * http://hl7.org/fhir/CoverageEligibilityRequestEventComponent
 */
export const CoverageEligibilityRequestEventComponent = 'http://hl7.org/fhir/CoverageEligibilityRequestEventComponent' satisfies OwlClass;

/**
 * _milestone
 *
 * (Modified) ResearchSubject.progress.milestone
 *
 * http://hl7.org/fhir/_milestone
 */
export const _milestone = 'http://hl7.org/fhir/_milestone' satisfies OwlObjectProperty;

/**
 * page
 *
 * ImplementationGuide.definition.page.page: Nested Pages/Sections under this page.
 *
 * http://hl7.org/fhir/page
 */
export const page = 'http://hl7.org/fhir/page' satisfies OwlObjectProperty;

/**
 * params
 *
 * TestScript.setup.action.operation.params: Path plus parameters after [type].  Used to set parts of the request URL explicitly.
 *
 * http://hl7.org/fhir/params
 */
export const params = 'http://hl7.org/fhir/params' satisfies OwlObjectProperty;

/**
 * regionsCalled
 *
 * GenomicStudy.analysis.regionsCalled: Genomic regions actually called in the analysis event (BED file).
 *
 * http://hl7.org/fhir/regionsCalled
 */
export const regionsCalled = 'http://hl7.org/fhir/regionsCalled' satisfies OwlObjectProperty;

/**
 * conditionalCreate
 *
 * CapabilityStatement.rest.resource.conditionalCreate: A flag that indicates that the server supports conditional create.
 *
 * http://hl7.org/fhir/conditionalCreate
 */
export const conditionalCreate = 'http://hl7.org/fhir/conditionalCreate' satisfies OwlObjectProperty;

/**
 * lensSpecification
 *
 * VisionPrescription.lensSpecification: Contain the details of  the individual lens specifications and serves as the authorization for the fullfillment by certified professionals.
 *
 * http://hl7.org/fhir/lensSpecification
 */
export const lensSpecification = 'http://hl7.org/fhir/lensSpecification' satisfies OwlObjectProperty;

/**
 * _grantor
 *
 * (Modified) Consent.grantor
 *
 * http://hl7.org/fhir/_grantor
 */
export const _grantor = 'http://hl7.org/fhir/_grantor' satisfies OwlObjectProperty;

/**
 * coverage
 *
 * Account.coverage.coverage: The party(s) that contribute to payment (or part of) of the charges applied to this account (including self-pay).
 * 
 * A coverage may only be responsible for specific types of charges, and the sequence of the coverages in the account could be important when processing billing.
 *
 * http://hl7.org/fhir/coverage
 */
export const coverage = 'http://hl7.org/fhir/coverage' satisfies OwlObjectProperty;

/**
 * authorizationSupporting
 *
 * CoverageEligibilityResponse.insurance.item.authorizationSupporting: Codes or comments regarding information or actions associated with the preauthorization.
 *
 * http://hl7.org/fhir/authorizationSupporting
 */
export const authorizationSupporting = 'http://hl7.org/fhir/authorizationSupporting' satisfies OwlObjectProperty;

/**
 * ElementDefinitionBindingAdditionalComponent
 *
 * ElementDefinitionBindingComponent.ElementDefinitionBindingAdditionalComponent: Additional bindings that help applications implementing this element. Additional bindings do not replace the main binding but provide more information and/or context.
 *
 * http://hl7.org/fhir/ElementDefinitionBindingAdditionalComponent
 */
export const ElementDefinitionBindingAdditionalComponent = 'http://hl7.org/fhir/ElementDefinitionBindingAdditionalComponent' satisfies OwlClass;

/**
 * _benefit
 *
 * (Modified) InsurancePlan.plan.specificCost.benefit
 *
 * http://hl7.org/fhir/_benefit
 */
export const _benefit = 'http://hl7.org/fhir/_benefit' satisfies OwlObjectProperty;

/**
 * _testData
 *
 * (Modified) TestPlan.testCase.testData
 *
 * http://hl7.org/fhir/_testData
 */
export const _testData = 'http://hl7.org/fhir/_testData' satisfies OwlObjectProperty;

/**
 * _OrganizationAffiliation
 *
 * (Modified) OrganizationAffiliation
 *
 * http://hl7.org/fhir/_OrganizationAffiliation
 */
export const _OrganizationAffiliation = 'http://hl7.org/fhir/_OrganizationAffiliation' satisfies OwlClass;

/**
 * excludedStructure
 *
 * BodyStructure.excludedStructure: The anatomical location(s) or region(s) not occupied or represented by the specimen, lesion, or body structure.
 *
 * http://hl7.org/fhir/excludedStructure
 */
export const excludedStructure = 'http://hl7.org/fhir/excludedStructure' satisfies OwlObjectProperty;

/**
 * _searchRevInclude
 *
 * (Modified) CapabilityStatement.rest.resource.searchRevInclude
 *
 * http://hl7.org/fhir/_searchRevInclude
 */
export const _searchRevInclude = 'http://hl7.org/fhir/_searchRevInclude' satisfies OwlObjectProperty;

/**
 * serviceProvisionCode
 *
 * HealthcareService.serviceProvisionCode: The code(s) that detail the conditions under which the healthcare service is available/offered.
 *
 * http://hl7.org/fhir/serviceProvisionCode
 */
export const serviceProvisionCode = 'http://hl7.org/fhir/serviceProvisionCode' satisfies OwlObjectProperty;

/**
 * typeMode
 *
 * StructureMap.group.typeMode: If this is the default rule set to apply for the source type or this combination of types.
 *
 * http://hl7.org/fhir/typeMode
 */
export const typeMode = 'http://hl7.org/fhir/typeMode' satisfies OwlObjectProperty;

/**
 * ValueSetScopeComponent
 *
 * ValueSetScopeComponent: Description of the semantic space the Value Set Expansion is intended to cover and should further clarify the text in ValueSet.description.
 *
 * http://hl7.org/fhir/ValueSetScopeComponent
 */
export const ValueSetScopeComponent = 'http://hl7.org/fhir/ValueSetScopeComponent' satisfies OwlClass;

/**
 * SupplyRequestParameterComponent
 *
 * SupplyRequestParameterComponent: Specific parameters for the ordered item.  For example, the size of the indicated item.
 *
 * http://hl7.org/fhir/SupplyRequestParameterComponent
 */
export const SupplyRequestParameterComponent = 'http://hl7.org/fhir/SupplyRequestParameterComponent' satisfies OwlClass;

/**
 * attributeEstimate
 *
 * Evidence.statistic.modelCharacteristic.attributeEstimate: An attribute of the statistic used as a model characteristic.
 *
 * http://hl7.org/fhir/attributeEstimate
 */
export const attributeEstimate = 'http://hl7.org/fhir/attributeEstimate' satisfies OwlObjectProperty;

/**
 * immutable
 *
 * ValueSet.immutable: If this is set to 'true', then no new versions of the content logical definition can be created.  Note: Other metadata might still change.
 *
 * http://hl7.org/fhir/immutable
 */
export const immutable = 'http://hl7.org/fhir/immutable' satisfies OwlObjectProperty;

/**
 * _relatedAccount
 *
 * (Modified) Account.relatedAccount
 *
 * http://hl7.org/fhir/_relatedAccount
 */
export const _relatedAccount = 'http://hl7.org/fhir/_relatedAccount' satisfies OwlObjectProperty;

/**
 * _RiskAssessment
 *
 * (Modified) RiskAssessment
 *
 * http://hl7.org/fhir/_RiskAssessment
 */
export const _RiskAssessment = 'http://hl7.org/fhir/_RiskAssessment' satisfies OwlClass;

/**
 * BiologicallyDerivedProductPropertyComponent
 *
 * BiologicallyDerivedProductPropertyComponent: A property that is specific to this BiologicallyDerviedProduct instance.
 *
 * http://hl7.org/fhir/BiologicallyDerivedProductPropertyComponent
 */
export const BiologicallyDerivedProductPropertyComponent = 'http://hl7.org/fhir/BiologicallyDerivedProductPropertyComponent' satisfies OwlClass;

/**
 * _totalVolume
 *
 * (Modified) Medication.totalVolume
 *
 * http://hl7.org/fhir/_totalVolume
 */
export const _totalVolume = 'http://hl7.org/fhir/_totalVolume' satisfies OwlObjectProperty;

/**
 * _adjudication
 *
 * (Modified) ExplanationOfBenefit.adjudication
 *
 * http://hl7.org/fhir/_adjudication
 */
export const _adjudication = 'http://hl7.org/fhir/_adjudication' satisfies OwlObjectProperty;

/**
 * history
 *
 * Transport.history: The transport event prior to this one.
 *
 * http://hl7.org/fhir/history
 */
export const history = 'http://hl7.org/fhir/history' satisfies OwlObjectProperty;

/**
 * _isSubpotent
 *
 * (Modified) Immunization.isSubpotent
 *
 * http://hl7.org/fhir/_isSubpotent
 */
export const _isSubpotent = 'http://hl7.org/fhir/_isSubpotent' satisfies OwlObjectProperty;

/**
 * _longitude
 *
 * (Modified) Location.position.longitude
 *
 * http://hl7.org/fhir/_longitude
 */
export const _longitude = 'http://hl7.org/fhir/_longitude' satisfies OwlObjectProperty;

/**
 * _sliceIsConstraining
 *
 * (Modified) ElementDefinition.sliceIsConstraining
 *
 * http://hl7.org/fhir/_sliceIsConstraining
 */
export const _sliceIsConstraining = 'http://hl7.org/fhir/_sliceIsConstraining' satisfies OwlObjectProperty;

/**
 * collected
 *
 * Specimen.collection.collected
 *
 * http://hl7.org/fhir/collected
 */
export const collected = 'http://hl7.org/fhir/collected' satisfies OwlObjectProperty;

/**
 * medicineClassification
 *
 * MedicationKnowledge.medicineClassification: Categorization of the medication within a formulary or classification system.
 *
 * http://hl7.org/fhir/medicineClassification
 */
export const medicineClassification = 'http://hl7.org/fhir/medicineClassification' satisfies OwlObjectProperty;

/**
 * Signature
 *
 * A signature along with supporting context. The signature may be a digital signature that is cryptographic in nature, or some other signature acceptable to the domain. This other signature may be as simple as a graphical image representing a hand-written signature, or a signature ceremony Different signature approaches have different utilities.
 *
 * http://hl7.org/fhir/Signature
 */
export const Signature = 'http://hl7.org/fhir/Signature' satisfies OwlClass;

/**
 * ConceptReference
 *
 * ValueSetComposeComponent.ConceptSet.ConceptReference: Specifies a concept to be included or excluded.
 *
 * http://hl7.org/fhir/ConceptReference
 */
export const ConceptReference = 'http://hl7.org/fhir/ConceptReference' satisfies OwlClass;

/**
 * TransportRestrictionComponent
 *
 * TransportRestrictionComponent: If the Transport.focus is a request resource and the transport is seeking fulfillment (i.e. is asking for the request to be actioned), this element identifies any limitations on what parts of the referenced request should be actioned.
 *
 * http://hl7.org/fhir/TransportRestrictionComponent
 */
export const TransportRestrictionComponent = 'http://hl7.org/fhir/TransportRestrictionComponent' satisfies OwlClass;

/**
 * _rank
 *
 * (Modified) ContactPoint.rank
 *
 * http://hl7.org/fhir/_rank
 */
export const _rank = 'http://hl7.org/fhir/_rank' satisfies OwlObjectProperty;

/**
 * _inResponseTo
 *
 * (Modified) Communication.inResponseTo
 *
 * http://hl7.org/fhir/_inResponseTo
 */
export const _inResponseTo = 'http://hl7.org/fhir/_inResponseTo' satisfies OwlObjectProperty;

/**
 * CitationCitedArtifactAbstractComponent
 *
 * CitationCitedArtifactComponent.CitationCitedArtifactAbstractComponent: The abstract may be used to convey article-contained abstracts, externally-created abstracts, or other descriptive summaries.
 *
 * http://hl7.org/fhir/CitationCitedArtifactAbstractComponent
 */
export const CitationCitedArtifactAbstractComponent = 'http://hl7.org/fhir/CitationCitedArtifactAbstractComponent' satisfies OwlClass;

/**
 * _error
 *
 * (Modified) SubscriptionStatus.error
 *
 * http://hl7.org/fhir/_error
 */
export const _error = 'http://hl7.org/fhir/_error' satisfies OwlObjectProperty;

/**
 * origin
 *
 * TestScript.test.action.operation.origin: The server where the request message originates from.  Must be one of the server numbers listed in TestScript.origin section.
 *
 * http://hl7.org/fhir/origin
 */
export const origin = 'http://hl7.org/fhir/origin' satisfies OwlObjectProperty;

/**
 * treeRoot
 *
 * http://hl7.org/fhir/treeRoot
 */
export const treeRoot = 'http://hl7.org/fhir/treeRoot' satisfies OwlClass;

/**
 * _sourceMaterialType
 *
 * (Modified) SubstanceSourceMaterial.sourceMaterialType
 *
 * http://hl7.org/fhir/_sourceMaterialType
 */
export const _sourceMaterialType = 'http://hl7.org/fhir/_sourceMaterialType' satisfies OwlObjectProperty;

/**
 * bodyStructure
 *
 * ServiceRequest.bodyStructure: Anatomic location where the procedure should be performed. This is the target site.
 *
 * http://hl7.org/fhir/bodyStructure
 */
export const bodyStructure = 'http://hl7.org/fhir/bodyStructure' satisfies OwlObjectProperty;

/**
 * _releaseDate
 *
 * (Modified) CapabilityStatement.software.releaseDate
 *
 * http://hl7.org/fhir/_releaseDate
 */
export const _releaseDate = 'http://hl7.org/fhir/_releaseDate' satisfies OwlObjectProperty;

/**
 * normalValue
 *
 * Observation.component.referenceRange.normalValue: The value of the normal value of the reference range.
 *
 * http://hl7.org/fhir/normalValue
 */
export const normalValue = 'http://hl7.org/fhir/normalValue' satisfies OwlObjectProperty;

/**
 * PractitionerCommunicationComponent
 *
 * PractitionerCommunicationComponent: A language which may be used to communicate with the practitioner, often for correspondence/administrative purposes.

The `PractitionerRole.communication` property should be used for publishing the languages that a practitioner is able to communicate with patients (on a per Organization/Role basis).
 *
 * http://hl7.org/fhir/PractitionerCommunicationComponent
 */
export const PractitionerCommunicationComponent = 'http://hl7.org/fhir/PractitionerCommunicationComponent' satisfies OwlClass;

/**
 * targetProfile
 *
 * OperationDefinition.parameter.part.targetProfile: Used when the type is "Reference" or "canonical", and identifies a profile structure or implementation Guide that applies to the target of the reference this parameter refers to. If any profiles are specified, then the content must conform to at least one of them. The URL can be a local reference - to a contained StructureDefinition, or a reference to another StructureDefinition or Implementation Guide by a canonical URL. When an implementation guide is specified, the target resource SHALL conform to at least one profile defined in the implementation guide.
 *
 * http://hl7.org/fhir/targetProfile
 */
export const targetProfile = 'http://hl7.org/fhir/targetProfile' satisfies OwlObjectProperty;

/**
 * bounds
 *
 * Timing.repeat.bounds
 *
 * http://hl7.org/fhir/bounds
 */
export const bounds = 'http://hl7.org/fhir/bounds' satisfies OwlObjectProperty;

/**
 * _op
 *
 * (Modified) ValueSet.compose.exclude.filter.op
 *
 * http://hl7.org/fhir/_op
 */
export const _op = 'http://hl7.org/fhir/_op' satisfies OwlObjectProperty;

/**
 * OperationDefinitionParameterComponentParameterParameter
 *
 * The parts of a nested Parameter.
 *
 * http://hl7.org/fhir/OperationDefinitionParameterComponentParameterParameter
 */
export const OperationDefinitionParameterComponentParameterParameter = 'http://hl7.org/fhir/OperationDefinitionParameterComponentParameterParameter' satisfies OwlClass;

/**
 * plannedActivityReference
 *
 * CarePlan.activity.plannedActivityReference: The details of the proposed activity represented in a specific resource.
 *
 * http://hl7.org/fhir/plannedActivityReference
 */
export const plannedActivityReference = 'http://hl7.org/fhir/plannedActivityReference' satisfies OwlObjectProperty;

/**
 * _preAuthRef
 *
 * (Modified) ExplanationOfBenefit.addItem.detail.subDetail.reviewOutcome.preAuthRef
 *
 * http://hl7.org/fhir/_preAuthRef
 */
export const _preAuthRef = 'http://hl7.org/fhir/_preAuthRef' satisfies OwlObjectProperty;

/**
 * _imageRegion3D
 *
 * (Modified) ImagingSelection.instance.imageRegion3D
 *
 * http://hl7.org/fhir/_imageRegion3D
 */
export const _imageRegion3D = 'http://hl7.org/fhir/_imageRegion3D' satisfies OwlObjectProperty;

/**
 * _object
 *
 * (Modified) TestPlan.testCase.assertion.object
 *
 * http://hl7.org/fhir/_object
 */
export const _object = 'http://hl7.org/fhir/_object' satisfies OwlObjectProperty;

/**
 * DocumentReferenceAttesterComponent
 *
 * DocumentReferenceAttesterComponent: A participant who has authenticated the accuracy of the document.
 *
 * http://hl7.org/fhir/DocumentReferenceAttesterComponent
 */
export const DocumentReferenceAttesterComponent = 'http://hl7.org/fhir/DocumentReferenceAttesterComponent' satisfies OwlClass;

/**
 * _recall
 *
 * (Modified) DeviceDefinition.correctiveAction.recall
 *
 * http://hl7.org/fhir/_recall
 */
export const _recall = 'http://hl7.org/fhir/_recall' satisfies OwlObjectProperty;

/**
 * fastingStatus
 *
 * Specimen.collection.fastingStatus
 *
 * http://hl7.org/fhir/fastingStatus
 */
export const fastingStatus = 'http://hl7.org/fhir/fastingStatus' satisfies OwlObjectProperty;

/**
 * seriesUid
 *
 * ImagingSelection.seriesUid: The Series Instance UID for the DICOM Series from which the images were selected.
 *
 * http://hl7.org/fhir/seriesUid
 */
export const seriesUid = 'http://hl7.org/fhir/seriesUid' satisfies OwlObjectProperty;

/**
 * SubstanceSourceMaterialPartDescriptionComponent
 *
 * SubstanceSourceMaterialPartDescriptionComponent: To do.
 *
 * http://hl7.org/fhir/SubstanceSourceMaterialPartDescriptionComponent
 */
export const SubstanceSourceMaterialPartDescriptionComponent = 'http://hl7.org/fhir/SubstanceSourceMaterialPartDescriptionComponent' satisfies OwlClass;

/**
 * _geneElement
 *
 * (Modified) SubstanceReferenceInformation.geneElement
 *
 * http://hl7.org/fhir/_geneElement
 */
export const _geneElement = 'http://hl7.org/fhir/_geneElement' satisfies OwlObjectProperty;

/**
 * publicationDateText
 *
 * Citation.citedArtifact.publicationForm.publicationDateText: Text representation of the date on which the issue of the cited artifact was published.
 *
 * http://hl7.org/fhir/publicationDateText
 */
export const publicationDateText = 'http://hl7.org/fhir/publicationDateText' satisfies OwlObjectProperty;

/**
 * EpisodeOfCareStatusHistoryComponent
 *
 * EpisodeOfCareStatusHistoryComponent: The history of statuses that the EpisodeOfCare has been through (without requiring processing the history of the resource).
 *
 * http://hl7.org/fhir/EpisodeOfCareStatusHistoryComponent
 */
export const EpisodeOfCareStatusHistoryComponent = 'http://hl7.org/fhir/EpisodeOfCareStatusHistoryComponent' satisfies OwlClass;

/**
 * evaluationMessage
 *
 * GuidanceResponse.evaluationMessage: Messages resulting from the evaluation of the artifact or artifacts. As part of evaluating the request, the engine may produce informational or warning messages. These messages will be provided by this element.
 *
 * http://hl7.org/fhir/evaluationMessage
 */
export const evaluationMessage = 'http://hl7.org/fhir/evaluationMessage' satisfies OwlObjectProperty;

/**
 * division
 *
 * BiologicallyDerivedProduct.division: A unique identifier for an aliquot of a product.  Used to distinguish individual aliquots of a product carrying the same biologicalSource and productCode identifiers.
 *
 * http://hl7.org/fhir/division
 */
export const division = 'http://hl7.org/fhir/division' satisfies OwlObjectProperty;

/**
 * windowEnd
 *
 * MolecularSequence.relative.startingSequence.windowEnd: End position of the window on the starting sequence. This value should honor the rules of the  coordinateSystem.
 *
 * http://hl7.org/fhir/windowEnd
 */
export const windowEnd = 'http://hl7.org/fhir/windowEnd' satisfies OwlObjectProperty;

/**
 * _foodType
 *
 * (Modified) NutritionOrder.oralDiet.texture.foodType
 *
 * http://hl7.org/fhir/_foodType
 */
export const _foodType = 'http://hl7.org/fhir/_foodType' satisfies OwlObjectProperty;

/**
 * _repeats
 *
 * (Modified) Questionnaire.item.item.repeats
 *
 * http://hl7.org/fhir/_repeats
 */
export const _repeats = 'http://hl7.org/fhir/_repeats' satisfies OwlObjectProperty;

/**
 * _Observation
 *
 * (Modified) Observation
 *
 * http://hl7.org/fhir/_Observation
 */
export const _Observation = 'http://hl7.org/fhir/_Observation' satisfies OwlClass;

/**
 * validateCode
 *
 * TerminologyCapabilities.validateCode: Information about the [ValueSet/$validate-code](valueset-operation-validate-code.html) operation.
 *
 * http://hl7.org/fhir/validateCode
 */
export const validateCode = 'http://hl7.org/fhir/validateCode' satisfies OwlObjectProperty;

/**
 * parameterName
 *
 * OperationDefinition.overload.parameterName: Name of parameter to include in overload.
 *
 * http://hl7.org/fhir/parameterName
 */
export const parameterName = 'http://hl7.org/fhir/parameterName' satisfies OwlObjectProperty;

/**
 * source
 *
 * MedicationKnowledge.medicineClassification.source
 *
 * http://hl7.org/fhir/source
 */
export const source = 'http://hl7.org/fhir/source' satisfies OwlObjectProperty;

/**
 * currentState
 *
 * Citation.citedArtifact.currentState: The status of the cited artifact.
 *
 * http://hl7.org/fhir/currentState
 */
export const currentState = 'http://hl7.org/fhir/currentState' satisfies OwlObjectProperty;

/**
 * publicationStatus
 *
 * Contract.contentDefinition.publicationStatus: amended | appended | cancelled | disputed | entered-in-error | executable +.
 *
 * http://hl7.org/fhir/publicationStatus
 */
export const publicationStatus = 'http://hl7.org/fhir/publicationStatus' satisfies OwlObjectProperty;

/**
 * _license
 *
 * (Modified) ImplementationGuide.license
 *
 * http://hl7.org/fhir/_license
 */
export const _license = 'http://hl7.org/fhir/_license' satisfies OwlObjectProperty;

/**
 * _created
 *
 * (Modified) EnrollmentResponse.created
 *
 * http://hl7.org/fhir/_created
 */
export const _created = 'http://hl7.org/fhir/_created' satisfies OwlObjectProperty;

/**
 * ClinicalUseDefinitionContraindicationOtherTherapyComponent
 *
 * ClinicalUseDefinitionContraindicationComponent.ClinicalUseDefinitionContraindicationOtherTherapyComponent: Information about the use of the medicinal product in relation to other therapies described as part of the contraindication.
 *
 * http://hl7.org/fhir/ClinicalUseDefinitionContraindicationOtherTherapyComponent
 */
export const ClinicalUseDefinitionContraindicationOtherTherapyComponent = 'http://hl7.org/fhir/ClinicalUseDefinitionContraindicationOtherTherapyComponent' satisfies OwlClass;

/**
 * isModifier
 *
 * ElementDefinition.isModifier: If true, the value of this element affects the interpretation of the element or resource that contains it, and the value of the element cannot be ignored. Typically, this is used for status, negation and qualification codes. The effect of this is that the element cannot be ignored by systems: they SHALL either recognize the element and process it, and/or a pre-determination has been made that it is not relevant to their particular system. When used on the root element in an extension definition, this indicates whether or not the extension is a modifier extension.
 *
 * http://hl7.org/fhir/isModifier
 */
export const isModifier = 'http://hl7.org/fhir/isModifier' satisfies OwlObjectProperty;

/**
 * _needsMap
 *
 * (Modified) TerminologyCapabilities.translation.needsMap
 *
 * http://hl7.org/fhir/_needsMap
 */
export const _needsMap = 'http://hl7.org/fhir/_needsMap' satisfies OwlObjectProperty;

/**
 * performerType
 *
 * ObservationDefinition.performerType: The type of individual/organization/device that is expected to act upon instances of this definition.
 *
 * http://hl7.org/fhir/performerType
 */
export const performerType = 'http://hl7.org/fhir/performerType' satisfies OwlObjectProperty;

/**
 * unitPrice
 *
 * ExplanationOfBenefit.item.detail.subDetail.unitPrice: If the item is not a group then this is the fee for the product or service, otherwise this is the total of the fees for the details of the group.
 *
 * http://hl7.org/fhir/unitPrice
 */
export const unitPrice = 'http://hl7.org/fhir/unitPrice' satisfies OwlObjectProperty;

/**
 * _topic
 *
 * (Modified) Contract.term.group.topic
 *
 * http://hl7.org/fhir/_topic
 */
export const _topic = 'http://hl7.org/fhir/_topic' satisfies OwlObjectProperty;

/**
 * _lastUpdated
 *
 * (Modified) Meta.lastUpdated
 *
 * http://hl7.org/fhir/_lastUpdated
 */
export const _lastUpdated = 'http://hl7.org/fhir/_lastUpdated' satisfies OwlObjectProperty;

/**
 * preparedDate
 *
 * DeviceDispense.preparedDate: The time when the dispensed product was packaged and reviewed.
 *
 * http://hl7.org/fhir/preparedDate
 */
export const preparedDate = 'http://hl7.org/fhir/preparedDate' satisfies OwlObjectProperty;

/**
 * accident
 *
 * ExplanationOfBenefit.accident: Details of a accident which resulted in injuries which required the products and services listed in the claim.
 *
 * http://hl7.org/fhir/accident
 */
export const accident = 'http://hl7.org/fhir/accident' satisfies OwlObjectProperty;

/**
 * code
 *
 * ChargeItemDefinition.code: The defined billing details in this resource pertain to the given billing code.
 *
 * http://hl7.org/fhir/code
 */
export const code = 'http://hl7.org/fhir/code' satisfies OwlClass;

/**
 * _designation
 *
 * (Modified) ValueSet.expansion.contains.contains.designation
 *
 * http://hl7.org/fhir/_designation
 */
export const _designation = 'http://hl7.org/fhir/_designation' satisfies OwlObjectProperty;

/**
 * _creation
 *
 * (Modified) Invoice.creation
 *
 * http://hl7.org/fhir/_creation
 */
export const _creation = 'http://hl7.org/fhir/_creation' satisfies OwlObjectProperty;

/**
 * verificationType
 *
 * Consent.verification.verificationType: Extensible list of verification type starting with verification and re-validation.
 *
 * http://hl7.org/fhir/verificationType
 */
export const verificationType = 'http://hl7.org/fhir/verificationType' satisfies OwlObjectProperty;

/**
 * DeviceDefinitionPackagingComponentPackagingUdiDeviceIdentifier
 *
 * Unique Device Identifier (UDI) Barcode string on the packaging.
 *
 * http://hl7.org/fhir/DeviceDefinitionPackagingComponentPackagingUdiDeviceIdentifier
 */
export const DeviceDefinitionPackagingComponentPackagingUdiDeviceIdentifier = 'http://hl7.org/fhir/DeviceDefinitionPackagingComponentPackagingUdiDeviceIdentifier' satisfies OwlClass;

/**
 * _containedInstance
 *
 * (Modified) ExampleScenario.instance.containedInstance
 *
 * http://hl7.org/fhir/_containedInstance
 */
export const _containedInstance = 'http://hl7.org/fhir/_containedInstance' satisfies OwlObjectProperty;

/**
 * PackagedProductDefinitionLegalStatusOfSupplyComponent
 *
 * PackagedProductDefinitionLegalStatusOfSupplyComponent: The legal status of supply of the packaged item as classified by the regulator.
 *
 * http://hl7.org/fhir/PackagedProductDefinitionLegalStatusOfSupplyComponent
 */
export const PackagedProductDefinitionLegalStatusOfSupplyComponent = 'http://hl7.org/fhir/PackagedProductDefinitionLegalStatusOfSupplyComponent' satisfies OwlClass;

/**
 * _recipient
 *
 * (Modified) Communication.recipient
 *
 * http://hl7.org/fhir/_recipient
 */
export const _recipient = 'http://hl7.org/fhir/_recipient' satisfies OwlObjectProperty;

/**
 * ifMatch
 *
 * Bundle.entry.request.ifMatch: Only perform the operation if the Etag value matches. For more information, see the API section ["Managing Resource Contention"](http.html#concurrency).
 *
 * http://hl7.org/fhir/ifMatch
 */
export const ifMatch = 'http://hl7.org/fhir/ifMatch' satisfies OwlObjectProperty;

/**
 * partNumber
 *
 * DeviceDefinition.partNumber: The part number or catalog number of the device.
 *
 * http://hl7.org/fhir/partNumber
 */
export const partNumber = 'http://hl7.org/fhir/partNumber' satisfies OwlObjectProperty;

/**
 * _severity
 *
 * (Modified) OperationOutcome.issue.severity
 *
 * http://hl7.org/fhir/_severity
 */
export const _severity = 'http://hl7.org/fhir/_severity' satisfies OwlObjectProperty;

/**
 * _filterBy
 *
 * (Modified) Subscription.filterBy
 *
 * http://hl7.org/fhir/_filterBy
 */
export const _filterBy = 'http://hl7.org/fhir/_filterBy' satisfies OwlObjectProperty;

/**
 * _NutritionIntake
 *
 * (Modified) NutritionIntake
 *
 * http://hl7.org/fhir/_NutritionIntake
 */
export const _NutritionIntake = 'http://hl7.org/fhir/_NutritionIntake' satisfies OwlClass;

/**
 * BundleEntrySearchComponent
 *
 * BundleEntryComponent.BundleEntrySearchComponent: Information about the search process that lead to the creation of this entry.
 *
 * http://hl7.org/fhir/BundleEntrySearchComponent
 */
export const BundleEntrySearchComponent = 'http://hl7.org/fhir/BundleEntrySearchComponent' satisfies OwlClass;

/**
 * _responseCode
 *
 * (Modified) TestScript.test.action.assert.responseCode
 *
 * http://hl7.org/fhir/_responseCode
 */
export const _responseCode = 'http://hl7.org/fhir/_responseCode' satisfies OwlObjectProperty;

/**
 * _eventHistory
 *
 * (Modified) MedicationRequest.eventHistory
 *
 * http://hl7.org/fhir/_eventHistory
 */
export const _eventHistory = 'http://hl7.org/fhir/_eventHistory' satisfies OwlObjectProperty;

/**
 * _rejectionCriterion
 *
 * (Modified) SpecimenDefinition.typeTested.rejectionCriterion
 *
 * http://hl7.org/fhir/_rejectionCriterion
 */
export const _rejectionCriterion = 'http://hl7.org/fhir/_rejectionCriterion' satisfies OwlObjectProperty;

/**
 * notPerformedReason
 *
 * MedicationDispense.notPerformedReason: Indicates the reason why a dispense was not performed.
 *
 * http://hl7.org/fhir/notPerformedReason
 */
export const notPerformedReason = 'http://hl7.org/fhir/notPerformedReason' satisfies OwlObjectProperty;

/**
 * _entryType
 *
 * (Modified) Device.udiCarrier.entryType
 *
 * http://hl7.org/fhir/_entryType
 */
export const _entryType = 'http://hl7.org/fhir/_entryType' satisfies OwlObjectProperty;

/**
 * EncounterHistory
 *
 * A record of significant events/milestones key data throughout the history of an Encounter
 *
 * http://hl7.org/fhir/EncounterHistory
 */
export const EncounterHistory = 'http://hl7.org/fhir/EncounterHistory' satisfies OwlClass;

/**
 * _specialPrecautionsForStorage
 *
 * (Modified) ProductShelfLife.specialPrecautionsForStorage
 *
 * http://hl7.org/fhir/_specialPrecautionsForStorage
 */
export const _specialPrecautionsForStorage = 'http://hl7.org/fhir/_specialPrecautionsForStorage' satisfies OwlObjectProperty;

/**
 * SearchParameter
 *
 * A search parameter that defines a named search item that can be used to search/filter on a resource.
 *
 * http://hl7.org/fhir/SearchParameter
 */
export const SearchParameter = 'http://hl7.org/fhir/SearchParameter' satisfies OwlClass;

/**
 * gender
 *
 * ObservationDefinition.qualifiedValue.gender: The gender this  set of qualified values applies to.
 *
 * http://hl7.org/fhir/gender
 */
export const gender = 'http://hl7.org/fhir/gender' satisfies OwlObjectProperty;

/**
 * coding
 *
 * CodeableConcept.coding: A reference to a code defined by a terminology system.
 *
 * http://hl7.org/fhir/coding
 */
export const coding = 'http://hl7.org/fhir/coding' satisfies OwlObjectProperty;

/**
 * ProductShelfLife
 *
 * The shelf-life and storage information for a medicinal product item or container can be described using this class.
 *
 * http://hl7.org/fhir/ProductShelfLife
 */
export const ProductShelfLife = 'http://hl7.org/fhir/ProductShelfLife' satisfies OwlClass;

/**
 * system
 *
 * ValueSet.expansion.contains.contains.system: An absolute URI which is the code system in which the code for this item in the expansion is defined.
 *
 * http://hl7.org/fhir/system
 */
export const system = 'http://hl7.org/fhir/system' satisfies OwlObjectProperty;

/**
 * _tissue
 *
 * (Modified) AdministrableProductDefinition.routeOfAdministration.targetSpecies.withdrawalPeriod.tissue
 *
 * http://hl7.org/fhir/_tissue
 */
export const _tissue = 'http://hl7.org/fhir/_tissue' satisfies OwlObjectProperty;

/**
 * associatedParty
 *
 * ResearchStudy.associatedParty: Sponsors, collaborators, and other parties.
 *
 * http://hl7.org/fhir/associatedParty
 */
export const associatedParty = 'http://hl7.org/fhir/associatedParty' satisfies OwlObjectProperty;

/**
 * statistic
 *
 * Evidence.statistic: Values and parameters for a single statistic.
 *
 * http://hl7.org/fhir/statistic
 */
export const statistic = 'http://hl7.org/fhir/statistic' satisfies OwlObjectProperty;

/**
 * DataRequirement
 *
 * Describes a required data item for evaluation in terms of the type of data, and optional code or date-based filters of the data.
 *
 * http://hl7.org/fhir/DataRequirement
 */
export const DataRequirement = 'http://hl7.org/fhir/DataRequirement' satisfies OwlClass;

/**
 * MedicationKnowledgeRegulatoryMaxDispenseComponent
 *
 * MedicationKnowledgeRegulatoryComponent.MedicationKnowledgeRegulatoryMaxDispenseComponent: The maximum number of units of the medication that can be dispensed in a period.
 *
 * http://hl7.org/fhir/MedicationKnowledgeRegulatoryMaxDispenseComponent
 */
export const MedicationKnowledgeRegulatoryMaxDispenseComponent = 'http://hl7.org/fhir/MedicationKnowledgeRegulatoryMaxDispenseComponent' satisfies OwlClass;

/**
 * udiCarrier
 *
 * Device.udiCarrier: Unique device identifier (UDI) assigned to device label or package.  Note that the Device may include multiple udiCarriers as it either may include just the udiCarrier for the jurisdiction it is sold, or for multiple jurisdictions it could have been sold.
 *
 * http://hl7.org/fhir/udiCarrier
 */
export const udiCarrier = 'http://hl7.org/fhir/udiCarrier' satisfies OwlObjectProperty;

/**
 * Availability
 *
 * Availability data for an {item}.
 *
 * http://hl7.org/fhir/Availability
 */
export const Availability = 'http://hl7.org/fhir/Availability' satisfies OwlClass;

/**
 * sender
 *
 * MessageHeader.sender: Identifies the sending system to allow the use of a trust relationship.
 *
 * http://hl7.org/fhir/sender
 */
export const sender = 'http://hl7.org/fhir/sender' satisfies OwlObjectProperty;

/**
 * _strand
 *
 * (Modified) MolecularSequence.relative.startingSequence.strand
 *
 * http://hl7.org/fhir/_strand
 */
export const _strand = 'http://hl7.org/fhir/_strand' satisfies OwlObjectProperty;

/**
 * IngredientSubstanceStrengthComponent
 *
 * IngredientSubstanceComponent.IngredientSubstanceStrengthComponent: The quantity of substance in the unit of presentation, or in the volume (or mass) of the single pharmaceutical product or manufactured item. The allowed repetitions do not represent different strengths, but are different representations - mathematically equivalent - of a single strength.
 *
 * http://hl7.org/fhir/IngredientSubstanceStrengthComponent
 */
export const IngredientSubstanceStrengthComponent = 'http://hl7.org/fhir/IngredientSubstanceStrengthComponent' satisfies OwlClass;

/**
 * MedicationKnowledgeMonitoringProgramComponent
 *
 * MedicationKnowledgeMonitoringProgramComponent: The program under which the medication is reviewed.
 *
 * http://hl7.org/fhir/MedicationKnowledgeMonitoringProgramComponent
 */
export const MedicationKnowledgeMonitoringProgramComponent = 'http://hl7.org/fhir/MedicationKnowledgeMonitoringProgramComponent' satisfies OwlClass;

/**
 * _derivation
 *
 * (Modified) StructureDefinition.derivation
 *
 * http://hl7.org/fhir/_derivation
 */
export const _derivation = 'http://hl7.org/fhir/_derivation' satisfies OwlObjectProperty;

/**
 * Condition
 *
 * A clinical condition, problem, diagnosis, or other event, situation, issue, or clinical concept that has risen to a level of concern.
 *
 * http://hl7.org/fhir/Condition
 */
export const Condition = 'http://hl7.org/fhir/Condition' satisfies OwlClass;

/**
 * AdministrableProductDefinitionRouteOfAdministrationTargetSpeciesWithdrawalPeriodComponent
 *
 * AdministrableProductDefinitionRouteOfAdministrationComponent.AdministrableProductDefinitionRouteOfAdministrationTargetSpeciesComponent.AdministrableProductDefinitionRouteOfAdministrationTargetSpeciesWithdrawalPeriodComponent: A species specific time during which consumption of animal product is not appropriate.
 *
 * http://hl7.org/fhir/AdministrableProductDefinitionRouteOfAdministrationTargetSpeciesWithdrawalPeriodComponent
 */
export const AdministrableProductDefinitionRouteOfAdministrationTargetSpeciesWithdrawalPeriodComponent = 'http://hl7.org/fhir/AdministrableProductDefinitionRouteOfAdministrationTargetSpeciesWithdrawalPeriodComponent' satisfies OwlClass;

/**
 * diagnostics
 *
 * OperationOutcome.issue.diagnostics: Additional diagnostic information about the issue.
 *
 * http://hl7.org/fhir/diagnostics
 */
export const diagnostics = 'http://hl7.org/fhir/diagnostics' satisfies OwlObjectProperty;

/**
 * assessment
 *
 * Condition.stage.assessment: Reference to a formal record of the evidence on which the staging assessment is based.
 *
 * http://hl7.org/fhir/assessment
 */
export const assessment = 'http://hl7.org/fhir/assessment' satisfies OwlObjectProperty;

/**
 * _clockFacePosition
 *
 * (Modified) BodyStructure.excludedStructure.bodyLandmarkOrientation.clockFacePosition
 *
 * http://hl7.org/fhir/_clockFacePosition
 */
export const _clockFacePosition = 'http://hl7.org/fhir/_clockFacePosition' satisfies OwlObjectProperty;

/**
 * attestation
 *
 * VerificationResult.attestation: Information about the entity attesting to information.
 *
 * http://hl7.org/fhir/attestation
 */
export const attestation = 'http://hl7.org/fhir/attestation' satisfies OwlObjectProperty;

/**
 * identified
 *
 * DetectedIssue.identified
 *
 * http://hl7.org/fhir/identified
 */
export const identified = 'http://hl7.org/fhir/identified' satisfies OwlObjectProperty;
